{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "ab757425",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-11-19T17:06:01.964616Z",
     "start_time": "2021-11-19T17:06:01.956350Z"
    }
   },
   "source": [
    "(explainer_basicstats)=\n",
    "Descriptive Statistics\n",
    "==================\n"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "7c08cde6",
   "metadata": {},
   "source": [
    "In this section we look further into some basic properties of our network. We will use the node attributes and edgelist from our [Data Collection](explainer_data_collection) notebook. Initially we will model a directed network where each node constitutes a Wikipedia page and each edge constitutes a hyperlink from one page to another. We furthermore subset our network to only include the weakly connected component."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "deaf2bfa",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:48:28.491519Z",
     "start_time": "2021-12-08T20:48:28.466471Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "    <div class=\"bk-root\">\n",
       "        <a href=\"https://bokeh.org\" target=\"_blank\" class=\"bk-logo bk-logo-small bk-logo-notebook\"></a>\n",
       "        <span id=\"1033\">Loading BokehJS ...</span>\n",
       "    </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "\n",
       "(function(root) {\n",
       "  function now() {\n",
       "    return new Date();\n",
       "  }\n",
       "\n",
       "  var force = true;\n",
       "\n",
       "  if (typeof root._bokeh_onload_callbacks === \"undefined\" || force === true) {\n",
       "    root._bokeh_onload_callbacks = [];\n",
       "    root._bokeh_is_loading = undefined;\n",
       "  }\n",
       "\n",
       "  var JS_MIME_TYPE = 'application/javascript';\n",
       "  var HTML_MIME_TYPE = 'text/html';\n",
       "  var EXEC_MIME_TYPE = 'application/vnd.bokehjs_exec.v0+json';\n",
       "  var CLASS_NAME = 'output_bokeh rendered_html';\n",
       "\n",
       "  /**\n",
       "   * Render data to the DOM node\n",
       "   */\n",
       "  function render(props, node) {\n",
       "    var script = document.createElement(\"script\");\n",
       "    node.appendChild(script);\n",
       "  }\n",
       "\n",
       "  /**\n",
       "   * Handle when an output is cleared or removed\n",
       "   */\n",
       "  function handleClearOutput(event, handle) {\n",
       "    var cell = handle.cell;\n",
       "\n",
       "    var id = cell.output_area._bokeh_element_id;\n",
       "    var server_id = cell.output_area._bokeh_server_id;\n",
       "    // Clean up Bokeh references\n",
       "    if (id != null && id in Bokeh.index) {\n",
       "      Bokeh.index[id].model.document.clear();\n",
       "      delete Bokeh.index[id];\n",
       "    }\n",
       "\n",
       "    if (server_id !== undefined) {\n",
       "      // Clean up Bokeh references\n",
       "      var cmd = \"from bokeh.io.state import curstate; print(curstate().uuid_to_server['\" + server_id + \"'].get_sessions()[0].document.roots[0]._id)\";\n",
       "      cell.notebook.kernel.execute(cmd, {\n",
       "        iopub: {\n",
       "          output: function(msg) {\n",
       "            var id = msg.content.text.trim();\n",
       "            if (id in Bokeh.index) {\n",
       "              Bokeh.index[id].model.document.clear();\n",
       "              delete Bokeh.index[id];\n",
       "            }\n",
       "          }\n",
       "        }\n",
       "      });\n",
       "      // Destroy server and session\n",
       "      var cmd = \"import bokeh.io.notebook as ion; ion.destroy_server('\" + server_id + \"')\";\n",
       "      cell.notebook.kernel.execute(cmd);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  /**\n",
       "   * Handle when a new output is added\n",
       "   */\n",
       "  function handleAddOutput(event, handle) {\n",
       "    var output_area = handle.output_area;\n",
       "    var output = handle.output;\n",
       "\n",
       "    // limit handleAddOutput to display_data with EXEC_MIME_TYPE content only\n",
       "    if ((output.output_type != \"display_data\") || (!Object.prototype.hasOwnProperty.call(output.data, EXEC_MIME_TYPE))) {\n",
       "      return\n",
       "    }\n",
       "\n",
       "    var toinsert = output_area.element.find(\".\" + CLASS_NAME.split(' ')[0]);\n",
       "\n",
       "    if (output.metadata[EXEC_MIME_TYPE][\"id\"] !== undefined) {\n",
       "      toinsert[toinsert.length - 1].firstChild.textContent = output.data[JS_MIME_TYPE];\n",
       "      // store reference to embed id on output_area\n",
       "      output_area._bokeh_element_id = output.metadata[EXEC_MIME_TYPE][\"id\"];\n",
       "    }\n",
       "    if (output.metadata[EXEC_MIME_TYPE][\"server_id\"] !== undefined) {\n",
       "      var bk_div = document.createElement(\"div\");\n",
       "      bk_div.innerHTML = output.data[HTML_MIME_TYPE];\n",
       "      var script_attrs = bk_div.children[0].attributes;\n",
       "      for (var i = 0; i < script_attrs.length; i++) {\n",
       "        toinsert[toinsert.length - 1].firstChild.setAttribute(script_attrs[i].name, script_attrs[i].value);\n",
       "        toinsert[toinsert.length - 1].firstChild.textContent = bk_div.children[0].textContent\n",
       "      }\n",
       "      // store reference to server id on output_area\n",
       "      output_area._bokeh_server_id = output.metadata[EXEC_MIME_TYPE][\"server_id\"];\n",
       "    }\n",
       "  }\n",
       "\n",
       "  function register_renderer(events, OutputArea) {\n",
       "\n",
       "    function append_mime(data, metadata, element) {\n",
       "      // create a DOM node to render to\n",
       "      var toinsert = this.create_output_subarea(\n",
       "        metadata,\n",
       "        CLASS_NAME,\n",
       "        EXEC_MIME_TYPE\n",
       "      );\n",
       "      this.keyboard_manager.register_events(toinsert);\n",
       "      // Render to node\n",
       "      var props = {data: data, metadata: metadata[EXEC_MIME_TYPE]};\n",
       "      render(props, toinsert[toinsert.length - 1]);\n",
       "      element.append(toinsert);\n",
       "      return toinsert\n",
       "    }\n",
       "\n",
       "    /* Handle when an output is cleared or removed */\n",
       "    events.on('clear_output.CodeCell', handleClearOutput);\n",
       "    events.on('delete.Cell', handleClearOutput);\n",
       "\n",
       "    /* Handle when a new output is added */\n",
       "    events.on('output_added.OutputArea', handleAddOutput);\n",
       "\n",
       "    /**\n",
       "     * Register the mime type and append_mime function with output_area\n",
       "     */\n",
       "    OutputArea.prototype.register_mime_type(EXEC_MIME_TYPE, append_mime, {\n",
       "      /* Is output safe? */\n",
       "      safe: true,\n",
       "      /* Index of renderer in `output_area.display_order` */\n",
       "      index: 0\n",
       "    });\n",
       "  }\n",
       "\n",
       "  // register the mime type if in Jupyter Notebook environment and previously unregistered\n",
       "  if (root.Jupyter !== undefined) {\n",
       "    var events = require('base/js/events');\n",
       "    var OutputArea = require('notebook/js/outputarea').OutputArea;\n",
       "\n",
       "    if (OutputArea.prototype.mime_types().indexOf(EXEC_MIME_TYPE) == -1) {\n",
       "      register_renderer(events, OutputArea);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  \n",
       "  if (typeof (root._bokeh_timeout) === \"undefined\" || force === true) {\n",
       "    root._bokeh_timeout = Date.now() + 5000;\n",
       "    root._bokeh_failed_load = false;\n",
       "  }\n",
       "\n",
       "  var NB_LOAD_WARNING = {'data': {'text/html':\n",
       "     \"<div style='background-color: #fdd'>\\n\"+\n",
       "     \"<p>\\n\"+\n",
       "     \"BokehJS does not appear to have successfully loaded. If loading BokehJS from CDN, this \\n\"+\n",
       "     \"may be due to a slow or bad network connection. Possible fixes:\\n\"+\n",
       "     \"</p>\\n\"+\n",
       "     \"<ul>\\n\"+\n",
       "     \"<li>re-rerun `output_notebook()` to attempt to load from CDN again, or</li>\\n\"+\n",
       "     \"<li>use INLINE resources instead, as so:</li>\\n\"+\n",
       "     \"</ul>\\n\"+\n",
       "     \"<code>\\n\"+\n",
       "     \"from bokeh.resources import INLINE\\n\"+\n",
       "     \"output_notebook(resources=INLINE)\\n\"+\n",
       "     \"</code>\\n\"+\n",
       "     \"</div>\"}};\n",
       "\n",
       "  function display_loaded() {\n",
       "    var el = document.getElementById(\"1033\");\n",
       "    if (el != null) {\n",
       "      el.textContent = \"BokehJS is loading...\";\n",
       "    }\n",
       "    if (root.Bokeh !== undefined) {\n",
       "      if (el != null) {\n",
       "        el.textContent = \"BokehJS \" + root.Bokeh.version + \" successfully loaded.\";\n",
       "      }\n",
       "    } else if (Date.now() < root._bokeh_timeout) {\n",
       "      setTimeout(display_loaded, 100)\n",
       "    }\n",
       "  }\n",
       "\n",
       "\n",
       "  function run_callbacks() {\n",
       "    try {\n",
       "      root._bokeh_onload_callbacks.forEach(function(callback) {\n",
       "        if (callback != null)\n",
       "          callback();\n",
       "      });\n",
       "    } finally {\n",
       "      delete root._bokeh_onload_callbacks\n",
       "    }\n",
       "    console.debug(\"Bokeh: all callbacks have finished\");\n",
       "  }\n",
       "\n",
       "  function load_libs(css_urls, js_urls, callback) {\n",
       "    if (css_urls == null) css_urls = [];\n",
       "    if (js_urls == null) js_urls = [];\n",
       "\n",
       "    root._bokeh_onload_callbacks.push(callback);\n",
       "    if (root._bokeh_is_loading > 0) {\n",
       "      console.debug(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n",
       "      return null;\n",
       "    }\n",
       "    if (js_urls == null || js_urls.length === 0) {\n",
       "      run_callbacks();\n",
       "      return null;\n",
       "    }\n",
       "    console.debug(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n",
       "    root._bokeh_is_loading = css_urls.length + js_urls.length;\n",
       "\n",
       "    function on_load() {\n",
       "      root._bokeh_is_loading--;\n",
       "      if (root._bokeh_is_loading === 0) {\n",
       "        console.debug(\"Bokeh: all BokehJS libraries/stylesheets loaded\");\n",
       "        run_callbacks()\n",
       "      }\n",
       "    }\n",
       "\n",
       "    function on_error(url) {\n",
       "      console.error(\"failed to load \" + url);\n",
       "    }\n",
       "\n",
       "    for (let i = 0; i < css_urls.length; i++) {\n",
       "      const url = css_urls[i];\n",
       "      const element = document.createElement(\"link\");\n",
       "      element.onload = on_load;\n",
       "      element.onerror = on_error.bind(null, url);\n",
       "      element.rel = \"stylesheet\";\n",
       "      element.type = \"text/css\";\n",
       "      element.href = url;\n",
       "      console.debug(\"Bokeh: injecting link tag for BokehJS stylesheet: \", url);\n",
       "      document.body.appendChild(element);\n",
       "    }\n",
       "\n",
       "    const hashes = {\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.2.min.js\": \"XypntL49z55iwGVUW4qsEu83zKL3XEcz0MjuGOQ9SlaaQ68X/g+k1FcioZi7oQAc\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.2.min.js\": \"bEsM86IHGDTLCS0Zod8a8WM6Y4+lafAL/eSiyQcuPzinmWNgNO2/olUF0Z2Dkn5i\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.2.min.js\": \"TX0gSQTdXTTeScqxj6PVQxTiRW8DOoGVwinyi1D3kxv7wuxQ02XkOxv0xwiypcAH\"};\n",
       "\n",
       "    for (let i = 0; i < js_urls.length; i++) {\n",
       "      const url = js_urls[i];\n",
       "      const element = document.createElement('script');\n",
       "      element.onload = on_load;\n",
       "      element.onerror = on_error.bind(null, url);\n",
       "      element.async = false;\n",
       "      element.src = url;\n",
       "      if (url in hashes) {\n",
       "        element.crossOrigin = \"anonymous\";\n",
       "        element.integrity = \"sha384-\" + hashes[url];\n",
       "      }\n",
       "      console.debug(\"Bokeh: injecting script tag for BokehJS library: \", url);\n",
       "      document.head.appendChild(element);\n",
       "    }\n",
       "  };\n",
       "\n",
       "  function inject_raw_css(css) {\n",
       "    const element = document.createElement(\"style\");\n",
       "    element.appendChild(document.createTextNode(css));\n",
       "    document.body.appendChild(element);\n",
       "  }\n",
       "\n",
       "  \n",
       "  var js_urls = [\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.2.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.2.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.2.min.js\"];\n",
       "  var css_urls = [];\n",
       "  \n",
       "\n",
       "  var inline_js = [\n",
       "    function(Bokeh) {\n",
       "      Bokeh.set_log_level(\"info\");\n",
       "    },\n",
       "    function(Bokeh) {\n",
       "    \n",
       "    \n",
       "    }\n",
       "  ];\n",
       "\n",
       "  function run_inline_js() {\n",
       "    \n",
       "    if (root.Bokeh !== undefined || force === true) {\n",
       "      \n",
       "    for (var i = 0; i < inline_js.length; i++) {\n",
       "      inline_js[i].call(root, root.Bokeh);\n",
       "    }\n",
       "    if (force === true) {\n",
       "        display_loaded();\n",
       "      }} else if (Date.now() < root._bokeh_timeout) {\n",
       "      setTimeout(run_inline_js, 100);\n",
       "    } else if (!root._bokeh_failed_load) {\n",
       "      console.log(\"Bokeh: BokehJS failed to load within specified timeout.\");\n",
       "      root._bokeh_failed_load = true;\n",
       "    } else if (force !== true) {\n",
       "      var cell = $(document.getElementById(\"1033\")).parents('.cell').data().cell;\n",
       "      cell.output_area.append_execute_result(NB_LOAD_WARNING)\n",
       "    }\n",
       "\n",
       "  }\n",
       "\n",
       "  if (root._bokeh_is_loading === 0) {\n",
       "    console.debug(\"Bokeh: BokehJS loaded, going straight to plotting\");\n",
       "    run_inline_js();\n",
       "  } else {\n",
       "    load_libs(css_urls, js_urls, function() {\n",
       "      console.debug(\"Bokeh: BokehJS plotting callback run at\", now());\n",
       "      run_inline_js();\n",
       "    });\n",
       "  }\n",
       "}(window));"
      ],
      "application/vnd.bokehjs_load.v0+json": "\n(function(root) {\n  function now() {\n    return new Date();\n  }\n\n  var force = true;\n\n  if (typeof root._bokeh_onload_callbacks === \"undefined\" || force === true) {\n    root._bokeh_onload_callbacks = [];\n    root._bokeh_is_loading = undefined;\n  }\n\n  \n\n  \n  if (typeof (root._bokeh_timeout) === \"undefined\" || force === true) {\n    root._bokeh_timeout = Date.now() + 5000;\n    root._bokeh_failed_load = false;\n  }\n\n  var NB_LOAD_WARNING = {'data': {'text/html':\n     \"<div style='background-color: #fdd'>\\n\"+\n     \"<p>\\n\"+\n     \"BokehJS does not appear to have successfully loaded. If loading BokehJS from CDN, this \\n\"+\n     \"may be due to a slow or bad network connection. Possible fixes:\\n\"+\n     \"</p>\\n\"+\n     \"<ul>\\n\"+\n     \"<li>re-rerun `output_notebook()` to attempt to load from CDN again, or</li>\\n\"+\n     \"<li>use INLINE resources instead, as so:</li>\\n\"+\n     \"</ul>\\n\"+\n     \"<code>\\n\"+\n     \"from bokeh.resources import INLINE\\n\"+\n     \"output_notebook(resources=INLINE)\\n\"+\n     \"</code>\\n\"+\n     \"</div>\"}};\n\n  function display_loaded() {\n    var el = document.getElementById(\"1033\");\n    if (el != null) {\n      el.textContent = \"BokehJS is loading...\";\n    }\n    if (root.Bokeh !== undefined) {\n      if (el != null) {\n        el.textContent = \"BokehJS \" + root.Bokeh.version + \" successfully loaded.\";\n      }\n    } else if (Date.now() < root._bokeh_timeout) {\n      setTimeout(display_loaded, 100)\n    }\n  }\n\n\n  function run_callbacks() {\n    try {\n      root._bokeh_onload_callbacks.forEach(function(callback) {\n        if (callback != null)\n          callback();\n      });\n    } finally {\n      delete root._bokeh_onload_callbacks\n    }\n    console.debug(\"Bokeh: all callbacks have finished\");\n  }\n\n  function load_libs(css_urls, js_urls, callback) {\n    if (css_urls == null) css_urls = [];\n    if (js_urls == null) js_urls = [];\n\n    root._bokeh_onload_callbacks.push(callback);\n    if (root._bokeh_is_loading > 0) {\n      console.debug(\"Bokeh: BokehJS is being loaded, scheduling callback at\", now());\n      return null;\n    }\n    if (js_urls == null || js_urls.length === 0) {\n      run_callbacks();\n      return null;\n    }\n    console.debug(\"Bokeh: BokehJS not loaded, scheduling load and callback at\", now());\n    root._bokeh_is_loading = css_urls.length + js_urls.length;\n\n    function on_load() {\n      root._bokeh_is_loading--;\n      if (root._bokeh_is_loading === 0) {\n        console.debug(\"Bokeh: all BokehJS libraries/stylesheets loaded\");\n        run_callbacks()\n      }\n    }\n\n    function on_error(url) {\n      console.error(\"failed to load \" + url);\n    }\n\n    for (let i = 0; i < css_urls.length; i++) {\n      const url = css_urls[i];\n      const element = document.createElement(\"link\");\n      element.onload = on_load;\n      element.onerror = on_error.bind(null, url);\n      element.rel = \"stylesheet\";\n      element.type = \"text/css\";\n      element.href = url;\n      console.debug(\"Bokeh: injecting link tag for BokehJS stylesheet: \", url);\n      document.body.appendChild(element);\n    }\n\n    const hashes = {\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.2.min.js\": \"XypntL49z55iwGVUW4qsEu83zKL3XEcz0MjuGOQ9SlaaQ68X/g+k1FcioZi7oQAc\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.2.min.js\": \"bEsM86IHGDTLCS0Zod8a8WM6Y4+lafAL/eSiyQcuPzinmWNgNO2/olUF0Z2Dkn5i\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.2.min.js\": \"TX0gSQTdXTTeScqxj6PVQxTiRW8DOoGVwinyi1D3kxv7wuxQ02XkOxv0xwiypcAH\"};\n\n    for (let i = 0; i < js_urls.length; i++) {\n      const url = js_urls[i];\n      const element = document.createElement('script');\n      element.onload = on_load;\n      element.onerror = on_error.bind(null, url);\n      element.async = false;\n      element.src = url;\n      if (url in hashes) {\n        element.crossOrigin = \"anonymous\";\n        element.integrity = \"sha384-\" + hashes[url];\n      }\n      console.debug(\"Bokeh: injecting script tag for BokehJS library: \", url);\n      document.head.appendChild(element);\n    }\n  };\n\n  function inject_raw_css(css) {\n    const element = document.createElement(\"style\");\n    element.appendChild(document.createTextNode(css));\n    document.body.appendChild(element);\n  }\n\n  \n  var js_urls = [\"https://cdn.bokeh.org/bokeh/release/bokeh-2.3.2.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-widgets-2.3.2.min.js\", \"https://cdn.bokeh.org/bokeh/release/bokeh-tables-2.3.2.min.js\"];\n  var css_urls = [];\n  \n\n  var inline_js = [\n    function(Bokeh) {\n      Bokeh.set_log_level(\"info\");\n    },\n    function(Bokeh) {\n    \n    \n    }\n  ];\n\n  function run_inline_js() {\n    \n    if (root.Bokeh !== undefined || force === true) {\n      \n    for (var i = 0; i < inline_js.length; i++) {\n      inline_js[i].call(root, root.Bokeh);\n    }\n    if (force === true) {\n        display_loaded();\n      }} else if (Date.now() < root._bokeh_timeout) {\n      setTimeout(run_inline_js, 100);\n    } else if (!root._bokeh_failed_load) {\n      console.log(\"Bokeh: BokehJS failed to load within specified timeout.\");\n      root._bokeh_failed_load = true;\n    } else if (force !== true) {\n      var cell = $(document.getElementById(\"1033\")).parents('.cell').data().cell;\n      cell.output_area.append_execute_result(NB_LOAD_WARNING)\n    }\n\n  }\n\n  if (root._bokeh_is_loading === 0) {\n    console.debug(\"Bokeh: BokehJS loaded, going straight to plotting\");\n    run_inline_js();\n  } else {\n    load_libs(css_urls, js_urls, function() {\n      console.debug(\"Bokeh: BokehJS plotting callback run at\", now());\n      run_inline_js();\n    });\n  }\n}(window));"
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# imports\n",
    "import pickle\n",
    "import powerlaw\n",
    "import warnings\n",
    "import pandas as pd\n",
    "import networkx as nx\n",
    "from fa2 import ForceAtlas2\n",
    "from tqdm.notebook import tqdm\n",
    "from collections import Counter\n",
    "\n",
    "import matplotlib.pyplot as plt\n",
    "from IPython.display import set_matplotlib_formats\n",
    "from matplotlib import rc\n",
    "plt.style.use('science')\n",
    "set_matplotlib_formats('svg')\n",
    "rc(\"text\", usetex=False)\n",
    "\n",
    "from pyvis.network import Network\n",
    "from bokeh.io import output_notebook, show, save, output_file\n",
    "from bokeh.models import Range1d, Circle, ColumnDataSource, MultiLine\n",
    "from bokeh.plotting import from_networkx\n",
    "from bokeh import palettes\n",
    "from bokeh.layouts import row\n",
    "from bokeh.plotting import figure\n",
    "from bokeh.models import Title\n",
    "output_notebook()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "id": "bc2a88c0",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:48:30.466551Z",
     "start_time": "2021-12-08T20:48:28.497919Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "The directed network has: 2649 nodes and 13666 edges.\n"
     ]
    }
   ],
   "source": [
    "# Load edgelist and node attributes\n",
    "edgelist = pd.read_pickle(\"https://drive.google.com/uc?export=download&id=1e3sy-VzJQXP1CozdBviCD5PYgrcWC_dw\")\n",
    "node_attr = pd.read_pickle(\"https://drive.google.com/uc?export=download&id=1HvB-OQt4P-MXEM7X-fT47_aso9-KL_pK\")\n",
    "\n",
    "# Gather the directed network\n",
    "G = nx.DiGraph()\n",
    "G.add_edges_from(edgelist)\n",
    "nx.set_node_attributes(G, node_attr)\n",
    "gcc = max(nx.weakly_connected_components(G), key=len)\n",
    "G = G.subgraph(gcc)\n",
    "print(f\"The directed network has: {len(G.nodes())} nodes and {len(G.edges())} edges.\")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "2a8af3db",
   "metadata": {},
   "source": [
    "To put our network under further scrutiny it is relevant to compute the in- and out-degree distributions. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "id": "4a858d5b",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:48:33.907735Z",
     "start_time": "2021-12-08T20:48:30.470252Z"
    }
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg height=\"413.05625pt\" version=\"1.1\" viewBox=\"0 0 704.766508 413.05625\" width=\"704.766508pt\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2021-12-08T21:48:33.179927</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.4.3, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linecap:butt;stroke-linejoin:round;}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 413.05625 \n",
       "L 704.766508 413.05625 \n",
       "L 704.766508 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill:none;\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 46.228125 173.698125 \n",
       "L 339.138026 173.698125 \n",
       "L 339.138026 18.718125 \n",
       "L 46.228125 18.718125 \n",
       "z\n",
       "\" style=\"fill:#ffffff;\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 0 -3 \n",
       "\" id=\"m7becfc96f8\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"59.542211\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_2\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 0 3 \n",
       "\" id=\"mc94ec28e17\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"59.542211\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(56.360961 184.796562)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2034 219 \n",
       "Q 2513 219 2750 744 \n",
       "Q 2988 1269 2988 2328 \n",
       "Q 2988 3391 2750 3916 \n",
       "Q 2513 4441 2034 4441 \n",
       "Q 1556 4441 1318 3916 \n",
       "Q 1081 3391 1081 2328 \n",
       "Q 1081 1269 1318 744 \n",
       "Q 1556 219 2034 219 \n",
       "z\n",
       "M 2034 -91 \n",
       "Q 1275 -91 848 546 \n",
       "Q 422 1184 422 2328 \n",
       "Q 422 3475 848 4112 \n",
       "Q 1275 4750 2034 4750 \n",
       "Q 2797 4750 3222 4112 \n",
       "Q 3647 3475 3647 2328 \n",
       "Q 3647 1184 3222 546 \n",
       "Q 2797 -91 2034 -91 \n",
       "z\n",
       "\" id=\"DejaVuSerif-30\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"105.771678\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"105.771678\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 50 -->\n",
       "      <g transform=\"translate(99.409178 184.796562)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 3219 4666 \n",
       "L 3219 4153 \n",
       "L 1081 4153 \n",
       "L 1081 2816 \n",
       "Q 1244 2928 1461 2984 \n",
       "Q 1678 3041 1947 3041 \n",
       "Q 2703 3041 3140 2622 \n",
       "Q 3578 2203 3578 1478 \n",
       "Q 3578 738 3136 323 \n",
       "Q 2694 -91 1894 -91 \n",
       "Q 1572 -91 1234 -12 \n",
       "Q 897 66 544 225 \n",
       "L 544 1131 \n",
       "L 897 1131 \n",
       "Q 925 688 1179 453 \n",
       "Q 1434 219 1894 219 \n",
       "Q 2388 219 2653 544 \n",
       "Q 2919 869 2919 1478 \n",
       "Q 2919 2084 2655 2407 \n",
       "Q 2391 2731 1894 2731 \n",
       "Q 1613 2731 1398 2631 \n",
       "Q 1184 2531 1019 2322 \n",
       "L 750 2322 \n",
       "L 750 4666 \n",
       "L 3219 4666 \n",
       "z\n",
       "\" id=\"DejaVuSerif-35\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"152.001145\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"152.001145\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 100 -->\n",
       "      <g transform=\"translate(142.457395 184.796562)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 909 0 \n",
       "L 909 331 \n",
       "L 1722 331 \n",
       "L 1722 4213 \n",
       "L 781 3603 \n",
       "L 781 4013 \n",
       "L 1919 4750 \n",
       "L 2350 4750 \n",
       "L 2350 331 \n",
       "L 3163 331 \n",
       "L 3163 0 \n",
       "L 909 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-31\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"198.230611\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"198.230611\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 150 -->\n",
       "      <g transform=\"translate(188.686861 184.796562)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"244.460078\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"244.460078\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 200 -->\n",
       "      <g transform=\"translate(234.916328 184.796562)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 819 3553 \n",
       "L 469 3553 \n",
       "L 469 4384 \n",
       "Q 803 4563 1142 4656 \n",
       "Q 1481 4750 1806 4750 \n",
       "Q 2534 4750 2956 4397 \n",
       "Q 3378 4044 3378 3438 \n",
       "Q 3378 2753 2422 1800 \n",
       "Q 2347 1728 2309 1691 \n",
       "L 1131 513 \n",
       "L 3078 513 \n",
       "L 3078 1088 \n",
       "L 3444 1088 \n",
       "L 3444 0 \n",
       "L 434 0 \n",
       "L 434 341 \n",
       "L 1850 1753 \n",
       "Q 2319 2222 2519 2614 \n",
       "Q 2719 3006 2719 3438 \n",
       "Q 2719 3909 2473 4175 \n",
       "Q 2228 4441 1797 4441 \n",
       "Q 1350 4441 1106 4219 \n",
       "Q 863 3997 819 3553 \n",
       "z\n",
       "\" id=\"DejaVuSerif-32\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-32\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"290.689545\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"290.689545\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 250 -->\n",
       "      <g transform=\"translate(281.145795 184.796562)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-32\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"336.919011\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"336.919011\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 300 -->\n",
       "      <g transform=\"translate(327.375261 184.796562)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 622 4469 \n",
       "Q 988 4606 1323 4678 \n",
       "Q 1659 4750 1953 4750 \n",
       "Q 2638 4750 3022 4454 \n",
       "Q 3406 4159 3406 3634 \n",
       "Q 3406 3213 3140 2930 \n",
       "Q 2875 2647 2388 2547 \n",
       "Q 2963 2466 3280 2130 \n",
       "Q 3597 1794 3597 1259 \n",
       "Q 3597 606 3158 257 \n",
       "Q 2719 -91 1894 -91 \n",
       "Q 1528 -91 1179 -12 \n",
       "Q 831 66 488 225 \n",
       "L 488 1131 \n",
       "L 838 1131 \n",
       "Q 869 681 1141 450 \n",
       "Q 1413 219 1906 219 \n",
       "Q 2384 219 2661 495 \n",
       "Q 2938 772 2938 1253 \n",
       "Q 2938 1803 2653 2086 \n",
       "Q 2369 2369 1819 2369 \n",
       "L 1522 2369 \n",
       "L 1522 2688 \n",
       "L 1678 2688 \n",
       "Q 2225 2688 2498 2914 \n",
       "Q 2772 3141 2772 3597 \n",
       "Q 2772 4006 2547 4223 \n",
       "Q 2322 4441 1900 4441 \n",
       "Q 1478 4441 1245 4241 \n",
       "Q 1013 4041 972 3647 \n",
       "L 622 3647 \n",
       "L 622 4469 \n",
       "z\n",
       "\" id=\"DejaVuSerif-33\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-33\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 0 -1.5 \n",
       "\" id=\"mcc18a4926f\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"50.296318\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_16\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 0 1.5 \n",
       "\" id=\"m9d231df80b\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"50.296318\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"68.788105\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"68.788105\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"78.033998\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"78.033998\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"87.279891\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"87.279891\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"96.525785\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"96.525785\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"115.017571\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"115.017571\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_14\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"124.263465\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"124.263465\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_15\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"133.509358\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"133.509358\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_16\">\n",
       "     <g id=\"line2d_31\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"142.755251\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_32\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"142.755251\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_17\">\n",
       "     <g id=\"line2d_33\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"161.247038\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_34\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"161.247038\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_18\">\n",
       "     <g id=\"line2d_35\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"170.492931\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"170.492931\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_19\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"179.738825\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"179.738825\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_20\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"188.984718\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"188.984718\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_21\">\n",
       "     <g id=\"line2d_41\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"207.476505\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_42\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"207.476505\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_22\">\n",
       "     <g id=\"line2d_43\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"216.722398\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_44\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"216.722398\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_23\">\n",
       "     <g id=\"line2d_45\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"225.968291\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_46\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"225.968291\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_24\">\n",
       "     <g id=\"line2d_47\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"235.214185\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_48\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"235.214185\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_25\">\n",
       "     <g id=\"line2d_49\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"253.705971\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_50\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"253.705971\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_26\">\n",
       "     <g id=\"line2d_51\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"262.951865\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_52\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"262.951865\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_27\">\n",
       "     <g id=\"line2d_53\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"272.197758\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_54\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"272.197758\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_28\">\n",
       "     <g id=\"line2d_55\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"281.443651\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_56\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"281.443651\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_29\">\n",
       "     <g id=\"line2d_57\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"299.935438\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_58\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"299.935438\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_30\">\n",
       "     <g id=\"line2d_59\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"309.181331\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_60\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"309.181331\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_31\">\n",
       "     <g id=\"line2d_61\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"318.427225\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_62\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"318.427225\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_32\">\n",
       "     <g id=\"line2d_63\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"327.673118\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_64\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"327.673118\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_8\">\n",
       "     <!-- In-degree -->\n",
       "     <g transform=\"translate(168.128388 198.474687)scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path d=\"M 1581 331 \n",
       "L 2175 331 \n",
       "L 2175 0 \n",
       "L 353 0 \n",
       "L 353 331 \n",
       "L 947 331 \n",
       "L 947 4331 \n",
       "L 353 4331 \n",
       "L 353 4666 \n",
       "L 2175 4666 \n",
       "L 2175 4331 \n",
       "L 1581 4331 \n",
       "L 1581 331 \n",
       "z\n",
       "\" id=\"DejaVuSerif-49\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 263 0 \n",
       "L 263 331 \n",
       "L 781 331 \n",
       "L 781 2988 \n",
       "L 231 2988 \n",
       "L 231 3322 \n",
       "L 1356 3322 \n",
       "L 1356 2731 \n",
       "Q 1516 3069 1770 3241 \n",
       "Q 2025 3413 2363 3413 \n",
       "Q 2913 3413 3172 3097 \n",
       "Q 3431 2781 3431 2113 \n",
       "L 3431 331 \n",
       "L 3944 331 \n",
       "L 3944 0 \n",
       "L 2356 0 \n",
       "L 2356 331 \n",
       "L 2853 331 \n",
       "L 2853 1931 \n",
       "Q 2853 2541 2703 2767 \n",
       "Q 2553 2994 2175 2994 \n",
       "Q 1775 2994 1565 2701 \n",
       "Q 1356 2409 1356 1850 \n",
       "L 1356 331 \n",
       "L 1856 331 \n",
       "L 1856 0 \n",
       "L 263 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6e\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 281 1959 \n",
       "L 1881 1959 \n",
       "L 1881 1472 \n",
       "L 281 1472 \n",
       "L 281 1959 \n",
       "z\n",
       "\" id=\"DejaVuSerif-2d\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 3359 331 \n",
       "L 3909 331 \n",
       "L 3909 0 \n",
       "L 2784 0 \n",
       "L 2784 519 \n",
       "Q 2616 206 2355 57 \n",
       "Q 2094 -91 1709 -91 \n",
       "Q 1097 -91 708 395 \n",
       "Q 319 881 319 1663 \n",
       "Q 319 2444 706 2928 \n",
       "Q 1094 3413 1709 3413 \n",
       "Q 2094 3413 2355 3264 \n",
       "Q 2616 3116 2784 2803 \n",
       "L 2784 4531 \n",
       "L 2241 4531 \n",
       "L 2241 4863 \n",
       "L 3359 4863 \n",
       "L 3359 331 \n",
       "z\n",
       "M 2784 1497 \n",
       "L 2784 1825 \n",
       "Q 2784 2422 2554 2737 \n",
       "Q 2325 3053 1888 3053 \n",
       "Q 1444 3053 1217 2703 \n",
       "Q 991 2353 991 1663 \n",
       "Q 991 975 1217 622 \n",
       "Q 1444 269 1888 269 \n",
       "Q 2325 269 2554 583 \n",
       "Q 2784 897 2784 1497 \n",
       "z\n",
       "\" id=\"DejaVuSerif-64\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 3469 1600 \n",
       "L 991 1600 \n",
       "L 991 1575 \n",
       "Q 991 903 1244 561 \n",
       "Q 1497 219 1991 219 \n",
       "Q 2369 219 2611 417 \n",
       "Q 2853 616 2950 1006 \n",
       "L 3413 1006 \n",
       "Q 3275 459 2904 184 \n",
       "Q 2534 -91 1931 -91 \n",
       "Q 1203 -91 761 389 \n",
       "Q 319 869 319 1663 \n",
       "Q 319 2450 753 2931 \n",
       "Q 1188 3413 1894 3413 \n",
       "Q 2647 3413 3050 2948 \n",
       "Q 3453 2484 3469 1600 \n",
       "z\n",
       "M 2791 1931 \n",
       "Q 2772 2513 2545 2808 \n",
       "Q 2319 3103 1894 3103 \n",
       "Q 1497 3103 1269 2806 \n",
       "Q 1041 2509 991 1931 \n",
       "L 2791 1931 \n",
       "z\n",
       "\" id=\"DejaVuSerif-65\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 3359 2988 \n",
       "L 3359 72 \n",
       "Q 3359 -644 2965 -1033 \n",
       "Q 2572 -1422 1844 -1422 \n",
       "Q 1516 -1422 1216 -1362 \n",
       "Q 916 -1303 641 -1184 \n",
       "L 641 -488 \n",
       "L 941 -488 \n",
       "Q 997 -813 1206 -963 \n",
       "Q 1416 -1113 1806 -1113 \n",
       "Q 2313 -1113 2548 -827 \n",
       "Q 2784 -541 2784 72 \n",
       "L 2784 519 \n",
       "Q 2616 206 2355 57 \n",
       "Q 2094 -91 1709 -91 \n",
       "Q 1097 -91 708 395 \n",
       "Q 319 881 319 1663 \n",
       "Q 319 2444 706 2928 \n",
       "Q 1094 3413 1709 3413 \n",
       "Q 2094 3413 2355 3264 \n",
       "Q 2616 3116 2784 2803 \n",
       "L 2784 3322 \n",
       "L 3909 3322 \n",
       "L 3909 2988 \n",
       "L 3359 2988 \n",
       "z\n",
       "M 2784 1825 \n",
       "Q 2784 2422 2554 2737 \n",
       "Q 2325 3053 1888 3053 \n",
       "Q 1444 3053 1217 2703 \n",
       "Q 991 2353 991 1663 \n",
       "Q 991 975 1217 622 \n",
       "Q 1444 269 1888 269 \n",
       "Q 2325 269 2554 583 \n",
       "Q 2784 897 2784 1497 \n",
       "L 2784 1825 \n",
       "z\n",
       "\" id=\"DejaVuSerif-67\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 3059 3328 \n",
       "L 3059 2497 \n",
       "L 2728 2497 \n",
       "Q 2713 2744 2591 2866 \n",
       "Q 2469 2988 2234 2988 \n",
       "Q 1809 2988 1582 2694 \n",
       "Q 1356 2400 1356 1850 \n",
       "L 1356 331 \n",
       "L 2022 331 \n",
       "L 2022 0 \n",
       "L 263 0 \n",
       "L 263 331 \n",
       "L 781 331 \n",
       "L 781 2994 \n",
       "L 231 2994 \n",
       "L 231 3322 \n",
       "L 1356 3322 \n",
       "L 1356 2731 \n",
       "Q 1525 3078 1790 3245 \n",
       "Q 2056 3413 2438 3413 \n",
       "Q 2578 3413 2733 3391 \n",
       "Q 2888 3369 3059 3328 \n",
       "z\n",
       "\" id=\"DejaVuSerif-72\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSerif-49\"/>\n",
       "      <use x=\"39.501953\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      <use x=\"103.90625\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "      <use x=\"137.695312\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "      <use x=\"201.708984\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use x=\"260.888672\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "      <use x=\"324.902344\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "      <use x=\"372.705078\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use x=\"431.884766\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_65\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 3 0 \n",
       "\" id=\"m5e70fb3546\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"166.801109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_66\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L -3 0 \n",
       "\" id=\"md49a03a24c\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"166.801109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(36.365625 170.600328)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_67\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"129.918672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_68\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"129.918672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 250 -->\n",
       "      <g transform=\"translate(23.640625 133.717891)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-32\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_69\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"93.036235\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_70\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"93.036235\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 500 -->\n",
       "      <g transform=\"translate(23.640625 96.835454)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_71\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"56.153798\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_72\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"56.153798\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 750 -->\n",
       "      <g transform=\"translate(23.640625 59.953017)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 3609 4347 \n",
       "L 1784 0 \n",
       "L 1319 0 \n",
       "L 3059 4153 \n",
       "L 903 4153 \n",
       "L 903 3578 \n",
       "L 538 3578 \n",
       "L 538 4666 \n",
       "L 3609 4666 \n",
       "L 3609 4347 \n",
       "z\n",
       "\" id=\"DejaVuSerif-37\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-37\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_73\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"19.271362\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_74\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"19.271362\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 1000 -->\n",
       "      <g transform=\"translate(17.278125 23.07058)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"190.869141\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_75\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 1.5 0 \n",
       "\" id=\"mf05794ed35\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"159.424622\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_76\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L -1.5 0 \n",
       "\" id=\"m233fe4f8d2\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"159.424622\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_77\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"152.048135\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_78\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"152.048135\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_79\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"144.671647\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_80\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"144.671647\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_81\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"137.29516\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_82\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"137.29516\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_83\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"122.542185\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_84\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"122.542185\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_85\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"115.165698\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_86\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"115.165698\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_87\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"107.78921\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_88\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"107.78921\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_89\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"100.412723\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_90\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"100.412723\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_91\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"85.659748\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_92\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"85.659748\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_93\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"78.283261\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_94\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"78.283261\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_95\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"70.906773\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_96\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"70.906773\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_17\">\n",
       "     <g id=\"line2d_97\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"63.530286\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_98\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"63.530286\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_18\">\n",
       "     <g id=\"line2d_99\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"48.777311\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_100\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"48.777311\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_19\">\n",
       "     <g id=\"line2d_101\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"41.400824\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_102\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"41.400824\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_20\">\n",
       "     <g id=\"line2d_103\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"34.024336\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_104\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"34.024336\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_21\">\n",
       "     <g id=\"line2d_105\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"26.647849\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_106\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"26.647849\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- count -->\n",
       "     <g transform=\"translate(11.198438 110.468281)rotate(-90)scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path d=\"M 3291 997 \n",
       "Q 3169 466 2822 187 \n",
       "Q 2475 -91 1925 -91 \n",
       "Q 1200 -91 759 389 \n",
       "Q 319 869 319 1663 \n",
       "Q 319 2459 759 2936 \n",
       "Q 1200 3413 1925 3413 \n",
       "Q 2241 3413 2553 3339 \n",
       "Q 2866 3266 3181 3116 \n",
       "L 3181 2266 \n",
       "L 2847 2266 \n",
       "Q 2781 2703 2561 2903 \n",
       "Q 2341 3103 1931 3103 \n",
       "Q 1466 3103 1228 2742 \n",
       "Q 991 2381 991 1663 \n",
       "Q 991 944 1227 581 \n",
       "Q 1463 219 1931 219 \n",
       "Q 2303 219 2525 412 \n",
       "Q 2747 606 2828 997 \n",
       "L 3291 997 \n",
       "z\n",
       "\" id=\"DejaVuSerif-63\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 1925 219 \n",
       "Q 2388 219 2623 584 \n",
       "Q 2859 950 2859 1663 \n",
       "Q 2859 2375 2623 2739 \n",
       "Q 2388 3103 1925 3103 \n",
       "Q 1463 3103 1227 2739 \n",
       "Q 991 2375 991 1663 \n",
       "Q 991 950 1228 584 \n",
       "Q 1466 219 1925 219 \n",
       "z\n",
       "M 1925 -91 \n",
       "Q 1200 -91 759 389 \n",
       "Q 319 869 319 1663 \n",
       "Q 319 2456 758 2934 \n",
       "Q 1197 3413 1925 3413 \n",
       "Q 2653 3413 3092 2934 \n",
       "Q 3531 2456 3531 1663 \n",
       "Q 3531 869 3092 389 \n",
       "Q 2653 -91 1925 -91 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6f\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 2266 3322 \n",
       "L 3341 3322 \n",
       "L 3341 331 \n",
       "L 3884 331 \n",
       "L 3884 0 \n",
       "L 2766 0 \n",
       "L 2766 588 \n",
       "Q 2606 256 2353 82 \n",
       "Q 2100 -91 1766 -91 \n",
       "Q 1213 -91 952 223 \n",
       "Q 691 538 691 1209 \n",
       "L 691 2988 \n",
       "L 172 2988 \n",
       "L 172 3322 \n",
       "L 1269 3322 \n",
       "L 1269 1388 \n",
       "Q 1269 781 1417 556 \n",
       "Q 1566 331 1947 331 \n",
       "Q 2347 331 2556 625 \n",
       "Q 2766 919 2766 1478 \n",
       "L 2766 2988 \n",
       "L 2266 2988 \n",
       "L 2266 3322 \n",
       "z\n",
       "\" id=\"DejaVuSerif-75\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 691 2988 \n",
       "L 184 2988 \n",
       "L 184 3322 \n",
       "L 691 3322 \n",
       "L 691 4353 \n",
       "L 1269 4353 \n",
       "L 1269 3322 \n",
       "L 2350 3322 \n",
       "L 2350 2988 \n",
       "L 1269 2988 \n",
       "L 1269 878 \n",
       "Q 1269 456 1350 337 \n",
       "Q 1431 219 1650 219 \n",
       "Q 1875 219 1978 351 \n",
       "Q 2081 484 2088 781 \n",
       "L 2522 781 \n",
       "Q 2497 328 2275 118 \n",
       "Q 2053 -91 1600 -91 \n",
       "Q 1103 -91 897 129 \n",
       "Q 691 350 691 878 \n",
       "L 691 2988 \n",
       "z\n",
       "\" id=\"DejaVuSerif-74\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSerif-63\"/>\n",
       "      <use x=\"56.005859\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use x=\"116.210938\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "      <use x=\"180.615234\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      <use x=\"245.019531\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_107\">\n",
       "    <defs>\n",
       "     <path d=\"M 0 1 \n",
       "C 0.265203 1 0.51958 0.894634 0.707107 0.707107 \n",
       "C 0.894634 0.51958 1 0.265203 1 0 \n",
       "C 1 -0.265203 0.894634 -0.51958 0.707107 -0.707107 \n",
       "C 0.51958 -0.894634 0.265203 -1 0 -1 \n",
       "C -0.265203 -1 -0.51958 -0.894634 -0.707107 -0.707107 \n",
       "C -0.894634 -0.51958 -1 -0.265203 -1 0 \n",
       "C -1 0.265203 -0.894634 0.51958 -0.707107 0.707107 \n",
       "C -0.51958 0.894634 -0.265203 1 0 1 \n",
       "z\n",
       "\" id=\"mc4d9143b4f\" style=\"stroke:#000000;\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p321e8e21c8)\">\n",
       "     <use style=\"stroke:#000000;\" x=\"59.542211\" xlink:href=\"#mc4d9143b4f\" y=\"25.76267\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"60.466801\" xlink:href=\"#mc4d9143b4f\" y=\"88.315283\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"61.39139\" xlink:href=\"#mc4d9143b4f\" y=\"129.771143\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"62.315979\" xlink:href=\"#mc4d9143b4f\" y=\"147.032123\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"63.240569\" xlink:href=\"#mc4d9143b4f\" y=\"149.687659\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"64.165158\" xlink:href=\"#mc4d9143b4f\" y=\"154.261081\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"65.089747\" xlink:href=\"#mc4d9143b4f\" y=\"155.736378\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"66.014337\" xlink:href=\"#mc4d9143b4f\" y=\"159.424622\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"66.938926\" xlink:href=\"#mc4d9143b4f\" y=\"160.75239\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"67.863515\" xlink:href=\"#mc4d9143b4f\" y=\"161.194979\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"68.788105\" xlink:href=\"#mc4d9143b4f\" y=\"161.194979\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"69.712694\" xlink:href=\"#mc4d9143b4f\" y=\"162.817806\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"70.637283\" xlink:href=\"#mc4d9143b4f\" y=\"161.932628\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"71.561873\" xlink:href=\"#mc4d9143b4f\" y=\"163.407925\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"72.486462\" xlink:href=\"#mc4d9143b4f\" y=\"163.407925\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"73.411051\" xlink:href=\"#mc4d9143b4f\" y=\"165.030752\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"74.335641\" xlink:href=\"#mc4d9143b4f\" y=\"163.998044\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"75.26023\" xlink:href=\"#mc4d9143b4f\" y=\"164.735693\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"76.184819\" xlink:href=\"#mc4d9143b4f\" y=\"165.473342\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"77.109409\" xlink:href=\"#mc4d9143b4f\" y=\"164.883223\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"78.033998\" xlink:href=\"#mc4d9143b4f\" y=\"165.620871\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"78.958587\" xlink:href=\"#mc4d9143b4f\" y=\"165.768401\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"79.883177\" xlink:href=\"#mc4d9143b4f\" y=\"165.178282\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"80.807766\" xlink:href=\"#mc4d9143b4f\" y=\"165.915931\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"81.732355\" xlink:href=\"#mc4d9143b4f\" y=\"165.620871\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"82.656945\" xlink:href=\"#mc4d9143b4f\" y=\"165.473342\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"83.581534\" xlink:href=\"#mc4d9143b4f\" y=\"165.768401\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"84.506123\" xlink:href=\"#mc4d9143b4f\" y=\"165.620871\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"85.430713\" xlink:href=\"#mc4d9143b4f\" y=\"166.21099\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"86.355302\" xlink:href=\"#mc4d9143b4f\" y=\"165.915931\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"87.279891\" xlink:href=\"#mc4d9143b4f\" y=\"166.21099\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"88.204481\" xlink:href=\"#mc4d9143b4f\" y=\"166.063461\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"89.12907\" xlink:href=\"#mc4d9143b4f\" y=\"165.915931\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"90.978249\" xlink:href=\"#mc4d9143b4f\" y=\"166.35852\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"91.902838\" xlink:href=\"#mc4d9143b4f\" y=\"166.21099\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"92.827427\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"93.752017\" xlink:href=\"#mc4d9143b4f\" y=\"166.35852\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"94.676606\" xlink:href=\"#mc4d9143b4f\" y=\"166.35852\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"95.601195\" xlink:href=\"#mc4d9143b4f\" y=\"166.35852\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"96.525785\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"98.374963\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"99.299553\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"101.148731\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"102.073321\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"102.99791\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"103.922499\" xlink:href=\"#mc4d9143b4f\" y=\"166.21099\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"104.847089\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"106.696267\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"108.545446\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"109.470035\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"110.394625\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"111.319214\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"113.168393\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"114.092982\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"115.017571\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"115.942161\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"116.86675\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"118.715929\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"119.640518\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"122.414286\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"124.263465\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"126.112643\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"127.037233\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"127.961822\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"128.886411\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"130.73559\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"133.509358\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"136.283126\" xlink:href=\"#mc4d9143b4f\" y=\"166.50605\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"139.056894\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"140.906073\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"141.830662\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"163.096217\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"173.266699\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"204.702737\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"217.646987\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"232.440417\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"313.804278\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"325.823939\" xlink:href=\"#mc4d9143b4f\" y=\"166.65358\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 46.228125 173.698125 \n",
       "L 46.228125 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 339.138026 173.698125 \n",
       "L 339.138026 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 46.228125 173.698125 \n",
       "L 339.138026 173.698125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 46.228125 18.718125 \n",
       "L 339.138026 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- In-degree distribution -->\n",
       "    <g transform=\"translate(125.761513 12.718125)scale(0.12 -0.12)\">\n",
       "     <defs>\n",
       "      <path id=\"DejaVuSerif-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path d=\"M 622 4353 \n",
       "Q 622 4497 726 4603 \n",
       "Q 831 4709 978 4709 \n",
       "Q 1122 4709 1226 4603 \n",
       "Q 1331 4497 1331 4353 \n",
       "Q 1331 4206 1228 4103 \n",
       "Q 1125 4000 978 4000 \n",
       "Q 831 4000 726 4103 \n",
       "Q 622 4206 622 4353 \n",
       "z\n",
       "M 1356 331 \n",
       "L 1900 331 \n",
       "L 1900 0 \n",
       "L 231 0 \n",
       "L 231 331 \n",
       "L 781 331 \n",
       "L 781 2988 \n",
       "L 231 2988 \n",
       "L 231 3322 \n",
       "L 1356 3322 \n",
       "L 1356 331 \n",
       "z\n",
       "\" id=\"DejaVuSerif-69\" transform=\"scale(0.015625)\"/>\n",
       "      <path d=\"M 359 184 \n",
       "L 359 959 \n",
       "L 691 959 \n",
       "Q 703 588 923 403 \n",
       "Q 1144 219 1575 219 \n",
       "Q 1963 219 2166 364 \n",
       "Q 2369 509 2369 788 \n",
       "Q 2369 1006 2220 1140 \n",
       "Q 2072 1275 1594 1428 \n",
       "L 1178 1569 \n",
       "Q 750 1706 558 1912 \n",
       "Q 366 2119 366 2438 \n",
       "Q 366 2894 700 3153 \n",
       "Q 1034 3413 1625 3413 \n",
       "Q 1888 3413 2178 3344 \n",
       "Q 2469 3275 2778 3144 \n",
       "L 2778 2419 \n",
       "L 2447 2419 \n",
       "Q 2434 2741 2221 2922 \n",
       "Q 2009 3103 1644 3103 \n",
       "Q 1281 3103 1095 2975 \n",
       "Q 909 2847 909 2591 \n",
       "Q 909 2381 1050 2254 \n",
       "Q 1191 2128 1613 1997 \n",
       "L 2069 1856 \n",
       "Q 2541 1709 2748 1489 \n",
       "Q 2956 1269 2956 922 \n",
       "Q 2956 450 2595 179 \n",
       "Q 2234 -91 1600 -91 \n",
       "Q 1278 -91 972 -22 \n",
       "Q 666 47 359 184 \n",
       "z\n",
       "\" id=\"DejaVuSerif-73\" transform=\"scale(0.015625)\"/>\n",
       "      <path d=\"M 738 331 \n",
       "L 738 4531 \n",
       "L 184 4531 \n",
       "L 184 4863 \n",
       "L 1313 4863 \n",
       "L 1313 2803 \n",
       "Q 1481 3116 1742 3264 \n",
       "Q 2003 3413 2388 3413 \n",
       "Q 3000 3413 3387 2928 \n",
       "Q 3775 2444 3775 1663 \n",
       "Q 3775 881 3387 395 \n",
       "Q 3000 -91 2388 -91 \n",
       "Q 2003 -91 1742 57 \n",
       "Q 1481 206 1313 519 \n",
       "L 1313 0 \n",
       "L 184 0 \n",
       "L 184 331 \n",
       "L 738 331 \n",
       "z\n",
       "M 1313 1497 \n",
       "Q 1313 897 1542 583 \n",
       "Q 1772 269 2209 269 \n",
       "Q 2650 269 2876 622 \n",
       "Q 3103 975 3103 1663 \n",
       "Q 3103 2353 2876 2703 \n",
       "Q 2650 3053 2209 3053 \n",
       "Q 1772 3053 1542 2737 \n",
       "Q 1313 2422 1313 1825 \n",
       "L 1313 1497 \n",
       "z\n",
       "\" id=\"DejaVuSerif-62\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#DejaVuSerif-49\"/>\n",
       "     <use x=\"39.501953\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "     <use x=\"103.90625\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "     <use x=\"137.695312\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"201.708984\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"260.888672\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"324.902344\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"372.705078\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"431.884766\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"491.064453\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"522.851562\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"586.865234\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"618.847656\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "     <use x=\"670.166016\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"710.351562\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"758.154297\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"790.136719\" xlink:href=\"#DejaVuSerif-62\"/>\n",
       "     <use x=\"854.150391\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "     <use x=\"918.554688\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"958.740234\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"990.722656\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"1050.927734\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 400.779038 173.698125 \n",
       "L 693.688939 173.698125 \n",
       "L 693.688939 18.718125 \n",
       "L 400.779038 18.718125 \n",
       "z\n",
       "\" style=\"fill:#ffffff;\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_33\">\n",
       "     <g id=\"line2d_108\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"414.093125\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_109\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"414.093125\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(410.911875 184.796562)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_34\">\n",
       "     <g id=\"line2d_110\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"479.039888\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_111\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"479.039888\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- 20 -->\n",
       "      <g transform=\"translate(472.677388 184.796562)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-32\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_35\">\n",
       "     <g id=\"line2d_112\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"543.986651\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_113\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"543.986651\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_18\">\n",
       "      <!-- 40 -->\n",
       "      <g transform=\"translate(537.624151 184.796562)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2234 1581 \n",
       "L 2234 4063 \n",
       "L 641 1581 \n",
       "L 2234 1581 \n",
       "z\n",
       "M 3609 0 \n",
       "L 1484 0 \n",
       "L 1484 331 \n",
       "L 2234 331 \n",
       "L 2234 1247 \n",
       "L 197 1247 \n",
       "L 197 1588 \n",
       "L 2241 4750 \n",
       "L 2859 4750 \n",
       "L 2859 1581 \n",
       "L 3750 1581 \n",
       "L 3750 1247 \n",
       "L 2859 1247 \n",
       "L 2859 331 \n",
       "L 3609 331 \n",
       "L 3609 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-34\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-34\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_36\">\n",
       "     <g id=\"line2d_114\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"608.933414\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_115\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"608.933414\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_19\">\n",
       "      <!-- 60 -->\n",
       "      <g transform=\"translate(602.570914 184.796562)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2094 219 \n",
       "Q 2534 219 2771 542 \n",
       "Q 3009 866 3009 1472 \n",
       "Q 3009 2078 2771 2401 \n",
       "Q 2534 2725 2094 2725 \n",
       "Q 1647 2725 1412 2412 \n",
       "Q 1178 2100 1178 1509 \n",
       "Q 1178 888 1415 553 \n",
       "Q 1653 219 2094 219 \n",
       "z\n",
       "M 1075 2569 \n",
       "Q 1288 2803 1556 2918 \n",
       "Q 1825 3034 2163 3034 \n",
       "Q 2859 3034 3264 2615 \n",
       "Q 3669 2197 3669 1472 \n",
       "Q 3669 763 3233 336 \n",
       "Q 2797 -91 2069 -91 \n",
       "Q 1278 -91 853 498 \n",
       "Q 428 1088 428 2181 \n",
       "Q 428 3406 931 4078 \n",
       "Q 1434 4750 2350 4750 \n",
       "Q 2597 4750 2869 4703 \n",
       "Q 3141 4656 3425 4563 \n",
       "L 3425 3794 \n",
       "L 3072 3794 \n",
       "Q 3034 4109 2831 4275 \n",
       "Q 2628 4441 2284 4441 \n",
       "Q 1678 4441 1381 3981 \n",
       "Q 1084 3522 1075 2569 \n",
       "z\n",
       "\" id=\"DejaVuSerif-36\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-36\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_37\">\n",
       "     <g id=\"line2d_116\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"673.880176\" xlink:href=\"#m7becfc96f8\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_117\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"673.880176\" xlink:href=\"#mc94ec28e17\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_20\">\n",
       "      <!-- 80 -->\n",
       "      <g transform=\"translate(667.517676 184.796562)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2981 1275 \n",
       "Q 2981 1775 2732 2051 \n",
       "Q 2484 2328 2034 2328 \n",
       "Q 1584 2328 1336 2051 \n",
       "Q 1088 1775 1088 1275 \n",
       "Q 1088 772 1336 495 \n",
       "Q 1584 219 2034 219 \n",
       "Q 2484 219 2732 495 \n",
       "Q 2981 772 2981 1275 \n",
       "z\n",
       "M 2853 3541 \n",
       "Q 2853 3966 2637 4203 \n",
       "Q 2422 4441 2034 4441 \n",
       "Q 1650 4441 1433 4203 \n",
       "Q 1216 3966 1216 3541 \n",
       "Q 1216 3113 1433 2875 \n",
       "Q 1650 2638 2034 2638 \n",
       "Q 2422 2638 2637 2875 \n",
       "Q 2853 3113 2853 3541 \n",
       "z\n",
       "M 2516 2484 \n",
       "Q 3047 2413 3344 2092 \n",
       "Q 3641 1772 3641 1275 \n",
       "Q 3641 619 3225 264 \n",
       "Q 2809 -91 2034 -91 \n",
       "Q 1263 -91 845 264 \n",
       "Q 428 619 428 1275 \n",
       "Q 428 1772 725 2092 \n",
       "Q 1022 2413 1556 2484 \n",
       "Q 1084 2569 832 2842 \n",
       "Q 581 3116 581 3541 \n",
       "Q 581 4103 968 4426 \n",
       "Q 1356 4750 2034 4750 \n",
       "Q 2713 4750 3100 4426 \n",
       "Q 3488 4103 3488 3541 \n",
       "Q 3488 3116 3236 2842 \n",
       "Q 2984 2569 2516 2484 \n",
       "z\n",
       "\" id=\"DejaVuSerif-38\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-38\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_38\">\n",
       "     <g id=\"line2d_118\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"430.329815\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_119\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"430.329815\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_39\">\n",
       "     <g id=\"line2d_120\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"446.566506\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_121\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"446.566506\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_40\">\n",
       "     <g id=\"line2d_122\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"462.803197\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_123\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"462.803197\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_41\">\n",
       "     <g id=\"line2d_124\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"495.276578\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_125\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"495.276578\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_42\">\n",
       "     <g id=\"line2d_126\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"511.513269\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_127\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"511.513269\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_43\">\n",
       "     <g id=\"line2d_128\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"527.74996\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_129\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"527.74996\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_44\">\n",
       "     <g id=\"line2d_130\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"560.223341\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_131\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"560.223341\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_45\">\n",
       "     <g id=\"line2d_132\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"576.460032\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_133\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"576.460032\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_46\">\n",
       "     <g id=\"line2d_134\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"592.696723\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_135\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"592.696723\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_47\">\n",
       "     <g id=\"line2d_136\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"625.170104\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_137\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"625.170104\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_48\">\n",
       "     <g id=\"line2d_138\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"641.406795\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_139\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"641.406795\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_49\">\n",
       "     <g id=\"line2d_140\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"657.643486\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_141\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"657.643486\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_50\">\n",
       "     <g id=\"line2d_142\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"690.116867\" xlink:href=\"#mcc18a4926f\" y=\"173.698125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_143\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"690.116867\" xlink:href=\"#m9d231df80b\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- Out-degree -->\n",
       "     <g transform=\"translate(518.545707 198.474687)scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path d=\"M 2625 244 \n",
       "Q 3391 244 3781 770 \n",
       "Q 4172 1297 4172 2328 \n",
       "Q 4172 3363 3781 3889 \n",
       "Q 3391 4416 2625 4416 \n",
       "Q 1856 4416 1465 3889 \n",
       "Q 1075 3363 1075 2328 \n",
       "Q 1075 1297 1465 770 \n",
       "Q 1856 244 2625 244 \n",
       "z\n",
       "M 2625 -91 \n",
       "Q 2150 -91 1751 65 \n",
       "Q 1353 222 1050 525 \n",
       "Q 700 875 529 1319 \n",
       "Q 359 1763 359 2328 \n",
       "Q 359 2894 529 3339 \n",
       "Q 700 3784 1050 4134 \n",
       "Q 1356 4441 1750 4595 \n",
       "Q 2144 4750 2625 4750 \n",
       "Q 3641 4750 4266 4084 \n",
       "Q 4891 3419 4891 2328 \n",
       "Q 4891 1769 4719 1320 \n",
       "Q 4547 872 4197 525 \n",
       "Q 3891 219 3497 64 \n",
       "Q 3103 -91 2625 -91 \n",
       "z\n",
       "\" id=\"DejaVuSerif-4f\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSerif-4f\"/>\n",
       "      <use x=\"81.982422\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "      <use x=\"146.386719\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "      <use x=\"186.572266\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "      <use x=\"220.361328\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "      <use x=\"284.375\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use x=\"343.554688\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "      <use x=\"407.568359\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "      <use x=\"455.371094\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use x=\"514.550781\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_22\">\n",
       "     <g id=\"line2d_144\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"168.110838\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_145\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"168.110838\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(390.916538 171.910056)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_23\">\n",
       "     <g id=\"line2d_146\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"130.762659\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_147\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"130.762659\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 250 -->\n",
       "      <g transform=\"translate(378.191538 134.561878)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-32\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_24\">\n",
       "     <g id=\"line2d_148\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"93.414481\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_149\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"93.414481\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 500 -->\n",
       "      <g transform=\"translate(378.191538 97.2137)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_25\">\n",
       "     <g id=\"line2d_150\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"56.066303\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_151\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"56.066303\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 750 -->\n",
       "      <g transform=\"translate(378.191538 59.865522)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-37\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_26\">\n",
       "     <g id=\"line2d_152\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_153\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 1000 -->\n",
       "      <g transform=\"translate(371.829038 22.517344)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"190.869141\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_27\">\n",
       "     <g id=\"line2d_154\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"160.641202\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_155\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"160.641202\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_28\">\n",
       "     <g id=\"line2d_156\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"153.171566\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_157\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"153.171566\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_29\">\n",
       "     <g id=\"line2d_158\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"145.701931\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_159\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"145.701931\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_30\">\n",
       "     <g id=\"line2d_160\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"138.232295\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_161\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"138.232295\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_31\">\n",
       "     <g id=\"line2d_162\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"123.293024\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_163\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"123.293024\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_32\">\n",
       "     <g id=\"line2d_164\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"115.823388\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_165\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"115.823388\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_33\">\n",
       "     <g id=\"line2d_166\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"108.353753\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_167\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"108.353753\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_34\">\n",
       "     <g id=\"line2d_168\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"100.884117\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_169\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"100.884117\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_35\">\n",
       "     <g id=\"line2d_170\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"85.944846\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_171\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"85.944846\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_36\">\n",
       "     <g id=\"line2d_172\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"78.47521\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_173\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"78.47521\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_37\">\n",
       "     <g id=\"line2d_174\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"71.005574\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_175\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"71.005574\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_38\">\n",
       "     <g id=\"line2d_176\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"63.535939\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_177\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"63.535939\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_39\">\n",
       "     <g id=\"line2d_178\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"48.596668\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_179\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"48.596668\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_40\">\n",
       "     <g id=\"line2d_180\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"41.127032\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_181\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"41.127032\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_41\">\n",
       "     <g id=\"line2d_182\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"33.657396\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_183\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"33.657396\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_42\">\n",
       "     <g id=\"line2d_184\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"26.187761\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_185\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"26.187761\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_27\">\n",
       "     <!-- count -->\n",
       "     <g transform=\"translate(365.749351 110.468281)rotate(-90)scale(0.1 -0.1)\">\n",
       "      <use xlink:href=\"#DejaVuSerif-63\"/>\n",
       "      <use x=\"56.005859\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use x=\"116.210938\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "      <use x=\"180.615234\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      <use x=\"245.019531\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_186\">\n",
       "    <g clip-path=\"url(#pf84eea4374)\">\n",
       "     <use style=\"stroke:#000000;\" x=\"414.093125\" xlink:href=\"#mc4d9143b4f\" y=\"141.518935\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"417.340463\" xlink:href=\"#mc4d9143b4f\" y=\"53.227842\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"420.587801\" xlink:href=\"#mc4d9143b4f\" y=\"102.228651\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"423.835139\" xlink:href=\"#mc4d9143b4f\" y=\"133.899906\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"427.082477\" xlink:href=\"#mc4d9143b4f\" y=\"143.610433\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"430.329815\" xlink:href=\"#mc4d9143b4f\" y=\"151.677639\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"433.577154\" xlink:href=\"#mc4d9143b4f\" y=\"153.769137\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"436.824492\" xlink:href=\"#mc4d9143b4f\" y=\"154.366708\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"440.07183\" xlink:href=\"#mc4d9143b4f\" y=\"155.860635\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"443.319168\" xlink:href=\"#mc4d9143b4f\" y=\"160.342416\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"446.566506\" xlink:href=\"#mc4d9143b4f\" y=\"159.44606\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"449.813844\" xlink:href=\"#mc4d9143b4f\" y=\"161.537558\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"453.061182\" xlink:href=\"#mc4d9143b4f\" y=\"161.686951\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"456.308521\" xlink:href=\"#mc4d9143b4f\" y=\"164.525412\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"459.555859\" xlink:href=\"#mc4d9143b4f\" y=\"164.973591\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"462.803197\" xlink:href=\"#mc4d9143b4f\" y=\"165.122983\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"466.050535\" xlink:href=\"#mc4d9143b4f\" y=\"164.077234\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"469.297873\" xlink:href=\"#mc4d9143b4f\" y=\"163.629056\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"472.545211\" xlink:href=\"#mc4d9143b4f\" y=\"163.927842\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"475.792549\" xlink:href=\"#mc4d9143b4f\" y=\"165.571161\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"479.039888\" xlink:href=\"#mc4d9143b4f\" y=\"166.61691\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"482.287226\" xlink:href=\"#mc4d9143b4f\" y=\"165.571161\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"485.534564\" xlink:href=\"#mc4d9143b4f\" y=\"166.61691\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"488.781902\" xlink:href=\"#mc4d9143b4f\" y=\"166.61691\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"492.02924\" xlink:href=\"#mc4d9143b4f\" y=\"166.915696\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"495.276578\" xlink:href=\"#mc4d9143b4f\" y=\"167.065089\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"498.523917\" xlink:href=\"#mc4d9143b4f\" y=\"166.915696\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"501.771255\" xlink:href=\"#mc4d9143b4f\" y=\"166.766303\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"505.018593\" xlink:href=\"#mc4d9143b4f\" y=\"167.513267\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"508.265931\" xlink:href=\"#mc4d9143b4f\" y=\"167.214481\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"511.513269\" xlink:href=\"#mc4d9143b4f\" y=\"167.065089\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"514.760607\" xlink:href=\"#mc4d9143b4f\" y=\"167.662659\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"518.007945\" xlink:href=\"#mc4d9143b4f\" y=\"167.812052\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"521.255284\" xlink:href=\"#mc4d9143b4f\" y=\"167.812052\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"524.502622\" xlink:href=\"#mc4d9143b4f\" y=\"167.513267\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"527.74996\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"530.997298\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"534.244636\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"537.491974\" xlink:href=\"#mc4d9143b4f\" y=\"167.812052\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"540.739312\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"550.481327\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"553.728665\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"569.965356\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"573.212694\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"586.202046\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"592.696723\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"595.944061\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"599.191399\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"615.42809\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"651.148809\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"680.374853\" xlink:href=\"#mc4d9143b4f\" y=\"167.961445\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.779038 173.698125 \n",
       "L 400.779038 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 693.688939 173.698125 \n",
       "L 693.688939 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 400.779038 173.698125 \n",
       "L 693.688939 173.698125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 400.779038 18.718125 \n",
       "L 693.688939 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"text_28\">\n",
       "    <!-- Out-degree distribution -->\n",
       "    <g transform=\"translate(475.352114 12.718125)scale(0.12 -0.12)\">\n",
       "     <use xlink:href=\"#DejaVuSerif-4f\"/>\n",
       "     <use x=\"81.982422\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "     <use x=\"146.386719\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"186.572266\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "     <use x=\"220.361328\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"284.375\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"343.554688\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"407.568359\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"455.371094\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"514.550781\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"573.730469\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"605.517578\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"669.53125\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"701.513672\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "     <use x=\"752.832031\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"793.017578\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"840.820312\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"872.802734\" xlink:href=\"#DejaVuSerif-62\"/>\n",
       "     <use x=\"936.816406\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "     <use x=\"1001.220703\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"1041.40625\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"1073.388672\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"1133.59375\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 46.228125 382.378125 \n",
       "L 339.138026 382.378125 \n",
       "L 339.138026 227.398125 \n",
       "L 46.228125 227.398125 \n",
       "z\n",
       "\" style=\"fill:#ffffff;\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_51\">\n",
       "     <g id=\"line2d_187\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"59.542211\" xlink:href=\"#m7becfc96f8\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_188\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"59.542211\" xlink:href=\"#mc94ec28e17\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- $\\mathdefault{10^{0}}$ -->\n",
       "      <g transform=\"translate(50.742211 393.476562)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_52\">\n",
       "     <g id=\"line2d_189\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"167.813555\" xlink:href=\"#m7becfc96f8\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_190\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"167.813555\" xlink:href=\"#mc94ec28e17\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- $\\mathdefault{10^{1}}$ -->\n",
       "      <g transform=\"translate(159.013555 393.476562)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_53\">\n",
       "     <g id=\"line2d_191\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"276.084898\" xlink:href=\"#m7becfc96f8\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_192\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"276.084898\" xlink:href=\"#mc94ec28e17\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- $\\mathdefault{10^{2}}$ -->\n",
       "      <g transform=\"translate(267.284898 393.476562)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_54\">\n",
       "     <g id=\"line2d_193\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"49.049634\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_194\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"49.049634\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_55\">\n",
       "     <g id=\"line2d_195\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"54.587986\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_196\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"54.587986\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_56\">\n",
       "     <g id=\"line2d_197\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"92.135133\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_198\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"92.135133\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_57\">\n",
       "     <g id=\"line2d_199\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"111.200771\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_200\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"111.200771\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_58\">\n",
       "     <g id=\"line2d_201\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"124.728055\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_202\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"124.728055\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_59\">\n",
       "     <g id=\"line2d_203\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"135.220633\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_204\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"135.220633\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_60\">\n",
       "     <g id=\"line2d_205\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"143.793692\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_206\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"143.793692\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_61\">\n",
       "     <g id=\"line2d_207\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"151.042111\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_208\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"151.042111\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_62\">\n",
       "     <g id=\"line2d_209\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"157.320977\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_210\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"157.320977\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_63\">\n",
       "     <g id=\"line2d_211\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"162.85933\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_212\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"162.85933\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_64\">\n",
       "     <g id=\"line2d_213\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"200.406477\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_214\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"200.406477\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_65\">\n",
       "     <g id=\"line2d_215\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"219.472114\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_216\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"219.472114\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_66\">\n",
       "     <g id=\"line2d_217\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"232.999399\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_218\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"232.999399\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_67\">\n",
       "     <g id=\"line2d_219\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"243.491976\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_220\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"243.491976\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_68\">\n",
       "     <g id=\"line2d_221\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"252.065036\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_222\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"252.065036\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_69\">\n",
       "     <g id=\"line2d_223\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"259.313455\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_224\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"259.313455\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_70\">\n",
       "     <g id=\"line2d_225\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"265.592321\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_226\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"265.592321\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_71\">\n",
       "     <g id=\"line2d_227\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"271.130673\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_228\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"271.130673\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_72\">\n",
       "     <g id=\"line2d_229\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"308.67782\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_230\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"308.67782\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_73\">\n",
       "     <g id=\"line2d_231\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"327.743457\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_232\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"327.743457\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_32\">\n",
       "     <!-- $\\log($In-degree$)$ -->\n",
       "     <g transform=\"translate(156.383075 407.15625)scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path d=\"M 1313 331 \n",
       "L 1856 331 \n",
       "L 1856 0 \n",
       "L 184 0 \n",
       "L 184 331 \n",
       "L 738 331 \n",
       "L 738 4531 \n",
       "L 184 4531 \n",
       "L 184 4863 \n",
       "L 1313 4863 \n",
       "L 1313 331 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6c\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 2041 -997 \n",
       "Q 1281 -656 893 83 \n",
       "Q 506 822 506 1931 \n",
       "Q 506 3044 893 3783 \n",
       "Q 1281 4522 2041 4863 \n",
       "L 2041 4556 \n",
       "Q 1559 4225 1350 3623 \n",
       "Q 1141 3022 1141 1931 \n",
       "Q 1141 844 1350 242 \n",
       "Q 1559 -359 2041 -691 \n",
       "L 2041 -997 \n",
       "z\n",
       "\" id=\"DejaVuSerif-28\" transform=\"scale(0.015625)\"/>\n",
       "       <path d=\"M 453 -997 \n",
       "L 453 -691 \n",
       "Q 934 -359 1145 242 \n",
       "Q 1356 844 1356 1931 \n",
       "Q 1356 3022 1145 3623 \n",
       "Q 934 4225 453 4556 \n",
       "L 453 4863 \n",
       "Q 1216 4522 1603 3783 \n",
       "Q 1991 3044 1991 1931 \n",
       "Q 1991 822 1603 83 \n",
       "Q 1216 -656 453 -997 \n",
       "z\n",
       "\" id=\"DejaVuSerif-29\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use transform=\"translate(0 0.015625)\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "      <use transform=\"translate(31.982422 0.015625)\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use transform=\"translate(92.1875 0.015625)\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "      <use transform=\"translate(156.201172 0.015625)\" xlink:href=\"#DejaVuSerif-28\"/>\n",
       "      <use transform=\"translate(195.214844 0.015625)\" xlink:href=\"#DejaVuSerif-49\"/>\n",
       "      <use transform=\"translate(234.716797 0.015625)\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      <use transform=\"translate(299.121094 0.015625)\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "      <use transform=\"translate(332.910156 0.015625)\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "      <use transform=\"translate(396.923828 0.015625)\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use transform=\"translate(456.103516 0.015625)\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "      <use transform=\"translate(520.117188 0.015625)\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "      <use transform=\"translate(567.919922 0.015625)\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use transform=\"translate(627.099609 0.015625)\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use transform=\"translate(686.279297 0.015625)\" xlink:href=\"#DejaVuSerif-29\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\">\n",
       "    <g id=\"ytick_43\">\n",
       "     <g id=\"line2d_233\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"375.33358\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_234\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"375.33358\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_33\">\n",
       "      <!-- $\\mathdefault{10^{0}}$ -->\n",
       "      <g transform=\"translate(25.128125 379.132798)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_44\">\n",
       "     <g id=\"line2d_235\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"328.062015\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_236\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"328.062015\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_34\">\n",
       "      <!-- $\\mathdefault{10^{1}}$ -->\n",
       "      <g transform=\"translate(25.128125 331.861233)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_45\">\n",
       "     <g id=\"line2d_237\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"280.790449\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_238\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"280.790449\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_35\">\n",
       "      <!-- $\\mathdefault{10^{2}}$ -->\n",
       "      <g transform=\"translate(25.128125 284.589668)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_46\">\n",
       "     <g id=\"line2d_239\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#m5e70fb3546\" y=\"233.518884\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_240\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#md49a03a24c\" y=\"233.518884\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_36\">\n",
       "      <!-- $\\mathdefault{10^{3}}$ -->\n",
       "      <g transform=\"translate(25.128125 237.318103)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-33\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_47\">\n",
       "     <g id=\"line2d_241\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"379.914668\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_242\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"379.914668\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_48\">\n",
       "     <g id=\"line2d_243\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"377.496608\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_244\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"377.496608\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_49\">\n",
       "     <g id=\"line2d_245\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"361.103421\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_246\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"361.103421\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_50\">\n",
       "     <g id=\"line2d_247\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"352.779311\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_248\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"352.779311\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_51\">\n",
       "     <g id=\"line2d_249\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"346.873262\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_250\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"346.873262\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_52\">\n",
       "     <g id=\"line2d_251\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"342.292174\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_252\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"342.292174\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_53\">\n",
       "     <g id=\"line2d_253\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"338.549152\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_254\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"338.549152\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_54\">\n",
       "     <g id=\"line2d_255\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"335.384473\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_256\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"335.384473\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_55\">\n",
       "     <g id=\"line2d_257\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"332.643102\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_258\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"332.643102\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_56\">\n",
       "     <g id=\"line2d_259\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"330.225043\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_260\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"330.225043\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_57\">\n",
       "     <g id=\"line2d_261\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"313.831855\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_262\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"313.831855\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_58\">\n",
       "     <g id=\"line2d_263\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"305.507746\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_264\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"305.507746\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_59\">\n",
       "     <g id=\"line2d_265\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"299.601696\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_266\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"299.601696\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_60\">\n",
       "     <g id=\"line2d_267\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"295.020608\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_268\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"295.020608\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_61\">\n",
       "     <g id=\"line2d_269\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"291.277587\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_270\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"291.277587\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_62\">\n",
       "     <g id=\"line2d_271\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"288.112908\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_272\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"288.112908\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_63\">\n",
       "     <g id=\"line2d_273\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"285.371537\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_274\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"285.371537\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_64\">\n",
       "     <g id=\"line2d_275\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"282.953478\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_276\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"282.953478\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_65\">\n",
       "     <g id=\"line2d_277\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"266.56029\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_278\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"266.56029\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_66\">\n",
       "     <g id=\"line2d_279\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"258.236181\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_280\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"258.236181\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_67\">\n",
       "     <g id=\"line2d_281\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"252.330131\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_282\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"252.330131\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_68\">\n",
       "     <g id=\"line2d_283\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"247.749043\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_284\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"247.749043\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_69\">\n",
       "     <g id=\"line2d_285\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"244.006022\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_286\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"244.006022\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_70\">\n",
       "     <g id=\"line2d_287\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"240.841343\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_288\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"240.841343\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_71\">\n",
       "     <g id=\"line2d_289\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"238.099972\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_290\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"238.099972\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_72\">\n",
       "     <g id=\"line2d_291\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"46.228125\" xlink:href=\"#mf05794ed35\" y=\"235.681913\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_292\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"339.138026\" xlink:href=\"#m233fe4f8d2\" y=\"235.681913\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_37\">\n",
       "     <!-- $\\log($count$)$ -->\n",
       "     <g transform=\"translate(18.828125 330.888125)rotate(-90)scale(0.1 -0.1)\">\n",
       "      <use transform=\"translate(0 0.015625)\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "      <use transform=\"translate(31.982422 0.015625)\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use transform=\"translate(92.1875 0.015625)\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "      <use transform=\"translate(156.201172 0.015625)\" xlink:href=\"#DejaVuSerif-28\"/>\n",
       "      <use transform=\"translate(195.214844 0.015625)\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "      <use transform=\"translate(251.220703 0.015625)\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use transform=\"translate(311.425781 0.015625)\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "      <use transform=\"translate(375.830078 0.015625)\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      <use transform=\"translate(440.234375 0.015625)\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "      <use transform=\"translate(480.419922 0.015625)\" xlink:href=\"#DejaVuSerif-29\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_293\">\n",
       "    <g clip-path=\"url(#p0503f07a2c)\">\n",
       "     <use style=\"stroke:#000000;\" x=\"-1\" xlink:href=\"#mc4d9143b4f\" y=\"246.468742\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"59.542211\" xlink:href=\"#mc4d9143b4f\" y=\"246.475471\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"92.135133\" xlink:href=\"#mc4d9143b4f\" y=\"261.897247\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"111.200771\" xlink:href=\"#mc4d9143b4f\" y=\"274.782007\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"124.728055\" xlink:href=\"#mc4d9143b4f\" y=\"277.743419\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"135.220633\" xlink:href=\"#mc4d9143b4f\" y=\"284.126927\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"143.793692\" xlink:href=\"#mc4d9143b4f\" y=\"286.696499\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"151.042111\" xlink:href=\"#mc4d9143b4f\" y=\"295.020608\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"157.320977\" xlink:href=\"#mc4d9143b4f\" y=\"299.094763\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"162.85933\" xlink:href=\"#mc4d9143b4f\" y=\"300.654737\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"167.813555\" xlink:href=\"#mc4d9143b4f\" y=\"300.654737\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"172.295196\" xlink:href=\"#mc4d9143b4f\" y=\"307.670774\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"176.386614\" xlink:href=\"#mc4d9143b4f\" y=\"303.551049\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"180.150354\" xlink:href=\"#mc4d9143b4f\" y=\"310.962574\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"183.635033\" xlink:href=\"#mc4d9143b4f\" y=\"310.962574\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"186.879192\" xlink:href=\"#mc4d9143b4f\" y=\"324.318993\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"189.913899\" xlink:href=\"#mc4d9143b4f\" y=\"314.884896\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"192.764569\" xlink:href=\"#mc4d9143b4f\" y=\"321.154314\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"195.452252\" xlink:href=\"#mc4d9143b4f\" y=\"330.225043\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"197.994581\" xlink:href=\"#mc4d9143b4f\" y=\"322.675734\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"200.406477\" xlink:href=\"#mc4d9143b4f\" y=\"332.643102\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"202.70067\" xlink:href=\"#mc4d9143b4f\" y=\"335.384473\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"204.888118\" xlink:href=\"#mc4d9143b4f\" y=\"326.105318\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"206.978313\" xlink:href=\"#mc4d9143b4f\" y=\"338.549152\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"208.979536\" xlink:href=\"#mc4d9143b4f\" y=\"332.643102\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"210.899054\" xlink:href=\"#mc4d9143b4f\" y=\"330.225043\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"212.743276\" xlink:href=\"#mc4d9143b4f\" y=\"335.384473\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"214.517889\" xlink:href=\"#mc4d9143b4f\" y=\"332.643102\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"216.227955\" xlink:href=\"#mc4d9143b4f\" y=\"346.873262\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"217.878007\" xlink:href=\"#mc4d9143b4f\" y=\"338.549152\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"219.472114\" xlink:href=\"#mc4d9143b4f\" y=\"346.873262\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"221.013945\" xlink:href=\"#mc4d9143b4f\" y=\"342.292174\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"222.506821\" xlink:href=\"#mc4d9143b4f\" y=\"338.549152\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"225.357491\" xlink:href=\"#mc4d9143b4f\" y=\"352.779311\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"226.720533\" xlink:href=\"#mc4d9143b4f\" y=\"346.873262\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"228.045174\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"229.333518\" xlink:href=\"#mc4d9143b4f\" y=\"352.779311\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"230.587503\" xlink:href=\"#mc4d9143b4f\" y=\"352.779311\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"231.808914\" xlink:href=\"#mc4d9143b4f\" y=\"352.779311\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"232.999399\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"235.293592\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"236.400035\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"238.537751\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"239.571235\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"240.582492\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"241.572458\" xlink:href=\"#mc4d9143b4f\" y=\"346.873262\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"242.542011\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"244.423128\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"246.231876\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"247.110811\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"247.973617\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"248.820877\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"250.470929\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"251.274737\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"252.065036\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"252.842271\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"253.606867\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"255.099743\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"255.828776\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"257.950413\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"259.313455\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"260.638096\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"261.28668\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"261.92644\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"262.557613\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"263.795096\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"265.592321\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"267.323374\" xlink:href=\"#mc4d9143b4f\" y=\"361.103421\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"268.992957\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"270.073962\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"270.605286\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"281.413799\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"285.819045\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"297.295216\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"301.3117\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"305.517554\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"323.652039\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"325.823939\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 46.228125 382.378125 \n",
       "L 46.228125 227.398125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_14\">\n",
       "    <path d=\"M 339.138026 382.378125 \n",
       "L 339.138026 227.398125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_15\">\n",
       "    <path d=\"M 46.228125 382.378125 \n",
       "L 339.138026 382.378125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_16\">\n",
       "    <path d=\"M 46.228125 227.398125 \n",
       "L 339.138026 227.398125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"text_38\">\n",
       "    <!-- Log-log In-degree distribution -->\n",
       "    <g transform=\"translate(101.017138 221.398125)scale(0.12 -0.12)\">\n",
       "     <defs>\n",
       "      <path d=\"M 353 0 \n",
       "L 353 331 \n",
       "L 947 331 \n",
       "L 947 4331 \n",
       "L 353 4331 \n",
       "L 353 4666 \n",
       "L 2175 4666 \n",
       "L 2175 4331 \n",
       "L 1581 4331 \n",
       "L 1581 384 \n",
       "L 3713 384 \n",
       "L 3713 1166 \n",
       "L 4097 1166 \n",
       "L 4097 0 \n",
       "L 353 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-4c\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#DejaVuSerif-4c\"/>\n",
       "     <use x=\"66.40625\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"126.611328\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"190.625\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "     <use x=\"224.414062\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "     <use x=\"256.396484\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"316.601562\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"380.615234\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"412.402344\" xlink:href=\"#DejaVuSerif-49\"/>\n",
       "     <use x=\"451.904297\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "     <use x=\"516.308594\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "     <use x=\"550.097656\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"614.111328\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"673.291016\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"737.304688\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"785.107422\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"844.287109\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"903.466797\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"935.253906\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"999.267578\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"1031.25\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "     <use x=\"1082.568359\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"1122.753906\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"1170.556641\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"1202.539062\" xlink:href=\"#DejaVuSerif-62\"/>\n",
       "     <use x=\"1266.552734\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "     <use x=\"1330.957031\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"1371.142578\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"1403.125\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"1463.330078\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_17\">\n",
       "    <path d=\"M 400.779038 382.378125 \n",
       "L 693.688939 382.378125 \n",
       "L 693.688939 227.398125 \n",
       "L 400.779038 227.398125 \n",
       "z\n",
       "\" style=\"fill:#ffffff;\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_74\">\n",
       "     <g id=\"line2d_294\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"414.093125\" xlink:href=\"#m7becfc96f8\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_295\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"414.093125\" xlink:href=\"#mc94ec28e17\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_39\">\n",
       "      <!-- $\\mathdefault{10^{0}}$ -->\n",
       "      <g transform=\"translate(405.293125 393.476562)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_75\">\n",
       "     <g id=\"line2d_296\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"553.229816\" xlink:href=\"#m7becfc96f8\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_297\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"553.229816\" xlink:href=\"#mc94ec28e17\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_40\">\n",
       "      <!-- $\\mathdefault{10^{1}}$ -->\n",
       "      <g transform=\"translate(544.429816 393.476562)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_76\">\n",
       "     <g id=\"line2d_298\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"692.366508\" xlink:href=\"#m7becfc96f8\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_299\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"692.366508\" xlink:href=\"#mc94ec28e17\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_41\">\n",
       "      <!-- $\\mathdefault{10^{2}}$ -->\n",
       "      <g transform=\"translate(683.566508 393.476562)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_77\">\n",
       "     <g id=\"line2d_300\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"407.726579\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_301\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"407.726579\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_78\">\n",
       "     <g id=\"line2d_302\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"455.977442\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_303\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"455.977442\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_79\">\n",
       "     <g id=\"line2d_304\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"480.478198\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_305\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"480.478198\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_80\">\n",
       "     <g id=\"line2d_306\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"497.86176\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_307\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"497.86176\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_81\">\n",
       "     <g id=\"line2d_308\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"511.345499\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_309\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"511.345499\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_82\">\n",
       "     <g id=\"line2d_310\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"522.362515\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_311\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"522.362515\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_83\">\n",
       "     <g id=\"line2d_312\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"531.67727\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_313\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"531.67727\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_84\">\n",
       "     <g id=\"line2d_314\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"539.746078\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_315\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"539.746078\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_85\">\n",
       "     <g id=\"line2d_316\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"546.863271\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_317\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"546.863271\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_86\">\n",
       "     <g id=\"line2d_318\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"595.114134\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_319\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"595.114134\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_87\">\n",
       "     <g id=\"line2d_320\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"619.614889\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_321\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"619.614889\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_88\">\n",
       "     <g id=\"line2d_322\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"636.998452\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_323\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"636.998452\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_89\">\n",
       "     <g id=\"line2d_324\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"650.48219\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_325\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"650.48219\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_90\">\n",
       "     <g id=\"line2d_326\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"661.499207\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_327\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"661.499207\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_91\">\n",
       "     <g id=\"line2d_328\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"670.813962\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_329\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"670.813962\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_92\">\n",
       "     <g id=\"line2d_330\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"678.88277\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_331\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"678.88277\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_93\">\n",
       "     <g id=\"line2d_332\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"685.999962\" xlink:href=\"#mcc18a4926f\" y=\"382.378125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_333\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"685.999962\" xlink:href=\"#m9d231df80b\" y=\"227.398125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_42\">\n",
       "     <!-- $\\log($Out-degree$)$ -->\n",
       "     <g transform=\"translate(506.833989 407.15625)scale(0.1 -0.1)\">\n",
       "      <use transform=\"translate(0 0.015625)\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "      <use transform=\"translate(31.982422 0.015625)\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use transform=\"translate(92.1875 0.015625)\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "      <use transform=\"translate(156.201172 0.015625)\" xlink:href=\"#DejaVuSerif-28\"/>\n",
       "      <use transform=\"translate(195.214844 0.015625)\" xlink:href=\"#DejaVuSerif-4f\"/>\n",
       "      <use transform=\"translate(277.197266 0.015625)\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "      <use transform=\"translate(341.601562 0.015625)\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "      <use transform=\"translate(381.787109 0.015625)\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "      <use transform=\"translate(415.576172 0.015625)\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "      <use transform=\"translate(479.589844 0.015625)\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use transform=\"translate(538.769531 0.015625)\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "      <use transform=\"translate(602.783203 0.015625)\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "      <use transform=\"translate(650.585938 0.015625)\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use transform=\"translate(709.765625 0.015625)\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      <use transform=\"translate(768.945312 0.015625)\" xlink:href=\"#DejaVuSerif-29\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\">\n",
       "    <g id=\"ytick_73\">\n",
       "     <g id=\"line2d_334\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"375.33358\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_335\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"375.33358\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_43\">\n",
       "      <!-- $\\mathdefault{10^{0}}$ -->\n",
       "      <g transform=\"translate(379.679038 379.132798)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_74\">\n",
       "     <g id=\"line2d_336\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"326.513585\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_337\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"326.513585\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_44\">\n",
       "      <!-- $\\mathdefault{10^{1}}$ -->\n",
       "      <g transform=\"translate(379.679038 330.312803)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_75\">\n",
       "     <g id=\"line2d_338\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"277.69359\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_339\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"277.69359\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_45\">\n",
       "      <!-- $\\mathdefault{10^{2}}$ -->\n",
       "      <g transform=\"translate(379.679038 281.492809)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_76\">\n",
       "     <g id=\"line2d_340\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#m5e70fb3546\" y=\"228.873595\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_341\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#md49a03a24c\" y=\"228.873595\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_46\">\n",
       "      <!-- $\\mathdefault{10^{3}}$ -->\n",
       "      <g transform=\"translate(379.679038 232.672814)scale(0.1 -0.1)\">\n",
       "       <use transform=\"translate(0 0.7125)\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use transform=\"translate(63.623047 0.7125)\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use transform=\"translate(128.154453 37.046875)scale(0.7)\" xlink:href=\"#DejaVuSerif-33\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_77\">\n",
       "     <g id=\"line2d_342\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"380.064726\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_343\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"380.064726\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_78\">\n",
       "     <g id=\"line2d_344\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"377.56746\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_345\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"377.56746\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_79\">\n",
       "     <g id=\"line2d_346\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"360.637297\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_347\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"360.637297\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_80\">\n",
       "     <g id=\"line2d_348\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"352.040522\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_349\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"352.040522\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_81\">\n",
       "     <g id=\"line2d_350\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"345.941014\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_351\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"345.941014\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_82\">\n",
       "     <g id=\"line2d_352\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"341.209868\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_353\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"341.209868\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_83\">\n",
       "     <g id=\"line2d_354\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"337.344239\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_355\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"337.344239\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_84\">\n",
       "     <g id=\"line2d_356\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"334.075898\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_357\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"334.075898\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_85\">\n",
       "     <g id=\"line2d_358\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"331.244731\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_359\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"331.244731\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_86\">\n",
       "     <g id=\"line2d_360\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"328.747465\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_361\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"328.747465\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_87\">\n",
       "     <g id=\"line2d_362\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"311.817302\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_363\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"311.817302\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_88\">\n",
       "     <g id=\"line2d_364\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"303.220527\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_365\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"303.220527\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_89\">\n",
       "     <g id=\"line2d_366\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"297.121019\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_367\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"297.121019\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_90\">\n",
       "     <g id=\"line2d_368\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"292.389873\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_369\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"292.389873\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_91\">\n",
       "     <g id=\"line2d_370\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"288.524245\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_371\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"288.524245\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_92\">\n",
       "     <g id=\"line2d_372\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"285.255903\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_373\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"285.255903\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_93\">\n",
       "     <g id=\"line2d_374\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"282.424736\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_375\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"282.424736\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_94\">\n",
       "     <g id=\"line2d_376\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"279.92747\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_377\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"279.92747\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_95\">\n",
       "     <g id=\"line2d_378\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"262.997307\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_379\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"262.997307\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_96\">\n",
       "     <g id=\"line2d_380\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"254.400533\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_381\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"254.400533\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_97\">\n",
       "     <g id=\"line2d_382\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"248.301024\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_383\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"248.301024\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_98\">\n",
       "     <g id=\"line2d_384\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"243.569878\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_385\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"243.569878\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_99\">\n",
       "     <g id=\"line2d_386\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"239.70425\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_387\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"239.70425\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_100\">\n",
       "     <g id=\"line2d_388\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"236.435908\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_389\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"236.435908\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_101\">\n",
       "     <g id=\"line2d_390\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"233.604741\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_391\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"233.604741\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_102\">\n",
       "     <g id=\"line2d_392\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"400.779038\" xlink:href=\"#mf05794ed35\" y=\"231.107475\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_393\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"693.688939\" xlink:href=\"#m233fe4f8d2\" y=\"231.107475\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_47\">\n",
       "     <!-- $\\log($count$)$ -->\n",
       "     <g transform=\"translate(373.379038 330.888125)rotate(-90)scale(0.1 -0.1)\">\n",
       "      <use transform=\"translate(0 0.015625)\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "      <use transform=\"translate(31.982422 0.015625)\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use transform=\"translate(92.1875 0.015625)\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "      <use transform=\"translate(156.201172 0.015625)\" xlink:href=\"#DejaVuSerif-28\"/>\n",
       "      <use transform=\"translate(195.214844 0.015625)\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "      <use transform=\"translate(251.220703 0.015625)\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use transform=\"translate(311.425781 0.015625)\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "      <use transform=\"translate(375.830078 0.015625)\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      <use transform=\"translate(440.234375 0.015625)\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "      <use transform=\"translate(480.419922 0.015625)\" xlink:href=\"#DejaVuSerif-29\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_394\">\n",
       "    <g clip-path=\"url(#pddcddbb51c)\">\n",
       "     <use style=\"stroke:#000000;\" x=\"-1\" xlink:href=\"#mc4d9143b4f\" y=\"234.53523\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"414.093125\" xlink:href=\"#mc4d9143b4f\" y=\"234.44267\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"455.977442\" xlink:href=\"#mc4d9143b4f\" y=\"246.232101\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"480.478198\" xlink:href=\"#mc4d9143b4f\" y=\"260.126423\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"497.86176\" xlink:href=\"#mc4d9143b4f\" y=\"267.204914\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"511.345499\" xlink:href=\"#mc4d9143b4f\" y=\"275.672799\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"522.362515\" xlink:href=\"#mc4d9143b4f\" y=\"278.559108\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"531.67727\" xlink:href=\"#mc4d9143b4f\" y=\"279.461468\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"539.746078\" xlink:href=\"#mc4d9143b4f\" y=\"281.901197\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"546.863271\" xlink:href=\"#mc4d9143b4f\" y=\"291.558305\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"553.229816\" xlink:href=\"#mc4d9143b4f\" y=\"289.243034\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"558.989058\" xlink:href=\"#mc4d9143b4f\" y=\"295.100228\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"564.246833\" xlink:href=\"#mc4d9143b4f\" y=\"295.587658\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"569.083518\" xlink:href=\"#mc4d9143b4f\" y=\"307.951674\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"573.561588\" xlink:href=\"#mc4d9143b4f\" y=\"310.78284\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"577.730572\" xlink:href=\"#mc4d9143b4f\" y=\"311.817302\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"581.630396\" xlink:href=\"#mc4d9143b4f\" y=\"305.454408\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"585.293717\" xlink:href=\"#mc4d9143b4f\" y=\"303.220527\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"588.747588\" xlink:href=\"#mc4d9143b4f\" y=\"304.683332\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"592.01467\" xlink:href=\"#mc4d9143b4f\" y=\"315.26307\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"595.114134\" xlink:href=\"#mc4d9143b4f\" y=\"326.513585\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"598.062343\" xlink:href=\"#mc4d9143b4f\" y=\"315.26307\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"600.873375\" xlink:href=\"#mc4d9143b4f\" y=\"326.513585\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"603.559431\" xlink:href=\"#mc4d9143b4f\" y=\"326.513585\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"606.131151\" xlink:href=\"#mc4d9143b4f\" y=\"331.244731\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"608.597873\" xlink:href=\"#mc4d9143b4f\" y=\"334.075898\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"610.967835\" xlink:href=\"#mc4d9143b4f\" y=\"331.244731\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"613.248344\" xlink:href=\"#mc4d9143b4f\" y=\"328.747465\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"615.445906\" xlink:href=\"#mc4d9143b4f\" y=\"345.941014\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"617.566344\" xlink:href=\"#mc4d9143b4f\" y=\"337.344239\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"619.614889\" xlink:href=\"#mc4d9143b4f\" y=\"334.075898\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"621.596257\" xlink:href=\"#mc4d9143b4f\" y=\"352.040522\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"623.514713\" xlink:href=\"#mc4d9143b4f\" y=\"360.637297\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"625.374131\" xlink:href=\"#mc4d9143b4f\" y=\"360.637297\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"627.178035\" xlink:href=\"#mc4d9143b4f\" y=\"345.941014\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"628.929644\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"630.631906\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"632.287525\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"633.898988\" xlink:href=\"#mc4d9143b4f\" y=\"360.637297\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"635.46859\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"639.946661\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"641.368522\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"648.015469\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"649.261416\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"654.003165\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"656.241432\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"657.330223\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"658.399743\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"663.480575\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"673.349703\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "     <use style=\"stroke:#000000;\" x=\"680.374853\" xlink:href=\"#mc4d9143b4f\" y=\"375.33358\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_18\">\n",
       "    <path d=\"M 400.779038 382.378125 \n",
       "L 400.779038 227.398125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_19\">\n",
       "    <path d=\"M 693.688939 382.378125 \n",
       "L 693.688939 227.398125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_20\">\n",
       "    <path d=\"M 400.779038 382.378125 \n",
       "L 693.688939 382.378125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_21\">\n",
       "    <path d=\"M 400.779038 227.398125 \n",
       "L 693.688939 227.398125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"text_48\">\n",
       "    <!-- Log-log Out-degree distribution -->\n",
       "    <g transform=\"translate(450.607739 221.398125)scale(0.12 -0.12)\">\n",
       "     <use xlink:href=\"#DejaVuSerif-4c\"/>\n",
       "     <use x=\"66.40625\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"126.611328\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"190.625\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "     <use x=\"224.414062\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "     <use x=\"256.396484\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"316.601562\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"380.615234\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"412.402344\" xlink:href=\"#DejaVuSerif-4f\"/>\n",
       "     <use x=\"494.384766\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "     <use x=\"558.789062\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"598.974609\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "     <use x=\"632.763672\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"696.777344\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"755.957031\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"819.970703\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"867.773438\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"926.953125\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"986.132812\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"1017.919922\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"1081.933594\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"1113.916016\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "     <use x=\"1165.234375\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"1205.419922\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"1253.222656\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"1285.205078\" xlink:href=\"#DejaVuSerif-62\"/>\n",
       "     <use x=\"1349.21875\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "     <use x=\"1413.623047\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"1453.808594\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "     <use x=\"1485.791016\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"1545.996094\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p321e8e21c8\">\n",
       "   <rect height=\"154.98\" width=\"292.909901\" x=\"46.228125\" y=\"18.718125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pf84eea4374\">\n",
       "   <rect height=\"154.98\" width=\"292.909901\" x=\"400.779038\" y=\"18.718125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p0503f07a2c\">\n",
       "   <rect height=\"154.98\" width=\"292.909901\" x=\"46.228125\" y=\"227.398125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pddcddbb51c\">\n",
       "   <rect height=\"154.98\" width=\"292.909901\" x=\"400.779038\" y=\"227.398125\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1200x720 with 4 Axes>"
      ]
     },
     "metadata": {
      "needs_background": "light"
     },
     "output_type": "display_data"
    }
   ],
   "source": [
    "def get_degree_distributions(G: nx.DiGraph, degree: str=\"In\") -> list:\n",
    "        \"\"\"\n",
    "        Takes a graph as input and returns a list, x, that contains the different degrees,\n",
    "        and an additional list, y, that contains the count of the corresponding counts.\n",
    "        \"\"\"\n",
    "        if degree==\"In\":\n",
    "            count = Counter([i[1] for i in list(G.in_degree())])\n",
    "        elif degree==\"Out\":\n",
    "            count = Counter([i[1] for i in list(G.out_degree())])\n",
    "        count = sorted(count.items())\n",
    "        x = [i[0] for i in count]\n",
    "        y = [i[1] for i in count]\n",
    "        return x, y\n",
    "\n",
    "def draw_degree_distributions(G: nx.DiGraph):\n",
    "    \"\"\"\n",
    "    Draws four plots (two log-log and two linear) based on a directed graph's\n",
    "    in-degree and out-degree distributions. \n",
    "    \"\"\"\n",
    "\n",
    "    fig, axs = plt.subplots(2, 2, dpi = 120, figsize = (10,6))\n",
    "    for i in range(2):\n",
    "        for j, d in enumerate([\"In\", \"Out\"]):\n",
    "            x, y = get_degree_distributions(G, degree = d)\n",
    "\n",
    "            # for linear plots\n",
    "            axs[i][j].plot(x, y, 'ko', markersize=2)\n",
    "            axs[i][j].set_yticks(range(0, max(y)+250, 250))\n",
    "            axs[i][j].set_ylabel('count')\n",
    "            axs[i][j].set_xlabel(f'{d}-degree')\n",
    "            axs[i][j].set_title(f'{d}-degree distribution')\n",
    "\n",
    "            # for log-log-plots\n",
    "            if i == 1:\n",
    "                axs[i][j].loglog()\n",
    "                axs[i][j].set_ylabel('$\\log($count$)$')\n",
    "                axs[i][j].set_xlabel(f'$\\log(${d}-degree$)$')\n",
    "                axs[i][j].set_title(f'Log-log {d}-degree distribution')\n",
    "\n",
    "    plt.tight_layout()\n",
    "\n",
    "draw_degree_distributions(G)\n"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "7797745e",
   "metadata": {},
   "source": [
    "When comparing both of the linear plots with the log-log plots, it is clear that our directed network has scale-free properties. The reason for this is that the in-degree and out-degree distriubtions are well approximated by a linear model on a log-log scale suggesting that they follow a power-law distribution {cite}`barabasi2016network`. Formally the power-law distribution can be expressed as:  \n",
    "\n",
    "$Pk \\sim$ $k^{-\\gamma}$\n",
    "\n",
    "where $P_k$ is the probability that a random node links to another node, and $k$ constitutes the degree exponent {cite}`barabasi2016network` If we rewrite the expression to $Pk_{out} \\sim$ $k^{-\\gamma_{out}}$ and $Pk_{in} \\sim$ $k^{-\\gamma_{in}}$ we can calculate the exponent for both of the distributions."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "id": "882ef098",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:48:34.113754Z",
     "start_time": "2021-12-08T20:48:33.913477Z"
    }
   },
   "outputs": [],
   "source": [
    "%%capture\n",
    "# We extract the exponent\n",
    "in_degree_dist = [i[1] for i in G.in_degree()]\n",
    "out_degree_dist = [i[1] for i in G.out_degree()]\n",
    "in_degree_exp = powerlaw.Fit(in_degree_dist)\n",
    "out_degree_exp = powerlaw.Fit(out_degree_dist)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "id": "0d6a4c73",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:48:34.132131Z",
     "start_time": "2021-12-08T20:48:34.121027Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "The exponent of the In-degree distribution is: 2.649729526892168\n",
      "The exponent of the Out-degree distribution is: 4.909211267133928\n"
     ]
    }
   ],
   "source": [
    "print(\"The exponent of the In-degree distribution is: {}\"\\\n",
    "      .format(in_degree_exp.power_law.alpha))\n",
    "print(\"The exponent of the Out-degree distribution is: {}\"\\\n",
    "      .format(out_degree_exp.power_law.alpha))"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "1c22d25b",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-11-23T13:47:26.426175Z",
     "start_time": "2021-11-23T13:47:26.371405Z"
    }
   },
   "source": [
    "As the exponent corresponds to the slope of the straight line in a log-log plot, this means that the out-degree distribution to a larger degree than the in-degree distribution is scale-free. In practice this entails that a few pages with a lot of links to other pages are dominating the out-degree distribution. Although a smaller exponent, we still see that this is also the case for the in-degree distribution, where some pages have a lot more pages linking to it than the rest. In the following we try to inspect some of these nodes by plotting the ones with the highest in- or out-degree."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "id": "2eb7af50",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:48:34.779320Z",
     "start_time": "2021-12-08T20:48:34.138952Z"
    }
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg height=\"426.710625pt\" version=\"1.1\" viewBox=\"0 0 601.465625 426.710625\" width=\"601.465625pt\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2021-12-08T21:48:34.654675</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.4.3, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linecap:butt;stroke-linejoin:round;}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 426.710625 \n",
       "L 601.465625 426.710625 \n",
       "L 601.465625 -0 \n",
       "L 0 -0 \n",
       "z\n",
       "\" style=\"fill:none;\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 39.865625 181.798125 \n",
       "L 293.501989 181.798125 \n",
       "L 293.501989 18.718125 \n",
       "L 39.865625 18.718125 \n",
       "z\n",
       "\" style=\"fill:#ffffff;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 51.394551 181.798125 \n",
       "L 70.217286 181.798125 \n",
       "L 70.217286 135.419554 \n",
       "L 51.394551 135.419554 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 74.92297 181.798125 \n",
       "L 93.745706 181.798125 \n",
       "L 93.745706 134.340982 \n",
       "L 74.92297 134.340982 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 98.45139 181.798125 \n",
       "L 117.274126 181.798125 \n",
       "L 117.274126 133.801696 \n",
       "L 98.45139 133.801696 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 121.97981 181.798125 \n",
       "L 140.802545 181.798125 \n",
       "L 140.802545 121.398125 \n",
       "L 121.97981 121.398125 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 145.508229 181.798125 \n",
       "L 164.330965 181.798125 \n",
       "L 164.330965 115.465982 \n",
       "L 145.508229 115.465982 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 169.036649 181.798125 \n",
       "L 187.859384 181.798125 \n",
       "L 187.859384 97.130268 \n",
       "L 169.036649 97.130268 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 192.565068 181.798125 \n",
       "L 211.387804 181.798125 \n",
       "L 211.387804 89.580268 \n",
       "L 192.565068 89.580268 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 216.093488 181.798125 \n",
       "L 234.916224 181.798125 \n",
       "L 234.916224 80.951696 \n",
       "L 216.093488 80.951696 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 239.621908 181.798125 \n",
       "L 258.444643 181.798125 \n",
       "L 258.444643 33.494554 \n",
       "L 239.621908 33.494554 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path clip-path=\"url(#pd1904f2520)\" d=\"M 263.150327 181.798125 \n",
       "L 281.973063 181.798125 \n",
       "L 281.973063 26.483839 \n",
       "L 263.150327 26.483839 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 0 -3 \n",
       "\" id=\"mcbc08eb5a5\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"60.805918\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_2\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 0 3 \n",
       "\" id=\"me73616a5f4\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"60.805918\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- friedrich hayek -->\n",
       "      <g transform=\"translate(63.4942 262.52625)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2753 4078 \n",
       "L 2450 4078 \n",
       "Q 2447 4313 2317 4434 \n",
       "Q 2188 4556 1941 4556 \n",
       "Q 1619 4556 1487 4379 \n",
       "Q 1356 4203 1356 3750 \n",
       "L 1356 3322 \n",
       "L 2284 3322 \n",
       "L 2284 2988 \n",
       "L 1356 2988 \n",
       "L 1356 331 \n",
       "L 2094 331 \n",
       "L 2094 0 \n",
       "L 231 0 \n",
       "L 231 331 \n",
       "L 781 331 \n",
       "L 781 2988 \n",
       "L 231 2988 \n",
       "L 231 3322 \n",
       "L 781 3322 \n",
       "L 781 3738 \n",
       "Q 781 4294 1070 4578 \n",
       "Q 1359 4863 1919 4863 \n",
       "Q 2128 4863 2337 4825 \n",
       "Q 2547 4788 2753 4709 \n",
       "L 2753 4078 \n",
       "z\n",
       "\" id=\"DejaVuSerif-66\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 3059 3328 \n",
       "L 3059 2497 \n",
       "L 2728 2497 \n",
       "Q 2713 2744 2591 2866 \n",
       "Q 2469 2988 2234 2988 \n",
       "Q 1809 2988 1582 2694 \n",
       "Q 1356 2400 1356 1850 \n",
       "L 1356 331 \n",
       "L 2022 331 \n",
       "L 2022 0 \n",
       "L 263 0 \n",
       "L 263 331 \n",
       "L 781 331 \n",
       "L 781 2994 \n",
       "L 231 2994 \n",
       "L 231 3322 \n",
       "L 1356 3322 \n",
       "L 1356 2731 \n",
       "Q 1525 3078 1790 3245 \n",
       "Q 2056 3413 2438 3413 \n",
       "Q 2578 3413 2733 3391 \n",
       "Q 2888 3369 3059 3328 \n",
       "z\n",
       "\" id=\"DejaVuSerif-72\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 622 4353 \n",
       "Q 622 4497 726 4603 \n",
       "Q 831 4709 978 4709 \n",
       "Q 1122 4709 1226 4603 \n",
       "Q 1331 4497 1331 4353 \n",
       "Q 1331 4206 1228 4103 \n",
       "Q 1125 4000 978 4000 \n",
       "Q 831 4000 726 4103 \n",
       "Q 622 4206 622 4353 \n",
       "z\n",
       "M 1356 331 \n",
       "L 1900 331 \n",
       "L 1900 0 \n",
       "L 231 0 \n",
       "L 231 331 \n",
       "L 781 331 \n",
       "L 781 2988 \n",
       "L 231 2988 \n",
       "L 231 3322 \n",
       "L 1356 3322 \n",
       "L 1356 331 \n",
       "z\n",
       "\" id=\"DejaVuSerif-69\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 3469 1600 \n",
       "L 991 1600 \n",
       "L 991 1575 \n",
       "Q 991 903 1244 561 \n",
       "Q 1497 219 1991 219 \n",
       "Q 2369 219 2611 417 \n",
       "Q 2853 616 2950 1006 \n",
       "L 3413 1006 \n",
       "Q 3275 459 2904 184 \n",
       "Q 2534 -91 1931 -91 \n",
       "Q 1203 -91 761 389 \n",
       "Q 319 869 319 1663 \n",
       "Q 319 2450 753 2931 \n",
       "Q 1188 3413 1894 3413 \n",
       "Q 2647 3413 3050 2948 \n",
       "Q 3453 2484 3469 1600 \n",
       "z\n",
       "M 2791 1931 \n",
       "Q 2772 2513 2545 2808 \n",
       "Q 2319 3103 1894 3103 \n",
       "Q 1497 3103 1269 2806 \n",
       "Q 1041 2509 991 1931 \n",
       "L 2791 1931 \n",
       "z\n",
       "\" id=\"DejaVuSerif-65\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 3359 331 \n",
       "L 3909 331 \n",
       "L 3909 0 \n",
       "L 2784 0 \n",
       "L 2784 519 \n",
       "Q 2616 206 2355 57 \n",
       "Q 2094 -91 1709 -91 \n",
       "Q 1097 -91 708 395 \n",
       "Q 319 881 319 1663 \n",
       "Q 319 2444 706 2928 \n",
       "Q 1094 3413 1709 3413 \n",
       "Q 2094 3413 2355 3264 \n",
       "Q 2616 3116 2784 2803 \n",
       "L 2784 4531 \n",
       "L 2241 4531 \n",
       "L 2241 4863 \n",
       "L 3359 4863 \n",
       "L 3359 331 \n",
       "z\n",
       "M 2784 1497 \n",
       "L 2784 1825 \n",
       "Q 2784 2422 2554 2737 \n",
       "Q 2325 3053 1888 3053 \n",
       "Q 1444 3053 1217 2703 \n",
       "Q 991 2353 991 1663 \n",
       "Q 991 975 1217 622 \n",
       "Q 1444 269 1888 269 \n",
       "Q 2325 269 2554 583 \n",
       "Q 2784 897 2784 1497 \n",
       "z\n",
       "\" id=\"DejaVuSerif-64\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 3291 997 \n",
       "Q 3169 466 2822 187 \n",
       "Q 2475 -91 1925 -91 \n",
       "Q 1200 -91 759 389 \n",
       "Q 319 869 319 1663 \n",
       "Q 319 2459 759 2936 \n",
       "Q 1200 3413 1925 3413 \n",
       "Q 2241 3413 2553 3339 \n",
       "Q 2866 3266 3181 3116 \n",
       "L 3181 2266 \n",
       "L 2847 2266 \n",
       "Q 2781 2703 2561 2903 \n",
       "Q 2341 3103 1931 3103 \n",
       "Q 1466 3103 1228 2742 \n",
       "Q 991 2381 991 1663 \n",
       "Q 991 944 1227 581 \n",
       "Q 1463 219 1931 219 \n",
       "Q 2303 219 2525 412 \n",
       "Q 2747 606 2828 997 \n",
       "L 3291 997 \n",
       "z\n",
       "\" id=\"DejaVuSerif-63\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 263 0 \n",
       "L 263 331 \n",
       "L 781 331 \n",
       "L 781 4531 \n",
       "L 231 4531 \n",
       "L 231 4863 \n",
       "L 1356 4863 \n",
       "L 1356 2731 \n",
       "Q 1516 3069 1770 3241 \n",
       "Q 2025 3413 2363 3413 \n",
       "Q 2913 3413 3172 3097 \n",
       "Q 3431 2781 3431 2113 \n",
       "L 3431 331 \n",
       "L 3944 331 \n",
       "L 3944 0 \n",
       "L 2356 0 \n",
       "L 2356 331 \n",
       "L 2853 331 \n",
       "L 2853 1931 \n",
       "Q 2853 2541 2704 2764 \n",
       "Q 2556 2988 2175 2988 \n",
       "Q 1775 2988 1565 2697 \n",
       "Q 1356 2406 1356 1850 \n",
       "L 1356 331 \n",
       "L 1856 331 \n",
       "L 1856 0 \n",
       "L 263 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-68\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"DejaVuSerif-20\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 2547 1044 \n",
       "L 2547 1747 \n",
       "L 1806 1747 \n",
       "Q 1378 1747 1168 1562 \n",
       "Q 959 1378 959 997 \n",
       "Q 959 650 1171 447 \n",
       "Q 1384 244 1747 244 \n",
       "Q 2106 244 2326 466 \n",
       "Q 2547 688 2547 1044 \n",
       "z\n",
       "M 3122 2075 \n",
       "L 3122 331 \n",
       "L 3634 331 \n",
       "L 3634 0 \n",
       "L 2547 0 \n",
       "L 2547 359 \n",
       "Q 2356 128 2106 18 \n",
       "Q 1856 -91 1522 -91 \n",
       "Q 969 -91 644 203 \n",
       "Q 319 497 319 997 \n",
       "Q 319 1513 691 1797 \n",
       "Q 1063 2081 1741 2081 \n",
       "L 2547 2081 \n",
       "L 2547 2309 \n",
       "Q 2547 2688 2317 2895 \n",
       "Q 2088 3103 1672 3103 \n",
       "Q 1328 3103 1125 2947 \n",
       "Q 922 2791 872 2484 \n",
       "L 575 2484 \n",
       "L 575 3156 \n",
       "Q 875 3284 1158 3348 \n",
       "Q 1441 3413 1709 3413 \n",
       "Q 2400 3413 2761 3070 \n",
       "Q 3122 2728 3122 2075 \n",
       "z\n",
       "\" id=\"DejaVuSerif-61\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 1381 -609 \n",
       "L 1600 -56 \n",
       "L 359 2988 \n",
       "L -19 2988 \n",
       "L -19 3322 \n",
       "L 1509 3322 \n",
       "L 1509 2988 \n",
       "L 978 2988 \n",
       "L 1913 703 \n",
       "L 2847 2988 \n",
       "L 2350 2988 \n",
       "L 2350 3322 \n",
       "L 3597 3322 \n",
       "L 3597 2988 \n",
       "L 3225 2988 \n",
       "L 1703 -750 \n",
       "Q 1547 -1138 1356 -1280 \n",
       "Q 1166 -1422 819 -1422 \n",
       "Q 672 -1422 517 -1397 \n",
       "Q 363 -1372 206 -1325 \n",
       "L 206 -691 \n",
       "L 500 -691 \n",
       "Q 519 -903 608 -995 \n",
       "Q 697 -1088 884 -1088 \n",
       "Q 1056 -1088 1161 -992 \n",
       "Q 1266 -897 1381 -609 \n",
       "z\n",
       "\" id=\"DejaVuSerif-79\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 1831 0 \n",
       "L 219 0 \n",
       "L 219 331 \n",
       "L 738 331 \n",
       "L 738 4531 \n",
       "L 184 4531 \n",
       "L 184 4863 \n",
       "L 1313 4863 \n",
       "L 1313 1697 \n",
       "L 2713 2988 \n",
       "L 2234 2988 \n",
       "L 2234 3322 \n",
       "L 3738 3322 \n",
       "L 3738 2988 \n",
       "L 3169 2988 \n",
       "L 2181 2075 \n",
       "L 3444 331 \n",
       "L 3922 331 \n",
       "L 3922 0 \n",
       "L 2284 0 \n",
       "L 2284 331 \n",
       "L 2759 331 \n",
       "L 1766 1697 \n",
       "L 1313 1275 \n",
       "L 1313 331 \n",
       "L 1831 331 \n",
       "L 1831 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6b\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-66\"/>\n",
       "       <use x=\"37.011719\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"84.814453\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"116.796875\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"175.976562\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"239.990234\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"287.792969\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"319.775391\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"375.78125\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"440.185547\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"471.972656\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"536.376953\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"595.996094\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "       <use x=\"652.490234\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"711.669922\" xlink:href=\"#DejaVuSerif-6b\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"84.334338\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"84.334338\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- jurisprudence -->\n",
       "      <g transform=\"translate(87.022619 255.849687)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 641 4353 \n",
       "Q 641 4497 745 4603 \n",
       "Q 850 4709 997 4709 \n",
       "Q 1141 4709 1245 4603 \n",
       "Q 1350 4497 1350 4353 \n",
       "Q 1350 4206 1248 4103 \n",
       "Q 1147 4000 997 4000 \n",
       "Q 850 4000 745 4103 \n",
       "Q 641 4206 641 4353 \n",
       "z\n",
       "M 781 2988 \n",
       "L 238 2988 \n",
       "L 238 3322 \n",
       "L 1356 3322 \n",
       "L 1356 -325 \n",
       "Q 1356 -838 1051 -1130 \n",
       "Q 747 -1422 213 -1422 \n",
       "Q -13 -1422 -217 -1370 \n",
       "Q -422 -1319 -616 -1216 \n",
       "L -616 -531 \n",
       "L -319 -531 \n",
       "Q -297 -831 -164 -972 \n",
       "Q -31 -1113 225 -1113 \n",
       "Q 509 -1113 645 -920 \n",
       "Q 781 -728 781 -325 \n",
       "L 781 2988 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6a\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 2266 3322 \n",
       "L 3341 3322 \n",
       "L 3341 331 \n",
       "L 3884 331 \n",
       "L 3884 0 \n",
       "L 2766 0 \n",
       "L 2766 588 \n",
       "Q 2606 256 2353 82 \n",
       "Q 2100 -91 1766 -91 \n",
       "Q 1213 -91 952 223 \n",
       "Q 691 538 691 1209 \n",
       "L 691 2988 \n",
       "L 172 2988 \n",
       "L 172 3322 \n",
       "L 1269 3322 \n",
       "L 1269 1388 \n",
       "Q 1269 781 1417 556 \n",
       "Q 1566 331 1947 331 \n",
       "Q 2347 331 2556 625 \n",
       "Q 2766 919 2766 1478 \n",
       "L 2766 2988 \n",
       "L 2266 2988 \n",
       "L 2266 3322 \n",
       "z\n",
       "\" id=\"DejaVuSerif-75\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 359 184 \n",
       "L 359 959 \n",
       "L 691 959 \n",
       "Q 703 588 923 403 \n",
       "Q 1144 219 1575 219 \n",
       "Q 1963 219 2166 364 \n",
       "Q 2369 509 2369 788 \n",
       "Q 2369 1006 2220 1140 \n",
       "Q 2072 1275 1594 1428 \n",
       "L 1178 1569 \n",
       "Q 750 1706 558 1912 \n",
       "Q 366 2119 366 2438 \n",
       "Q 366 2894 700 3153 \n",
       "Q 1034 3413 1625 3413 \n",
       "Q 1888 3413 2178 3344 \n",
       "Q 2469 3275 2778 3144 \n",
       "L 2778 2419 \n",
       "L 2447 2419 \n",
       "Q 2434 2741 2221 2922 \n",
       "Q 2009 3103 1644 3103 \n",
       "Q 1281 3103 1095 2975 \n",
       "Q 909 2847 909 2591 \n",
       "Q 909 2381 1050 2254 \n",
       "Q 1191 2128 1613 1997 \n",
       "L 2069 1856 \n",
       "Q 2541 1709 2748 1489 \n",
       "Q 2956 1269 2956 922 \n",
       "Q 2956 450 2595 179 \n",
       "Q 2234 -91 1600 -91 \n",
       "Q 1278 -91 972 -22 \n",
       "Q 666 47 359 184 \n",
       "z\n",
       "\" id=\"DejaVuSerif-73\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 1313 1825 \n",
       "L 1313 1497 \n",
       "Q 1313 897 1542 583 \n",
       "Q 1772 269 2209 269 \n",
       "Q 2650 269 2876 622 \n",
       "Q 3103 975 3103 1663 \n",
       "Q 3103 2353 2876 2703 \n",
       "Q 2650 3053 2209 3053 \n",
       "Q 1772 3053 1542 2737 \n",
       "Q 1313 2422 1313 1825 \n",
       "z\n",
       "M 738 2988 \n",
       "L 184 2988 \n",
       "L 184 3322 \n",
       "L 1313 3322 \n",
       "L 1313 2803 \n",
       "Q 1481 3116 1742 3264 \n",
       "Q 2003 3413 2388 3413 \n",
       "Q 3000 3413 3387 2928 \n",
       "Q 3775 2444 3775 1663 \n",
       "Q 3775 881 3387 395 \n",
       "Q 3000 -91 2388 -91 \n",
       "Q 2003 -91 1742 57 \n",
       "Q 1481 206 1313 519 \n",
       "L 1313 -997 \n",
       "L 1856 -997 \n",
       "L 1856 -1331 \n",
       "L 184 -1331 \n",
       "L 184 -997 \n",
       "L 738 -997 \n",
       "L 738 2988 \n",
       "z\n",
       "\" id=\"DejaVuSerif-70\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 263 0 \n",
       "L 263 331 \n",
       "L 781 331 \n",
       "L 781 2988 \n",
       "L 231 2988 \n",
       "L 231 3322 \n",
       "L 1356 3322 \n",
       "L 1356 2731 \n",
       "Q 1516 3069 1770 3241 \n",
       "Q 2025 3413 2363 3413 \n",
       "Q 2913 3413 3172 3097 \n",
       "Q 3431 2781 3431 2113 \n",
       "L 3431 331 \n",
       "L 3944 331 \n",
       "L 3944 0 \n",
       "L 2356 0 \n",
       "L 2356 331 \n",
       "L 2853 331 \n",
       "L 2853 1931 \n",
       "Q 2853 2541 2703 2767 \n",
       "Q 2553 2994 2175 2994 \n",
       "Q 1775 2994 1565 2701 \n",
       "Q 1356 2409 1356 1850 \n",
       "L 1356 331 \n",
       "L 1856 331 \n",
       "L 1856 0 \n",
       "L 263 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6e\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-6a\"/>\n",
       "       <use x=\"31.005859\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "       <use x=\"95.410156\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"143.212891\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"175.195312\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"226.513672\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"290.527344\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"338.330078\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "       <use x=\"402.734375\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"466.748047\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"525.927734\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"590.332031\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"646.337891\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"107.862758\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"107.862758\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- cultural anthropology -->\n",
       "      <g transform=\"translate(110.551039 295.47)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 1313 331 \n",
       "L 1856 331 \n",
       "L 1856 0 \n",
       "L 184 0 \n",
       "L 184 331 \n",
       "L 738 331 \n",
       "L 738 4531 \n",
       "L 184 4531 \n",
       "L 184 4863 \n",
       "L 1313 4863 \n",
       "L 1313 331 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6c\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 691 2988 \n",
       "L 184 2988 \n",
       "L 184 3322 \n",
       "L 691 3322 \n",
       "L 691 4353 \n",
       "L 1269 4353 \n",
       "L 1269 3322 \n",
       "L 2350 3322 \n",
       "L 2350 2988 \n",
       "L 1269 2988 \n",
       "L 1269 878 \n",
       "Q 1269 456 1350 337 \n",
       "Q 1431 219 1650 219 \n",
       "Q 1875 219 1978 351 \n",
       "Q 2081 484 2088 781 \n",
       "L 2522 781 \n",
       "Q 2497 328 2275 118 \n",
       "Q 2053 -91 1600 -91 \n",
       "Q 1103 -91 897 129 \n",
       "Q 691 350 691 878 \n",
       "L 691 2988 \n",
       "z\n",
       "\" id=\"DejaVuSerif-74\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 1925 219 \n",
       "Q 2388 219 2623 584 \n",
       "Q 2859 950 2859 1663 \n",
       "Q 2859 2375 2623 2739 \n",
       "Q 2388 3103 1925 3103 \n",
       "Q 1463 3103 1227 2739 \n",
       "Q 991 2375 991 1663 \n",
       "Q 991 950 1228 584 \n",
       "Q 1466 219 1925 219 \n",
       "z\n",
       "M 1925 -91 \n",
       "Q 1200 -91 759 389 \n",
       "Q 319 869 319 1663 \n",
       "Q 319 2456 758 2934 \n",
       "Q 1197 3413 1925 3413 \n",
       "Q 2653 3413 3092 2934 \n",
       "Q 3531 2456 3531 1663 \n",
       "Q 3531 869 3092 389 \n",
       "Q 2653 -91 1925 -91 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6f\" transform=\"scale(0.015625)\"/>\n",
       "        <path d=\"M 3359 2988 \n",
       "L 3359 72 \n",
       "Q 3359 -644 2965 -1033 \n",
       "Q 2572 -1422 1844 -1422 \n",
       "Q 1516 -1422 1216 -1362 \n",
       "Q 916 -1303 641 -1184 \n",
       "L 641 -488 \n",
       "L 941 -488 \n",
       "Q 997 -813 1206 -963 \n",
       "Q 1416 -1113 1806 -1113 \n",
       "Q 2313 -1113 2548 -827 \n",
       "Q 2784 -541 2784 72 \n",
       "L 2784 519 \n",
       "Q 2616 206 2355 57 \n",
       "Q 2094 -91 1709 -91 \n",
       "Q 1097 -91 708 395 \n",
       "Q 319 881 319 1663 \n",
       "Q 319 2444 706 2928 \n",
       "Q 1094 3413 1709 3413 \n",
       "Q 2094 3413 2355 3264 \n",
       "Q 2616 3116 2784 2803 \n",
       "L 2784 3322 \n",
       "L 3909 3322 \n",
       "L 3909 2988 \n",
       "L 3359 2988 \n",
       "z\n",
       "M 2784 1825 \n",
       "Q 2784 2422 2554 2737 \n",
       "Q 2325 3053 1888 3053 \n",
       "Q 1444 3053 1217 2703 \n",
       "Q 991 2353 991 1663 \n",
       "Q 991 975 1217 622 \n",
       "Q 1444 269 1888 269 \n",
       "Q 2325 269 2554 583 \n",
       "Q 2784 897 2784 1497 \n",
       "L 2784 1825 \n",
       "z\n",
       "\" id=\"DejaVuSerif-67\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"56.005859\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "       <use x=\"120.410156\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"152.392578\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"192.578125\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "       <use x=\"256.982422\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"304.785156\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"364.404297\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"396.386719\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"428.173828\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"487.792969\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"552.197266\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"592.382812\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"656.787109\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"704.589844\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"764.794922\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"828.808594\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"889.013672\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"920.996094\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"981.201172\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"1045.214844\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"131.391177\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"131.391177\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- intelligence -->\n",
       "      <g transform=\"translate(134.079459 244.749687)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"31.982422\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"96.386719\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"136.572266\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"195.751953\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"227.734375\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"259.716797\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"291.699219\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"355.712891\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"414.892578\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"479.296875\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"535.302734\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"154.919597\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"154.919597\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- adam smith -->\n",
       "      <g transform=\"translate(157.678972 244.5575)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 3316 2675 \n",
       "Q 3481 3041 3739 3227 \n",
       "Q 3997 3413 4341 3413 \n",
       "Q 4863 3413 5119 3089 \n",
       "Q 5375 2766 5375 2113 \n",
       "L 5375 331 \n",
       "L 5894 331 \n",
       "L 5894 0 \n",
       "L 4300 0 \n",
       "L 4300 331 \n",
       "L 4800 331 \n",
       "L 4800 2047 \n",
       "Q 4800 2556 4650 2772 \n",
       "Q 4500 2988 4153 2988 \n",
       "Q 3769 2988 3567 2697 \n",
       "Q 3366 2406 3366 1850 \n",
       "L 3366 331 \n",
       "L 3866 331 \n",
       "L 3866 0 \n",
       "L 2291 0 \n",
       "L 2291 331 \n",
       "L 2791 331 \n",
       "L 2791 2069 \n",
       "Q 2791 2566 2641 2777 \n",
       "Q 2491 2988 2144 2988 \n",
       "Q 1759 2988 1557 2697 \n",
       "Q 1356 2406 1356 1850 \n",
       "L 1356 331 \n",
       "L 1856 331 \n",
       "L 1856 0 \n",
       "L 263 0 \n",
       "L 263 331 \n",
       "L 781 331 \n",
       "L 781 2994 \n",
       "L 231 2994 \n",
       "L 231 3322 \n",
       "L 1356 3322 \n",
       "L 1356 2731 \n",
       "Q 1516 3063 1762 3238 \n",
       "Q 2009 3413 2322 3413 \n",
       "Q 2709 3413 2968 3220 \n",
       "Q 3228 3028 3316 2675 \n",
       "z\n",
       "\" id=\"DejaVuSerif-6d\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"59.619141\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"123.632812\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"183.251953\" xlink:href=\"#DejaVuSerif-6d\"/>\n",
       "       <use x=\"278.076172\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"309.863281\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"361.181641\" xlink:href=\"#DejaVuSerif-6d\"/>\n",
       "       <use x=\"456.005859\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"487.988281\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"528.173828\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"178.448017\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"178.448017\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- language -->\n",
       "      <g transform=\"translate(181.136298 232.024687)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"31.982422\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"91.601562\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"156.005859\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"220.019531\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "       <use x=\"284.423828\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"344.042969\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"408.056641\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"201.976436\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"201.976436\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- people -->\n",
       "      <g transform=\"translate(204.735811 219.1575)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"64.013672\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"123.193359\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"183.398438\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"247.412109\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"279.394531\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"225.504856\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"225.504856\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- anthropology -->\n",
       "      <g transform=\"translate(228.193137 252.652812)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"59.619141\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"124.023438\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"164.208984\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"228.613281\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"276.416016\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"336.621094\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"400.634766\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"460.839844\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"492.822266\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"553.027344\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"617.041016\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"249.033276\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"249.033276\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- political science -->\n",
       "      <g transform=\"translate(251.792651 267.080937)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"64.013672\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"124.21875\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"156.201172\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"188.183594\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"228.369141\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"260.351562\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"316.357422\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"375.976562\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"407.958984\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"439.746094\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"491.064453\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"547.070312\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"579.052734\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"638.232422\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"702.636719\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"758.642578\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"272.561695\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"272.561695\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- religion -->\n",
       "      <g transform=\"translate(275.249976 224.454375)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"47.802734\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"106.982422\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"138.964844\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"170.947266\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"234.960938\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"266.943359\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"327.148438\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L 3 0 \n",
       "\" id=\"md8c0b97564\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"39.865625\" xlink:href=\"#md8c0b97564\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_22\">\n",
       "      <defs>\n",
       "       <path d=\"M 0 0 \n",
       "L -3 0 \n",
       "\" id=\"m4e0ab084e9\" style=\"stroke:#000000;stroke-width:0.5;\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"293.501989\" xlink:href=\"#m4e0ab084e9\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(30.003125 185.597344)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2034 219 \n",
       "Q 2513 219 2750 744 \n",
       "Q 2988 1269 2988 2328 \n",
       "Q 2988 3391 2750 3916 \n",
       "Q 2513 4441 2034 4441 \n",
       "Q 1556 4441 1318 3916 \n",
       "Q 1081 3391 1081 2328 \n",
       "Q 1081 1269 1318 744 \n",
       "Q 1556 219 2034 219 \n",
       "z\n",
       "M 2034 -91 \n",
       "Q 1275 -91 848 546 \n",
       "Q 422 1184 422 2328 \n",
       "Q 422 3475 848 4112 \n",
       "Q 1275 4750 2034 4750 \n",
       "Q 2797 4750 3222 4112 \n",
       "Q 3647 3475 3647 2328 \n",
       "Q 3647 1184 3222 546 \n",
       "Q 2797 -91 2034 -91 \n",
       "z\n",
       "\" id=\"DejaVuSerif-30\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"39.865625\" xlink:href=\"#md8c0b97564\" y=\"154.833839\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"293.501989\" xlink:href=\"#m4e0ab084e9\" y=\"154.833839\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 50 -->\n",
       "      <g transform=\"translate(23.640625 158.633058)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 3219 4666 \n",
       "L 3219 4153 \n",
       "L 1081 4153 \n",
       "L 1081 2816 \n",
       "Q 1244 2928 1461 2984 \n",
       "Q 1678 3041 1947 3041 \n",
       "Q 2703 3041 3140 2622 \n",
       "Q 3578 2203 3578 1478 \n",
       "Q 3578 738 3136 323 \n",
       "Q 2694 -91 1894 -91 \n",
       "Q 1572 -91 1234 -12 \n",
       "Q 897 66 544 225 \n",
       "L 544 1131 \n",
       "L 897 1131 \n",
       "Q 925 688 1179 453 \n",
       "Q 1434 219 1894 219 \n",
       "Q 2388 219 2653 544 \n",
       "Q 2919 869 2919 1478 \n",
       "Q 2919 2084 2655 2407 \n",
       "Q 2391 2731 1894 2731 \n",
       "Q 1613 2731 1398 2631 \n",
       "Q 1184 2531 1019 2322 \n",
       "L 750 2322 \n",
       "L 750 4666 \n",
       "L 3219 4666 \n",
       "z\n",
       "\" id=\"DejaVuSerif-35\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"39.865625\" xlink:href=\"#md8c0b97564\" y=\"127.869554\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"293.501989\" xlink:href=\"#m4e0ab084e9\" y=\"127.869554\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 100 -->\n",
       "      <g transform=\"translate(17.278125 131.668772)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 909 0 \n",
       "L 909 331 \n",
       "L 1722 331 \n",
       "L 1722 4213 \n",
       "L 781 3603 \n",
       "L 781 4013 \n",
       "L 1919 4750 \n",
       "L 2350 4750 \n",
       "L 2350 331 \n",
       "L 3163 331 \n",
       "L 3163 0 \n",
       "L 909 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-31\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"39.865625\" xlink:href=\"#md8c0b97564\" y=\"100.905268\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"293.501989\" xlink:href=\"#m4e0ab084e9\" y=\"100.905268\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 150 -->\n",
       "      <g transform=\"translate(17.278125 104.704487)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-31\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"39.865625\" xlink:href=\"#md8c0b97564\" y=\"73.940982\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"293.501989\" xlink:href=\"#m4e0ab084e9\" y=\"73.940982\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 200 -->\n",
       "      <g transform=\"translate(17.278125 77.740201)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 819 3553 \n",
       "L 469 3553 \n",
       "L 469 4384 \n",
       "Q 803 4563 1142 4656 \n",
       "Q 1481 4750 1806 4750 \n",
       "Q 2534 4750 2956 4397 \n",
       "Q 3378 4044 3378 3438 \n",
       "Q 3378 2753 2422 1800 \n",
       "Q 2347 1728 2309 1691 \n",
       "L 1131 513 \n",
       "L 3078 513 \n",
       "L 3078 1088 \n",
       "L 3444 1088 \n",
       "L 3444 0 \n",
       "L 434 0 \n",
       "L 434 341 \n",
       "L 1850 1753 \n",
       "Q 2319 2222 2519 2614 \n",
       "Q 2719 3006 2719 3438 \n",
       "Q 2719 3909 2473 4175 \n",
       "Q 2228 4441 1797 4441 \n",
       "Q 1350 4441 1106 4219 \n",
       "Q 863 3997 819 3553 \n",
       "z\n",
       "\" id=\"DejaVuSerif-32\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-32\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_31\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"39.865625\" xlink:href=\"#md8c0b97564\" y=\"46.976696\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_32\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"293.501989\" xlink:href=\"#m4e0ab084e9\" y=\"46.976696\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 250 -->\n",
       "      <g transform=\"translate(17.278125 50.775915)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-32\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-35\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_33\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"39.865625\" xlink:href=\"#md8c0b97564\" y=\"20.012411\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_34\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"293.501989\" xlink:href=\"#m4e0ab084e9\" y=\"20.012411\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- 300 -->\n",
       "      <g transform=\"translate(17.278125 23.811629)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 622 4469 \n",
       "Q 988 4606 1323 4678 \n",
       "Q 1659 4750 1953 4750 \n",
       "Q 2638 4750 3022 4454 \n",
       "Q 3406 4159 3406 3634 \n",
       "Q 3406 3213 3140 2930 \n",
       "Q 2875 2647 2388 2547 \n",
       "Q 2963 2466 3280 2130 \n",
       "Q 3597 1794 3597 1259 \n",
       "Q 3597 606 3158 257 \n",
       "Q 2719 -91 1894 -91 \n",
       "Q 1528 -91 1179 -12 \n",
       "Q 831 66 488 225 \n",
       "L 488 1131 \n",
       "L 838 1131 \n",
       "Q 869 681 1141 450 \n",
       "Q 1413 219 1906 219 \n",
       "Q 2384 219 2661 495 \n",
       "Q 2938 772 2938 1253 \n",
       "Q 2938 1803 2653 2086 \n",
       "Q 2369 2369 1819 2369 \n",
       "L 1522 2369 \n",
       "L 1522 2688 \n",
       "L 1678 2688 \n",
       "Q 2225 2688 2498 2914 \n",
       "Q 2772 3141 2772 3597 \n",
       "Q 2772 4006 2547 4223 \n",
       "Q 2322 4441 1900 4441 \n",
       "Q 1478 4441 1245 4241 \n",
       "Q 1013 4041 972 3647 \n",
       "L 622 3647 \n",
       "L 622 4469 \n",
       "z\n",
       "\" id=\"DejaVuSerif-33\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-33\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "       <use x=\"127.246094\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- count -->\n",
       "     <g transform=\"translate(11.198438 114.518281)rotate(-90)scale(0.1 -0.1)\">\n",
       "      <use xlink:href=\"#DejaVuSerif-63\"/>\n",
       "      <use x=\"56.005859\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use x=\"116.210938\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "      <use x=\"180.615234\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      <use x=\"245.019531\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 39.865625 181.798125 \n",
       "L 39.865625 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_14\">\n",
       "    <path d=\"M 293.501989 181.798125 \n",
       "L 293.501989 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_15\">\n",
       "    <path d=\"M 39.865625 181.798125 \n",
       "L 293.501989 181.798125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_16\">\n",
       "    <path d=\"M 39.865625 18.718125 \n",
       "L 293.501989 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"text_19\">\n",
       "    <!-- Top 10: In-degree -->\n",
       "    <g transform=\"translate(112.757869 12.718125)scale(0.12 -0.12)\">\n",
       "     <defs>\n",
       "      <path d=\"M 1222 0 \n",
       "L 1222 331 \n",
       "L 1819 331 \n",
       "L 1819 4294 \n",
       "L 447 4294 \n",
       "L 447 3566 \n",
       "L 63 3566 \n",
       "L 63 4666 \n",
       "L 4206 4666 \n",
       "L 4206 3566 \n",
       "L 3822 3566 \n",
       "L 3822 4294 \n",
       "L 2450 4294 \n",
       "L 2450 331 \n",
       "L 3047 331 \n",
       "L 3047 0 \n",
       "L 1222 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-54\" transform=\"scale(0.015625)\"/>\n",
       "      <path d=\"M 666 325 \n",
       "Q 666 500 786 622 \n",
       "Q 906 744 1081 744 \n",
       "Q 1256 744 1376 622 \n",
       "Q 1497 500 1497 325 \n",
       "Q 1497 150 1378 29 \n",
       "Q 1259 -91 1081 -91 \n",
       "Q 903 -91 784 29 \n",
       "Q 666 150 666 325 \n",
       "z\n",
       "M 666 2363 \n",
       "Q 666 2538 786 2658 \n",
       "Q 906 2778 1081 2778 \n",
       "Q 1259 2778 1378 2659 \n",
       "Q 1497 2541 1497 2363 \n",
       "Q 1497 2184 1378 2065 \n",
       "Q 1259 1947 1081 1947 \n",
       "Q 906 1947 786 2067 \n",
       "Q 666 2188 666 2363 \n",
       "z\n",
       "\" id=\"DejaVuSerif-3a\" transform=\"scale(0.015625)\"/>\n",
       "      <path d=\"M 1581 331 \n",
       "L 2175 331 \n",
       "L 2175 0 \n",
       "L 353 0 \n",
       "L 353 331 \n",
       "L 947 331 \n",
       "L 947 4331 \n",
       "L 353 4331 \n",
       "L 353 4666 \n",
       "L 2175 4666 \n",
       "L 2175 4331 \n",
       "L 1581 4331 \n",
       "L 1581 331 \n",
       "z\n",
       "\" id=\"DejaVuSerif-49\" transform=\"scale(0.015625)\"/>\n",
       "      <path d=\"M 281 1959 \n",
       "L 1881 1959 \n",
       "L 1881 1472 \n",
       "L 281 1472 \n",
       "L 281 1959 \n",
       "z\n",
       "\" id=\"DejaVuSerif-2d\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#DejaVuSerif-54\"/>\n",
       "     <use x=\"58.949219\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"119.154297\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "     <use x=\"183.167969\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"214.955078\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "     <use x=\"278.578125\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "     <use x=\"342.201172\" xlink:href=\"#DejaVuSerif-3a\"/>\n",
       "     <use x=\"375.892578\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"407.679688\" xlink:href=\"#DejaVuSerif-49\"/>\n",
       "     <use x=\"447.181641\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "     <use x=\"511.585938\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "     <use x=\"545.375\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"609.388672\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"668.568359\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"732.582031\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"780.384766\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"839.564453\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_17\">\n",
       "    <path d=\"M 344.229261 181.798125 \n",
       "L 597.865625 181.798125 \n",
       "L 597.865625 18.718125 \n",
       "L 344.229261 18.718125 \n",
       "z\n",
       "\" style=\"fill:#ffffff;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_18\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 355.758187 181.798125 \n",
       "L 374.580923 181.798125 \n",
       "L 374.580923 100.352829 \n",
       "L 355.758187 100.352829 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_19\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 379.286607 181.798125 \n",
       "L 398.109342 181.798125 \n",
       "L 398.109342 90.882446 \n",
       "L 379.286607 90.882446 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_20\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 402.815026 181.798125 \n",
       "L 421.637762 181.798125 \n",
       "L 421.637762 88.988369 \n",
       "L 402.815026 88.988369 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_21\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 426.343446 181.798125 \n",
       "L 445.166182 181.798125 \n",
       "L 445.166182 81.412062 \n",
       "L 426.343446 81.412062 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_22\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 449.871866 181.798125 \n",
       "L 468.694601 181.798125 \n",
       "L 468.694601 77.623909 \n",
       "L 449.871866 77.623909 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_23\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 473.400285 181.798125 \n",
       "L 492.223021 181.798125 \n",
       "L 492.223021 75.729832 \n",
       "L 473.400285 75.729832 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_24\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 496.928705 181.798125 \n",
       "L 515.75144 181.798125 \n",
       "L 515.75144 73.835756 \n",
       "L 496.928705 73.835756 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_25\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 520.457124 181.798125 \n",
       "L 539.27986 181.798125 \n",
       "L 539.27986 64.365372 \n",
       "L 520.457124 64.365372 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_26\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 543.985544 181.798125 \n",
       "L 562.80828 181.798125 \n",
       "L 562.80828 43.530529 \n",
       "L 543.985544 43.530529 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_27\">\n",
       "    <path clip-path=\"url(#p9aafa9e479)\" d=\"M 567.513964 181.798125 \n",
       "L 586.336699 181.798125 \n",
       "L 586.336699 26.483839 \n",
       "L 567.513964 26.483839 \n",
       "z\n",
       "\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_35\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"365.169555\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"365.169555\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_20\">\n",
       "      <!-- adam smith -->\n",
       "      <g transform=\"translate(367.92893 244.5575)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"59.619141\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"123.632812\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"183.251953\" xlink:href=\"#DejaVuSerif-6d\"/>\n",
       "       <use x=\"278.076172\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"309.863281\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"361.181641\" xlink:href=\"#DejaVuSerif-6d\"/>\n",
       "       <use x=\"456.005859\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"487.988281\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"528.173828\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"388.697974\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"388.697974\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- friedrich hayek -->\n",
       "      <g transform=\"translate(391.386256 262.52625)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-66\"/>\n",
       "       <use x=\"37.011719\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"84.814453\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"116.796875\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"175.976562\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"239.990234\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"287.792969\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"319.775391\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"375.78125\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"440.185547\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"471.972656\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"536.376953\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"595.996094\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "       <use x=\"652.490234\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"711.669922\" xlink:href=\"#DejaVuSerif-6b\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_13\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"412.226394\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"412.226394\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- ideology -->\n",
       "      <g transform=\"translate(414.914675 228.1075)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"31.982422\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"95.996094\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"155.175781\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"215.380859\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"247.363281\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"307.568359\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"371.582031\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_14\">\n",
       "     <g id=\"line2d_41\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"435.754814\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_42\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"435.754814\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- slavery -->\n",
       "      <g transform=\"translate(438.443095 221.58875)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 1581 0 \n",
       "L 359 2988 \n",
       "L -19 2988 \n",
       "L -19 3322 \n",
       "L 1509 3322 \n",
       "L 1509 2988 \n",
       "L 978 2988 \n",
       "L 1913 703 \n",
       "L 2847 2988 \n",
       "L 2350 2988 \n",
       "L 2350 3322 \n",
       "L 3597 3322 \n",
       "L 3597 2988 \n",
       "L 3225 2988 \n",
       "L 2003 0 \n",
       "L 1581 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-76\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"51.318359\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"83.300781\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"142.919922\" xlink:href=\"#DejaVuSerif-76\"/>\n",
       "       <use x=\"199.414062\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"258.59375\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"306.396484\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_15\">\n",
       "     <g id=\"line2d_43\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"459.283233\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_44\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"459.283233\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- criticism of capitalism -->\n",
       "      <g transform=\"translate(462.042608 297.73875)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"56.005859\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"103.808594\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"135.791016\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"175.976562\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"207.958984\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"263.964844\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"295.947266\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"347.265625\" xlink:href=\"#DejaVuSerif-6d\"/>\n",
       "       <use x=\"442.089844\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"473.876953\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"534.082031\" xlink:href=\"#DejaVuSerif-66\"/>\n",
       "       <use x=\"571.09375\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"602.880859\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"658.886719\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"718.505859\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"782.519531\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"814.501953\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"854.6875\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"914.306641\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"946.289062\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"978.271484\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"1029.589844\" xlink:href=\"#DejaVuSerif-6d\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_16\">\n",
       "     <g id=\"line2d_45\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"482.811653\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_46\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"482.811653\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- anthropology -->\n",
       "      <g transform=\"translate(485.499934 252.652812)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"59.619141\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"124.023438\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"164.208984\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"228.613281\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"276.416016\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"336.621094\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"400.634766\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"460.839844\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"492.822266\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"553.027344\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"617.041016\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_17\">\n",
       "     <g id=\"line2d_47\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"506.340073\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_48\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"506.340073\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- glossary of economics -->\n",
       "      <g transform=\"translate(509.028354 297.06375)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"64.013672\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"95.996094\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"156.201172\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"207.519531\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"258.837891\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"318.457031\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"366.259766\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "       <use x=\"422.753906\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"454.541016\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"514.746094\" xlink:href=\"#DejaVuSerif-66\"/>\n",
       "       <use x=\"551.757812\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"583.544922\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"642.724609\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"698.730469\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"758.935547\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"823.339844\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"883.544922\" xlink:href=\"#DejaVuSerif-6d\"/>\n",
       "       <use x=\"978.369141\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"1010.351562\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"1066.357422\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_18\">\n",
       "     <g id=\"line2d_49\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"529.868492\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_50\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"529.868492\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- index of social and political philosophy articles -->\n",
       "      <g transform=\"translate(532.556774 423.110625)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 1863 2028 \n",
       "L 2559 2988 \n",
       "L 2113 2988 \n",
       "L 2113 3322 \n",
       "L 3391 3322 \n",
       "L 3391 2988 \n",
       "L 2950 2988 \n",
       "L 2059 1759 \n",
       "L 3097 331 \n",
       "L 3531 331 \n",
       "L 3531 0 \n",
       "L 1997 0 \n",
       "L 1997 331 \n",
       "L 2419 331 \n",
       "L 1697 1325 \n",
       "L 972 331 \n",
       "L 1403 331 \n",
       "L 1403 0 \n",
       "L 141 0 \n",
       "L 141 331 \n",
       "L 581 331 \n",
       "L 1497 1594 \n",
       "L 488 2988 \n",
       "L 78 2988 \n",
       "L 78 3322 \n",
       "L 1563 3322 \n",
       "L 1563 2988 \n",
       "L 1166 2988 \n",
       "L 1863 2028 \n",
       "z\n",
       "\" id=\"DejaVuSerif-78\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"31.982422\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"96.386719\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"160.400391\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"219.580078\" xlink:href=\"#DejaVuSerif-78\"/>\n",
       "       <use x=\"275.976562\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"307.763672\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"367.96875\" xlink:href=\"#DejaVuSerif-66\"/>\n",
       "       <use x=\"404.980469\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"436.767578\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"488.085938\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"548.291016\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"604.296875\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"636.279297\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"695.898438\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"727.880859\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"759.667969\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"819.287109\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"883.691406\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"947.705078\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"979.492188\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"1043.505859\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"1103.710938\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"1135.693359\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"1167.675781\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"1207.861328\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"1239.84375\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"1295.849609\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"1355.46875\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"1387.451172\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"1419.238281\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"1483.251953\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"1547.65625\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"1579.638672\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"1611.621094\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"1671.826172\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"1723.144531\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"1783.349609\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "       <use x=\"1847.363281\" xlink:href=\"#DejaVuSerif-68\"/>\n",
       "       <use x=\"1911.767578\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "       <use x=\"1968.261719\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"2000.048828\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"2059.667969\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"2107.470703\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"2147.65625\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"2179.638672\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"2235.644531\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"2267.626953\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"2326.806641\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_19\">\n",
       "     <g id=\"line2d_51\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"553.396912\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_52\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"553.396912\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- index of economics articles -->\n",
       "      <g transform=\"translate(556.156287 323.373125)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"31.982422\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"96.386719\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"160.400391\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"219.580078\" xlink:href=\"#DejaVuSerif-78\"/>\n",
       "       <use x=\"275.976562\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"307.763672\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"367.96875\" xlink:href=\"#DejaVuSerif-66\"/>\n",
       "       <use x=\"404.980469\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"436.767578\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"495.947266\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"551.953125\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"612.158203\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"676.5625\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"736.767578\" xlink:href=\"#DejaVuSerif-6d\"/>\n",
       "       <use x=\"831.591797\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"863.574219\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"919.580078\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"970.898438\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"1002.685547\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"1062.304688\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"1110.107422\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"1150.292969\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"1182.275391\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"1238.28125\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"1270.263672\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"1329.443359\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_20\">\n",
       "     <g id=\"line2d_53\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"576.925332\" xlink:href=\"#mcbc08eb5a5\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_54\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"576.925332\" xlink:href=\"#me73616a5f4\" y=\"18.718125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- index of sociology articles -->\n",
       "      <g transform=\"translate(579.613613 317.20125)rotate(-90)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"31.982422\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "       <use x=\"96.386719\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "       <use x=\"160.400391\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"219.580078\" xlink:href=\"#DejaVuSerif-78\"/>\n",
       "       <use x=\"275.976562\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"307.763672\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"367.96875\" xlink:href=\"#DejaVuSerif-66\"/>\n",
       "       <use x=\"404.980469\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"436.767578\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "       <use x=\"488.085938\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"548.291016\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"604.296875\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"636.279297\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"696.484375\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"728.466797\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "       <use x=\"788.671875\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "       <use x=\"852.685547\" xlink:href=\"#DejaVuSerif-79\"/>\n",
       "       <use x=\"909.179688\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "       <use x=\"940.966797\" xlink:href=\"#DejaVuSerif-61\"/>\n",
       "       <use x=\"1000.585938\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "       <use x=\"1048.388672\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "       <use x=\"1088.574219\" xlink:href=\"#DejaVuSerif-69\"/>\n",
       "       <use x=\"1120.556641\" xlink:href=\"#DejaVuSerif-63\"/>\n",
       "       <use x=\"1176.5625\" xlink:href=\"#DejaVuSerif-6c\"/>\n",
       "       <use x=\"1208.544922\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "       <use x=\"1267.724609\" xlink:href=\"#DejaVuSerif-73\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_55\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"344.229261\" xlink:href=\"#md8c0b97564\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_56\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"597.865625\" xlink:href=\"#m4e0ab084e9\" y=\"181.798125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(334.366761 185.597344)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_57\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"344.229261\" xlink:href=\"#md8c0b97564\" y=\"143.916592\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_58\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"597.865625\" xlink:href=\"#m4e0ab084e9\" y=\"143.916592\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- 20 -->\n",
       "      <g transform=\"translate(328.004261 147.715811)scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSerif-32\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_59\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"344.229261\" xlink:href=\"#md8c0b97564\" y=\"106.035059\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_60\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"597.865625\" xlink:href=\"#m4e0ab084e9\" y=\"106.035059\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_32\">\n",
       "      <!-- 40 -->\n",
       "      <g transform=\"translate(328.004261 109.834278)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2234 1581 \n",
       "L 2234 4063 \n",
       "L 641 1581 \n",
       "L 2234 1581 \n",
       "z\n",
       "M 3609 0 \n",
       "L 1484 0 \n",
       "L 1484 331 \n",
       "L 2234 331 \n",
       "L 2234 1247 \n",
       "L 197 1247 \n",
       "L 197 1588 \n",
       "L 2241 4750 \n",
       "L 2859 4750 \n",
       "L 2859 1581 \n",
       "L 3750 1581 \n",
       "L 3750 1247 \n",
       "L 2859 1247 \n",
       "L 2859 331 \n",
       "L 3609 331 \n",
       "L 3609 0 \n",
       "z\n",
       "\" id=\"DejaVuSerif-34\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-34\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_61\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"344.229261\" xlink:href=\"#md8c0b97564\" y=\"68.153526\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_62\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"597.865625\" xlink:href=\"#m4e0ab084e9\" y=\"68.153526\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_33\">\n",
       "      <!-- 60 -->\n",
       "      <g transform=\"translate(328.004261 71.952744)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2094 219 \n",
       "Q 2534 219 2771 542 \n",
       "Q 3009 866 3009 1472 \n",
       "Q 3009 2078 2771 2401 \n",
       "Q 2534 2725 2094 2725 \n",
       "Q 1647 2725 1412 2412 \n",
       "Q 1178 2100 1178 1509 \n",
       "Q 1178 888 1415 553 \n",
       "Q 1653 219 2094 219 \n",
       "z\n",
       "M 1075 2569 \n",
       "Q 1288 2803 1556 2918 \n",
       "Q 1825 3034 2163 3034 \n",
       "Q 2859 3034 3264 2615 \n",
       "Q 3669 2197 3669 1472 \n",
       "Q 3669 763 3233 336 \n",
       "Q 2797 -91 2069 -91 \n",
       "Q 1278 -91 853 498 \n",
       "Q 428 1088 428 2181 \n",
       "Q 428 3406 931 4078 \n",
       "Q 1434 4750 2350 4750 \n",
       "Q 2597 4750 2869 4703 \n",
       "Q 3141 4656 3425 4563 \n",
       "L 3425 3794 \n",
       "L 3072 3794 \n",
       "Q 3034 4109 2831 4275 \n",
       "Q 2628 4441 2284 4441 \n",
       "Q 1678 4441 1381 3981 \n",
       "Q 1084 3522 1075 2569 \n",
       "z\n",
       "\" id=\"DejaVuSerif-36\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-36\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_63\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"344.229261\" xlink:href=\"#md8c0b97564\" y=\"30.271993\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"line2d_64\">\n",
       "      <g>\n",
       "       <use style=\"stroke:#000000;stroke-width:0.5;\" x=\"597.865625\" xlink:href=\"#m4e0ab084e9\" y=\"30.271993\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_34\">\n",
       "      <!-- 80 -->\n",
       "      <g transform=\"translate(328.004261 34.071211)scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path d=\"M 2981 1275 \n",
       "Q 2981 1775 2732 2051 \n",
       "Q 2484 2328 2034 2328 \n",
       "Q 1584 2328 1336 2051 \n",
       "Q 1088 1775 1088 1275 \n",
       "Q 1088 772 1336 495 \n",
       "Q 1584 219 2034 219 \n",
       "Q 2484 219 2732 495 \n",
       "Q 2981 772 2981 1275 \n",
       "z\n",
       "M 2853 3541 \n",
       "Q 2853 3966 2637 4203 \n",
       "Q 2422 4441 2034 4441 \n",
       "Q 1650 4441 1433 4203 \n",
       "Q 1216 3966 1216 3541 \n",
       "Q 1216 3113 1433 2875 \n",
       "Q 1650 2638 2034 2638 \n",
       "Q 2422 2638 2637 2875 \n",
       "Q 2853 3113 2853 3541 \n",
       "z\n",
       "M 2516 2484 \n",
       "Q 3047 2413 3344 2092 \n",
       "Q 3641 1772 3641 1275 \n",
       "Q 3641 619 3225 264 \n",
       "Q 2809 -91 2034 -91 \n",
       "Q 1263 -91 845 264 \n",
       "Q 428 619 428 1275 \n",
       "Q 428 1772 725 2092 \n",
       "Q 1022 2413 1556 2484 \n",
       "Q 1084 2569 832 2842 \n",
       "Q 581 3116 581 3541 \n",
       "Q 581 4103 968 4426 \n",
       "Q 1356 4750 2034 4750 \n",
       "Q 2713 4750 3100 4426 \n",
       "Q 3488 4103 3488 3541 \n",
       "Q 3488 3116 3236 2842 \n",
       "Q 2984 2569 2516 2484 \n",
       "z\n",
       "\" id=\"DejaVuSerif-38\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSerif-38\"/>\n",
       "       <use x=\"63.623047\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_35\">\n",
       "     <!-- count -->\n",
       "     <g transform=\"translate(321.924574 114.518281)rotate(-90)scale(0.1 -0.1)\">\n",
       "      <use xlink:href=\"#DejaVuSerif-63\"/>\n",
       "      <use x=\"56.005859\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "      <use x=\"116.210938\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "      <use x=\"180.615234\" xlink:href=\"#DejaVuSerif-6e\"/>\n",
       "      <use x=\"245.019531\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_28\">\n",
       "    <path d=\"M 344.229261 181.798125 \n",
       "L 344.229261 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_29\">\n",
       "    <path d=\"M 597.865625 181.798125 \n",
       "L 597.865625 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_30\">\n",
       "    <path d=\"M 344.229261 181.798125 \n",
       "L 597.865625 181.798125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_31\">\n",
       "    <path d=\"M 344.229261 18.718125 \n",
       "L 597.865625 18.718125 \n",
       "\" style=\"fill:none;stroke:#000000;stroke-linecap:square;stroke-linejoin:miter;stroke-width:0.5;\"/>\n",
       "   </g>\n",
       "   <g id=\"text_36\">\n",
       "    <!-- Top 10: Out-degree -->\n",
       "    <g transform=\"translate(412.161193 12.718125)scale(0.12 -0.12)\">\n",
       "     <defs>\n",
       "      <path d=\"M 2625 244 \n",
       "Q 3391 244 3781 770 \n",
       "Q 4172 1297 4172 2328 \n",
       "Q 4172 3363 3781 3889 \n",
       "Q 3391 4416 2625 4416 \n",
       "Q 1856 4416 1465 3889 \n",
       "Q 1075 3363 1075 2328 \n",
       "Q 1075 1297 1465 770 \n",
       "Q 1856 244 2625 244 \n",
       "z\n",
       "M 2625 -91 \n",
       "Q 2150 -91 1751 65 \n",
       "Q 1353 222 1050 525 \n",
       "Q 700 875 529 1319 \n",
       "Q 359 1763 359 2328 \n",
       "Q 359 2894 529 3339 \n",
       "Q 700 3784 1050 4134 \n",
       "Q 1356 4441 1750 4595 \n",
       "Q 2144 4750 2625 4750 \n",
       "Q 3641 4750 4266 4084 \n",
       "Q 4891 3419 4891 2328 \n",
       "Q 4891 1769 4719 1320 \n",
       "Q 4547 872 4197 525 \n",
       "Q 3891 219 3497 64 \n",
       "Q 3103 -91 2625 -91 \n",
       "z\n",
       "\" id=\"DejaVuSerif-4f\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#DejaVuSerif-54\"/>\n",
       "     <use x=\"58.949219\" xlink:href=\"#DejaVuSerif-6f\"/>\n",
       "     <use x=\"119.154297\" xlink:href=\"#DejaVuSerif-70\"/>\n",
       "     <use x=\"183.167969\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"214.955078\" xlink:href=\"#DejaVuSerif-31\"/>\n",
       "     <use x=\"278.578125\" xlink:href=\"#DejaVuSerif-30\"/>\n",
       "     <use x=\"342.201172\" xlink:href=\"#DejaVuSerif-3a\"/>\n",
       "     <use x=\"375.892578\" xlink:href=\"#DejaVuSerif-20\"/>\n",
       "     <use x=\"407.679688\" xlink:href=\"#DejaVuSerif-4f\"/>\n",
       "     <use x=\"489.662109\" xlink:href=\"#DejaVuSerif-75\"/>\n",
       "     <use x=\"554.066406\" xlink:href=\"#DejaVuSerif-74\"/>\n",
       "     <use x=\"594.251953\" xlink:href=\"#DejaVuSerif-2d\"/>\n",
       "     <use x=\"628.041016\" xlink:href=\"#DejaVuSerif-64\"/>\n",
       "     <use x=\"692.054688\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"751.234375\" xlink:href=\"#DejaVuSerif-67\"/>\n",
       "     <use x=\"815.248047\" xlink:href=\"#DejaVuSerif-72\"/>\n",
       "     <use x=\"863.050781\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "     <use x=\"922.230469\" xlink:href=\"#DejaVuSerif-65\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pd1904f2520\">\n",
       "   <rect height=\"163.08\" width=\"253.636364\" x=\"39.865625\" y=\"18.718125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p9aafa9e479\">\n",
       "   <rect height=\"163.08\" width=\"253.636364\" x=\"344.229261\" y=\"18.718125\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1200x360 with 2 Axes>"
      ]
     },
     "metadata": {
      "needs_background": "light"
     },
     "output_type": "display_data"
    }
   ],
   "source": [
    " def get_high_k_nodes(G: nx.DiGraph, degree: str=\"In\", n: int=10):\n",
    "    \"\"\"\n",
    "    Function to get the name of nodes with a high k and their corresponding k\n",
    "    \"\"\"\n",
    "    if degree==\"In\":\n",
    "        degree_list = sorted(G.in_degree(), key=lambda tup: tup[1], reverse=True)[0:n]\n",
    "    elif degree==\"Out\":\n",
    "        degree_list = sorted(G.out_degree(), key=lambda tup: tup[1], reverse=True)[0:n]\n",
    "    x = [\" \".join(i[0].split(\"_\")) for i in degree_list]\n",
    "    y = [i[1] for i in degree_list]\n",
    "    x.reverse()\n",
    "    y.reverse()\n",
    "    return x, y\n",
    "\n",
    "def draw_high_k_nodes(G: nx.DiGraph):\n",
    "    \"\"\"\n",
    "    Draws two plots based on nodes in a network with a high in-degree and out-degree.\n",
    "    \"\"\"\n",
    "    fig, axs = plt.subplots(ncols=2, dpi = 120, figsize = (10,3))\n",
    "    for j, d in enumerate([\"In\", \"Out\"]):\n",
    "        x, y = get_high_k_nodes(G, degree = d)\n",
    "        axs[j].bar(x, y, color = \"k\")\n",
    "        axs[j].set_ylabel('count')\n",
    "        axs[j].set_xticklabels(x, rotation = 90)\n",
    "        axs[j].set_title(f'Top 10: {d}-degree')\n",
    "        axs[j].minorticks_off()\n",
    "        \n",
    "warnings.filterwarnings('ignore')  # Hide UserWarning\n",
    "draw_high_k_nodes(G) "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "0227ca4b",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-11-23T14:15:58.329171Z",
     "start_time": "2021-11-23T14:15:58.318613Z"
    }
   },
   "source": [
    "The inspection of the pages with high degrees reveals the most central pages are what can be labelled as \"metapages\", that is describing social science disciplines or broad societal phenomenons such as religion or language. Naturally, a large share of the other pages refer to these, why three out of five disciplines' Wikipedia pages are among the pages with the highest in-degree. Interestingly, some of the most prominent founding fathers of economics [Friedrich Hayek](https://en.wikipedia.org/wiki/Friedrich_Hayek) and [Adam Smith](https://en.wikipedia.org/wiki/Adam_Smith) seem to be some of the most central persons to the social sciences. "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "7f97717c",
   "metadata": {},
   "source": [
    "Next we visually inspect our network by drawing it. In order to enhance readability of our plot we turn the directed network into an undirected network and specify Force Atlas 2 as our layout algorithm. Furthermore we specify node sizes according to degree and colour according to discipline."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "id": "23f5db44",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:50:28.350762Z",
     "start_time": "2021-12-08T20:48:34.799196Z"
    }
   },
   "outputs": [],
   "source": [
    "%%capture\n",
    "G = nx.to_undirected(G)\n",
    "\n",
    "def change_node_names(node):\n",
    "    \"\"\"\n",
    "    Replaces \"_\" to \" \" in node names.\n",
    "    \"\"\"\n",
    "    return \" \".join(node.split(\"_\"))\n",
    "G = nx.relabel_nodes(G, change_node_names)\n",
    "\n",
    "# Position algorithm\n",
    "forceatlas2 = ForceAtlas2(gravity=1)\n",
    "positions = forceatlas2.forceatlas2_networkx_layout(G, pos=None, iterations=2000)\n",
    "\n",
    "# Setting colours\n",
    "def get_colors_palette_from_parent(G: nx.DiGraph) -> dict:\n",
    "    \"\"\"\n",
    "    Creates a color palette given the parent attributes of the \n",
    "    nodes in a network.\n",
    "    \"\"\"\n",
    "    disciplines = set([G.nodes[node][\"parent\"] for node in G.nodes()])\n",
    "    col_pal = palettes.viridis(len(disciplines))\n",
    "    col_pal = {parent: col_pal[key] for key, parent in enumerate(disciplines)}\n",
    "    return col_pal\n",
    "\n",
    "col_pal = get_colors_palette_from_parent(G)\n",
    "\n",
    "def get_color_list_from_palette(G: nx.Graph, col_pal: dict=col_pal) -> list:\n",
    "    \"\"\"\n",
    "    Creates a list of colors given the parent attribute of a node\n",
    "    and its color defined in the color palette.\n",
    "    \"\"\"\n",
    "    return [col_pal[G.nodes[i][\"parent\"]] for i in G.nodes]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "id": "ae7ac797",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:50:28.647474Z",
     "start_time": "2021-12-08T20:50:28.354758Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "  <div class=\"bk-root\" id=\"f2455d81-0c7a-4c77-8999-2d24fd3786f4\" data-root-id=\"1036\"></div>\n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "(function(root) {\n",
       "  function embed_document(root) {\n",
       "    \n",
       "  var docs_json = {\"ed309431-8520-45ae-8831-6397d519dd8b\":{\"defs\":[],\"roots\":{\"references\":[{\"attributes\":{\"above\":[{\"id\":\"1062\"}],\"below\":[{\"id\":\"1043\"}],\"center\":[{\"id\":\"1046\"},{\"id\":\"1050\"}],\"left\":[{\"id\":\"1047\"}],\"renderers\":[{\"id\":\"1063\"}],\"title\":{\"id\":\"1099\"},\"toolbar\":{\"id\":\"1056\"},\"x_range\":{\"id\":\"1034\"},\"x_scale\":{\"id\":\"1039\"},\"y_range\":{\"id\":\"1035\"},\"y_scale\":{\"id\":\"1041\"}},\"id\":\"1036\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{},\"id\":\"1120\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"1101\",\"type\":\"AllLabels\"},{\"attributes\":{},\"id\":\"1051\",\"type\":\"PanTool\"},{\"attributes\":{},\"id\":\"1119\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"1106\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"1052\",\"type\":\"WheelZoomTool\"},{\"attributes\":{},\"id\":\"1104\",\"type\":\"AllLabels\"},{\"attributes\":{\"data_source\":{\"id\":\"1069\"},\"glyph\":{\"id\":\"1094\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1071\"}},\"id\":\"1070\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"1116\",\"type\":\"NodesOnly\"},{\"attributes\":{\"formatter\":{\"id\":\"1103\"},\"major_label_policy\":{\"id\":\"1101\"},\"ticker\":{\"id\":\"1048\"},\"visible\":false},\"id\":\"1047\",\"type\":\"LinearAxis\"},{\"attributes\":{\"line_alpha\":{\"value\":0.8},\"line_width\":{\"value\":0.1}},\"id\":\"1094\",\"type\":\"MultiLine\"},{\"attributes\":{},\"id\":\"1107\",\"type\":\"NodesOnly\"},{\"attributes\":{},\"id\":\"1053\",\"type\":\"SaveTool\"},{\"attributes\":{\"data\":{\"alpha\":[0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75],\"depth\":[0,0,1,2,1,0,1,0,2,0,1,1,1,1,1,1,1,0,0,1,1,1,2,1,0,1,2,2,1,1,1,2,1,2,0,0,2,2,1,2,2,0,1,2,2,2,2,2,1,1,2,0,2,1,1,0,0,1,2,2,0,0,2,1,0,1,0,2,2,2,2,0,0,2,0,0,0,2,0,2,0,1,1,2,0,1,1,1,0,2,0,1,2,2,2,1,1,2,2,1,2,2,0,2,1,0,1,2,0,2,0,1,0,2,0,1,1,1,0,1,1,1,0,1,1,0,1,1,0,0,1,0,0,0,2,0,1,0,2,2,2,2,0,2,1,0,0,2,0,0,0,0,1,1,0,0,1,2,1,2,2,2,1,2,1,1,2,1,1,2,1,1,1,1,1,2,1,1,1,2,2,2,2,2,1,1,1,1,1,2,1,2,2,1,1,1,1,1,1,2,1,2,1,2,1,1,1,2,2,2,2,2,2,1,2,1,2,1,1,2,2,1,0,0,1,0,0,0,0,1,0,0,1,1,0,1,1,1,1,1,0,0,1,0,0,1,0,1,1,1,0,0,1,0,1,0,1,1,1,1,0,1,1,0,1,1,1,1,0,1,0,1,1,1,1,1,2,1,0,2,1,1,0,2,0,0,1,2,2,1,0,1,2,1,1,1,0,1,0,1,1,1,1,2,1,1,2,1,0,2,2,1,0,1,0,0,1,1,1,1,0,0,2,0,0,2,1,1,0,0,1,2,0,1,1,0,0,0,2,1,2,1,1,0,1,0,0,2,2,0,0,0,1,2,0,0,2,0,0,1,1,1,1,2,2,0,0,1,0,0,1,0,0,1,1,0,1,1,2,0,1,1,0,0,0,0,0,0,2,0,1,0,0,0,1,0,0,0,0,2,2,1,2,2,1,2,2,2,2,1,0,0,1,1,0,0,0,0,0,0,0,0,0,1,1,1,2,1,2,1,1,0,1,0,0,0,2,0,0,0,0,0,0,0,2,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,1,1,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,2,1,2,1,2,2,2,2,2,1,1,2,2,1,2,2,2,2,2,1,2,2,1,1,2,2,2,1,2,2,1,2,1,2,2,2,2,1,1,1,1,2,2,2,2,1,2,2,1,1,2,1,1,1,2,1,2,2,1,1,2,1,1,1,2,1,1,1,2,1,2,1,1,2,2,1,0,2,1,2,1,1,1,1,2,2,1,1,2,1,1,1,1,2,1,2,2,1,1,2,2,2,1,1,2,1,1,1,2,1,2,2,2,2,2,1,1,2,2,1,1,2,2,2,2,2,2,1,2,1,2,2,2,2,2,1,2,2,2,1,1,2,2,1,2,2,2,1,2,2,2,2,2,1,2,2,2,2,2,1,2,1,2,1,2,1,1,2,2,2,2,2,1,1,1,1,1,2,1,2,1,2,2,2,1,1,1,2,2,2,1,1,1,1,2,2,1,1,1,2,1,1,1,2,2,1,1,1,2,2,1,2,1,1,2,2,2,1,2,2,1,1,1,1,2,1,2,2,2,1,1,1,2,2,1,2,2,1,1,1,1,1,1,1,2,2,1,2,1,1,1,2,2,1,1,1,1,1,1,1,2,1,2,1,1,2,1,1,1,1,1,1,2,2,1,1,1,2,2,1,1,2,1,1,1,1,1,1,1,2,2,1,2,1,2,2,2,1,1,1,1,1,1,1,2,1,1,2,1,2,1,2,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,2,1,1,1,1,2,2,1,1,2,1,1,1,1,0,1,2,2,2,1,1,1,1,1,1,1,1,1,1,2,2,1,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,1,1,1,1,1,1,1,1,2,1,2,1,1,1,1,2,1,2,2,2,2,2,1,1,1,1,2,2,1,1,2,1,1,1,2,2,1,1,1,1,1,1,2,2,1,1,1,1,1,1,2,2,2,2,1,1,1,2,2,1,1,1,1,2,1,1,1,1,1,2,2,1,2,2,1,1,1,1,1,2,1,1,1,2,1,2,1,2,1,1,2,1,1,1,2,1,1,1,1,1,2,1,1,1,2,1,1,2,1,2,1,1,2,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,2,1,2,1,2,1,2,2,1,1,1,1,1,1,1,1,1,2,1,2,1,1,1,1,1,1,1,1,2,2,2,2,1,1,1,1,1,1,2,1,1,2,1,1,1,1,1,1,2,1,1,1,1,1,2,1,1,1,1,1,1,1,2,1,2,1,1,2,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,2,1,2,1,2,1,1,1,1,1,2,2,2,1,1,1,2,2,1,1,1,1,2,2,1,2,1,2,1,1,1,1,1,2,1,2,1,2,1,2,1,2,2,2,2,1,2,1,1,1,1,2,1,1,2,2,2,2,2,1,2,1,2,2,2,1,2,1,2,2,2,2,2,1,2,1,2,1,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,2,2,1,1,1,2,1,1,1,2,2,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,1,1,1,1,1,2,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,2,2,1,1,2,1,1,1,1,2,1,1,1,2,2,2,1,1,1,1,1,1,1,1,1,1,2,1,2,1,2,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,2,1,1,2,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,2,2,1,1,2,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,1,1,1,2,1,1,2,1,1,1,1,1,1,1,2,1,1,1,1,1,2,1,1,1,1,2,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,2,1,1,1,1,2,1,1,2,1,1,2,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,2,1,1,1,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,1,1,1,2,2,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,1,1,1,1,1,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,1,2,1,1,1,2,2,1,2,1,2,2,2,2,2,1,1,2,1,2,1,1,1,1,1,2,1,1,1,2,2,2,2,2,1,2,2,1,2,1,1,2,2,1,1,1,2,2,1,2,1,1,2,1,1,2,2,1,2,1,1,1,2,2,2,1,2,2,1,1,1,2,2,2,1,2,1,2,1,1,1,1,2,1,2,2,1,1,1,1,1,1,1,1,2,1,1,2,2,2,2,1,2,1,1,1,1,1,1,1,2,1,1,1,2,2,1,1,2,1,1,2,2,2,1,1,2,1,2,1,1,2,2,2,2,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,2,2,1,1,1,1,1,1,1,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2],\"index\":[\"political science\",\"comparative politics\",\"public administration\",\"technocracy\",\"foreign policy\",\"biology and political orientation\",\"ideology\",\"political methodology\",\"social policy\",\"history of political science\",\"philip converse\",\"evolutionary psychology\",\"experimental political science\",\"modernity\",\"nation state\",\"structure and agency\",\"pi sigma alpha\",\"anthropology\",\"archaeology\",\"linguistics\",\"jurisprudence\",\"area studies\",\"historical sociology\",\"human ecology\",\"world values survey\",\"religion\",\"left-wing politics\",\"joseph schumpeter\",\"non-sampling error\",\"coverage error\",\"psychometrics\",\"statistical inference\",\"opinion poll\",\"afrobarometer\",\"comparative study of electoral systems\",\"voter turnout\",\"tactical voting\",\"political party\",\"slavery\",\"human development index\",\"anthony downs\",\"political groups of the european parliament\",\"civil service\",\"london school of economics\",\"eurosphere\",\"intergovernmentalism\",\"carl joachim friedrich\",\"stein rokkan\",\"otto kirchheimer\",\"comparative historical research\",\"composite index of national capability\",\"democracy-dictatorship index\",\"global terrorism index\",\"behavioralism\",\"international political science association\",\"strict father model\",\"nurturant parent model\",\"developmental psychology\",\"attachment parenting\",\"creativity\",\"systems theory in political science\",\"legitimation crisis\",\"constitutionalism\",\"social integration\",\"public engagement\",\"filter bubble\",\"digital era governance\",\"debate\",\"helen margetts\",\"cyberocracy\",\"e-government\",\"bureau-shaping model\",\"institutional analysis\",\"elinor ostrom\",\"minimal effects hypothesis\",\"political alienation\",\"perestroika movement (political science)\",\"perestroika\",\"effective number of parties\",\"party system\",\"political communication\",\"social media use in politics\",\"propaganda\",\"symbol\",\"serfdom in tibet controversy\",\"serfdom\",\"social system\",\"peasant\",\"rowman & littlefield award in innovative teaching\",\"international law\",\"horseshoe theory\",\"totalitarianism\",\"populism\",\"left-wing populism\",\"left\\u2013right political spectrum\",\"nolan chart\",\"political research associates\",\"third way\",\"nazism\",\"social imperialism\",\"reactionary\",\"hardline\",\"politics of memory\",\"collective memory\",\"cultural memory\",\"valence issue\",\"supply and demand\",\"gun control\",\"international centre for black sea studies\",\"international relations and security network\",\"public comment\",\"freedom\",\"open philanthropy (doctrine)\",\"theory of change\",\"ethnosymbolism\",\"language\",\"constitutional patriotism\",\"ethnoarchaeology\",\"ethnobiology\",\"ethnozoology\",\"netnography\",\"ethnomedicine\",\"ethnomuseology\",\"ethnic religion\",\"nation-building\",\"moderation theory\",\"median voter theorem\",\"radicalization\",\"tryph\\u00e9\",\"nominate (scaling method)\",\"scale analysis (statistics)\",\"gladstone professor of government\",\"multistakeholder governance\",\"bureaucratic drift\",\"journal of theoretical politics\",\"peace\\u2013industrial complex\",\"peace and conflict studies\",\"the birth of biopolitics\",\"ordoliberalism\",\"adam smith\",\"friedrich hayek\",\"homo economicus\",\"security, territory, population\",\"anti-psychiatry\",\"people\",\"coercion, capital, and european states, ad 990\\u20131992\",\"india quarterly\",\"research papers in economics\",\"benevolence and the mandate of heaven\",\"east european politics\",\"computational politics\",\"the establishment (pakistan)\",\"oligarchy\",\"intelligence\",\"linked fate\",\"index of economics articles\",\"mainstream economics\",\"international economics\",\"jel classification codes\",\"experimental economics\",\"public economics\",\"john hicks\",\"assume a can opener\",\"appropriate technology\",\"arrow's impossibility theorem\",\"big push model\",\"cash crop\",\"ceteris paribus\",\"cobweb model\",\"consumer sovereignty\",\"cournot competition\",\"differentiated bertrand competition\",\"dispersed knowledge\",\"economic base analysis\",\"economic graph\",\"economic indicator\",\"economic model\",\"economics terminology that differs from common usage\",\"edgeworth box\",\"excess burden of taxation\",\"factors of production\",\"financial economics\",\"fractional-reserve banking\",\"georgism\",\"gerschenkron effect\",\"giffen good\",\"harris\\u2013todaro model\",\"hotelling's law\",\"identity economics\",\"import substitution industrialization\",\"indifference curve\",\"information economics\",\"intertemporal choice\",\"intertemporal equilibrium\",\"ithaca hours\",\"joint product pricing\",\"knowledge economy\",\"list of unsolved problems in economics\",\"lorenz curve\",\"marginal rate of substitution\",\"marginalism\",\"market anomaly\",\"merger simulation\",\"natural capital\",\"network effect\",\"opportunity cost\",\"phillips curve\",\"purchasing power parity\",\"ricardian equivalence\",\"risk premium\",\"robin hood effect\",\"social cost\",\"subsidy\",\"substitution effect\",\"surplus value\",\"universe (economics)\",\"utility\",\"glossary of economics\",\"list of production functions\",\"e. f. schumacher\",\"kenneth arrow\",\"cultural relativism\",\"emic and etic\",\"alliance theory\",\"culture theory\",\"performance studies\",\"cultural anthropology\",\"linguistic anthropology\",\"biological anthropology\",\"social organization\",\"standard cross-cultural sample\",\"anthropology of art\",\"nanook of the north\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"development anthropology\",\"nomadic pastoralism\",\"peasant economics\",\"shell money\",\"nutritional anthropology\",\"heritage commodification\",\"polygyny\",\"feminist anthropology\",\"feminist theory\",\"cognitive anthropology\",\"critical medical anthropology\",\"society for medical anthropology\",\"medical anthropology\",\"transpersonal psychology\",\"age set\",\"leveling mechanism\",\"theatre state\",\"circumscription theory\",\"f. g. bailey\",\"ecological anthropology\",\"soul dualism\",\"biocultural anthropology\",\"osteology\",\"moving anthropology student network\",\"usc center for visual anthropology\",\"human terrain system\",\"human behavioral ecology\",\"human ethology\",\"list of anthropologists\",\"bibliography of anthropology\",\"multimodal anthropology\",\"ceremonial pole\",\"bioculture\",\"cultural mapping\",\"transcultural nursing\",\"high culture\",\"cultural practice\",\"cultural liberalism\",\"cultural nationalism\",\"cultural radicalism\",\"cultural movement\",\"culture hero\",\"culturgen\",\"welfare culture\",\"wedding\",\"international security\",\"raptio\",\"paleopathology\",\"paleoanthropology\",\"richard dawkins\",\"cultural group selection\",\"race and intelligence\",\"human genetic variation\",\"intelligence quotient\",\"learning\",\"white wedding\",\"ceremony\",\"wedding reception\",\"fiqh\",\"honeymoon\",\"consummation\",\"wedding vow renewal ceremony\",\"promiscuity\",\"histrionic personality disorder\",\"female promiscuity\",\"hunter-gatherer\",\"edvard westermarck\",\"men who have sex with men\",\"women who have sex with women\",\"behavior\",\"theory of language\",\"linguistic relativity\",\"performance\",\"identity (social science)\",\"semiotic anthropology\",\"health policy\",\"health system\",\"population health\",\"headhunting\",\"soul\",\"shrunken head\",\"warrior\",\"kshatriya\",\"mudsill theory\",\"business magnate\",\"pitt rivers museum\",\"digging stick\",\"grave goods\",\"spirituality\",\"urban revolution\",\"susto\",\"psychological trauma\",\"auspicious wedding dates\",\"urban legend\",\"direct historical approach\",\"hoplology\",\"psychoanalysis\",\"university of san diego\",\"cognitive archaeology\",\"literacy\",\"ecological psychology\",\"sympathetic magic\",\"anthrobotics\",\"hau (anthropology)\",\"ecofeminism\",\"psychogeography\",\"biophilia hypothesis\",\"ethnoichthyology\",\"ethnolichenology\",\"ethnoornithology\",\"zooarchaeology\",\"poppet\",\"primitivism\",\"situationist international\",\"socialist realism\",\"koteka\",\"hunting hypothesis\",\"biocultural diversity\",\"hawaiian ethnobiology\",\"security studies\",\"sedentism\",\"reterritorialization\",\"la borde clinic\",\"typology (anthropology)\",\"negroid\",\"sinodonty and sundadonty\",\"john beddoe\",\"bertil lundman\",\"history of anthropometry\",\"decolonization\",\"evolutionary game theory\",\"chinese kinship\",\"online ethnography\",\"online research methods\",\"friction of distance\",\"proto-malay\",\"woman, culture, and society\",\"classificatory kinship\",\"structural endogamy\",\"assortative mixing\",\"social invisibility\",\"neuroanthropology\",\"behavioral neuroscience\",\"neurophilosophy\",\"detection theory\",\"anthropological criminology\",\"biosocial criminology\",\"pathognomy\",\"cognized environment\",\"fordisc\",\"endocannibalism\",\"exocannibalism\",\"sodality (social anthropology)\",\"contrast set\",\"general semantics\",\"frazer lecture\",\"arthur evans\",\"postmodernist anthropology\",\"hill people\",\"high-altitude adaptation in humans\",\"andean civilizations\",\"deep history\",\"ethnopediatrics\",\"educational anthropology\",\"neo-nationalism\",\"service economy\",\"far-right politics\",\"national conservatism\",\"plurinationalism\",\"right-wing politics\",\"statism\",\"blood and soil\",\"fourteen words\",\"kalergi plan\",\"basket of deplorables\",\"trash doves\",\"historical behaviour studies\",\"guanche mummies\",\"mummy of san andr\\u00e9s\",\"upper class\",\"anthropological survey of india\",\"skhul and qafzeh hominins\",\"rossville points\",\"nations and iq\",\"waga sculpture\",\"australian aboriginal kinship\",\"lambda alpha\",\"darwinian anthropology\",\"cha\\u00eene op\\u00e9ratoire\",\"joint attention\",\"asch conformity experiments\",\"prenatal hormones and sexual orientation\",\"mania\",\"fallen woman\",\"the protestant ethic and the spirit of capitalism\",\"deep play: notes on the balinese cockfight\",\"human universals\",\"list of years in anthropology\",\"recent human evolution\",\"anthropology of institutions\",\"kalahari debate\",\"postpartum confinement\",\"major depressive disorder\",\"paleoradiology\",\"americanoid\",\"cornell-peru project\",\"applied anthropology research methods\",\"list of stateless societies\",\"official cantonese translations of english names for british officials\",\"off the verandah\",\"armchair theorizing\",\"outline of psychology\",\"abnormal psychology\",\"medical psychology\",\"music psychology\",\"occupational health psychology\",\"gestalt psychology\",\"timeline of psychology\",\"timeline of psychotherapy\",\"list of psychological research methods\",\"list of mnemonics\",\"dsm-iv codes\",\"list of mental disorders\",\"outline of autism\",\"list of psychiatric medications\",\"list of psychiatric medications by condition treated\",\"list of credentials in psychology\",\"list of schools of psychoanalysis\",\"list of psychology organizations\",\"interpersonal neurobiology\",\"code of hammurabi\",\"marriage of the virgin\",\"hierarchical organization\",\"manorialism\",\"requisite organization\",\"matrix management\",\"julius stone\",\"feminist legal theory\",\"virtue jurisprudence\",\"john rawls\",\"brocard (law)\",\"constitutional economics\",\"political jurisprudence\",\"the province of jurisprudence determined\",\"history of the legal profession\",\"history of the american legal profession\",\"executive order\",\"national liberalism\",\"philosophy of sex\",\"particracy\",\"dependent territory\",\"regional power\",\"great power\",\"roman question\",\"regional autonomy\",\"secession\",\"balkanization\",\"civilization state\",\"westphalian sovereignty\",\"synarchism\",\"timocracy\",\"constitutional dictatorship\",\"corporate republic\",\"dictablanda\",\"one-party state\",\"authoritarian capitalism\",\"authoritarian democracy\",\"ecoauthoritarianism\",\"enlightened absolutism\",\"soft despotism\",\"tyranny of the majority\",\"magnate\",\"the rich get richer and the poor get poorer\",\"history of propaganda\",\"music and political warfare\",\"post-truth politics\",\"counterpropaganda\",\"strategy of tension\",\"demonizing the enemy\",\"gish gallop\",\"obscurantism\",\"slogan\",\"enemy of the people\",\"blacklisting\",\"brainwashing\",\"peer pressure\",\"communal reinforcement\",\"shock value\",\"f\\u00fchrer\",\"political repression\",\"bertrand russell\",\"new left review\",\"proletarian nation\",\"social order\",\"ilminism\",\"rumor\",\"proverb\",\"non-governmental organization\",\"friedrich naumann foundation\",\"responsibility to protect\",\"ngo-ization\",\"broken windows theory\",\"solitary confinement\",\"community policing\",\"informal social control\",\"proactive policing\",\"problem-oriented policing\",\"small government\",\"night-watchman state\",\"eastern bloc\",\"rivers state civil service\",\"perpetual war\",\"democratic peace theory\",\"influence of mass media\",\"social conservatism\",\"private property\",\"eurasianism\",\"maternalism\",\"blue labour\",\"social liberalism\",\"christian corporatism\",\"christian communism\",\"ethical socialism\",\"public policy doctrine\",\"public policy school\",\"archibald crossley\",\"roper center for public opinion research\",\"party platform\",\"american journal of political science\",\"prediction market\",\"futarchy\",\"public opinion quarterly\",\"institution\",\"social complexity\",\"astrosociology\",\"social experiment\",\"sociology of punishment\",\"base and superstructure\",\"institutionalist political economy\",\"vaticanology\",\"boosterism\",\"master of public policy\",\"master of public administration\",\"sciences po\",\"superpower collapse\",\"spatial politics\",\"implementation\",\"democratic capitalism\",\"majoritarianism\",\"polyarchy\",\"selectorate theory\",\"capitalist peace\",\"critical security studies\",\"rationalism\",\"international ethics\",\"donald e. stokes\",\"international society of political psychology\",\"walter f. dodd\",\"emmette redford\",\"henry e. brady\",\"principle-policy puzzle\",\"opinion leadership\",\"elihu katz\",\"manifest and latent functions and dysfunctions\",\"sociological positivism\",\"antipositivism\",\"post-behavioralism\",\"instrumentalism\",\"structuration theory\",\"werturteilsstreit\",\"regional hegemony\",\"kyklos\",\"organizational theory\",\"public budgeting\",\"blavatnik school of government\",\"german university of administrative sciences speyer\",\"corporative federalism\",\"right to exist\",\"home rule\",\"elective dictatorship\",\"china watcher\",\"kremlinology\",\"list of liberal theorists\",\"whiggism\",\"equal opportunity\",\"modern liberalism in the united states\",\"isaiah berlin\",\"anarcho-capitalism\",\"liberal conservatism\",\"peelian principles\",\"china university of political science and law\",\"communication university of china\",\"self-criticism\",\"social patriotism\",\"barracks communism\",\"dictatorship of the proletariat\",\"proletarian revolution\",\"world revolution\",\"commanding heights of the economy\",\"worker cooperative\",\"real socialism\",\"social revolution\",\"seek truth from facts\",\"instituts d'\\u00e9tudes politiques\",\"sanford school of public policy\",\"princeton school of public and international affairs\",\"bush school of government and public service\",\"schar school of policy and government\",\"european master of public administration consortium\",\"nonpartisanism\",\"an economic theory of democracy\",\"journal of public economics\",\"cato institute\",\"rentier state\",\"resource curse\",\"institut d'\\u00e9tudes politiques d'aix-en-provence\",\"institut d'\\u00e9tudes politiques de toulouse\",\"nanosocialism\",\"industrial democracy\",\"labour voucher\",\"workplace democracy\",\"blanquism\",\"criticism of capitalism\",\"participism\",\"left communism\",\"equality of outcome\",\"history of communism\",\"structural violence\",\"conflict resolution research\",\"antimilitarism\",\"appeasement\",\"non-interventionism\",\"peace journalism\",\"essence of decision\",\"thomas schelling\",\"security of tenure\",\"impeachment\",\"party political broadcast\",\"campaign finance\",\"johnson cult\",\"two-level game theory\",\"sequential game\",\"daniel kahneman\",\"john harsanyi\",\"paul milgrom\",\"william vickrey\",\"divided government in the united states\",\"net worth\",\"deviationism\",\"interventionism (politics)\",\"hypodermic needle model\",\"third-person effect\",\"social media in the 2016 united states presidential election\",\"media circus\",\"religious socialism\",\"religious communism\",\"christian egalitarianism\",\"christian fascism\",\"constitutional autochthony\",\"conservative liberalism\",\"sacralism\",\"law and order\",\"persistent vegetative state\",\"freedom of contract\",\"commodity form theory\",\"transitology\",\"big man (political science)\",\"corporate statism\",\"organicism\",\"economic nationalism\",\"pathos\",\"political socialization\",\"parochialism\",\"pork barrel\",\"paid survey\",\"survey data collection\",\"alan wolfe\",\"econtalk\",\"astrology\",\"polarized pluralism\",\"militarized interstate dispute\",\"political studies association\",\"british journal of politics and international relations\",\"political studies review\",\"transnational progressivism\",\"global citizenship\",\"security sector governance and reform\",\"equality before the law\",\"law of equal liberty\",\"personhood\",\"right to development\",\"karl deutsch award\",\"norman chester\",\"john coakley\",\"regionalism (international relations)\",\"second-order election\",\"victim study\",\"dark figure of crime\",\"national crime victimization survey\",\"tripartite consultation (international labour standards) convention, 1976\",\"ratification\",\"no war but the class war\",\"civil libertarianism\",\"ap comparative government and politics\",\"political criticism\",\"fenno's paradox\",\"hedonism\",\"catch-22\",\"kissinger lecture\",\"classical test theory\",\"guttman scale\",\"party identification\",\"sophomore surge\",\"domestic analogy\",\"the engineering of consent\",\"politico-media complex\",\"associationalism\",\"eco-nationalism\",\"eco-capitalism\",\"queer ecology\",\"cosmopolitan democracy\",\"united nations parliamentary assembly\",\"societal attitudes towards abortion\",\"high and low politics\",\"antinaturalism (politics)\",\"gender essentialism\",\"morphological freedom\",\"public consultation\",\"holocaust trivialization\",\"ljiljana radoni\\u0107\",\"international journal of public opinion research\",\"preselection\",\"echo chamber (media)\",\"social reality\",\"self-deception\",\"identity (philosophy)\",\"abilene paradox\",\"collective effervescence\",\"social actions\",\"unitarian universalism\",\"reductionism\",\"parallel state\",\"horace campbell\",\"faculty of political science, chulalongkorn university\",\"fundacion manantiales\",\"military policy\",\"private military company\",\"peace dividend\",\"guns versus butter model\",\"charg\\u00e9 de mission\",\"full spectrum diplomacy\",\"science diplomacy\",\"exequatur\",\"trusteeship (gandhism)\",\"canadian political science association\",\"grace skogstad\",\"civic political culture\",\"the civic culture\",\"parochial political culture\",\"political culture of germany\",\"political culture of the united states\",\"school of political and social sciences, unam\",\"proprietary community\",\"voluntary society\",\"privatism\",\"new political economy (journal)\",\"review of international political economy\",\"public opinion on climate change\",\"attention economy\",\"global environmental politics\",\"sustainable energy\",\"culture 21\",\"taftian theory\",\"al-ahram center for political and strategic studies\",\"total survey error\",\"intergenerational policy\",\"bloc party (politics)\",\"postfunctionalism\",\"liesbet hooghe\",\"curvilinear disparity\",\"regulatory competition\",\"bryan caplan\",\"european union studies association\",\"fritz w. scharpf\",\"white power music\",\"christian privilege\",\"oppression\",\"social model of disability\",\"denationalized citizenship\",\"diplomatic protection\",\"pal lahara state\",\"enterprise theory\",\"data collection system\",\"caucus for a new political science\",\"cand.scient.pol.\",\"uk heo\",\"fred w. riggs\",\"public opinion on nuclear issues\",\"print capitalism\",\"philip oxhorn\",\"distributive tendency\",\"journal of policy history\",\"school of politics and international relations, university of nottingham\",\"interviewer effect\",\"pippa norris\",\"university of chicago institute of politics\",\"data editing\",\"bonai state\",\"frankfurt declaration\",\"social corporatism\",\"values modes\",\"law without the state\",\"institute for international law of peace and armed conflict\",\"gustave le bon\",\"xuanchuan\",\"international convention concerning the use of broadcasting in the cause of peace\",\"overview of 21st-century propaganda\",\"mass media and american politics\",\"political journalism\",\"deployment management\",\"the final days (2000 film)\",\"berkeley school of political theory\",\"social media use by donald trump\",\"twitter diplomacy\",\"local service delivery\",\"corporatization\",\"inter-municipal cooperation\",\"global politics\",\"bad governance\",\"legal norm\",\"cube root rule\",\"social media in the 2020 united states presidential election\",\"wilson\\u2013patterson conservatism scale\",\"chiara bottici\",\"social media use in african politics\",\"democratic recession\",\"successor ideology\",\"glossary of international relations terms\",\"international sanctions\",\"status quo state\",\"malikism in algeria\",\"awza'i\",\"thawri\",\"ahl al-hadith\",\"madhhab\",\"statecraft (political science)\",\"principle of inalienability of the public domain\",\"mus\\u00e9e de l'homme\",\"ishraga mustafa hamid\",\"metcalfe's law\",\"beckstrom's law\",\"reed's law\",\"social multiplier effect\",\"demand curve\",\"law of supply\",\"primary market\",\"arbitrage pricing theory\",\"growth stock\",\"market trend\",\"sunk cost\",\"convex preferences\",\"is\\u2013lm model\",\"keynesian cross\",\"macroeconomic model\",\"accelerator effect\",\"ad\\u2013ia model\",\"triangle model\",\"national average salary\",\"discouraged worker\",\"weighted average cost of capital\",\"rate of return\",\"seasoned equity offering\",\"diminishing returns\",\"paradox of value\",\"st. petersburg paradox\",\"degrowth\",\"world economy\",\"least developed countries\",\"economics of science\",\"blue economy\",\"democratic globalization\",\"ronen palan\",\"in kind\",\"openness\",\"learning economy\",\"credit default option\",\"forward price\",\"consumer debt\",\"diamond-water paradox\",\"economic data\",\"vernon l. smith\",\"starve the beast\",\"production\\u2013possibility frontier\",\"world3\",\"population and development review\",\"cumulative prospect theory\",\"bertrand paradox (economics)\",\"edgeworth paradox\",\"open economy\",\"fei\\u2013ranis model of economic growth\",\"hubbert peak theory\",\"kuznets curve\",\"peak wheat\",\"pickens plan\",\"problems with economic models\",\"solow\\u2013swan model\",\"heckscher\\u2013ohlin model\",\"ramsey\\u2013cass\\u2013koopmans model\",\"eonia\",\"euronia\",\"marginal propensity to consume\",\"steven n. s. cheung\",\"nava ashraf\",\"georg weizs\\u00e4cker\",\"hiding hand principle\",\"economic power\",\"list of important publications in economics\",\"on the principles of political economy and taxation\",\"myron scholes\",\"kenneth boulding's evolutionary perspective\",\"noosphere\",\"neo-ricardianism\",\"market-based valuation\",\"time series\",\"equity premium puzzle\",\"list of cognitive biases\",\"economic puzzle\",\"forward premium anomaly\",\"balassa\\u2013samuelson effect\",\"b\\u00e9la balassa\",\"price index\",\"land management\",\"collaboration\",\"managerialism\",\"convergence (economics)\",\"structural inequality\",\"impossible trinity\",\"dollar voting\",\"history of capitalist theory\",\"new institutional economics\",\"economic mobility\",\"equity home bias puzzle\",\"stylized fact\",\"econophysics\",\"net national product\",\"value product\",\"breakout (technical analysis)\",\"doji\",\"donchian channel\",\"bertrand competition\",\"pork cycle\",\"beveridge curve\",\"circular flow of income\",\"nominal yield\",\"perpetual bond\",\"i-spread\",\"leontief paradox\",\"forward exchange market\",\"paradox of thrift\",\"sectoral balances\",\"excess reserves\",\"price support\",\"backward bending supply curve of labour\",\"encouraged industry catalogue\",\"national equities exchange and quotations\",\"leontief production function\",\"samuelson condition\",\"simulation modeling\",\"inertial inflation\",\"elhanan helpman\",\"implicit cost\",\"induced consumption\",\"autonomous consumption\",\"j curve\",\"market allocation scheme\",\"electronic funds transfer\",\"open music model\",\"market mechanism\",\"precautionary demand\",\"real economy\",\"rat race\",\"average variable cost\",\"average fixed cost\",\"mundell\\u2013tobin effect\",\"revealed preference\",\"backus\\u2013kehoe\\u2013kydland puzzle\",\"feldstein\\u2013horioka puzzle\",\"liquidity premium\",\"scitovsky paradox\",\"tibor\",\"sofr\",\"conceptual economy\",\"food processing\",\"keynes\\u2013ramsey rule\",\"dynamical system\",\"discrete choice\",\"daniel mcfadden\",\"conjoint analysis\",\"dynamic discrete choice\",\"cost-weighted activity index\",\"macroeconomic regulation and control\",\"extended-hours trading\",\"late trading\",\"loopco\",\"auction theory\",\"downs\\u2013thomson paradox\",\"concentration risk\",\"political risk\",\"law of rent\",\"labor theory of property\",\"per capita personal income in the united states\",\"option screener\",\"economic transformation\",\"factor endowment\",\"dynamic pricing\",\"demand shaping\",\"rebound effect (conservation)\",\"snackwell effect\",\"ecolabel\",\"material flow analysis\",\"urban metabolism\",\"community-supported agriculture\",\"mandeville's paradox\",\"fischer black prize\",\"jensen prize\",\"proto-industrialization\",\"market for corporate control\",\"volume index\",\"chaining\",\"economic law\",\"gabor\\u2013granger method\",\"clive granger\",\"hicks-neutral technical change\",\"kiyotaki\\u2013moore model\",\"icarus paradox\",\"preclusive purchasing\",\"relative income hypothesis\",\"the theory of interstellar trade\",\"time value of money\",\"lipstick index\",\"theories of poverty\",\"social vulnerability\",\"scottish index of multiple deprivation\",\"marginal return\",\"returns (economics)\",\"peso problem (finance)\",\"economic satiation\",\"law of increasing costs\",\"housing affordability index\",\"base period\",\"deflator\",\"toothpaste tube theory\",\"cycle of poverty\",\"men's underwear index\",\"hemline index\",\"market rate\",\"ak model\",\"paul romer\",\"output elasticity\",\"variable rate debt obligation\",\"sectoral output\",\"term (time)\",\"unplanned economies\",\"99ers\",\"american recovery and reinvestment act of 2009\",\"lawrence summers\",\"identity line\",\"survey on household income and wealth\",\"bowley's law\",\"long-run cost curve\",\"hanging man (candlestick pattern)\",\"real-time economy\",\"list of economics films\",\"debtocracy\",\"vent for surplus\",\"principles of political economy\",\"robinson crusoe economy\",\"marginal rate of transformation\",\"norwegian paradox\",\"colonial origins of comparative development\",\"paradox of prosperity\",\"schelling's segregation model\",\"hobbesian trap\",\"internality\",\"trygve haavelmo\",\"bengt holmstr\\u00f6m\",\"great gatsby curve\",\"least-cost theory\",\"list of sociologists\",\"roman agrarian history and its significance for public and private law\",\"sociology of the world religions\",\"ideal type\",\"iron cage\",\"life chances\",\"tripartite classification of authority\",\"science as a vocation\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"sailing ship effect\",\"richard koo\",\"history of microeconomics\",\"michael spence\",\"dixit\\u2013stiglitz model\",\"list of special economic zones\",\"productive capacity\",\"capital cost\",\"inventory bounce\",\"guido tabellini\",\"shale band\",\"international energy agency\",\"duck curve\",\"power-to-x\",\"global retirement index\",\"bric\",\"production for profit\",\"surplus labour\",\"john roemer\",\"real-world economics review\",\"marxist sociology\",\"inframarginal analysis\",\"corner solution\",\"economic evaluation of time\",\"the elephant curve\",\"visible hand (economics)\",\"lerner paradox\",\"task force\",\"emotivism\",\"possible world\",\"david chalmers\",\"sociology of scientific ignorance\",\"wilhelm windelband\",\"henri poincar\\u00e9\",\"c. d. broad\",\"peter sloterdijk\",\"ideocracy\",\"self-awareness\",\"public affairs quarterly\",\"role ethics\",\"william frankena\",\"responsibility\",\"ecomodernism\",\"passing (sociology)\",\"ernst borinski\",\"rogers brubaker\",\"chua beng huat\",\"randy david\",\"donatella della porta\",\"riane eisler\",\"franz oppenheimer\",\"helmuth plessner\",\"ferdinand de saussure\",\"max scheler\",\"p\\u0131nar selek\",\"saskia wieringa\",\"eviatar zerubavel\",\"quantitative research\",\"action theory (sociology)\",\"health geography\",\"chicago school (sociology)\",\"anti-modernization\",\"interactionism\",\"total institution\",\"open-mindedness\",\"person of color\",\"visible minority\",\"life-process model of addiction\",\"private sphere\",\"injustice\",\"matrix of domination\",\"neglect\",\"destabilisation\",\"new social movements\",\"clustering (demographics)\",\"agency (philosophy)\",\"agency (sociology)\",\"figurational sociology\",\"instrumental and value-rational action\",\"international sociological association\",\"l'ann\\u00e9e sociologique\",\"list of sociology journals\",\"authority (sociology)\",\"identity crisis\",\"greatness\",\"person\",\"reality distortion field\",\"hypnosis\",\"complex adaptive system\",\"computational sociology\",\"jacqueline rose\",\"pride\",\"anti-gender movement\",\"value judgment\",\"instrumental and intrinsic value\",\"instrumental and value rationality\",\"medicalization\",\"index of sociology articles\",\"commodity chain\",\"ferdinand t\\u00f6nnies society\",\"first world\",\"kindness\",\"matrilocal residence\",\"microsociology\",\"non-state actor\",\"resocialization\",\"secondary deviance\",\"split labor market theory\",\"status group\",\"social balance theory\",\"social conflict\",\"social geometry\",\"social phenomenon\",\"social reproduction\",\"social risk positions\",\"sociological imagination\",\"sociological naturalism\",\"underclass\",\"value-added theory\",\"vertical mobility\",\"control theory (sociology)\",\"mesosociology\",\"national question (quebec)\",\"quiet revolution\",\"official bilingualism in the public service of canada\",\"performativity\",\"performative interval\",\"sociotechnology\",\"double hermeneutic\",\"mapping controversies\",\"scientocracy\",\"normalization process theory\",\"technical change\",\"regulation of science\",\"humanistic sociology\",\"leipzig school (sociology)\",\"group action (sociology)\",\"reflexive modernization\",\"humanistic coefficient\",\"analytic induction\",\"taste (sociology)\",\"psychoanalytic theory\",\"mass action (sociology)\",\"global social mobility index\",\"status attainment\",\"civic virtue\",\"civility\",\"generosity\",\"generative actor\",\"blau space\",\"public morality\",\"nudity\",\"social situation in the french suburbs\",\"tschandala\",\"ressentiment\",\"social threefolding\",\"resentment\",\"hostility\",\"label (sociology)\",\"law of the jungle\",\"might makes right\",\"procreative beneficence\",\"analytic frame\",\"state of affairs (sociology)\",\"sociologists without borders\",\"food sovereignty\",\"reflexivity (social theory)\",\"pay it forward\",\"reciprocity (cultural anthropology)\",\"the american journal of economics and sociology\",\"contemporary jewry\",\"journal of sociology\",\"sociological insight\",\"science in action (book)\",\"protest cycle\",\"symbolic power\",\"asabiyyah\",\"middle-range theory (sociology)\",\"analytical sociology\",\"social organism\",\"social death\",\"collective mental state\",\"acceptance\",\"amusement\",\"anguish\",\"confusion\",\"gratitude\",\"heterosociality\",\"dynamic density\",\"emotive (sociology)\",\"duality of structure\",\"average joe\",\"moral entrepreneur\",\"norm entrepreneur\",\"racial literacy\",\"recuperation (politics)\",\"the revolution of everyday life\",\"german sociological association\",\"new york state sociological association\",\"sociologists for women in society\",\"social rule system theory\",\"european sociological association\",\"fragmentation (sociology)\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"ren\\u00e9-k\\u00f6nig-gesellschaft\",\"people power\",\"revolutions of 1989\",\"imagery of nude celebrities\",\"contest mobility\",\"social transformation\",\"sociology in poland\",\"correspondence principle (sociology)\",\"social rights (social contract theory)\",\"free migration\",\"occupational closure\",\"index of urban sociology articles\",\"strategic choice theory\",\"preference theory\",\"dyad (sociology)\",\"religious literacy\",\"status\\u2013income disequilibrium\",\"index of sociopolitical thinkers\",\"weighted network\",\"island mentality\",\"ipse dixit\",\"davis\\u2013moore hypothesis\",\"indian economic and social history review\",\"international political sociology (ips)\",\"substitutes for leadership theory\",\"bibliography of sociology\",\"policy sociology\",\"sociology of manchester\",\"cognitive bias\",\"sequential probability ratio test\",\"intergroup anxiety\",\"vulnerable adult\",\"indian sociological society\",\"field theory (sociology)\",\"safety-valve institution\",\"theories of humor\",\"outline of globalization\",\"ecological imperialism\",\"globalization and women in china\",\"institutional trust (social sciences)\",\"immigrant-host model\",\"an anarchist faq\",\"grave candle\",\"symbolic religiosity\",\"relational sociology\",\"memory space (social science)\",\"local multiplier effect\",\"necropolitics\",\"out-of-body experience\",\"prohibition of dying\",\"norwegian sociology canon\",\"norwegian sociological association\",\"christian fuchs (sociologist)\",\"structural discrimination\",\"science capital\",\"social construction of the body\",\"group threat theory\",\"racial threat\",\"concentrated disadvantage\",\"market-dominant minority\",\"day of empire\",\"sociology in japan\",\"post-work society\",\"universal basic income\",\"friendly fascism (book)\",\"groupism\",\"sociology of morality\",\"akademie f\\u00fcr soziologie\",\"obshchestvovedeniye\",\"black tax\",\"gaia philosophy\",\"mediumship\",\"hobby\",\"personal life\",\"travel behavior\",\"metalanguage\",\"logophonetic\",\"feoffment\",\"trobriand islands\",\"proverbial phrase\",\"marija gimbutas\",\"bicameral mentality\",\"lectures on jurisprudence\",\"cephalic index\",\"cephalic index in cats and dogs\",\"biology and sexual orientation\",\"homosexual behavior in animals\",\"sex and gender distinction\",\"causes of transsexuality\",\"linguistic description\",\"the white goddess\",\"the hebrew goddess\",\"early modern human\",\"names for the human species\",\"serer-ndut people\",\"serer people\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"serer maternal clans\",\"lingeer\",\"cultural resource management\",\"bumiputera (malaysia)\",\"bioregionalism\",\"non-representational theory\",\"minangkabau people\",\"moana (1926 film)\",\"psychohistory\",\"consensus democracy\",\"androcentrism\",\"honorary male\",\"time-use research\",\"lila: an inquiry into morals\",\"alter ego\",\"list of matrilineal or matrilocal societies\",\"patrilocal residence\",\"business oligarch\",\"hoi polloi\",\"gloss (annotation)\",\"constitutionality\",\"warrior (character class)\",\"donor class\",\"joan roughgarden\",\"list of birds displaying homosexual behavior\",\"list of mammals displaying homosexual behavior\",\"list of animals displaying homosexual behavior\",\"topic and comment\",\"homo faber\",\"decoloniality\",\"cogito, ergo sum\",\"squib (writing)\",\"fount of honour\",\"canadian honours system\",\"general knowledge\",\"middlebrow\",\"constantin noica\",\"moralia\",\"ghazi (warrior)\",\"istihlal\",\"maceration (bone)\",\"forensic facial reconstruction\",\"development geography\",\"guatemalan forensic anthropology foundation\",\"argentine forensic anthropology team\",\"australian institute of aboriginal and torres strait islander studies\",\"martial race\",\"apuli\",\"orthograde posture\",\"craig stanford\",\"village head\",\"naturalistic disease theories\",\"museum of world culture\",\"endocast\",\"gallowglass\",\"encyclopedia of anthropology\",\"theta criterion\",\"logical form (linguistics)\",\"human genetic clustering\",\"cultural survival\",\"museum of mankind\",\"children's geographies\",\"1910s in anthropology\",\"utinahica\",\"1890s in anthropology\",\"1990s in anthropology\",\"2000s in anthropology\",\"prickly paradigm press\",\"mandailing people\",\"evolutionary studies institute\",\"geography of antisemitism\",\"muted group theory\",\"solano people\",\"robert christison\",\"anthropological index online\",\"sexual inversion (sexology)\",\"diane bell (anthropologist)\",\"laura boulton\",\"hong kong honours system\",\"hypnopompic\",\"psychonautics\",\"sleep and learning\",\"museum of archaeology and anthropology, university of cambridge\",\"rudolf virchow award\",\"taboo (2002 tv series)\",\"altered states\",\"live free or die\",\"museu da lourinh\\u00e3\",\"society for economic anthropology\",\"nomads of the longbow\",\"maloca\",\"confucian classes\",\"cabang atas\",\"unsaid\",\"facial expression\",\"microexpression\",\"les ma\\u00eetres fous\",\"university of tennessee anthropological research facility\",\"vanua\",\"gaonburha\",\"heterotopia (space)\",\"museo nacional de antropolog\\u00eda (madrid)\",\"gate crashing\",\"moral emotions\",\"museo de antropolog\\u00eda de xalapa\",\"list of timothy asch films\",\"magical death\",\"the witch-cult in western europe\",\"heide g\\u00f6ttner-abendroth\",\"martti olavi siirala\",\"the hunters (1957 film)\",\"list of visual anthropology films\",\"ogilvie professor of human geography\",\"koestler parapsychology unit\",\"mus\\u00e9e des confluences\",\"gotai\",\"tropical geography\",\"outline of culture\",\"poker\",\"mars needs moms\",\"philosophy of life\",\"metanoia (psychology)\",\"aion: researches into the phenomenology of the self\",\"civilization in transition\",\"mosuo women\",\"biblical patriarchy\",\"consumer class\",\"microgeneration\",\"consumption (sociology)\",\"commercialism\",\"society of anthropology of paris\",\"das mutterrecht\",\"displacement (linguistics)\",\"maya research program\",\"linguistic system\",\"media linguistics\",\"anthropometric history\",\"census of india prior to independence\",\"viking fund medal\",\"angkola people\",\"kluet people\",\"journal of ethnobiology\",\"ethnoscape\",\"jerzy adam kowalski\",\"podom\",\"list of women anthropologists\",\"faye v. harrison\",\"poverty class\",\"joseph rowntree foundation\",\"environmental racism in the united states\",\"food bank\",\"linguistic linked open data\",\"heel\\u2013ball index\",\"population health policies and interventions\",\"oikofobie. de angst voor het eigene\",\"womyn's land\",\"journal of lesbian studies\",\"women's week provincetown\",\"geography of media and communication\",\"neolinguistics\",\"michelle rosaldo book prize\",\"kriza j\\u00e1nos ethnographic society\",\"tonograph\",\"toloy\",\"linguistics in science fiction\",\"aparna rao\",\"richard gaskin\",\"dominic boyer\",\"georg pfeffer\",\"releasing the spirits: a balinese ceremony\",\"disability anthropology\",\"male state\",\"communicative dynamism\",\"hermann lotze\",\"ernst mally\",\"barbara rogoff\",\"piaget's theory of cognitive development\",\"naturalistic observation\",\"crying\",\"sociometric status\",\"harry harlow\",\"computational theory of mind\",\"shadow (psychology)\",\"self-hypnosis\",\"catharsis\",\"subconscious\",\"automatic writing\",\"acceptance and commitment therapy\",\"behaviour therapy\",\"autogenic training\",\"psychological statistics\",\"applied psychological measurement\",\"preconscious\",\"id, ego and super-ego\",\"ernest jones\",\"adlerian\",\"on narcissism\",\"mourning and melancholia\",\"object relations theory\",\"british psychotherapy foundation\",\"journal of the american psychoanalytic association\",\"paradoxical intention\",\"inner peace\",\"contemplation\",\"awareness\",\"anhedonia\",\"dysthymia\",\"bipolar i disorder\",\"eating disorder\",\"list of neurological conditions and disorders\",\"hong kong college of psychiatrists\",\"psycho-oncology\",\"philosophical analysis\",\"coma\",\"gestalt theoretical psychotherapy\",\"gestaltzerfall\",\"pattern recognition (psychology)\",\"quantitative psychological research\",\"psychological evaluation\",\"emotionality\",\"sublimation (psychology)\",\"models of abnormality\",\"seasonal affective disorder\",\"altered state of consciousness\",\"flow (psychology)\",\"wakefulness\",\"global workspace theory\",\"the emperor's new mind\",\"id\\u00e9e fixe (psychology)\",\"cognitivism (psychology)\",\"dynamicism\",\"participatory theory\",\"is the glass half empty or half full?\",\"schadenfreude\",\"fight-or-flight response\",\"little albert experiment\",\"neutral stimulus\",\"law of the instrument\",\"normalcy bias\",\"probability matching\",\"proportionality bias\",\"trait ascription bias\",\"defence mechanism\",\"outline of thought\",\"information metabolism\",\"stimulation\",\"answer to job\",\"alchemical studies\",\"marie-louise von franz\",\"verbal behavior\",\"social dominance orientation\",\"schizotypy\",\"transliminality\",\"sybil (schreiber book)\",\"five stages of grief\",\"blank expression\",\"creativity and mental health\",\"ambidexterity\",\"frieda fromm-reichmann\",\"tortured artist\",\"mortido\",\"post-cognitivist psychology\",\"social degeneration\",\"list of psychological schools\",\"repertory grid\",\"life and how to survive it\",\"emotional abuse\",\"superiority complex\",\"dark triad\",\"entitlement\",\"cabin fever\",\"emotional reasoning\",\"intensity of preference\",\"games for change\",\"auditory hallucination\",\"nobody nowhere\",\"hereditarianism\",\"laterality\",\"jenkins activity survey\",\"two-factor theory of emotion\",\"james\\u2013lange theory\",\"helene deutsch\",\"internal family systems model\",\"sid parnes\",\"apprehension (understanding)\",\"the concept of anxiety\",\"law of effect\",\"gay, straight, and the reason why\",\"causa sui\",\"tractatus politicus\",\"egosyntonic and egodystonic\",\"psychological nativism\",\"behavioural despair test\",\"animal testing regulations\",\"pit of despair\",\"open field (animal test)\",\"argument from marginal cases\",\"gary l. francione\",\"siobhan o'sullivan\",\"thumos\",\"transfer (propaganda)\",\"menninger foundation\",\"european federation of psychologists' associations\",\"national association of school psychologists\",\"cognitive intervention\",\"radical psychology network\",\"american association for the abolition of involuntary mental hospitalization\",\"mad pride\",\"mindfreedom international\",\"crazy therapies\",\"index of psychometrics articles\",\"oskar pfister award\",\"list of psychology awards\",\"specialist in psychology\",\"cyranoid\",\"accuracy and precision\",\"feeling good: the new mood therapy\",\"appraisal theory\",\"conversational model\",\"freud's seduction theory\",\"the freudian coverup\",\"society for philosophy and psychology\",\"history of psychotherapy\",\"sarnoff a. mednick\",\"emotional selection\",\"vocabulary development\",\"self-assessment\",\"field theory (psychology)\",\"history of dyslexia research\",\"cosmos and psyche\",\"child behavior checklist\",\"women-are-wonderful effect\",\"frustration\\u2013aggression hypothesis\",\"behavioral pharmacology\",\"maritza montero\",\"core self-evaluations\",\"conditioned emotional response\",\"technobiophilia\",\"emotions in virtual communication\",\"reasoned action approach\",\"spearman medal\",\"social cognition and interaction training\",\"swanson, nolan and pelham teacher and parent rating scale\",\"bps barbara wilson lifetime achievement award\",\"gnosis (chaos magic)\",\"relational developmental systems\",\"kurt koffka medal\",\"character computing\",\"obliviousness\",\"modular cognition framework\",\"unipolar mania\",\"psychoinformatics\",\"boris maciejovsky\",\"bay'ah\",\"mahr\",\"writ\",\"international council for science\",\"you have two cows\",\"global justice movement\",\"list of left-wing internationals\",\"organization & environment\",\"clientelism\",\"cleavage (politics)\",\"gar alperovitz\",\"list of national independence days\",\"autonomous communities of spain\",\"autonomous administrative division\",\"autonomous communities administration\",\"the good soldier \\u0161vejk\",\"d\\u00e9j\\u00e0 vu\",\"research excellence framework\",\"national student survey\",\"kim campbell\",\"parliamentary procedure\",\"deliberation\",\"dizzy with success\",\"burmese way to socialism\",\"national communism\",\"failed state\",\"violent non-state actor\",\"public property\",\"william a. niskanen\",\"list of national legal systems\",\"backlash (sociology)\",\"they shall not pass\",\"molon labe\",\"kaarlo juho st\\u00e5hlberg\",\"imperium\",\"jhai foundation\",\"international conference on theory and practice of electronic governance\",\"inquisitorial system\",\"east turkestan\",\"political cartoon\",\"caudillo\",\"peace through strength\",\"gadsden flag\",\"the independent review\",\"david laidler\",\"eugene fama\",\"jus commune\",\"vacatio legis\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"legalism (chinese philosophy)\",\"school of diplomacy\",\"publicity stunt\",\"bevanism\",\"federal law\",\"border control\",\"ethnarch\",\"list of enlightened despots\",\"samuel von pufendorf\",\"garveyism\",\"violent non-state actors at sea\",\"bolivarian revolution\",\"\\u00bfpor qu\\u00e9 no te callas?\",\"ministry of magic\",\"joint organisations data initiative\",\"lesser of two evils principle\",\"white paper\",\"content marketing\",\"communications management\",\"knowledge gap hypothesis\",\"heavily indebted poor countries\",\"small office/home office\",\"we shall overcome\",\"extemporaneous speaking\",\"parliamentary debate\",\"gevald campaign\",\"state decoration\",\"state order\",\"drang nach osten\",\"the journal of political philosophy\",\"tiocfaidh \\u00e1r l\\u00e1\",\"against equality of opportunity\",\"worshipful company of butchers\",\"he who does not work, neither shall he eat\",\"crimes against humanity under communist regimes\",\"liberal international order\",\"liberal democratic basic order\",\"socialist campaign group\",\"neil maccormick\",\"administrative divisions of portugal\",\"liechtenstein institute on self-determination\",\"consequentialist justifications of the state\",\"continuismo\",\"liberalism and conservatism in latin america\",\"international peacekeeping\",\"cacique\",\"oryx and crake\",\"maddaddam\",\"the castle (novel)\",\"national power\",\"franciscan school of theology\",\"electronic media\",\"atlanticism\",\"resource conservation and recovery act\",\"voting rights in the united states\",\"one man, one vote\",\"timeline of voting rights in the united states\",\"united nations office on drugs and crime\",\"administrative divisions of peru\",\"spin room\",\"cura annonae\",\"the road to serfdom\",\"regionalisation\",\"build\\u2013operate\\u2013transfer\",\"neosocialism\",\"better red than dead\",\"stakeholder (corporate)\",\"independent labour publications\",\"ralph borsodi\",\"give peace a chance\",\"popular socialism\",\"robert f. wagner graduate school of public service\",\"technocracy movement\",\"post-politics\",\"chester barnard\",\"finance & development\",\"nur f\\u00fcr deutsche\",\"michael albert\",\"neo-capitalism\",\"rosa luxemburg foundation\",\"petition of right\",\"concurrent powers\",\"exclusive federal powers\",\"implied powers\",\"plenary power\",\"authoritarian left\",\"jean bethke elshtain\",\"german model\",\"gruppi di acquisto solidale\",\"in place of strife\",\"fukoku ky\\u014dhei\",\"islamic sexual jurisprudence\",\"menstruation in islam\",\"proposed national unification promotion law\",\"dang guo\",\"fiscal imbalance\",\"equalization payments\",\"list of social democratic parties\",\"communist correspondence committee\",\"michael thrasher\",\"colin rallings\",\"american university school of international service\",\"grenoble institute of political studies\",\"olivier ihl\",\"nancy program\",\"science & society\",\"the twenty years' crisis\",\"anglo-saxon model\",\"the great transformation (book)\",\"idealism in international relations\",\"job cohen\",\"public opinion and activism in the terri schiavo case\",\"jamiat-e islami\",\"regulatory economics\",\"muhammad taqi usmani\",\"syed hayatullah\",\"qazi syed inayatullah\",\"international isolation\",\"democratic party for a new society\",\"english votes for english laws\",\"overlapping consensus\",\"unearned income\",\"air rights\",\"energy community\",\"energy charter treaty\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"ash-shab yurid isqat an-nizam\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"world politics\",\"swiss neutrality\",\"fiscal policy of the united states\",\"criticism of the federal reserve\",\"harvard institute of politics\",\"the journal of politics\",\"pensions crisis\",\"renewable energy transition\",\"cost of electricity by source\",\"prague conference\",\"school of international and public affairs, columbia university\",\"critique: journal of socialist theory\",\"foreign service officer\",\"foreign agricultural service\",\"urban village\",\"stephen barber\",\"contingent sovereignty\",\"legal naturalism\",\"leslie green (philosopher)\",\"multi-level governance\",\"un-energy\",\"vocational panel\",\"critical review (journal)\",\"paul van riper (political scientist)\",\"advocacy journalism\",\"comparative criminal justice\",\"edward j. bloustein school of planning and public policy\",\"rosa brooks\",\"corporate communication\",\"graduate program in public management\",\"mccourt school of public policy\",\"robert m. la follette school of public affairs\",\"frank batten school of leadership and public policy\",\"graduate school of public policy, university of tokyo\",\"decentralized computing\",\"decentralized autonomous organization\",\"occupatio\",\"i did not have sexual relations with that woman\",\"history of science policy\",\"journal of democracy\",\"elif shafak\",\"international review of the red cross\",\"res publica christiana\",\"obreption and subreption (catholic canon law)\",\"dyab abou jahjah\",\"list of rugrats characters\",\"grazing rights\",\"henry habib\",\"lloyd\\u2013la follette act\",\"the triple revolution\",\"robert heilbroner\",\"maladministration\",\"rent-setting\",\"asu college of public service & community solutions\",\"electronic authentication\",\"the machiavellian moment\",\"this machine kills fascists\",\"islamic toilet etiquette\",\"energy superpower\",\"early social changes under islam\",\"islam and children\",\"islamic funeral\",\"warren miller (political scientist)\",\"the soldier and the state\",\"the crisis of democracy\",\"making democracy work\",\"designing social inquiry\",\"ernest barker\",\"biological organisation\",\"latin american public opinion project\",\"commentary on palestine: peace not apartheid\",\"a call to action: women, religion, violence, and power\",\"2000-watt society\",\"green job\",\"carbon fee and dividend\",\"steven b. smith (professor)\",\"radical egalitarianism\",\"relative gain (international relations)\",\"catonism\",\"list of environmental ministries\",\"ecocide\",\"ministry of infrastructure and water management\",\"environment minister\",\"ucla luskin school of public affairs\",\"michael l. gross (ethicist)\",\"british polling council\",\"colin hughes\",\"supreme court of justice of colombia\",\"clarita carlos\",\"james tully (philosopher)\",\"choosing scotland's future\",\"scotland's future\",\"\\u00e5land islands peace institute\",\"high policing\",\"wisconsin school (diplomatic history)\",\"special relationship (international relations)\",\"australian quarterly\",\"political man\",\"carl albert center\",\"outline of anarchism\",\"dualism (law)\",\"earned media\",\"petitions of right (ireland) act 1873\",\"common informer\",\"eternity clause\",\"i like ike\",\"feeding the chooks\",\"squirrel (debate)\",\"index of social and political philosophy articles\",\"agonism\",\"delegated authority\",\"indian political philosophy\",\"grey room\",\"democratic liberalism\",\"free newfoundland\",\"liberal legalism\",\"journal of current chinese affairs\",\"journal of current southeast asian affairs\",\"spatial justice\",\"andr\\u00e9 du pisani\",\"enbau\",\"phillip blond\",\"rodney tiffen\",\"free-market healthcare\",\"a green new deal\",\"multiliteracy\",\"grey-zone (international relations)\",\"beatrice heuser\",\"party-state capitalism\",\"ipm (software)\",\"politique africaine\",\"patient participation\",\"communism and lgbt rights\",\"proclamation by the crown act 1539\",\"present age\",\"energy certificate\",\"after saturday comes sunday\",\"class traitor\",\"insight turkey\",\"left group of finnish workers\",\"bananas, beaches and bases\",\"note verbale\",\"crypto-communism\",\"journal of political ideologies\",\"democracies: patterns of majoritarian & consensus government in twenty-one countries\",\"sovereignty of the philippines\",\"karl schwedler\",\"her majesty's government (term)\",\"human resource management in public administration\",\"border outpost\",\"security studies (journal)\",\"stephanos bibas\",\"liberal corporatism\",\"conservative corporatism\",\"janet ajzenstat\",\"nonkilling global political science\",\"land consolidation\",\"election law journal\",\"argumentation and advocacy\",\"development bureau\",\"institute for economics and peace\",\"economists for peace and security\",\"politeia (journal)\",\"attorney-general v de keyser's royal hotel ltd\",\"marc lynch\",\"the lexus and the olive tree\",\"singleton (global governance)\",\"environmental peacebuilding\",\"alternatives: turkish journal of international relations\",\"united federal workers of america\",\"list of futurama characters\",\"national forum (georgia)\",\"nigel simmonds\",\"josepha laroche\",\"institute for political studies \\u2013 catholic university of portugal\",\"right to the city\",\"harvest hills cooperative community\",\"coal phase-out\",\"powering past coal alliance\",\"postinternationalism\",\"limitarianism (ethical)\",\"work, employment & society\",\"classical realism (international relations)\",\"national agrarian party\",\"scientific man versus power politics\",\"new aspects of politics\",\"andrew westmoreland\",\"green institute foundation\",\"sustainable business\",\"archery\",\"the good society\",\"promulgation (catholic canon law)\",\"yehuda zvi blum\",\"wyn grant\",\"crown servant\",\"list of food labeling regulations\",\"in defense of the national interest\",\"political studies (journal)\",\"tobacco-free pharmacy\",\"ministry of infrastructure (ukraine)\",\"liberal social movement (portugal)\",\"afke schaart\",\"kinder, k\\u00fcche, kirche\",\"politics, philosophy & economics\",\"nicole bacharan\",\"small media, big revolution\",\"inclusion and democracy\",\"journal of european social policy\",\"science & diplomacy\",\"fiscal policy of the philippines\",\"territorialisation of carbon governance\",\"centre for health and international relations\",\"dominium maris baltici\",\"journal of ethnic and migration studies\",\"mediations (journal)\",\"antemurale myth\",\"william james booth\",\"say's political economy\",\"marian van landingham\",\"kansas city preventive patrol experiment\",\"predictive policing\",\"gwendolen m. carter\",\"winner-take-all politics\",\"health policy in bangladesh\",\"the end of liberalism\",\"expansionary fiscal contraction\",\"journal of the european economic association\",\"worldwide influence of the constitution of the united states\",\"quadrilateral security dialogue\",\"marcellina (gnostic)\",\"electronic process of law\",\"jurisprudence of concepts\",\"hannah arendt institute for totalitarianism studies\",\"david e. campbell (political scientist)\",\"the democratic paradox\",\"alex brillantes jr.\",\"slapsoftware\",\"comparing media systems\",\"transformation processes (media systems)\",\"martens centre\",\"mariya gabriel\",\"greek withdrawal from the eurozone\",\"edinburgh university socialist society\",\"global apartheid\",\"environmental policy of the european union\",\"bankocracy\",\"(don't) touch me on my studio\",\"policy studies journal\",\"corporate anniversary\",\"eric helleiner\",\"list of public works ministries\",\"ministry of land, infrastructure, transport and tourism\",\"pakistan public works department\",\"western cape department of transport and public works\",\"jewish-palestinian living room dialogue group\",\"ursula apitzsch\",\"valerie bryson\",\"brigitte young\",\"coppieters foundation\",\"svetlana tatunts\",\"international workers' day\",\"thucydides trap\",\"\\u00fcmit cizre\",\"public image of cristina fern\\u00e1ndez de kirchner\",\"magna carta for philippine internet freedom\",\"digest of middle east studies\",\"risk, hazards & crisis in public policy\",\"communist front\",\"domestic trade\",\"proactive law\",\"sexual jihad\",\"katharine hayhoe\",\"economic stimulus appropriations act of 1977\",\"the indian struggle\",\"praxis: the fletcher journal of human security\",\"technoliberalism\",\"sovereignty of puerto rico during the cold war\",\"glory to ukraine\",\"glory to hong kong\",\"logology (science)\",\"how voters feel\",\"indonesian village law\",\"people's democracy (marxism\\u2013leninism)\",\"salvador minguij\\u00f3n adri\\u00e1n\",\"democratic marxism\",\"sam potolicchio\",\"australian journal of political science\",\"communist era\",\"margaret clark (political scientist)\",\"ministry of housing and works (pakistan)\",\"theory x and theory y\",\"galician student league\",\"erguer-estudantes da galiza\",\"xeira\",\"comit\\u00e9s abertos de estudantes\",\"revolutionary students federation\",\"robert kent gooch\",\"free market fairness\",\"keep indy indie\",\"canadian public policy\",\"galician workers union\",\"international area studies review\",\"arab barometer\",\"marco tarchi\",\"brandalism\",\"w. meredith bacon\",\"rena dourou\",\"ed miliband bacon sandwich photograph\",\"public image of narendra modi\",\"cipp evaluation model\",\"international journal of intelligence and counterintelligence\",\"danish defence agreement 2013\\u20132017\",\"fiscal transparency\",\"neoclassical liberalism\",\"school of public policy at central european university\",\"usul fiqh in ja'fari school\",\"political geography (journal)\",\"journal of european integration\",\"custom (catholic canon law)\",\"fiscal capacity\",\"notary (catholic canon law)\",\"debate chamber\",\"policy sciences\",\"classification of advocacy groups\",\"politics (academic journal)\",\"jane duckett\",\"peruvian nitrate monopoly\",\"social welfare in luxembourg\",\"grab em by the pussy\",\"maxims of islamic law\",\"oliver lepsius\",\"open energy system databases\",\"green industrial policy\",\"environmental politics (journal)\",\"violence peace and peace research\",\"reichsministerium des innern\",\"the hidden hand: middle east fears of conspiracy\",\"ariane chebel d'appollonia\",\"celeb jihad\",\"jihad satire\",\"democracy and security\",\"principles of political economy (malthus book)\",\"neoauthoritarianism (china)\",\"pilar calveiro\",\"terry karl\",\"marlon bundo\",\"social impact entertainment\",\"primakov readings\",\"emilia justyna powell\",\"passing on the right\",\"fascism: a warning\",\"priya kurian\",\"we don't coast\",\"carles boix\",\"history of democratic socialism\",\"svoboda ili smart\",\"niamh reilly\",\"the permanent revolution and results and prospects\",\"triangular diplomacy\",\"joe biden (the onion)\",\"american political thought\",\"european school of political and social sciences\",\"yelyzaveta yasko\",\"enemy of the people (albania)\",\"all animals are equal, but some animals are more equal than others\",\"val\\u00e9rie igounet\",\"marie-christine kessler\",\"adaptive capacity\",\"carbon bubble\",\"malinda s. smith\",\"v-dem institute\",\"louise dandurand\",\"raisons politiques\",\"nonna mayer\",\"aromanian question\",\"catherine wihtol de wenden\",\"alexandra goujon\",\"murfee\",\"rasma k\\u0101rkli\\u0146a\",\"lorena parini\",\"challengeaccepted\",\"red wall (us politics)\",\"frente despertar\",\"behavioral public administration\",\"zombie liberalism\",\"bibliography of works about communism\",\"no war, no peace\",\"catherine eschle\",\"making peace\",\"contemporary voices\",\"rent extraction\",\"history of social democracy\",\"alva myrdal\",\"comunismo a la tica\",\"marginal factor cost\",\"conservative research department\",\"the counter-revolution of science\",\"industry (economics)\",\"wood industry\",\"contingent claim analysis\",\"fama\\u2013french three-factor model\",\"binomial options pricing model\",\"financial models with long-tailed distributions and volatility clustering\",\"volatility clustering\",\"skew\",\"low-volatility anomaly\",\"market microstructure\",\"list of financial economists\",\"superrationality\",\"erwin plein nemmers prize in economics\",\"infant industry argument\",\"leonid kantorovich\",\"sustainable development goal 14\",\"development-supported agriculture\",\"edgeworth binomial tree\",\"list of countries by share of income of the richest one percent\",\"charlie bean (economist)\",\"fabrizio zilibotti\",\"american system of manufacturing\",\"inside contracting\",\"unevenly spaced time series\",\"maturity transformation\",\"timo ter\\u00e4svirta\",\"freelancer\",\"quaternary sector of the economy\",\"voluntary sector\",\"weston a. price foundation\",\"abnormal profit\",\"risk factor (finance)\",\"efficiency wage\",\"obshchina\",\"sharon oster\",\"lag operator\",\"index (economics)\",\"private highway\",\"commodity credit corporation\",\"risk management agency\",\"alpha (finance)\",\"reproduction (economics)\",\"marginal propensity to import\",\"economic humanitarianism (ra\\u00eblianism)\",\"tax-allocation district\",\"black\\u2013derman\\u2013toy model\",\"bishop\\u2013cannings theorem\",\"list of jewish american economists\",\"asset specificity\",\"mesoeconomics\",\"centre for appropriate technology (australia)\",\"jacob hollander\",\"vertical farming\",\"el centro integrado de technologia appropriada\",\"bipu\",\"google finance\",\"walras's law\",\"pierre-andr\\u00e9 chiappori\",\"gerald shove\",\"corn exchange\",\"iza institute of labor economics\",\"songun\",\"ap microeconomics\",\"lump-sum tax\",\"self-defeating prophecy\",\"consumption distribution\",\"economics (textbook)\",\"analysis of rhythmic variance\",\"secular variation\",\"technical indicator\",\"institute for international economic studies\",\"martin hellwig\",\"foundation for european economic development\",\"george hilton (historian)\",\"robert ekelund\",\"nayakrishi\",\"supreme court economic review\",\"united states farm bill\",\"national agricultural policy center\",\"drought tolerance\",\"structural estimation\",\"indirect inference\",\"methodology of econometrics\",\"principles of economics (marshall book)\",\"momentum (finance)\",\"istv\\u00e1n hont\",\"financial innovation\",\"foreclosure rescue\",\"tore ellingsen\",\"black hole bomb\",\"alternative financial service\",\"masters in agricultural economics\",\"qem\",\"richard timberlake\",\"3g (countries)\",\"benefit financing model\",\"knowledge assessment methodology\",\"weak and strong sustainability\",\"stochastic investment model\",\"garman-kohlhagen model\",\"economics handbooks\",\"rethinking economics\",\"pricing kernel\",\"roll-geske-whaley\",\"wallace neutrality\",\"ecological economics (journal)\",\"paul de grauwe\",\"cumulative process\",\"state price density\",\"outworker\",\"peter jaeckel\",\"farshid jamshidian\",\"gustav stolper prize\",\"taxation in uruguay\",\"w. kip viscusi\",\"murray's hypocycloidal engine\",\"woolrich electrical generator\",\"civilizing the economy\",\"investment arbitration\",\"k\\u00e4the leichter\",\"sex and reason\",\"giancarlo corsetti\",\"venture capital in spaceflight\",\"blue justice\",\"time warp edit distance\",\"journal of behavioral and experimental economics\",\"the reformation in economics\",\"charles henry hull\",\"austerity: the history of a dangerous idea\",\"hicks-tinbergen award\",\"benny moldovanu\",\"l'empire de la honte\",\"francesco caselli\",\"interprovincial migration in canada\",\"beatrice cherrier\",\"ioana marinescu\",\"benjamin moll\",\"paola giuliano\",\"andrea weber\",\"pauline barrieu\",\"two-sided matching\",\"jane semeleer\",\"arif ahmed (philosopher)\",\"yakama manty jones\",\"eric french (professor)\",\"wilson doctrine (economics)\",\"gold-collar worker\",\"ecodynamics\",\"payment for ecosystem services\",\"greenwashing\",\"conspicuous conservation\",\"moor's head (heraldry)\",\"nw 39th street enclave\",\"cover-up\",\"energy research & social science\",\"garden of allah (cabaret)\",\"cooper do-nuts riot\",\"julia's on broadway\",\"sustainability standards and certification\",\"porter hypothesis\",\"demonstration effect\",\"noel ignatiev\",\"concession (contract)\",\"scare\",\"burlesque\",\"center on conscience & war\",\"the culture of narcissism\",\"sissyphobia: gay men and effeminate behavior\",\"doing gender\",\"suzanne kessler\",\"organigraph\",\"philosophy of max stirner\",\"john murray cuddihy\",\"das argument\",\"control (management)\",\"west pride\",\"encyclopedia of women and islamic cultures\",\"lowell l. bennion\",\"medical sociologist\",\"alphons silbermann\",\"list of countries by labour force\",\"digital ecosystem\",\"argument from authority\",\"the state (book)\",\"doncaster pride\",\"gochisosama\",\"organizational space\",\"angst und vorurteil\",\"civil discourse\",\"archon fung\",\"social service review\",\"norwegian journal of sociology\",\"verbal self-defense\",\"renata salecl\",\"sustainability and environmental management\",\"eugen relgis\",\"list of bordering countries with greatest relative differences in gdp (ppp) per capita\",\"time & society\",\"gender and development\",\"civilian-based defense\",\"kurt heinrich wolff\",\"nonprofit and voluntary sector quarterly\",\"global social policy\",\"list of scientific occupations\",\"richard rottenburg\",\"the morals of chess\",\"summerhill (book)\",\"viola klein\",\"discrimination against autistic people\",\"resource justice\",\"programme for economic advancement and community empowerment\",\"numbers (vancouver)\",\"black eagle (montreal)\",\"revisionist school of islamic studies\",\"family disruption\",\"silence=death project\",\"research in social stratification and mobility\",\"word gap\",\"flourish of approval\",\"carmen a. mir\\u00f3\",\"martine-anstett award\",\"critique of modernity\",\"organizational adaptation\",\"performative activism\",\"knowledge of the holocaust in nazi germany and german-occupied europe\",\"sustainable development goal 17\",\"sustainable development goal 12\",\"sustainable development goal 11\",\"rajputisation\",\"anti-gender campaigns in europe\",\"list of countries by inequality-adjusted income\",\"delmos jones\",\"daphne dorman\",\"capital (marxism)\",\"obtundation\",\"psychomotor retardation\",\"multidimensional aptitude battery ii\",\"sleep-learning\",\"repeatability\",\"biorhythm (pseudoscience)\",\"richard wiseman\",\"johann friedrich herbart\",\"reliability (statistics)\",\"who moved my cheese?\",\"psychological resistance\",\"eustress\",\"direct and indirect realism\",\"levitation (paranormal)\",\"sopor (sleep)\",\"list of cycles\",\"disordered eating\",\"slain in the spirit\",\"aversives\",\"imaginary audience\",\"motivational salience\",\"just-noticeable difference\",\"titicut follies\",\"task analysis\",\"blink: the power of thinking without thinking\",\"adaptive unconscious\",\"implicit-association test\",\"influence: science and practice\",\"waking the tiger\",\"sock puppet account\",\"flashback (psychology)\",\"harvey jackins\",\"international association of art critics\",\"neural adaptation\",\"nominative determinism\",\"rage (emotion)\",\"meta learning\",\"mentalization\",\"how are we to live?\",\"sensory threshold\",\"affect (psychology)\",\"david marks (psychologist)\",\"categorical perception\",\"minsky's burlesque\",\"pseudodysphagia\",\"mental environment\",\"hypnodermatology\",\"why zebras don't get ulcers\",\"cat intelligence\",\"international general medical society for psychotherapy\",\"paul ferdinand schilder\",\"comprehension approach\",\"sascha altman dubrul\",\"grotesque body\",\"lady wonder\",\"ego integrity\"],\"node_colour\":[\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#208F8C\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#FDE724\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#FDE724\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#440154\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#208F8C\",\"#FDE724\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#3B518A\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#5BC862\",\"#FDE724\",\"#440154\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#3B518A\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#FDE724\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#3B518A\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#440154\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#FDE724\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#FDE724\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#208F8C\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#FDE724\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#208F8C\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#440154\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#208F8C\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#208F8C\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#440154\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#FDE724\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#208F8C\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#208F8C\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#208F8C\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#440154\",\"#FDE724\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#FDE724\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#208F8C\",\"#FDE724\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#3B518A\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#3B518A\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#3B518A\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#3B518A\",\"#5BC862\",\"#208F8C\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#3B518A\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#440154\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#5BC862\",\"#3B518A\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#5BC862\",\"#5BC862\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#3B518A\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#FDE724\",\"#208F8C\",\"#440154\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#440154\",\"#208F8C\",\"#208F8C\",\"#5BC862\",\"#440154\",\"#440154\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#440154\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#208F8C\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#3B518A\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#5BC862\",\"#440154\",\"#3B518A\",\"#440154\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#5BC862\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#208F8C\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#440154\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\"],\"node_sizes\":[70.5,8.5,15.0,19.5,16.75,6.5,28.5,0.25,5.25,1.0,2.25,16.25,1.0,5.5,13.5,3.25,0.25,51.75,19.5,18.75,23.5,6.75,11.25,12.25,4.75,76.5,17.5,22.25,1.75,1.75,16.75,3.5,4.0,2.75,2.25,2.75,1.5,11.0,26.5,5.75,3.5,2.0,4.25,15.5,2.5,5.75,3.0,3.0,2.0,2.25,2.75,1.25,1.5,2.75,2.0,0.75,1.0,9.75,3.25,12.0,2.25,1.75,10.5,4.75,0.5,3.5,1.25,4.0,1.75,2.25,5.0,0.25,0.25,20.25,0.25,0.25,0.5,4.75,0.75,5.5,4.0,2.0,22.0,7.0,1.0,6.0,7.75,6.0,0.5,15.0,5.25,22.0,14.75,4.25,5.75,4.25,0.5,21.75,20.5,8.0,12.25,6.0,0.75,1.75,5.5,0.5,15.5,2.0,0.75,0.5,0.25,14.25,0.25,1.25,4.75,40.75,7.5,5.75,8.75,5.25,3.5,6.25,5.25,4.75,4.25,0.5,2.0,1.25,0.75,0.75,0.75,0.25,0.5,0.5,1.0,0.5,4.5,2.5,7.5,34.25,28.25,6.75,2.0,7.75,43.5,0.25,0.5,1.5,0.25,0.5,0.25,0.5,12.75,29.25,0.25,18.25,12.25,16.0,9.25,16.0,16.0,18.0,7.75,4.0,5.5,3.0,2.0,3.25,1.25,1.75,4.0,1.0,1.25,0.25,0.5,5.75,8.0,1.25,1.0,1.75,7.75,12.5,1.0,19.75,1.0,6.0,0.25,1.0,0.25,2.25,3.75,4.5,3.0,0.5,0.5,0.5,8.0,2.25,1.5,4.0,17.5,3.0,0.75,5.25,2.25,9.0,8.5,6.5,1.25,2.75,0.5,4.5,0.75,4.25,12.5,0.25,12.75,14.5,1.0,10.25,16.0,13.75,7.5,10.0,13.5,8.0,25.75,4.0,9.25,2.75,2.0,5.25,3.0,2.0,4.75,2.5,2.75,3.25,5.75,3.25,8.5,5.5,8.25,3.5,2.25,2.0,6.5,4.75,1.75,1.75,2.0,1.75,1.75,7.25,0.75,1.25,3.25,0.25,0.25,1.0,1.75,2.0,0.75,4.0,0.25,0.75,4.5,6.0,4.5,6.75,4.5,8.25,6.75,5.25,11.0,4.5,4.75,5.0,3.75,3.5,0.75,1.75,3.75,6.0,3.75,3.0,1.5,3.25,6.75,1.25,1.25,1.25,8.25,1.75,1.5,1.5,3.75,2.25,1.75,7.75,1.5,1.25,1.5,8.5,3.25,3.75,2.75,6.25,2.25,4.75,1.25,1.5,0.5,10.25,0.5,4.0,4.5,4.75,5.25,1.5,1.25,1.75,7.5,0.75,1.0,3.5,0.5,5.25,0.5,0.25,16.75,1.0,1.5,16.0,1.75,0.5,0.25,0.25,8.25,5.0,1.75,4.0,2.25,2.5,4.0,1.0,1.25,7.0,3.5,1.75,1.75,0.5,0.25,4.0,2.5,0.5,0.25,1.5,1.5,2.0,1.75,1.5,3.5,5.75,6.25,1.0,4.5,0.25,0.25,1.0,0.5,1.25,1.0,1.0,1.0,5.0,11.0,4.0,3.5,1.25,4.25,6.75,0.25,0.5,0.25,0.5,0.25,0.25,1.25,0.25,2.5,2.25,0.5,0.75,0.75,0.75,0.25,0.5,7.0,6.5,8.25,5.0,3.75,9.0,9.5,4.5,2.0,3.25,1.75,1.0,0.5,0.5,0.25,5.25,0.25,0.75,0.5,1.75,0.25,1.25,0.25,0.75,0.5,0.75,5.0,0.75,4.5,0.75,5.0,0.25,1.5,2.0,1.5,2.0,0.25,0.25,4.75,0.75,0.25,0.25,0.75,0.25,0.5,0.25,0.5,6.75,6.25,2.0,3.75,4.5,4.75,6.25,1.5,2.5,0.5,2.25,3.25,0.75,1.75,2.25,0.25,3.5,2.75,2.25,1.75,0.75,2.0,4.0,0.25,0.25,0.75,3.0,3.25,11.25,0.25,4.25,0.5,0.25,2.75,2.75,3.0,7.25,4.0,5.0,6.75,6.0,6.5,0.5,0.25,4.25,2.75,4.5,2.0,2.0,1.25,4.5,5.5,3.25,9.0,8.25,6.5,6.5,5.5,3.25,10.5,2.75,2.25,4.0,0.5,1.5,1.0,1.25,1.5,1.5,3.0,4.0,9.25,4.0,7.25,5.5,5.25,3.0,3.25,2.75,16.75,1.25,4.5,5.75,2.0,1.25,1.25,3.5,0.5,1.25,0.5,2.25,3.0,2.0,0.5,0.75,0.75,3.5,6.5,9.25,0.25,2.25,7.75,3.5,5.0,23.0,2.25,2.5,1.5,7.5,1.5,10.0,7.25,4.0,6.0,0.5,0.25,1.25,1.0,1.25,2.0,2.0,5.5,13.5,13.0,14.5,2.75,9.75,2.75,0.75,0.25,2.25,2.0,6.0,3.5,3.0,1.0,9.75,5.0,6.5,0.25,3.75,5.0,16.75,3.5,0.5,0.75,1.75,1.5,2.0,0.5,1.25,1.5,2.75,10.0,8.5,1.75,8.0,3.75,3.5,0.5,0.75,3.75,0.5,2.0,1.75,1.75,1.0,1.5,0.5,0.25,1.0,7.75,8.75,12.25,4.75,4.5,13.25,7.0,0.75,0.5,0.75,5.25,1.0,4.5,13.0,12.0,11.25,5.5,8.0,10.0,9.5,0.5,1.75,2.25,3.0,3.0,3.0,0.75,0.5,0.75,1.0,8.5,0.75,2.75,0.5,0.75,7.0,10.75,6.75,10.25,6.0,19.25,12.5,10.0,4.75,10.25,4.5,0.5,4.5,5.25,7.5,2.25,1.0,8.0,0.5,2.75,0.5,2.0,1.75,2.5,3.25,19.25,5.5,8.0,9.0,0.75,1.0,0.75,0.5,1.0,0.75,1.0,1.75,6.0,4.25,1.25,4.0,0.25,4.75,0.5,1.25,2.75,3.25,0.5,0.5,0.25,1.25,3.75,3.75,7.75,0.5,0.5,0.75,0.25,2.5,1.25,1.5,8.5,0.25,0.25,2.25,0.75,1.5,5.25,2.5,0.5,5.0,9.25,4.75,1.25,0.75,0.5,0.5,2.0,0.25,0.5,2.5,0.75,0.25,1.0,0.75,7.0,0.25,0.25,0.75,8.5,6.0,0.25,1.5,0.5,0.75,0.25,0.5,0.5,1.0,1.25,3.0,4.75,3.0,0.75,1.75,0.75,2.0,0.75,2.0,1.25,0.5,0.5,0.5,0.25,2.0,7.25,8.25,3.25,3.75,3.5,3.0,4.5,3.25,11.0,0.25,0.5,0.75,0.25,2.75,1.0,0.75,1.25,1.5,1.5,4.5,2.75,0.25,0.5,0.25,1.5,0.25,0.75,0.5,1.0,0.75,0.25,4.25,6.0,0.5,0.75,1.5,4.75,0.25,5.0,0.5,0.25,0.25,2.25,0.5,0.5,0.5,1.0,0.25,0.75,7.75,0.75,0.75,4.5,3.25,8.5,3.75,0.25,0.5,0.25,0.75,1.0,0.25,0.25,0.25,0.5,0.25,0.25,0.25,0.25,0.5,0.25,0.25,2.0,0.25,0.25,0.25,2.5,2.75,0.25,1.0,0.25,2.75,0.75,0.5,0.5,0.5,0.5,0.75,0.5,0.75,1.25,0.25,0.5,3.75,0.25,3.0,0.25,0.75,0.25,0.25,0.25,0.75,0.25,0.25,0.25,1.25,2.25,0.5,1.25,1.25,1.25,1.75,2.75,0.25,0.25,1.0,0.25,1.5,0.75,1.0,0.5,3.0,2.75,2.25,4.25,2.25,3.75,3.25,0.75,5.75,6.75,7.25,6.75,0.25,0.25,1.75,2.0,1.0,3.25,0.5,6.75,1.5,2.25,8.0,3.5,4.5,4.5,2.75,2.5,2.25,3.25,2.25,0.25,1.75,1.75,5.0,1.25,1.5,7.75,0.25,1.25,0.5,1.0,0.75,4.25,1.5,2.5,3.0,1.0,0.75,1.25,1.75,0.5,5.75,2.75,5.25,1.25,0.75,2.0,4.0,2.75,2.75,2.25,2.5,5.0,1.25,5.75,0.25,1.25,1.25,0.25,4.0,3.25,3.0,1.25,1.0,1.5,0.25,3.25,1.0,3.5,1.75,2.75,0.75,0.75,0.5,4.75,9.25,2.25,1.25,0.5,4.5,0.5,4.5,0.75,1.5,1.5,3.25,0.5,0.25,1.75,1.0,1.0,1.0,1.75,0.25,3.25,0.75,1.0,0.5,0.5,0.25,0.75,0.5,0.75,0.5,0.25,1.75,3.25,1.5,1.75,0.25,0.25,0.25,0.25,0.5,0.25,0.75,1.0,0.5,0.5,0.25,1.75,0.5,0.5,0.25,0.75,0.75,0.75,1.0,1.5,0.5,1.25,0.75,5.0,0.75,0.5,0.25,0.25,1.5,0.25,0.25,1.0,1.0,1.0,1.5,2.75,3.25,1.5,0.75,3.0,0.25,0.75,0.25,2.0,0.25,1.5,1.5,3.0,3.0,1.25,0.75,0.5,2.0,0.25,0.5,3.0,0.75,0.25,3.25,0.5,0.5,0.75,0.25,0.5,0.5,1.5,0.25,1.5,1.0,1.25,0.5,0.75,0.75,0.25,2.25,0.25,0.75,1.25,0.25,2.75,0.25,0.5,0.25,2.5,6.25,0.25,0.75,0.25,0.5,1.25,5.75,2.5,3.75,0.75,0.25,0.75,0.5,0.75,0.25,0.5,0.25,0.5,1.25,2.0,1.0,0.75,0.25,0.75,3.5,0.75,0.5,6.0,5.75,1.25,2.5,5.75,2.75,2.25,4.25,3.5,3.0,2.75,2.5,2.25,0.25,0.5,6.0,3.5,0.25,0.25,0.25,0.75,0.25,1.25,0.5,3.25,0.25,1.0,0.25,2.75,4.75,6.75,2.75,1.0,6.5,3.0,0.5,0.25,0.25,4.5,0.75,4.25,3.0,2.0,5.25,7.5,7.25,4.5,5.75,2.5,1.0,3.5,0.25,1.75,1.5,1.75,2.0,0.5,0.25,1.0,0.75,0.25,1.0,1.0,2.0,1.0,4.0,1.75,1.0,0.25,0.25,9.5,2.5,1.5,0.25,0.25,4.0,1.75,1.0,0.75,2.0,0.25,0.25,2.0,0.5,7.75,2.25,1.5,0.25,1.5,2.25,1.75,1.5,3.5,1.5,3.0,0.25,1.0,0.75,2.75,0.75,7.25,2.75,2.25,1.25,10.25,3.25,1.75,0.75,1.0,3.75,20.5,0.5,0.25,5.75,8.5,2.75,2.25,0.75,0.75,0.5,0.25,3.25,0.25,2.0,0.5,1.5,3.25,0.25,0.5,1.0,3.0,2.25,2.75,1.5,0.25,0.75,1.25,0.5,2.5,0.25,3.75,4.0,4.0,5.5,3.75,3.5,4.0,1.0,0.25,0.75,1.5,0.25,0.25,1.0,9.0,0.5,0.25,0.75,1.5,0.75,1.25,0.25,0.25,0.75,1.25,0.5,0.25,2.75,1.0,7.75,8.0,0.25,0.75,1.0,0.75,0.5,0.25,0.5,1.25,3.0,1.5,3.0,1.5,0.25,0.5,0.25,0.25,0.25,0.5,2.25,0.25,0.5,0.5,0.25,4.25,8.0,7.5,7.5,8.0,7.75,1.25,0.5,1.0,0.5,1.75,1.75,0.25,0.25,2.25,1.0,0.5,0.25,0.25,0.5,2.5,0.75,2.25,0.25,4.25,6.25,0.5,0.5,0.75,2.5,0.25,0.25,4.0,0.25,0.75,0.25,0.25,2.5,1.5,0.25,2.75,0.75,0.5,1.0,0.25,0.25,0.75,0.25,3.75,0.25,0.25,5.5,0.5,0.5,0.25,2.5,1.5,0.5,0.5,2.5,0.25,0.75,0.5,0.5,2.5,0.25,1.5,2.0,0.25,0.25,1.75,3.5,1.5,0.25,0.75,0.25,2.0,0.25,0.25,1.75,0.25,1.5,0.5,0.25,1.5,0.5,3.5,2.25,0.5,1.5,0.25,0.25,0.5,2.75,4.0,1.25,2.25,0.75,1.5,0.25,2.0,1.75,1.0,1.25,2.0,0.5,1.0,0.25,3.0,2.5,3.5,1.0,3.0,0.75,0.75,2.75,1.75,1.25,2.0,1.25,1.25,1.25,0.5,2.5,0.5,2.25,1.25,0.75,4.25,5.0,3.25,0.25,0.25,0.5,1.0,2.25,1.75,1.75,1.0,0.5,0.5,0.25,4.25,0.25,1.75,1.75,1.25,0.75,1.25,1.0,2.5,0.25,1.0,0.25,0.75,0.5,1.75,0.75,0.75,1.0,1.25,2.0,2.5,0.25,0.5,0.75,1.5,1.0,0.25,0.25,0.25,0.75,0.5,0.25,0.25,0.25,0.5,0.75,0.5,0.5,2.5,0.25,0.5,0.25,0.25,0.5,0.25,0.75,0.75,0.25,0.5,1.0,0.25,0.75,1.25,1.0,1.25,0.5,0.75,1.25,1.25,1.25,1.5,0.75,0.5,0.5,1.0,0.25,0.25,0.25,0.25,2.5,0.75,1.25,1.75,1.0,0.5,0.25,0.25,0.25,0.75,0.5,0.25,4.75,1.0,0.25,0.5,0.25,0.25,0.25,1.0,1.5,0.25,1.5,0.25,0.5,0.25,6.0,1.5,0.25,1.5,0.5,3.0,2.0,1.25,0.5,6.75,4.75,0.75,0.5,0.5,0.5,0.5,0.25,0.25,0.5,0.25,0.25,0.5,0.5,0.5,0.25,0.5,0.25,0.25,1.0,0.75,4.25,0.25,0.5,0.5,0.25,0.75,1.0,0.25,2.0,0.5,0.5,1.0,0.25,0.25,1.25,0.25,1.0,1.0,0.5,0.5,0.25,0.25,0.25,0.75,0.25,0.75,2.75,1.5,0.5,1.25,0.25,1.0,0.5,9.0,1.75,3.5,0.75,2.75,3.25,2.5,4.0,2.5,3.0,1.0,0.25,4.75,4.5,4.0,3.5,2.5,1.75,3.5,5.25,0.5,0.5,2.5,1.75,4.75,3.0,2.5,1.75,6.0,1.75,2.5,2.25,4.5,2.5,0.25,0.25,1.0,2.0,0.75,7.0,1.0,1.0,2.5,5.25,1.25,1.5,2.0,1.0,0.75,3.0,1.0,0.5,0.5,7.0,1.25,1.0,0.5,1.25,0.75,0.25,0.5,1.0,2.75,5.5,0.25,4.0,1.75,1.75,2.25,1.0,3.0,1.0,0.5,0.25,0.25,0.75,1.5,1.0,0.25,0.25,3.25,0.25,4.0,3.75,1.75,0.25,1.5,1.25,1.75,1.75,0.75,5.5,0.75,0.25,2.25,0.25,1.0,0.75,0.25,1.0,0.25,1.75,0.25,0.25,0.25,1.75,0.5,0.25,0.75,1.0,0.75,1.0,1.0,1.5,1.75,1.0,1.0,2.25,1.5,0.25,0.5,0.5,0.5,0.25,0.25,2.0,1.75,2.75,2.0,2.0,0.5,0.25,1.75,0.25,0.25,1.5,0.5,4.0,1.25,1.25,0.25,0.25,1.75,0.25,4.0,1.0,0.25,0.25,0.25,0.75,0.25,3.0,1.0,0.25,0.5,0.25,2.0,0.25,4.0,0.25,0.25,3.0,2.25,0.25,0.5,0.25,1.0,0.25,0.25,0.25,0.25,0.25,0.25,1.75,2.75,0.25,1.0,0.25,4.5,4.75,0.25,3.75,1.25,1.75,0.5,1.75,1.25,0.25,0.25,1.0,0.25,0.25,0.75,1.0,1.5,0.25,1.5,5.75,1.5,2.5,2.0,2.25,5.25,0.25,0.5,0.5,0.75,2.0,0.25,0.75,2.0,0.75,1.0,1.0,0.25,1.25,1.25,2.0,5.5,2.0,2.0,4.0,4.5,0.5,0.25,0.5,0.5,1.5,0.5,0.25,2.0,1.0,0.75,2.0,0.5,0.75,0.25,1.5,1.5,0.5,2.0,0.5,2.0,0.75,0.5,0.25,1.5,0.5,0.75,0.75,0.25,0.25,0.25,0.5,0.25,0.75,1.75,1.25,0.25,0.75,0.5,0.5,0.75,0.5,0.25,3.25,0.25,0.75,0.5,0.25,0.25,1.25,0.25,0.25,2.25,0.75,1.75,1.0,0.75,0.25,0.25,0.5,0.5,4.0,0.25,0.5,2.5,0.25,0.25,0.5,0.75,1.5,2.25,1.25,1.25,0.75,1.0,0.75,2.0,2.5,3.25,0.25,1.75,1.25,0.25,1.25,1.0,6.75,0.25,1.0,0.25,0.25,0.5,3.0,1.0,0.75,1.25,0.25,1.0,5.5,0.25,0.5,0.25,1.75,0.75,0.75,0.25,0.25,0.75,4.0,3.5,2.5,0.75,0.25,0.25,0.5,1.25,1.0,0.75,0.75,0.5,0.25,0.5,0.75,2.0,0.75,0.75,1.0,0.25,3.25,0.5,0.5,0.75,0.25,0.25,0.75,0.25,1.75,1.75,0.25,2.25,0.5,0.25,0.75,0.25,0.25,0.75,3.25,0.5,1.5,0.25,0.25,0.25,0.5,0.5,0.25,1.0,0.5,0.75,0.25,0.75,1.5,0.5,1.0,0.25,1.25,0.5,0.75,3.5,0.75,0.75,0.25,0.25,1.0,0.25,0.25,1.75,0.5,0.25,0.75,1.75,1.0,1.0,0.75,0.25,0.5,0.25,1.5,0.5,1.5,1.5,0.75,1.5,0.75,0.5,0.25,0.5,0.75,0.5,0.25,0.25,0.75,1.5,1.5,1.0,0.25,0.5,1.75,0.5,1.0,1.75,0.5,0.5,0.25,0.25,0.25,0.25,0.25,0.5,1.0,0.25,0.5,0.25,0.5,0.5,0.25,0.25,0.5,0.75,4.0,0.75,0.25,0.25,0.25,0.25,0.25,0.25,0.25,15.5,0.5,0.25,0.25,0.25,2.25,0.25,0.5,0.25,0.25,0.5,0.5,0.25,0.75,0.25,1.0,1.25,0.25,1.0,0.25,0.25,0.25,0.25,0.25,3.25,0.25,0.75,0.25,0.25,0.25,0.25,0.25,2.0,1.5,2.0,0.25,0.5,0.25,0.25,0.25,0.5,0.25,0.75,0.75,1.75,1.5,0.25,0.75,0.25,0.25,0.25,0.5,0.75,1.0,0.5,0.25,0.25,0.25,0.25,0.25,0.25,0.5,1.0,0.25,0.5,0.25,0.25,0.25,0.5,1.5,0.25,1.75,0.25,0.25,1.75,0.5,2.5,0.5,0.25,0.25,1.0,0.75,0.25,1.0,0.5,0.5,0.75,0.25,0.25,0.5,0.5,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.5,0.75,0.75,0.5,0.25,0.25,0.25,1.75,0.25,0.25,0.25,0.25,2.5,0.25,0.25,0.25,0.25,0.5,1.75,1.25,0.25,0.25,0.5,0.25,1.25,0.25,0.25,0.25,0.25,1.0,1.0,0.75,0.75,0.75,5.0,1.5,1.0,1.75,0.75,0.25,0.25,0.5,1.25,0.25,0.5,0.25,0.5,0.5,0.25,0.25,0.5,0.5,0.75,0.5,0.25,0.25,0.25,0.5,0.25,1.5,0.5,0.5,0.25,0.5,1.0,0.25,0.25,2.0,1.5,0.25,1.25,8.5,0.5,0.25,4.25,0.25,0.25,0.25,1.0,1.75,0.25,0.25,0.5,1.5,1.25,1.25,0.75,0.75,0.25,1.25,0.5,0.25,0.75,0.25,0.5,0.75,0.25,0.25,0.5,0.25,0.25,0.25,0.5,0.25,0.25,7.0,0.5,0.75,0.25,0.25,1.0,0.25,1.0,0.5,0.25,0.5,0.5,0.5,0.25,0.25,0.5,0.25,0.25,0.5,0.75,0.25,0.5,0.25,0.25,0.5,0.5,0.25,0.25,0.5,2.0,0.25,0.75,0.75,0.25,0.5,0.25,0.5,0.25,0.25,0.75,0.5,6.25,0.25,0.25,0.5,2.25,0.5,0.25,0.25,0.5,6.75,0.75,0.25,0.5,0.5,0.5,0.5,0.75,0.25,0.5,0.5,1.0,0.25,0.5,0.25,0.25,0.25,1.0,0.25,1.75,0.5,2.5,6.5,0.25,0.25,0.5,0.25,0.75,4.5,1.0,2.0,0.25,0.25,1.25,0.5,1.0,0.25,1.0,1.75,0.75,0.5,0.5,0.75,0.25,2.0,0.75,1.0,0.25,2.5,0.25,0.5,1.5,1.25,0.5,1.5,0.5,0.5,0.25,0.25,0.25,0.75,0.5,0.5,0.25,0.25,1.75,0.75,0.25,0.25,0.25,4.0,0.75,0.75,0.5,1.25,1.75,0.25,0.5,0.25,1.5,0.25,0.5,0.5,1.25,0.25,1.25,0.25,0.25,0.25,0.25,0.25,0.5,0.25,0.25,0.5,0.5,0.25,0.25,0.5,0.25,1.0,0.25,0.5,0.75,0.25,0.75,0.5,0.25,0.25,0.25,0.5,0.5,0.25,0.25,0.5,0.5,0.75,1.25,1.75,0.75,0.25,0.25,0.25,0.25,0.25,0.75,0.5,0.5,0.25,0.25,0.25,0.5,0.25,0.75,0.5,0.25,1.0,1.5,0.25,0.5,0.5,0.25,1.0,0.5,0.25,0.25,0.5,0.75,0.25,1.0,0.75,0.5,0.25,0.25,0.75,0.75,0.5,0.25,0.25,0.25,0.25,1.5,0.75,0.75,0.75,0.25,0.25,1.0,0.25,0.5,0.5,0.25,0.25,0.25,0.5,0.25,0.25,0.25,0.25,0.25,1.5,0.25,1.0,3.25,0.25,0.25,0.25,1.25,1.0,1.0,1.5,0.75,0.5,0.75,0.5,0.75,0.25,5.25,1.25,1.25,0.75,0.75,0.5,0.5,0.25,1.75,0.5,0.25,1.25,0.75,0.25,0.25,2.75,0.25,0.25,0.25,1.25,0.25,0.25,0.5,2.0,0.25,1.25,0.25,0.5,0.25,0.25,0.5,0.5,0.5,1.0,0.25,0.25,0.25,0.25,0.5,0.25,0.25,0.25,0.75,0.25,0.5,2.0,0.25,0.25,0.5,0.5,0.25,1.75,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.5,0.25,0.75,0.25,0.25,0.25,0.5,0.25,1.25,0.25,0.25,0.25,1.25,1.0,0.25,0.5,0.5,0.75,1.5,1.25,1.5,0.25,0.75,0.75,1.25,3.25,0.75,0.5,0.25,0.5,0.5,0.25,0.5,0.25,0.25,0.5,1.0,0.5,1.25,0.25,0.25,0.25,2.5,0.5,0.25,0.25,0.25,4.75,0.5,0.25,0.25,0.25,4.5,0.5,0.75,0.25,0.25,0.25,0.25,0.25,0.75,0.5,0.25,0.75,2.0,0.5,1.5,1.0],\"parent\":[\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"sociology\",\"political_science\",\"sociology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"sociology\",\"anthropology\",\"political_science\",\"anthropology\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"psychology\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"anthropology\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"psychology\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"anthropology\",\"sociology\",\"anthropology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"anthropology\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"sociology\",\"political_science\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"economics\",\"economics\",\"political_science\",\"psychology\",\"anthropology\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"economics\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"psychology\",\"sociology\",\"anthropology\",\"political_science\",\"political_science\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"psychology\",\"political_science\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"economics\",\"anthropology\",\"anthropology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"sociology\",\"anthropology\",\"psychology\",\"psychology\",\"psychology\",\"anthropology\",\"psychology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"psychology\",\"anthropology\",\"psychology\",\"anthropology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"economics\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"political_science\",\"anthropology\",\"political_science\",\"anthropology\",\"sociology\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"anthropology\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"sociology\",\"psychology\",\"sociology\",\"sociology\",\"psychology\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"anthropology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"psychology\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"psychology\",\"psychology\",\"psychology\",\"sociology\",\"sociology\",\"psychology\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"anthropology\",\"political_science\",\"economics\",\"economics\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"psychology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"political_science\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"economics\",\"psychology\",\"economics\",\"economics\",\"economics\",\"economics\",\"psychology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"political_science\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"anthropology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"psychology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"psychology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"political_science\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"psychology\",\"psychology\",\"anthropology\",\"psychology\",\"sociology\",\"psychology\",\"psychology\",\"political_science\",\"anthropology\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"anthropology\",\"sociology\",\"anthropology\",\"psychology\",\"anthropology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"anthropology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"sociology\",\"anthropology\",\"sociology\",\"psychology\",\"sociology\",\"sociology\",\"psychology\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"economics\",\"sociology\",\"economics\",\"psychology\",\"anthropology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"economics\",\"anthropology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"anthropology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"economics\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"sociology\",\"economics\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"anthropology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"psychology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"anthropology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"economics\",\"sociology\",\"psychology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"political_science\",\"anthropology\",\"anthropology\",\"economics\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"political_science\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"psychology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"sociology\",\"economics\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"political_science\",\"sociology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"sociology\",\"sociology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"sociology\",\"psychology\",\"psychology\",\"economics\",\"sociology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"anthropology\",\"psychology\",\"political_science\",\"psychology\",\"psychology\",\"psychology\",\"political_science\",\"psychology\",\"psychology\",\"sociology\",\"political_science\",\"political_science\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"political_science\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"economics\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"psychology\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"economics\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"sociology\",\"political_science\",\"economics\",\"political_science\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"sociology\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"psychology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"sociology\",\"sociology\",\"psychology\",\"sociology\",\"sociology\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"political_science\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\"]},\"selected\":{\"id\":\"1118\"},\"selection_policy\":{\"id\":\"1117\"}},\"id\":\"1065\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"1117\",\"type\":\"UnionRenderers\"},{\"attributes\":{\"active_multi\":null,\"active_scroll\":{\"id\":\"1052\"},\"tools\":[{\"id\":\"1051\"},{\"id\":\"1052\"},{\"id\":\"1053\"},{\"id\":\"1054\"},{\"id\":\"1055\"}]},\"id\":\"1056\",\"type\":\"Toolbar\"},{\"attributes\":{},\"id\":\"1048\",\"type\":\"BasicTicker\"},{\"attributes\":{},\"id\":\"1044\",\"type\":\"BasicTicker\"},{\"attributes\":{\"axis\":{\"id\":\"1047\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"1050\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"1103\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"axis\":{\"id\":\"1043\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"1046\",\"type\":\"Grid\"},{\"attributes\":{\"formatter\":{\"id\":\"1106\"},\"major_label_policy\":{\"id\":\"1104\"},\"ticker\":{\"id\":\"1044\"},\"visible\":false},\"id\":\"1043\",\"type\":\"LinearAxis\"},{\"attributes\":{\"callback\":null,\"tooltips\":[[\"Page\",\"@index\"],[\"Discipline\",\"@parent\"]]},\"id\":\"1055\",\"type\":\"HoverTool\"},{\"attributes\":{},\"id\":\"1118\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"1099\",\"type\":\"Title\"},{\"attributes\":{\"end\":1000,\"start\":-1000},\"id\":\"1034\",\"type\":\"Range1d\"},{\"attributes\":{\"graph_layout\":{\"(don't) touch me on my studio\":[-21.618586513135178,-122.89601523282467],\"1890s in anthropology\":[223.01960807041436,671.9560675200385],\"1910s in anthropology\":[227.96891316519097,624.759777791675],\"1990s in anthropology\":[155.9020940969502,673.6276028482114],\"2000-watt society\":[-376.37698903522426,-535.2596186017832],\"2000s in anthropology\":[209.2161031723677,655.2347600044347],\"3g (countries)\":[-308.09038445577954,-337.51958214580594],\"99ers\":[-104.13539496748349,-500.9860885885996],\"a call to action: women, religion, violence, and power\":[433.1882511203795,-377.1350873943399],\"a green new deal\":[-315.7191438183971,-676.7685794243536],\"abilene paradox\":[-178.22587272945398,-105.33056617549535],\"abnormal profit\":[-135.17778395750574,-848.7157739420286],\"abnormal psychology\":[-283.02703469388837,389.77458958559134],\"accelerator effect\":[-126.58041839587652,-506.6083539054937],\"acceptance\":[-390.89961211325846,713.859381673795],\"acceptance and commitment therapy\":[-658.3585918038841,625.9971527786096],\"accuracy and precision\":[-667.558659584637,344.77622591064136],\"action theory (sociology)\":[63.92424390532064,282.61211338212485],\"adam smith\":[11.470148198635096,-487.36152297825305],\"adaptive capacity\":[-239.48267284707015,-258.6072878284112],\"adaptive unconscious\":[-513.9045869652139,441.54734768901085],\"adlerian\":[-675.1272803243504,685.0045626188111],\"administrative divisions of peru\":[-64.98473672421642,313.3114562364756],\"administrative divisions of portugal\":[82.5450400711165,164.5773755728429],\"advocacy journalism\":[188.20181739936191,-229.80349354966583],\"ad\\u2013ia model\":[-21.508223107548808,-789.2341003279167],\"affect (psychology)\":[-339.91466572988384,723.1917794062605],\"afke schaart\":[583.1051580080726,41.92374077888273],\"afrobarometer\":[-590.3481328455681,34.455873934165055],\"after saturday comes sunday\":[-67.26341049820442,700.1783379441354],\"against equality of opportunity\":[433.636998537808,-305.2123654156439],\"age set\":[331.4354983875953,705.1796746540269],\"agency (philosophy)\":[-72.09294933744073,196.6756922978107],\"agency (sociology)\":[78.16350866929666,287.48702533197314],\"agonism\":[-51.008288588657955,-97.21373238398134],\"ahl al-hadith\":[-520.1300397750872,213.9343820331712],\"aion: researches into the phenomenology of the self\":[-694.2257758752537,742.0559138574379],\"air rights\":[-62.411988295053554,-421.9702589011044],\"ak model\":[-101.11540101190383,-692.3881964232287],\"akademie f\\u00fcr soziologie\":[540.6969057000896,416.79723994889844],\"al-ahram center for political and strategic studies\":[549.2765593094521,57.09598144235819],\"alan wolfe\":[400.40246725040964,-96.81255362583019],\"alchemical studies\":[-667.4914150349824,733.4002289799062],\"alex brillantes jr.\":[593.305161512931,64.5413166577581],\"alexandra goujon\":[604.2889284798393,-56.9832012039816],\"all animals are equal, but some animals are more equal than others\":[13.825060315983073,-25.346925630809455],\"alliance theory\":[141.49740893774847,646.8083101934338],\"alpha (finance)\":[-538.1217255880837,-1173.597368987383],\"alphons silbermann\":[292.17718605880765,52.55953356996059],\"alter ego\":[-414.6483512214803,573.3351906596376],\"altered state of consciousness\":[-481.04037721914165,525.1370912227204],\"altered states\":[-657.5622819927089,360.55490731529767],\"alternative financial service\":[-145.05275039555653,-991.8099351008002],\"alternatives: turkish journal of international relations\":[561.0169175741308,108.63955558277299],\"alva myrdal\":[496.416495677884,-372.20638048990924],\"ambidexterity\":[-344.2776899567438,496.66577298388336],\"american association for the abolition of involuntary mental hospitalization\":[-549.9489114260941,626.4703452380317],\"american journal of political science\":[435.20219846682716,-264.6897091333945],\"american political thought\":[552.7275504786709,98.16924142306027],\"american recovery and reinvestment act of 2009\":[-141.07147799666802,-572.8059667727879],\"american system of manufacturing\":[-604.0332321838092,-22.847938247126166],\"american university school of international service\":[435.3248750842541,-313.00193218908953],\"americanoid\":[228.01723377706057,657.3475166321732],\"amusement\":[-382.29929893350385,732.250856381473],\"an anarchist faq\":[162.51422261088817,-197.46246546386917],\"an economic theory of democracy\":[-101.06834410637612,-332.6724850502421],\"analysis of rhythmic variance\":[-620.2659562295066,-416.5035519521072],\"analytic frame\":[-360.92444034821625,429.9022936108384],\"analytic induction\":[356.30364582227566,444.89110745354094],\"analytical sociology\":[-426.89398625845104,-750.7688805657403],\"anarcho-capitalism\":[61.64497359808563,-280.63307929546636],\"andean civilizations\":[-76.5231199765566,356.42375691098886],\"andrea weber\":[-202.93932032659004,-821.1248322314894],\"andrew westmoreland\":[582.163344081572,59.42195027264523],\"androcentrism\":[17.927067889984638,360.6581703899721],\"andr\\u00e9 du pisani\":[502.11255580756307,-145.79356656248598],\"angkola people\":[672.5549162411095,1459.029714847416],\"anglo-saxon model\":[91.92544488286974,-425.9585713606035],\"angst und vorurteil\":[216.17903715540868,181.86892676600368],\"anguish\":[-430.3547197220452,752.0173545168313],\"anhedonia\":[-694.2415262660318,475.9119794579485],\"animal testing regulations\":[-189.62082409149718,753.4322880155505],\"answer to job\":[-674.8540358245223,727.1051026613964],\"antemurale myth\":[146.39038178325708,135.92663691293177],\"anthony downs\":[-89.29990796487374,-441.92047983900864],\"anthrobotics\":[217.92995930647888,651.5422094582267],\"anthropological criminology\":[12.339769576644128,598.3251599134546],\"anthropological index online\":[163.17907177219055,585.4486837181527],\"anthropological survey of india\":[260.21684356048496,698.1875879876382],\"anthropology\":[152.88845593903997,528.5751045932545],\"anthropology of art\":[224.37193049538462,581.5594907459006],\"anthropology of institutions\":[161.22282799371015,620.5597933608888],\"anthropometric history\":[194.46883204775943,993.1026529393939],\"anti-gender campaigns in europe\":[-25.06870001647177,663.2216332287865],\"anti-gender movement\":[-19.047710741183337,534.9820768741276],\"anti-modernization\":[326.7415057515529,175.71720644670106],\"anti-psychiatry\":[-466.034860545131,470.6030383717564],\"antimilitarism\":[-7.691980522414772,-263.19229389288046],\"antinaturalism (politics)\":[152.58382546797623,423.2436837464245],\"antipositivism\":[-179.56029120307574,179.09098055587063],\"ap comparative government and politics\":[454.4192602727892,-74.4875083055283],\"ap microeconomics\":[-49.600041928280646,-872.5685224799679],\"aparna rao\":[287.20797729709665,536.3332436958291],\"appeasement\":[-256.4119202412436,-130.85800716028223],\"applied anthropology research methods\":[202.39444191117732,547.6069650841077],\"applied psychological measurement\":[-623.3864761249284,285.1630146768608],\"appraisal theory\":[-418.47398547137817,747.6682741239699],\"apprehension (understanding)\":[-539.3968505236711,783.790276237681],\"appropriate technology\":[-211.47529896560667,-595.0141097667533],\"apuli\":[108.92173606753782,419.23466501936974],\"arab barometer\":[460.3983750322678,-123.15264914805644],\"arbitrage pricing theory\":[-467.0300240666304,-1018.6292678998434],\"archaeology\":[189.7555540236725,364.7352539389637],\"archery\":[-922.3711581582091,376.16392315414697],\"archibald crossley\":[-539.5236578789271,2.680467777664774],\"archon fung\":[-822.0885731510846,38.13679911279069],\"area studies\":[119.4525866051168,387.7699945116644],\"argentine forensic anthropology team\":[425.7167651991824,573.2698011199777],\"argument from authority\":[-129.96120620571372,931.4081975239874],\"argument from marginal cases\":[-143.38787958070657,718.94260865719],\"argumentation and advocacy\":[-554.4083019794851,-181.059326647646],\"ariane chebel d'appollonia\":[469.9601134081394,-108.74783684130014],\"arif ahmed (philosopher)\":[-76.04330724216312,305.2253834258511],\"armchair theorizing\":[398.1682313566263,-682.9301273671687],\"aromanian question\":[133.39345840753847,118.06414452368746],\"arrow's impossibility theorem\":[-297.38477271445544,-505.3043217250876],\"arthur evans\":[243.03664100189377,712.1434938669953],\"asabiyyah\":[-10.088439975549912,219.98592901336113],\"asch conformity experiments\":[-79.1445389491316,322.5949800094399],\"ash-shab yurid isqat an-nizam\":[1401.397931502191,137.00111215227133],\"asset specificity\":[-215.5068439819191,-491.9359159302874],\"associationalism\":[164.87459880493412,-135.9883279770055],\"assortative mixing\":[-91.62953220949197,-1681.0219949762059],\"assume a can opener\":[6.326937938145439,-755.2644735096655],\"astrology\":[-347.2463520979772,265.16970769107115],\"astrosociology\":[116.0453923922859,322.3721494203609],\"asu college of public service & community solutions\":[389.3461730521668,385.36765514611153],\"atlanticism\":[-197.06434673897508,-64.52269813224406],\"attachment parenting\":[-371.6165215046662,474.18073870805307],\"attention economy\":[20.934659741692304,-532.9378054459478],\"attorney-general v de keyser's royal hotel ltd\":[-994.0401096732149,-191.11051174735948],\"auction theory\":[-197.1349468177878,-905.2506112931299],\"auditory hallucination\":[-622.9556400247831,591.9854373766008],\"auspicious wedding dates\":[-338.10269735736864,469.91363686647713],\"austerity: the history of a dangerous idea\":[80.37450586664163,-660.7248054122517],\"australian aboriginal kinship\":[130.48142562126392,714.734110549371],\"australian institute of aboriginal and torres strait islander studies\":[100.83276197858405,448.92051801548774],\"australian journal of political science\":[435.7256380642966,-68.90030760877177],\"australian quarterly\":[570.6353263925945,67.87669647416072],\"authoritarian capitalism\":[138.67732575103562,-257.97786509439567],\"authoritarian democracy\":[180.18209919730955,-66.85817668955019],\"authoritarian left\":[112.67360771893476,-78.39451655815905],\"authority (sociology)\":[482.848913745143,193.90455077179845],\"autogenic training\":[-706.5796917972193,614.0694481449979],\"automatic writing\":[-400.20647248997113,416.93306800569394],\"autonomous administrative division\":[-70.58838291782686,-147.01266526408497],\"autonomous communities administration\":[-79.68447911703294,-105.06700321155012],\"autonomous communities of spain\":[-23.483857343694005,-52.04234222260249],\"autonomous consumption\":[-149.25713175452452,-861.1304152019907],\"average fixed cost\":[-51.20618501058369,-918.2066451208992],\"average joe\":[-113.6339097170423,119.64479658825476],\"average variable cost\":[-56.26624632415636,-917.8173856035032],\"aversives\":[-496.8041557383192,608.8401529768345],\"awareness\":[-473.1396855948016,580.9870047296954],\"awza'i\":[-622.0992371458783,253.77503366384158],\"backlash (sociology)\":[241.13587300266852,-12.68640969919187],\"backus\\u2013kehoe\\u2013kydland puzzle\":[-337.0538204486445,-911.1516758222576],\"backward bending supply curve of labour\":[-145.18844210050884,-800.848169714288],\"bad governance\":[-183.59639069380515,-151.78918921555157],\"balassa\\u2013samuelson effect\":[-61.89811421961464,-841.5916989374031],\"balkanization\":[-97.17241709992449,-63.24369744727894],\"bananas, beaches and bases\":[-93.9855991380588,61.50691767256739],\"bankocracy\":[176.00698102631597,-30.892840785671588],\"barbara rogoff\":[-50.29722204760406,592.6023642291493],\"barracks communism\":[384.0918219239496,-177.02273092203814],\"base and superstructure\":[310.0337557166734,-37.065383455105795],\"base period\":[-87.10434739625688,-891.9700068014314],\"basket of deplorables\":[-10.84516521884718,103.77046263416032],\"bay'ah\":[-242.13582962322738,646.2607038815778],\"beatrice cherrier\":[-40.28862897031448,-766.9099182055013],\"beatrice heuser\":[469.5527648470062,-371.68684382685376],\"beckstrom's law\":[-102.41380331692467,-1325.088955178682],\"behavior\":[-349.12879022935994,445.1115402256363],\"behavioral neuroscience\":[-269.8776156691352,344.06330694310043],\"behavioral pharmacology\":[316.928940717737,741.5689367276526],\"behavioral public administration\":[494.3019341461881,55.1363940672343],\"behavioralism\":[20.797317408109922,139.76266309513088],\"behaviour therapy\":[-687.6139668965214,600.1722955767434],\"behavioural despair test\":[-277.33460860836067,739.1215968862218],\"benefit financing model\":[93.89745581979913,-1081.6629797047806],\"benevolence and the mandate of heaven\":[-71.74085028841564,312.08706460409627],\"bengt holmstr\\u00f6m\":[-271.76088498548785,-642.3641553367224],\"benjamin moll\":[227.65678405039642,-631.6412690085109],\"benny moldovanu\":[-36.51233666293347,-1018.9634312216688],\"berkeley school of political theory\":[132.30326450295448,171.40198237005447],\"bertil lundman\":[250.09119384211914,1070.870826832782],\"bertrand competition\":[-343.5781928670535,-583.0280027523263],\"bertrand paradox (economics)\":[-338.2478814822225,-554.9728886737056],\"bertrand russell\":[-47.57701572124853,87.56269344728466],\"better red than dead\":[-93.30667306365767,100.20086194685159],\"bevanism\":[475.288957328144,-247.81587122606606],\"beveridge curve\":[-147.95241579300702,-676.7846784552497],\"biblical patriarchy\":[482.80374384924056,207.18328599252578],\"bibliography of anthropology\":[145.72034636626955,559.2707244291072],\"bibliography of sociology\":[205.38376184214056,305.46339660027826],\"bibliography of works about communism\":[349.1183282378969,-153.1126335564307],\"bicameral mentality\":[-213.8532992348152,488.2417292391338],\"big man (political science)\":[584.4600054152755,55.8878975117018],\"big push model\":[-9.355287896063246,-754.7591348975297],\"binomial options pricing model\":[-238.4824865123388,-1187.3743806634989],\"biocultural anthropology\":[213.03730972243986,561.5060600115212],\"biocultural diversity\":[349.62791015699526,569.6365169253479],\"bioculture\":[91.218048328025,577.7769752657841],\"biological anthropology\":[117.07074537834768,487.41882521380563],\"biological organisation\":[-47.6245919087184,417.87372597123704],\"biology and political orientation\":[260.81866154384664,-46.285677318520115],\"biology and sexual orientation\":[-166.0374388395686,754.8973049957873],\"biophilia hypothesis\":[218.7528049165109,296.86930384518274],\"bioregionalism\":[120.66415798320342,108.97047074989139],\"biorhythm (pseudoscience)\":[-403.2665059958774,359.25884298841754],\"biosocial criminology\":[-18.70329170114156,364.9918233495923],\"bipolar i disorder\":[-728.8860979723388,550.4657496780469],\"bipu\":[-294.4724490591192,-702.9394767335081],\"bishop\\u2013cannings theorem\":[-370.46986283070186,-371.9480511461312],\"black eagle (montreal)\":[540.1419876294503,-139.40065940244443],\"black hole bomb\":[-581.0699835791874,623.4093554702957],\"black tax\":[-185.60634480192547,143.8356610995141],\"blacklisting\":[-118.61384994226619,258.0805697554817],\"black\\u2013derman\\u2013toy model\":[-280.6409648607798,-1620.379841138423],\"blank expression\":[-319.13272853672856,846.552669885931],\"blanquism\":[272.45390760878456,-285.08177667436513],\"blau space\":[277.3487356754225,164.91212707937328],\"blavatnik school of government\":[505.4495750515641,191.94631047623295],\"blink: the power of thinking without thinking\":[-353.14108065354736,369.6067211549976],\"bloc party (politics)\":[65.49731100886058,-167.36257758656447],\"blood and soil\":[84.95436409160666,94.5892206451011],\"blue economy\":[20.420266270576686,-701.0667207965631],\"blue justice\":[62.44332585481069,-822.9688227130167],\"blue labour\":[683.6939997036918,120.41715356775336],\"bolivarian revolution\":[193.6867946857476,-177.2447055370082],\"bonai state\":[555.1863359448455,56.59138667681575],\"boosterism\":[572.4730475777517,86.79012282109635],\"border control\":[-154.953316897896,-179.4063022427597],\"border outpost\":[-310.0938522496739,516.513689738865],\"boris maciejovsky\":[461.39280207886594,-373.39391113998965],\"bowley's law\":[114.79159128627346,-782.8970053881296],\"bps barbara wilson lifetime achievement award\":[-234.3550118977058,786.8693598441267],\"brainwashing\":[-172.6859968548573,259.87480006816156],\"brandalism\":[380.47168856801323,-246.96909746452184],\"breakout (technical analysis)\":[-632.9071395507195,-1337.2061474541583],\"bric\":[-212.57397482635045,-280.7068927805617],\"brigitte young\":[552.4329958554821,88.3686717804506],\"british journal of politics and international relations\":[602.6938523885931,-86.62103033026034],\"british polling council\":[-409.5237331959791,310.50017999126305],\"british psychotherapy foundation\":[-665.6307667397124,650.7537460622062],\"brocard (law)\":[-320.7432176839984,139.71686970357848],\"broken windows theory\":[84.04557902225147,677.6729825056498],\"bryan caplan\":[-26.178028936414734,-390.75674738465483],\"build\\u2013operate\\u2013transfer\":[-422.7114508602524,-698.0356426930399],\"bumiputera (malaysia)\":[74.7607413627105,362.1235679478036],\"bureau-shaping model\":[465.4736819680269,-369.1405020164651],\"bureaucratic drift\":[595.823325858138,-31.39773522072189],\"burlesque\":[-224.01129731124928,-384.84697875265414],\"burmese way to socialism\":[42.808565786076855,-44.27143874543562],\"bush school of government and public service\":[431.1932996288313,-212.39188164437616],\"business magnate\":[82.96849871701149,177.89901607111616],\"business oligarch\":[163.19491623113007,171.54465918147133],\"b\\u00e9la balassa\":[-58.93065774522995,-958.1324182410495],\"b\\u00e9la h. b\\u00e1n\\u00e1thy\":[229.26993662660632,123.09741549909859],\"c. d. broad\":[-234.90796681079334,252.68293668463483],\"cabang atas\":[-27.04419019500896,278.04094498674937],\"cabin fever\":[-862.7724650182304,611.3185854009442],\"cacique\":[877.0773503971584,410.6523646197447],\"campaign finance\":[-308.48039416286406,-124.21058898219347],\"canadian honours system\":[935.2442825897642,67.63608497045323],\"canadian political science association\":[634.0421823572743,167.266882025377],\"canadian public policy\":[586.8419202500885,88.2692250686878],\"cand.scient.pol.\":[558.0791568530451,74.07161290772933],\"capital (marxism)\":[377.8995237748351,73.90428332065996],\"capital cost\":[-191.83331054890203,-673.3689635504289],\"capitalist peace\":[-114.96704581242855,-54.96631144742973],\"carbon bubble\":[-526.9932532156644,-913.2177491632884],\"carbon fee and dividend\":[-308.5233110790259,-609.5436205882002],\"carl albert center\":[913.6678675760651,63.04436120953489],\"carl joachim friedrich\":[181.77699129298915,-343.7721701739746],\"carles boix\":[405.60545925811357,-42.743010162884744],\"carmen a. mir\\u00f3\":[471.0950338957371,-364.10793895777846],\"cash crop\":[-166.7059787263782,-296.79285776563734],\"cat intelligence\":[-406.7181276458016,519.0869582904785],\"catch-22\":[-366.2274980452578,-502.68252176010753],\"categorical perception\":[-199.6246828597481,452.3291384140915],\"catharsis\":[-622.2733409235202,663.6598714409729],\"catherine eschle\":[97.63200425655623,-441.9408238589398],\"catherine wihtol de wenden\":[561.8301965835742,44.99990904618326],\"cato institute\":[-31.790260299759606,-356.5380255841102],\"catonism\":[101.71108453393093,-62.388770653126066],\"caucus for a new political science\":[536.8919127903162,-126.1561656081602],\"caudillo\":[742.3185395279315,358.55153198529314],\"causa sui\":[-342.5938820425139,163.90404574763807],\"causes of transsexuality\":[-25.981070748516842,564.826530768713],\"celeb jihad\":[-478.3306160288621,1419.8351936925917],\"census of india prior to independence\":[153.4087808714315,349.39132169763553],\"center on conscience & war\":[-95.75044257873554,-249.35756760642377],\"centre for appropriate technology (australia)\":[-288.59427980397777,-697.4511740151102],\"centre for health and international relations\":[53.662442707427466,-245.01711874037863],\"cephalic index\":[237.8458183513631,1150.886326375806],\"cephalic index in cats and dogs\":[260.62255974782767,1233.402383122136],\"ceremonial pole\":[73.70101880689933,783.5449587841567],\"ceremony\":[-0.7123242842945121,1135.3429426861921],\"ceteris paribus\":[-89.47919768519068,-717.0793781473025],\"chaining\":[-675.1501284753242,523.4798932499323],\"challengeaccepted\":[192.30765055878692,331.5466739648022],\"character computing\":[-425.9327610432013,523.0680583984973],\"charg\\u00e9 de mission\":[-278.9483837524684,-37.31536918158383],\"charles henry hull\":[59.98676898501996,-605.3092054786779],\"charlie bean (economist)\":[388.00550246267744,-612.6761621007367],\"cha\\u00eene op\\u00e9ratoire\":[211.6395221498251,479.3418808346048],\"chester barnard\":[486.96079157910157,163.9672748993964],\"chiara bottici\":[-98.24519281264877,423.85332575304795],\"chicago school (sociology)\":[-260.95876446114664,235.56006542240425],\"child behavior checklist\":[-261.0955279996157,570.3118830644868],\"children's geographies\":[-70.2655126681051,546.5097491831616],\"china university of political science and law\":[757.9790555772751,74.95305692396077],\"china watcher\":[-467.80745580379534,-175.68749792298829],\"chinese kinship\":[123.81931008745244,730.5240396517443],\"choosing scotland's future\":[-824.5268092624241,-663.0449241627907],\"christian communism\":[298.1540299536383,-202.82036166503727],\"christian corporatism\":[272.9681371070727,-123.81170972612519],\"christian egalitarianism\":[451.0339098577849,-15.135446583255002],\"christian fascism\":[226.89310749564712,-44.23635835891836],\"christian fuchs (sociologist)\":[392.1328760976404,416.2979213799671],\"christian privilege\":[36.14126908786557,254.35762515192962],\"chua beng huat\":[332.0133125017941,61.85626916290832],\"cipp evaluation model\":[870.530299125631,91.32732845517198],\"circular flow of income\":[122.01820510235817,-573.6393414992809],\"circumscription theory\":[327.10025252111285,714.4467031265995],\"civic political culture\":[566.7564742456905,448.1524663710517],\"civic virtue\":[-472.14143691475846,106.83472484801679],\"civil discourse\":[-718.415154739812,43.08968690510358],\"civil libertarianism\":[7.275308380540379,-267.536539746465],\"civil service\":[-254.12712033372154,-28.122669974552455],\"civilian-based defense\":[421.3428653200134,-130.50734575190148],\"civility\":[-492.0651275028333,-13.555720730205874],\"civilization in transition\":[-687.110552762185,758.1689363070831],\"civilization state\":[288.61663072286564,296.6983745415487],\"civilizing the economy\":[-78.27594491733205,-271.9404378775988],\"clarita carlos\":[394.8898011859362,-56.0146177329914],\"class traitor\":[443.5290953960124,-295.0139282707134],\"classical realism (international relations)\":[-108.34799835540502,23.89950122903231],\"classical test theory\":[-639.3369940381572,232.70698566368506],\"classification of advocacy groups\":[593.007748719695,-213.73575372224198],\"classificatory kinship\":[141.01728711024703,720.1322588314773],\"cleavage (politics)\":[285.9113844081646,-51.0246023475326],\"clientelism\":[143.72164044988665,-116.65354600043882],\"clive granger\":[-350.1618068441504,-543.9022831080904],\"clustering (demographics)\":[-80.29368865518057,309.0636256708203],\"coal phase-out\":[-371.9813225298126,-607.7442523989296],\"cobweb model\":[-71.1932609324604,-789.6730624524745],\"code of hammurabi\":[-53.00377192463485,333.6418713812251],\"coercion, capital, and european states, ad 990\\u20131992\":[316.28679222270864,232.63528843118405],\"cogito, ergo sum\":[-282.5207032725089,430.56645460212803],\"cognitive anthropology\":[205.98375090291006,617.4697076003108],\"cognitive archaeology\":[-132.0980862327758,383.2236183452807],\"cognitive bias\":[-419.72566634224637,191.91844380935788],\"cognitive intervention\":[-749.7360614750693,696.927209746584],\"cognitivism (psychology)\":[-403.3801146141497,295.71197329586767],\"cognized environment\":[-39.622639998261704,580.647272839948],\"colin hughes\":[477.5217770922511,-363.5070270292931],\"colin rallings\":[943.3252872240325,-298.4670269654195],\"collaboration\":[-193.55549692920673,53.22205889038765],\"collective effervescence\":[3.50208984105113,204.7327525967107],\"collective memory\":[-137.02237759593345,501.59930409773864],\"collective mental state\":[-202.43227161391258,571.1447539454539],\"colonial origins of comparative development\":[-129.74064545518843,-561.2482204385908],\"coma\":[-557.0980604767033,658.5379683931126],\"comit\\u00e9s abertos de estudantes\":[414.2010863629989,1473.6969986760275],\"commanding heights of the economy\":[408.60365919108267,-214.27216923423978],\"commentary on palestine: peace not apartheid\":[532.5464705978889,-455.33559542269325],\"commercialism\":[266.97788044514647,-69.78886800791248],\"commodity chain\":[171.28046675199928,425.68421943303616],\"commodity credit corporation\":[-194.34189409190023,-1566.2590363374463],\"commodity form theory\":[-151.85355480974943,19.743679821384003],\"common informer\":[-988.1951752651313,-195.2092278136362],\"communal reinforcement\":[-185.12719508349682,242.11087427004236],\"communication university of china\":[908.7245534677078,82.94719385603744],\"communications management\":[-153.99095913388345,-231.05930122473893],\"communicative dynamism\":[-12.996654947774374,573.7868912660018],\"communism and lgbt rights\":[375.2902183598402,-134.22744325665317],\"communist correspondence committee\":[497.9335096788283,-272.91772252279486],\"communist era\":[396.8503949074092,-156.94144434665787],\"communist front\":[377.989025085193,-123.96874542911067],\"community policing\":[91.59135406256432,737.5468958704528],\"community-supported agriculture\":[139.2188693469835,-599.9214380203405],\"comparative criminal justice\":[-418.1536316091717,-109.98154248144607],\"comparative historical research\":[178.01135653374126,222.57526163151127],\"comparative politics\":[313.53222144064927,-63.12163895105287],\"comparative study of electoral systems\":[-611.6215340655591,53.44709163262907],\"comparing media systems\":[204.410586332824,-156.6357061312182],\"complex adaptive system\":[45.599707207391,77.59007692273867],\"composite index of national capability\":[-12.128729048861738,-218.72456185429675],\"comprehension approach\":[-60.168043892144986,504.1131218875586],\"computational politics\":[576.7541405800649,61.08984727947715],\"computational sociology\":[91.50722356653921,241.6587946559086],\"computational theory of mind\":[-292.01137280115285,370.15458398087793],\"comunismo a la tica\":[408.37570756965596,-168.75220693343368],\"concentrated disadvantage\":[93.3926826802238,291.92025159705827],\"concentration risk\":[-406.71895180998126,-971.5212094140363],\"conceptual economy\":[-94.77478993468716,148.69834041341812],\"concession (contract)\":[263.15222693670114,101.22748818066233],\"concurrent powers\":[-527.6888938655638,-446.28570861144624],\"conditioned emotional response\":[-370.07131140419597,295.78215241885675],\"conflict resolution research\":[301.8553218667018,-352.42844990224586],\"confucian classes\":[15.812665789645434,159.5993035330496],\"confusion\":[-441.2099281317091,728.2747343519129],\"conjoint analysis\":[-125.11867706815582,-895.8746998094582],\"consensus democracy\":[162.737388439438,-182.14258609172398],\"consequentialist justifications of the state\":[-82.03758637340064,-431.0608308270593],\"conservative corporatism\":[84.61039521197235,-137.24763026114536],\"conservative liberalism\":[69.39776367365299,-156.04505765005678],\"conservative research department\":[33.65462231295489,-551.0694654669961],\"conspicuous conservation\":[464.72927162032164,168.52022418098312],\"constantin noica\":[-62.91793851011912,335.9222232024691],\"constitutional autochthony\":[547.1278585599873,66.72086801509008],\"constitutional dictatorship\":[199.8329827855422,-82.03579889576385],\"constitutional economics\":[30.887054591144565,-463.0908265514379],\"constitutional patriotism\":[141.9380253114494,-58.305225999054024],\"constitutionalism\":[-58.73502312642245,-120.05943474111706],\"constitutionality\":[517.7447482126538,411.315209466362],\"consumer class\":[37.13311133144761,-297.47192646982904],\"consumer debt\":[-133.50832789812443,-883.7286693955571],\"consumer sovereignty\":[-134.5361286397951,-800.4647707973032],\"consummation\":[13.1857230515254,942.6386777876379],\"consumption (sociology)\":[-55.65533790812864,-397.8420602960229],\"consumption distribution\":[-515.382974684737,-819.0780232328315],\"contemplation\":[-467.83313263500816,686.1636498396822],\"contemporary jewry\":[227.66286833915277,261.39355270098497],\"contemporary voices\":[573.1567996862709,73.44749712843017],\"content marketing\":[-764.3492584294477,-618.8778455396362],\"contest mobility\":[120.02907634141673,148.64993571071608],\"contingent claim analysis\":[-277.29757151692695,-923.6924041250829],\"contingent sovereignty\":[-325.65535930129596,-140.28678587958524],\"continuismo\":[835.9073923487251,391.68883625016616],\"contrast set\":[212.8452560954146,657.4981544406145],\"control (management)\":[-107.3794063243445,165.11574595877565],\"control theory (sociology)\":[98.03860350079093,285.70490931864305],\"convergence (economics)\":[28.305202719400345,-710.7531457022894],\"conversational model\":[-726.7316915284374,625.6053039175856],\"convex preferences\":[-99.4153578465493,-876.4981601386244],\"cooper do-nuts riot\":[-29.287943761628547,735.8858767380227],\"coppieters foundation\":[-403.3928936302406,-228.29308649725414],\"core self-evaluations\":[-669.828021209034,-72.5645455119987],\"corn exchange\":[-255.79574028533352,-975.0591506700151],\"cornell-peru project\":[199.47387489550454,669.2401239024476],\"corner solution\":[-42.61226111937464,-828.7328633964171],\"corporate anniversary\":[-212.31788862524004,52.49427581468478],\"corporate communication\":[-182.86149607135678,255.57766902771056],\"corporate republic\":[182.3320870736697,-84.98570308387431],\"corporate statism\":[-37.219731591897144,125.58526639379467],\"corporative federalism\":[-93.27816467889707,-134.66097179158305],\"corporatization\":[114.93186150683873,-479.9422983352849],\"correspondence principle (sociology)\":[290.1532515791064,260.4557112885565],\"cosmopolitan democracy\":[-204.95106020021953,-233.71511833797425],\"cosmos and psyche\":[-352.84920712493323,413.90150601749866],\"cost of electricity by source\":[-399.8688106478166,-566.3081443422046],\"cost-weighted activity index\":[-217.37824998360034,-933.673706870304],\"counterpropaganda\":[-327.8647863900101,53.177664531463456],\"cournot competition\":[-277.6666720949963,-601.8661974658314],\"cover-up\":[-352.1770296483507,176.04902834492546],\"coverage error\":[-638.2677808679973,19.93312152643603],\"craig stanford\":[183.96924214706763,628.2103618375833],\"crazy therapies\":[-546.12089350703,599.3423645980172],\"creativity\":[-289.6105104182535,245.72015708637386],\"creativity and mental health\":[-506.65043508572643,533.7564797575467],\"credit default option\":[-226.9383970311833,-1163.2802538465048],\"crimes against humanity under communist regimes\":[440.0563756994381,-198.73226846622848],\"critical medical anthropology\":[238.68360438313772,490.3885801728701],\"critical review (journal)\":[562.7466966130819,82.99324350464826],\"critical security studies\":[-23.86144844250848,73.79915150877481],\"criticism of capitalism\":[186.14154413454904,-286.4650542939969],\"criticism of the federal reserve\":[170.06926670134354,-745.0018215959944],\"critique of modernity\":[140.56948014810683,279.32538445458357],\"critique: journal of socialist theory\":[315.5016205526427,19.951706166827293],\"crown servant\":[38.24859105808174,-19.94808541556285],\"crying\":[-335.3433783983397,577.9363456718152],\"crypto-communism\":[409.8241922443705,-178.04337452954783],\"cube root rule\":[582.3388927907873,92.52206247410817],\"cultural anthropology\":[192.31240589463363,583.1566215710757],\"cultural group selection\":[-47.66682738799579,171.55224012151254],\"cultural liberalism\":[133.06028842658918,292.17551581136865],\"cultural mapping\":[22.437948307640703,503.7093835659829],\"cultural memory\":[41.77576995101867,564.7006971832157],\"cultural movement\":[-51.18316347181119,360.5166866981508],\"cultural nationalism\":[134.06431329374396,440.8834054423329],\"cultural practice\":[78.6181549270525,578.7160155540903],\"cultural radicalism\":[95.55558814772851,518.3027053222173],\"cultural relativism\":[90.87995071749874,559.4545941431116],\"cultural resource management\":[266.5790749137534,560.9349010009965],\"cultural survival\":[-141.1126090894474,48.77114889349015],\"culture 21\":[152.34701647532205,677.5132852996197],\"culture hero\":[76.02767347752531,543.2147791899246],\"culture theory\":[129.3844562517146,574.5543234137559],\"culturgen\":[63.80988770672357,568.722985479656],\"cumulative process\":[55.7934016150367,-767.6474127177323],\"cumulative prospect theory\":[-419.61086581931346,-631.7796056206818],\"cura annonae\":[422.232412044324,-158.2295272988644],\"curvilinear disparity\":[-197.46779646012632,-510.74868805065415],\"custom (catholic canon law)\":[-466.03906898990704,63.02561365613745],\"cyberocracy\":[222.4563801667953,-23.316119516474725],\"cycle of poverty\":[-183.2453426144711,-22.02390724782198],\"cyranoid\":[478.6902781679266,-375.8024120282792],\"dang guo\":[-254.31552118471157,206.4745366714835],\"daniel kahneman\":[-312.43373322971024,-195.4981308356502],\"daniel mcfadden\":[-266.999667291151,-671.0737907423277],\"danish defence agreement 2013\\u20132017\":[-651.0930037251757,-546.9114860012604],\"daphne dorman\":[257.5841172612009,103.65302281702134],\"dark figure of crime\":[61.23273274231379,398.16702018263504],\"dark triad\":[-656.2685477780241,476.28488253280403],\"darwinian anthropology\":[-3.3432709617512026,452.5952519409083],\"das argument\":[174.60961427173132,716.1412285087524],\"das mutterrecht\":[249.5402508062415,616.0202344530745],\"data collection system\":[-608.1984008950657,105.22850462985501],\"data editing\":[289.7055095247298,442.764244802116],\"david chalmers\":[-311.0170836475864,369.1940038490561],\"david e. campbell (political scientist)\":[567.6903115576711,81.0080708700976],\"david laidler\":[-63.40586483689265,-563.6471428164348],\"david marks (psychologist)\":[-361.40259494048905,379.8410958442422],\"davis\\u2013moore hypothesis\":[257.19350802663496,-776.2207986367542],\"day of empire\":[-495.31680037405016,-151.86742643200398],\"debate\":[-446.11736811595983,-143.39574387960948],\"debate chamber\":[-403.9634391443684,-67.10368420753164],\"debtocracy\":[-483.8246257995867,-43.458825688445906],\"decentralized autonomous organization\":[-495.06815670141265,-76.07506049153724],\"decentralized computing\":[-605.8374335361812,-103.56926859122416],\"decoloniality\":[59.73094649625374,355.5265394369782],\"decolonization\":[-77.0364200580021,-47.06690371420398],\"deep history\":[159.893979037789,478.5322212469782],\"deep play: notes on the balinese cockfight\":[196.00135130714045,695.9890817502666],\"defence mechanism\":[-673.0437189359811,586.9098304808329],\"deflator\":[-121.30954130510875,-922.146482475305],\"degrowth\":[72.97426337950301,-302.83039203900285],\"delegated authority\":[-26.433454643392388,-75.5937782662514],\"deliberation\":[-579.1065712433384,-1.7532631756700787],\"delmos jones\":[-5.73091028150597,342.5018476744017],\"demand curve\":[-81.73970774603845,-841.2937365144973],\"demand shaping\":[-4.857668096283897,-996.374732638517],\"democracies: patterns of majoritarian & consensus government in twenty-one countries\":[477.4719948136705,-5.459316180025679],\"democracy and security\":[575.7194058857563,43.65605609171648],\"democracy-dictatorship index\":[-11.511423968658997,-314.57650582383803],\"democratic capitalism\":[133.94009736158446,-300.8529800252432],\"democratic globalization\":[-124.17943634138378,-181.58406203825433],\"democratic liberalism\":[34.69960615925462,-172.78107038072994],\"democratic marxism\":[448.18027302808986,-294.8993519481972],\"democratic party for a new society\":[-54.918976739629414,-56.46167352041754],\"democratic peace theory\":[-98.61358491505125,-28.36464024752403],\"democratic recession\":[571.2880887270436,40.985774068222156],\"demonizing the enemy\":[-421.70738695782,112.06967872092737],\"demonstration effect\":[75.08025741945463,318.8903888915741],\"denationalized citizenship\":[-88.68111690044174,920.1501969755745],\"dependent territory\":[96.65955474661398,-47.538846318325454],\"deployment management\":[636.1904038010779,74.09805161056406],\"designing social inquiry\":[-75.47100746555303,-131.6684114343626],\"destabilisation\":[-242.10175983938882,339.2092888602508],\"detection theory\":[-354.61369796692486,227.28483722100887],\"development anthropology\":[200.35613600736446,507.01717534506605],\"development bureau\":[-758.3634221568956,-192.8740769213385],\"development geography\":[-177.91157444202543,33.762449697105716],\"development-supported agriculture\":[264.0102774236945,-839.8611145201477],\"developmental psychology\":[-226.60320600276054,470.9427388454459],\"deviationism\":[226.55369551977222,-137.3818250248469],\"diamond-water paradox\":[-223.56688654426256,-510.659630120711],\"diane bell (anthropologist)\":[139.0116089132597,712.9530061669633],\"dictablanda\":[226.35930426562763,-87.52827669266671],\"dictatorship of the proletariat\":[316.96318471016457,-218.02163927849622],\"differentiated bertrand competition\":[-328.6329797446011,-723.7118535888111],\"digest of middle east studies\":[282.2134961462552,186.02552161201612],\"digging stick\":[131.60011263784793,359.5168343580939],\"digital ecosystem\":[202.4551258162593,220.96929739645452],\"digital era governance\":[242.0276788830932,-49.45314713882089],\"diminishing returns\":[-99.38274783867857,-642.8862588134546],\"diplomatic protection\":[-84.42032446830956,808.5953102704302],\"direct and indirect realism\":[-221.58374908968528,240.85225338744124],\"direct historical approach\":[355.2411273375353,503.99456582332544],\"disability anthropology\":[255.24612657998134,628.9886581873211],\"discouraged worker\":[-139.66648289765712,-224.3555862092298],\"discrete choice\":[-192.76590042298542,-947.4008328208827],\"discrimination against autistic people\":[-7.043713472223463,272.07375150939214],\"disordered eating\":[-688.3647488914527,564.4582821416491],\"dispersed knowledge\":[22.925965414773056,-577.4304270790316],\"displacement (linguistics)\":[36.68030668841417,452.3927026983262],\"distributive tendency\":[649.1558084380003,171.6937418889177],\"divided government in the united states\":[-303.5093069900553,-401.05468942752884],\"dixit\\u2013stiglitz model\":[-222.08107497630095,-939.2408819597339],\"dizzy with success\":[389.73674396881046,-219.0751151035239],\"doing gender\":[-30.17252564093381,789.1072875364581],\"doji\":[-621.4659463510367,-1328.59801152942],\"dollar voting\":[-43.367389924692596,-793.2583241512518],\"domestic analogy\":[245.0928948688421,285.7770688072468],\"domestic trade\":[288.69999396450896,-539.3728536749742],\"dominic boyer\":[395.7686253257562,861.2478412666594],\"dominium maris baltici\":[-417.50326834307407,-99.94643082730784],\"donald e. stokes\":[460.5712066114084,-219.5086038457908],\"donatella della porta\":[272.2521135624832,76.20385087330047],\"doncaster pride\":[481.5163055066714,-124.78849817639882],\"donchian channel\":[-626.630163513565,-1332.6248175917713],\"donor class\":[97.61046981861291,21.755410136121924],\"double hermeneutic\":[-243.77508541153748,190.80132901149258],\"downs\\u2013thomson paradox\":[-303.3730601942451,-463.8391004636026],\"drang nach osten\":[296.8193939325094,45.96386956732552],\"drought tolerance\":[-421.96172268118966,-556.04480490984],\"dsm-iv codes\":[-644.7982152316098,561.3662965494176],\"dualism (law)\":[-386.7652227128247,17.0657946737716],\"duality of structure\":[-78.29453950625452,115.05144173989952],\"duck curve\":[-480.35507934019694,-752.3418495596516],\"dyab abou jahjah\":[564.5387206391395,77.23054202561752],\"dyad (sociology)\":[81.68704991628752,307.91768406409597],\"dynamic density\":[85.82699005674225,-387.92190363023906],\"dynamic discrete choice\":[-138.78214497825365,-1047.221183913917],\"dynamic pricing\":[-25.694660872592518,-855.9158838891112],\"dynamical system\":[109.20855229584116,20.376355352559088],\"dynamicism\":[-720.6037080388777,364.7264915724693],\"dysthymia\":[-722.0735887295551,561.2705854734204],\"d\\u00e9j\\u00e0 vu\":[-577.2002670093435,-35.32461370863235],\"e-government\":[285.1487353855087,-27.15524999029164],\"e. f. schumacher\":[-77.57486699588125,-631.413846152568],\"early modern human\":[-172.55446577078635,319.6077899473311],\"early social changes under islam\":[-176.01646904460728,297.7217046011254],\"earned media\":[-842.0508407685885,-668.513406345618],\"east european politics\":[364.27404190357976,265.3242262986093],\"east turkestan\":[76.68017153225071,450.3827499924896],\"eastern bloc\":[254.54288155950954,-143.28652892923648],\"eating disorder\":[-580.1989508633387,520.6488513896765],\"echo chamber (media)\":[-139.8738978233038,149.74058958312273],\"eco-capitalism\":[141.84114233177564,-325.2766070264245],\"eco-nationalism\":[234.958225259671,164.26743580084394],\"ecoauthoritarianism\":[208.977241930567,-53.50866916861072],\"ecocide\":[-464.84661466136225,-299.162212172727],\"ecodynamics\":[218.54686820390353,-466.19709204043767],\"ecofeminism\":[131.7446793493929,264.62820766079045],\"ecolabel\":[465.55825753796194,-162.70097928375355],\"ecological anthropology\":[272.3995250270272,403.5441520572883],\"ecological economics (journal)\":[155.85483922784886,-411.61771044982055],\"ecological imperialism\":[-159.9029158753234,-248.80249180432187],\"ecological psychology\":[-382.63873237300766,436.61346856588045],\"ecomodernism\":[169.084686820423,181.48209135282553],\"economic base analysis\":[-181.8895804160905,-863.4752393338656],\"economic data\":[-177.0266123957257,-753.908450092596],\"economic evaluation of time\":[-421.15830592567335,-242.71924722528678],\"economic graph\":[-62.6369717195632,-788.5984765304258],\"economic humanitarianism (ra\\u00eblianism)\":[-107.92052075698622,-387.81701423465677],\"economic indicator\":[-72.88480419336251,-753.567071551209],\"economic law\":[128.5241744782624,-629.1149740112681],\"economic mobility\":[189.0681708700814,-316.11375102093155],\"economic model\":[-34.08552019437293,-731.9200982137096],\"economic nationalism\":[116.51109319839493,-132.39154134495936],\"economic power\":[-90.57671789071705,-228.74942693683917],\"economic puzzle\":[-430.20658012656554,-1051.1395448750827],\"economic satiation\":[-172.58770568840404,-779.5676956544107],\"economic stimulus appropriations act of 1977\":[119.84068453128054,-554.4347301341498],\"economic transformation\":[-80.05754503465421,-607.4448625738773],\"economics (textbook)\":[-122.09762899043528,-689.6901381676945],\"economics handbooks\":[57.7903399147646,-982.452865249536],\"economics of science\":[-247.07173819609295,40.12172547425621],\"economics terminology that differs from common usage\":[-54.22362835368714,-823.2745481047184],\"economists for peace and security\":[-328.39204535239435,-589.4350039916369],\"econophysics\":[-32.14646065310323,-547.4795627540368],\"econtalk\":[103.51551371585956,-429.27637927057015],\"ed miliband bacon sandwich photograph\":[360.5332373697696,276.1634839698894],\"edgeworth binomial tree\":[-232.64830723270495,-1235.990275991301],\"edgeworth box\":[-192.16539730264952,-688.7752285985874],\"edgeworth paradox\":[-358.41628752010405,-562.3808979521323],\"edinburgh university socialist society\":[179.9713389623836,-216.70181907085464],\"educational anthropology\":[140.53813441746468,478.0868870707564],\"edvard westermarck\":[52.644900520770456,420.473716075819],\"edward j. bloustein school of planning and public policy\":[470.2035011955338,107.61848855830978],\"effective number of parties\":[270.70074040570137,-53.051853626926835],\"efficiency wage\":[-231.83676183272036,-687.6149893104345],\"ego integrity\":[-381.52788563483773,421.869827413684],\"egosyntonic and egodystonic\":[-581.2825460505733,559.8631024640188],\"el centro integrado de technologia appropriada\":[-288.17685196774056,-705.0207768139211],\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\":[1332.430803153389,137.29541901055555],\"election law journal\":[572.1510435505678,78.31564119158033],\"elective dictatorship\":[371.02702823253395,43.18080001595237],\"electronic authentication\":[416.9536993530698,-32.3519691710209],\"electronic funds transfer\":[-264.34376065040993,-1085.9939779667745],\"electronic media\":[395.31975081721106,-121.06825346715696],\"electronic process of law\":[660.1651316692489,32.530276935475285],\"elhanan helpman\":[-248.7834397621833,-708.9533386438086],\"elif shafak\":[648.7857337327819,90.29301501675413],\"elihu katz\":[-103.71916147369095,87.4614897975846],\"elinor ostrom\":[-86.23355251677688,-528.6633812729074],\"emic and etic\":[148.29294284818548,615.5923878723258],\"emilia justyna powell\":[687.6114153487557,-296.2477718819667],\"emmette redford\":[221.03730059639534,-510.51634642860796],\"emotional abuse\":[-280.1696342696189,475.57014623998526],\"emotional reasoning\":[-414.8965232057056,611.3130390648464],\"emotional selection\":[-430.50409259923765,737.981747447435],\"emotionality\":[-452.2287823124799,765.6841633316134],\"emotions in virtual communication\":[-409.61785617329144,762.3120285888475],\"emotive (sociology)\":[-27.350066087613854,329.43228015603677],\"emotivism\":[-147.07939620651612,165.29973084716593],\"enbau\":[-469.9014194166554,-607.7060587133142],\"encouraged industry catalogue\":[-851.7118422888996,-315.06415571573194],\"encyclopedia of anthropology\":[234.13251881164211,665.408168286478],\"encyclopedia of women and islamic cultures\":[-67.53492374148944,304.6846891933999],\"endocannibalism\":[329.87814052015517,910.6556215693206],\"endocast\":[57.51726298801284,725.0896531177995],\"enemy of the people\":[208.04492103426745,45.733704857100356],\"enemy of the people (albania)\":[230.85870057316404,20.050254715423016],\"energy certificate\":[-713.2237685768488,-342.79459353333465],\"energy charter treaty\":[-648.7828941634777,-436.7323012161701],\"energy community\":[-611.6485642752401,-302.9372417766765],\"energy research & social science\":[202.18483258608916,80.09354529316177],\"energy superpower\":[-25.861238287842973,-203.52212306366954],\"english votes for english laws\":[194.47546616203536,-235.1438531832416],\"enlightened absolutism\":[97.4716722420644,-101.1720661373261],\"enterprise theory\":[13.557937468652387,301.1305048579014],\"entitlement\":[-769.6009278108304,568.2598584405022],\"environment minister\":[-937.8005353754626,-284.66527377125436],\"environmental peacebuilding\":[-210.33949033512482,-428.77909997454424],\"environmental policy of the european union\":[-239.43636972661477,-118.22821563195227],\"environmental politics (journal)\":[581.6306816209598,78.9378665084395],\"environmental racism in the united states\":[-272.54086159994563,-97.94958317607012],\"eonia\":[600.8959559275725,568.9332857444258],\"equal opportunity\":[102.66950277875516,-251.6247410246331],\"equality before the law\":[-129.97674077084594,-92.92084514247352],\"equality of outcome\":[263.7906249045172,-310.38497985614924],\"equalization payments\":[-759.0873228115443,102.20878423697052],\"equity home bias puzzle\":[-343.56115684801455,-945.2459697856237],\"equity premium puzzle\":[-463.1057070528618,-953.2406397801602],\"erguer-estudantes da galiza\":[419.90164464010445,1490.9456870916124],\"eric french (professor)\":[-34.3700687557758,-767.2852135620077],\"eric helleiner\":[599.6810899771791,-217.92294038149566],\"ernest barker\":[517.5404861361453,-410.5154048584328],\"ernest jones\":[-634.9180531713456,633.6328271616171],\"ernst borinski\":[296.4053376002361,318.9443501056486],\"ernst mally\":[-277.83791887042963,444.7046517597073],\"erwin plein nemmers prize in economics\":[-257.3717026631481,-806.7941881382775],\"essence of decision\":[-69.03162687292783,-327.1366055149338],\"eternity clause\":[19.175608079728047,-19.518790868540055],\"ethical socialism\":[213.4612970598117,-218.79359623375174],\"ethnarch\":[127.96167780835682,-56.456254652392765],\"ethnic religion\":[225.38332078283,429.73608103272835],\"ethnoarchaeology\":[349.5220672791392,519.095181900523],\"ethnobiology\":[329.22357987266673,415.76362793876893],\"ethnoichthyology\":[303.0874307994672,481.1605570178739],\"ethnolichenology\":[377.67602851087037,508.6188846701078],\"ethnomedicine\":[323.64315531214544,526.0525999014756],\"ethnomuseology\":[272.680364166697,528.9585372269627],\"ethnoornithology\":[360.95132817598824,466.5725802443609],\"ethnopediatrics\":[217.6771162773822,655.7589430149833],\"ethnoscape\":[226.35677404645983,548.9538493090392],\"ethnosymbolism\":[306.7497449324438,377.4759913450315],\"ethnozoology\":[319.75778482197046,492.4896102900076],\"eugen relgis\":[-143.92176073673912,356.50248610052483],\"eugene fama\":[-216.40694575330207,-661.2196974019132],\"eurasianism\":[51.24612294955862,-154.2133045040353],\"euronia\":[750.8184891571971,676.8438699294151],\"european federation of psychologists' associations\":[-306.9737024860248,558.6709730872855],\"european master of public administration consortium\":[547.5455700158658,-80.45467920365273],\"european school of political and social sciences\":[687.1235547136806,-180.48314199176878],\"european sociological association\":[275.2418709511527,348.140743202047],\"european union studies association\":[519.0961100188807,-211.25003220239873],\"eurosphere\":[-267.8061991089251,-49.65489451076391],\"eustress\":[-483.7906588617953,601.8259899207662],\"eviatar zerubavel\":[293.7912902152517,324.9529412925594],\"evolutionary game theory\":[-275.4730036710268,-314.4590640160841],\"evolutionary psychology\":[-150.88809771977196,228.5913379370177],\"evolutionary studies institute\":[275.2849059182611,100.49736938721126],\"excess burden of taxation\":[-163.11936914717282,-473.78293812617625],\"excess reserves\":[-213.19571018772712,-783.2271024246967],\"exclusive federal powers\":[-618.3092213240958,-501.32122943485314],\"executive order\":[-356.0653389312436,31.33415189060969],\"exequatur\":[-425.1735379945516,-8.581707813569118],\"exocannibalism\":[276.4391182847259,802.7517102319746],\"expansionary fiscal contraction\":[169.01106251064334,-848.9325037517743],\"experimental economics\":[-103.93649394516936,-620.7896358077493],\"experimental political science\":[-56.00444633311685,-300.2258947151037],\"extemporaneous speaking\":[-556.5416498655217,-175.5494038572251],\"extended-hours trading\":[-547.3025339340353,-1194.7172817989463],\"f. g. bailey\":[341.360309097001,709.320209497161],\"fabrizio zilibotti\":[297.28747050965876,-795.5901533347054],\"facial expression\":[-215.5634129755907,750.1868289469267],\"factor endowment\":[-207.47898334837956,-422.7522863038215],\"factors of production\":[159.4852117057936,-568.2749108765775],\"faculty of political science, chulalongkorn university\":[390.94230392148637,246.14359897089528],\"failed state\":[-172.87084830009223,-248.72431076352305],\"fallen woman\":[324.9095068633978,349.4751869523087],\"fama\\u2013french three-factor model\":[-367.50512736716104,-932.937402752021],\"family disruption\":[79.0122248314057,462.94868179024803],\"far-right politics\":[120.84331561424953,26.994403524461767],\"farshid jamshidian\":[-400.1379282080056,-796.8553882899615],\"fascism: a warning\":[593.6286061588288,57.46637330268529],\"faye v. harrison\":[248.73368737376336,467.9087614633417],\"federal law\":[-677.2662670038212,-10.147880313138703],\"feeding the chooks\":[81.58262244022731,-262.8738330223615],\"feeling good: the new mood therapy\":[-552.1979950370844,526.7854541901198],\"fei\\u2013ranis model of economic growth\":[23.660908759546917,-756.6741864057702],\"feldstein\\u2013horioka puzzle\":[-331.92741182254133,-915.077947151425],\"female promiscuity\":[-184.79201477280228,735.6688762237198],\"feminist anthropology\":[142.00722196250095,665.7310407156119],\"feminist legal theory\":[-169.58770267257648,148.76585396219417],\"feminist theory\":[43.91960125081422,207.19157420592626],\"fenno's paradox\":[-373.32314235461627,-464.9184387822949],\"feoffment\":[539.6172239466132,20.43999117957328],\"ferdinand de saussure\":[-28.031654996593765,391.0489910033167],\"ferdinand t\\u00f6nnies society\":[29.573162721653993,225.17424914131828],\"field theory (psychology)\":[-531.9333640156431,379.56176939766505],\"field theory (sociology)\":[91.8912836028906,301.30206827294336],\"fight-or-flight response\":[-359.948474002582,599.4798097227845],\"figurational sociology\":[114.27274819601514,298.70195930459056],\"filter bubble\":[-230.54062256409205,74.3627294679281],\"finance & development\":[248.88144450040028,-619.5936200615748],\"financial economics\":[-233.6596729386604,-822.8727489526883],\"financial innovation\":[67.46807549593488,-586.4844015716898],\"financial models with long-tailed distributions and volatility clustering\":[-429.96073834219715,-732.1246290774423],\"fiqh\":[-455.7238619095947,284.1231799002522],\"first world\":[-174.61845889962032,-200.92825640694204],\"fiscal capacity\":[574.5376496852944,83.62248647538736],\"fiscal imbalance\":[-858.6810868272648,102.50221461719731],\"fiscal policy of the philippines\":[89.41410402640106,365.9325690421182],\"fiscal policy of the united states\":[114.03081621803125,-635.6191354357723],\"fiscal transparency\":[-669.2739041079086,-65.62220298481229],\"fischer black prize\":[-295.9441870439914,-878.9431143037568],\"five stages of grief\":[-444.61897995929553,834.0327770019004],\"flashback (psychology)\":[-256.1148572992159,362.2305907532579],\"flourish of approval\":[253.99208927559025,246.67809231693153],\"flow (psychology)\":[-439.9097363656503,615.5500814273419],\"food bank\":[-482.7043338314711,-214.5309387098359],\"food processing\":[371.557904751542,416.4970334870637],\"food sovereignty\":[-128.72258665322522,-2.9216827039987754],\"fordisc\":[228.2117612856516,783.8743476873353],\"foreclosure rescue\":[264.626679616373,117.6159991512696],\"foreign agricultural service\":[-208.1389126538412,-1710.1188927033081],\"foreign policy\":[143.14703341169587,-154.6426481697187],\"foreign service officer\":[-212.93925165926802,-1765.5027172040573],\"forensic facial reconstruction\":[81.66734860268176,624.4373488765501],\"forward exchange market\":[62.97467772935257,-758.88469311821],\"forward premium anomaly\":[-428.1691758109551,-1026.0345951986342],\"forward price\":[-219.15328296034806,-1166.0690067774244],\"foundation for european economic development\":[64.4529526674718,-676.8683522008293],\"fount of honour\":[835.7358247802204,49.98102985536446],\"fourteen words\":[5.592316254856376,90.37760902876697],\"fractional-reserve banking\":[-237.75550938875182,-988.5547692680465],\"fragmentation (sociology)\":[-11.760214708496385,319.36309002021346],\"francesco caselli\":[474.55138770350214,-379.61522107199323],\"franciscan school of theology\":[258.20687498879596,1019.9343282802871],\"frank batten school of leadership and public policy\":[579.4027049911239,133.34356038813485],\"frankfurt declaration\":[175.9697413607617,-190.7012861282592],\"franz oppenheimer\":[144.80493713084866,-280.02615693788016],\"frazer lecture\":[294.34854164532624,820.5203262537655],\"fred w. riggs\":[494.13254918489474,50.22042888072381],\"free market fairness\":[-50.61295060580479,-277.0428915725195],\"free migration\":[26.832014723958082,-379.9680029960135],\"free newfoundland\":[-585.6334292702315,83.24821025918887],\"free-market healthcare\":[50.22528386765055,-457.01383614906354],\"freedom\":[-23.620448606821544,-93.67792586082884],\"freedom of contract\":[49.122717326437986,-322.7903616474214],\"freelancer\":[67.30038554710258,454.9124264499172],\"frente despertar\":[72.73803846602901,-256.4428652310574],\"freud's seduction theory\":[-759.6759949354762,675.6966151948999],\"friction of distance\":[53.15672796804123,402.20793009836973],\"frieda fromm-reichmann\":[-589.1520454879104,601.4783866132556],\"friedrich hayek\":[-19.096072023495616,-449.6978374910585],\"friedrich naumann foundation\":[-458.19874723199405,-318.0794202840669],\"friendly fascism (book)\":[248.75693186321715,8.87323619598575],\"fritz w. scharpf\":[324.5023661150411,-401.2643329358021],\"frustration\\u2013aggression hypothesis\":[-18.556481487864627,505.0325846575888],\"fukoku ky\\u014dhei\":[-234.25012624223163,-34.88062537503434],\"full spectrum diplomacy\":[-328.09887702218197,-72.35626333630186],\"fundacion manantiales\":[-287.0850175317738,-250.3393665771962],\"futarchy\":[90.02154324089848,-59.2969791098968],\"f\\u00fchrer\":[168.9123558420612,136.14087315248682],\"gabor\\u2013granger method\":[-443.9354355088627,-617.6801022772188],\"gadsden flag\":[157.46179931492333,-481.7802699541641],\"gaia philosophy\":[-216.89185489721484,342.73429621707237],\"galician student league\":[364.3915704893104,1329.7946274598316],\"galician workers union\":[406.5430918812166,1478.7596007929471],\"gallowglass\":[72.41916209391003,406.90732094763507],\"games for change\":[-495.81822815537765,707.7600666368824],\"gaonburha\":[233.42612622559213,653.46037252291],\"gar alperovitz\":[377.50975918168143,-228.835155210464],\"garden of allah (cabaret)\":[-31.24375835286321,850.6583907538258],\"garman-kohlhagen model\":[-196.58281710492906,-1131.0692372560206],\"garveyism\":[61.48819533083131,104.43253271314993],\"gary l. francione\":[-132.40508220572679,572.7847096772181],\"gate crashing\":[-37.46012253489487,994.4133988621974],\"gay, straight, and the reason why\":[-495.62894964630607,505.12229926272346],\"gender and development\":[237.85271915847275,320.9097109133134],\"gender essentialism\":[-14.927663653483126,608.5748965366423],\"general knowledge\":[-143.70215793182265,554.8822719229249],\"general semantics\":[-108.42052983133964,339.9226225400667],\"generative actor\":[-139.9698524706075,349.23681291530147],\"generosity\":[-50.565256261927686,137.32177033651905],\"geography of antisemitism\":[-89.97880679512409,137.8055699456066],\"geography of media and communication\":[18.27032347366735,458.3744842933825],\"georg pfeffer\":[215.32527051828805,646.1503486787717],\"georg weizs\\u00e4cker\":[-153.3320674924837,-353.41295050286976],\"george hilton (historian)\":[468.99908468806103,-377.42325034266463],\"georgism\":[-10.316719657134271,-536.1543381030383],\"gerald shove\":[-143.23837693439438,-768.6271186376105],\"german model\":[30.144038777600993,-84.73409013349652],\"german sociological association\":[206.4422991855066,406.023816382416],\"german university of administrative sciences speyer\":[451.06338244056803,-86.95064887376442],\"gerschenkron effect\":[-171.72533142910555,-493.34353433763476],\"gestalt psychology\":[-415.8148968402808,353.95276664184337],\"gestalt theoretical psychotherapy\":[-525.2655297931644,380.35308701664036],\"gestaltzerfall\":[-525.3404641815013,387.68236994355914],\"gevald campaign\":[-417.6956653036179,-85.26552666925637],\"ghazi (warrior)\":[-588.0420184400178,261.52496925803865],\"giancarlo corsetti\":[30.814037943930526,-876.8388156125977],\"giffen good\":[-285.03880178765513,-550.1880617691612],\"gish gallop\":[-417.89542557399926,105.41258698417015],\"give peace a chance\":[-81.10037738189608,-223.01170825310365],\"gladstone professor of government\":[485.22426026755545,39.54681527660202],\"global apartheid\":[-110.98815222529156,-191.80929236684278],\"global citizenship\":[-160.74411439788886,-98.81469882867091],\"global environmental politics\":[-267.4426086664943,-446.893646780985],\"global justice movement\":[54.26577439152516,-335.306589809349],\"global politics\":[3.4101630403782695,-241.02016096363877],\"global retirement index\":[-305.0125693212398,-342.84242766473415],\"global social mobility index\":[293.9776818954723,211.7132065225187],\"global social policy\":[413.4818162565961,159.79003814898758],\"global terrorism index\":[-116.94842372471513,-287.999052540659],\"global workspace theory\":[-406.4413515255753,479.4529675440204],\"globalization and women in china\":[-398.0321589338972,-164.2497538903825],\"glory to hong kong\":[1121.8296155750513,131.40533669162465],\"glory to ukraine\":[1201.2326784405439,133.3935704090669],\"gloss (annotation)\":[353.3197621094503,477.51189450458077],\"glossary of economics\":[-63.18829372000577,-734.7838934386974],\"glossary of international relations terms\":[-225.893038219483,-99.42908201505509],\"gnosis (chaos magic)\":[-686.7225094452098,613.0317025471555],\"gochisosama\":[92.24018615496321,173.75958497900191],\"gold-collar worker\":[-147.45181355507853,-243.7064698979517],\"google finance\":[268.341746020797,112.64345846291351],\"gotai\":[-134.68847730476026,627.3487806726553],\"grab em by the pussy\":[231.3334315151694,-32.85170031416406],\"grace skogstad\":[747.8339159117565,192.47334959898987],\"graduate program in public management\":[664.6632623111349,-8.120991376343321],\"graduate school of public policy, university of tokyo\":[592.5016448416612,-120.4383383886888],\"gratitude\":[-404.97751999448076,725.2724289097077],\"grave candle\":[-87.34144588097031,307.56192192171966],\"grave goods\":[43.223433185477916,406.2676541238762],\"grazing rights\":[-85.64405522746371,-340.4323278638636],\"great gatsby curve\":[202.05990637377818,-193.39131147805156],\"great power\":[166.0092453770329,-41.62908717821208],\"greatness\":[-90.33297935396145,702.4663416691133],\"greek withdrawal from the eurozone\":[428.5786888396755,301.0148790007195],\"green industrial policy\":[-454.35767289477104,-549.0168653253452],\"green institute foundation\":[427.72826286039117,-473.27072859504455],\"green job\":[-434.8121839403356,-600.4982194238387],\"greenwashing\":[339.51248779260106,126.62566666866451],\"grenoble institute of political studies\":[610.0905630928203,-32.48506540524221],\"grey room\":[578.66379409874,80.15891381734947],\"grey-zone (international relations)\":[-390.17635956338734,-153.79908184957176],\"grotesque body\":[-101.52456503268469,-160.17225890302277],\"group action (sociology)\":[-90.9743213023882,162.41294757864696],\"group threat theory\":[145.1369832478343,314.7950796412276],\"groupism\":[49.96592941573596,102.75388283508933],\"growth stock\":[-532.4475959616765,-1156.080560594342],\"gruppi di acquisto solidale\":[206.36920859293883,-707.9279547624748],\"guanche mummies\":[467.8009439475099,336.5183224050235],\"guatemalan forensic anthropology foundation\":[513.3035020023173,651.971409146791],\"guido tabellini\":[132.97518131705158,-828.0700240726634],\"gun control\":[-72.1319825638681,-382.9684268351275],\"guns versus butter model\":[145.55147652004595,-532.7641393484824],\"gustav stolper prize\":[-47.148331024188515,-956.7483560565194],\"gustave le bon\":[-148.84286130088185,406.95239630619164],\"guttman scale\":[-731.8077021099012,172.8702016650535],\"gwendolen m. carter\":[567.0148319734708,103.96755281881777],\"hanging man (candlestick pattern)\":[-621.7186311460256,-1340.5949923126066],\"hannah arendt institute for totalitarianism studies\":[338.0579407026515,-24.139100144135423],\"hardline\":[181.0911704952479,-99.0687016571782],\"harris\\u2013todaro model\":[-187.1151400773611,-859.5958320745717],\"harry harlow\":[-395.6107037517484,322.75338291974396],\"harvard institute of politics\":[508.45348339009075,-298.6484418913424],\"harvest hills cooperative community\":[241.5507267195762,198.7858854212843],\"harvey jackins\":[-602.7885577695612,614.4626217581846],\"hau (anthropology)\":[221.82504916078815,657.5076262696913],\"hawaiian ethnobiology\":[437.085146682942,489.00524989426566],\"he who does not work, neither shall he eat\":[489.6322926871879,-314.2441315626878],\"headhunting\":[-258.8922879327341,744.4948069584714],\"health geography\":[-31.941501643978032,416.5938604829404],\"health policy\":[424.2960351470826,202.80299874900763],\"health policy in bangladesh\":[546.7021088598747,245.74967092624485],\"health system\":[459.7077525317137,446.717868281974],\"heavily indebted poor countries\":[-340.3663280052273,-263.65016241069276],\"heckscher\\u2013ohlin model\":[-42.32796398312798,-840.9646648558661],\"hedonism\":[-257.81433792458864,-229.23261191214067],\"heel\\u2013ball index\":[117.68509548959972,544.111568156521],\"heide g\\u00f6ttner-abendroth\":[-279.4827060061141,528.0407877922893],\"helen margetts\":[504.7067147233996,-82.46079741906775],\"helene deutsch\":[-670.297312716614,637.727444321923],\"helmuth plessner\":[150.83616234837766,362.865447250766],\"hemline index\":[-70.67053766151139,-1014.499468996203],\"henri poincar\\u00e9\":[-227.27505842772993,265.54465781880685],\"henry e. brady\":[224.84986441866923,-452.84447700694216],\"henry habib\":[46.8283909190808,-16.258315222415874],\"her majesty's government (term)\":[542.9177714969463,70.18401003581434],\"hereditarianism\":[-394.65924424770134,388.37030929416255],\"heritage commodification\":[214.1487062283,498.2189584728527],\"hermann lotze\":[-329.30320604862357,485.6999215455865],\"heterosociality\":[-10.945733175186435,632.8724194669903],\"heterotopia (space)\":[-201.30106127292888,186.30257191218558],\"hicks-neutral technical change\":[37.26826171618916,-848.1427221937699],\"hicks-tinbergen award\":[110.88378084715,-875.2809331990811],\"hiding hand principle\":[-207.50810376741165,-324.1055401577991],\"hierarchical organization\":[-276.0088066893982,184.0141286157503],\"high and low politics\":[265.594270007342,-6.252603519780606],\"high culture\":[84.46613077801611,478.51708051786005],\"high policing\":[-196.69064334368633,272.91082624029895],\"high-altitude adaptation in humans\":[-236.4576290475614,361.19046349744553],\"hill people\":[-179.55838452155322,432.46428648190334],\"historical behaviour studies\":[232.36818183420164,644.9997222247101],\"historical sociology\":[54.68235018459003,260.8806939276519],\"history of anthropometry\":[168.91797593424263,892.2903163669822],\"history of capitalist theory\":[77.95016779347517,-400.1678673785899],\"history of communism\":[352.33805773819824,-202.23372448373823],\"history of democratic socialism\":[257.0220856285626,-246.7326782362484],\"history of dyslexia research\":[-367.90647202153843,518.8681150215408],\"history of microeconomics\":[-113.09002708832314,-701.1151968468289],\"history of political science\":[348.52764337074484,159.74618892638324],\"history of propaganda\":[-264.1054346286405,93.53379153233749],\"history of psychotherapy\":[-611.2139936245705,558.4000685123424],\"history of science policy\":[-270.2805609963244,143.17440889995078],\"history of social democracy\":[245.29776684845785,-201.22401140545207],\"history of the american legal profession\":[-345.66074453854964,73.06367888635755],\"history of the legal profession\":[-349.49196998169083,82.0850068407746],\"histrionic personality disorder\":[-514.9717338072829,623.0377108545425],\"hobbesian trap\":[-354.64790396802255,-595.0083414409265],\"hobby\":[-84.03835258331864,680.9908180571465],\"hoi polloi\":[221.05854749028984,313.1745423196439],\"holocaust trivialization\":[457.84445821457007,97.3867255326566],\"home rule\":[-128.63572257973055,-159.4177140717363],\"homo economicus\":[-171.36161563894763,-450.308635101936],\"homo faber\":[-213.3414490329776,430.5170387080432],\"homosexual behavior in animals\":[-185.2791867797051,864.4580332495294],\"honeymoon\":[73.28146386104814,968.9450627738007],\"hong kong college of psychiatrists\":[-685.7285117453134,581.0186783666203],\"hong kong honours system\":[72.23147296213544,99.48351899987146],\"honorary male\":[16.53561540787544,468.60763460433213],\"hoplology\":[-0.35168480661368645,303.6551881657301],\"horace campbell\":[476.76406670428094,-11.785020987368998],\"horseshoe theory\":[272.33037621691176,-82.92414204578773],\"hostility\":[-434.0507773562138,707.1809333773821],\"hotelling's law\":[-183.74710998693533,-475.62907804466056],\"housing affordability index\":[268.5950828349917,100.44767787638231],\"how are we to live?\":[72.63054976678765,-590.889197261625],\"how voters feel\":[484.49974732625566,28.8724794984963],\"hubbert peak theory\":[-342.23822101056913,-871.3440673112078],\"human behavioral ecology\":[0.6659511181146428,401.8721206129071],\"human development index\":[-326.5594123475677,-272.18507272943134],\"human ecology\":[219.87279217495697,346.8344946402711],\"human ethology\":[-13.402913907798856,489.10648567192146],\"human genetic clustering\":[-394.0741577533546,-120.55977070255848],\"human genetic variation\":[-345.9674659500697,127.79244695539563],\"human resource management in public administration\":[508.2724179331452,128.5215979409927],\"human terrain system\":[256.9698113585847,444.95030914417015],\"human universals\":[79.90780437184434,596.0818027645163],\"humanistic coefficient\":[362.6221647143573,444.11175666426413],\"humanistic sociology\":[248.7674585223281,371.6133736972819],\"hunter-gatherer\":[94.13026971298304,-126.8363795973724],\"hunting hypothesis\":[7.513433099078376,371.6463860885316],\"hypnodermatology\":[-660.3186012612281,515.8886246221804],\"hypnopompic\":[-618.4569540591376,568.4856497029576],\"hypnosis\":[-559.3577793254818,482.6206791752426],\"hypodermic needle model\":[-228.80376759737246,-10.709043713136687],\"i did not have sexual relations with that woman\":[-119.44055011735048,-349.8734014716718],\"i like ike\":[200.60751105162376,-237.1477092152902],\"i-spread\":[-299.76471449939237,-1802.1994999369863],\"icarus paradox\":[-362.00097081959757,-456.2518015872664],\"id, ego and super-ego\":[-628.664708872944,614.0811515598699],\"ideal type\":[211.88520922110422,143.4464550123417],\"idealism in international relations\":[-166.38650259409687,-8.763075598470667],\"identity (philosophy)\":[-165.80811673888715,343.3309136244609],\"identity (social science)\":[174.90765947160682,448.9777534378128],\"identity crisis\":[-148.9401408023808,562.9226233221336],\"identity economics\":[-175.67545322142806,-860.3170452458842],\"identity line\":[21.11410568252944,-862.9349839562497],\"ideocracy\":[52.827240658673546,-69.51391414834609],\"ideology\":[41.90280322429465,19.63646104291024],\"id\\u00e9e fixe (psychology)\":[-376.72223649775407,225.8500687967417],\"ilminism\":[229.8711394616035,-22.008787242281702],\"imagery of nude celebrities\":[-433.4499392888377,1248.3041080307028],\"imaginary audience\":[-392.4243147684278,484.0287089028142],\"immigrant-host model\":[185.85357335709156,-329.4125112368884],\"impeachment\":[-317.9802936726266,-379.8124867975292],\"imperium\":[-232.20567418371206,54.90829938396417],\"implementation\":[766.6646725765222,85.70296363012555],\"implicit cost\":[-71.21185039673986,-649.38077027435],\"implicit-association test\":[-169.49690297237245,475.62119958075783],\"implied powers\":[-477.2056144125261,-372.5112373395534],\"import substitution industrialization\":[45.64689041228102,-707.5060170457141],\"impossible trinity\":[-102.77575949375361,-811.9368162076569],\"in defense of the national interest\":[-191.58524116659325,-22.17985863345695],\"in kind\":[67.3663903642942,-427.7254359737481],\"in place of strife\":[-661.0294002142228,-548.1834207174762],\"inclusion and democracy\":[561.9785006004757,60.619606447026364],\"independent labour publications\":[722.3960012916094,144.29190068648424],\"index (economics)\":[-148.03498747095443,-640.057558584663],\"index of economics articles\":[-147.56128095073274,-741.1621463584869],\"index of psychometrics articles\":[-457.3689557405944,324.92069854937677],\"index of social and political philosophy articles\":[20.889991603083693,-51.96576554174531],\"index of sociology articles\":[12.43044992188944,179.3840571893509],\"index of sociopolitical thinkers\":[-89.50152551220123,-72.02423129853487],\"index of urban sociology articles\":[362.3117397099822,338.79282285879617],\"india quarterly\":[286.29196703006846,-461.4274254881329],\"indian economic and social history review\":[30.87942436830578,-930.284757749081],\"indian political philosophy\":[-25.965735555334245,-71.04407019203852],\"indian sociological society\":[148.94566727629163,380.42893847838013],\"indifference curve\":[-124.77455285679122,-779.4619576681755],\"indirect inference\":[-81.956215259654,-940.0139585898047],\"indonesian village law\":[-73.64432801671065,-152.84364215743543],\"induced consumption\":[-162.77867406800553,-872.5701940903303],\"industrial democracy\":[234.89195485332317,-249.89961700757013],\"industry (economics)\":[-195.7446670508443,173.33565003768476],\"inertial inflation\":[-216.28476166632493,-942.5511664528299],\"infant industry argument\":[97.60279833667227,-828.2209359879853],\"influence of mass media\":[-89.19479212827058,-117.02768161447081],\"influence: science and practice\":[232.10197740701392,660.1610915332925],\"informal social control\":[134.99751662956248,964.2402943575847],\"information economics\":[-84.58309047484721,-776.5506082038276],\"information metabolism\":[-616.7821157970739,632.0352555475048],\"inframarginal analysis\":[17.156517639701324,-687.1115274580047],\"injustice\":[-398.09615990056056,230.9275466178009],\"inner peace\":[-377.0546734489398,577.4419242912649],\"inquisitorial system\":[-374.2780794496703,63.21114088279116],\"inside contracting\":[-686.3460309790033,-39.03795682556459],\"insight turkey\":[554.463951069422,76.6682121389272],\"institut d'\\u00e9tudes politiques d'aix-en-provence\":[680.578820082514,-61.52334786192016],\"institut d'\\u00e9tudes politiques de toulouse\":[622.8057355278738,-19.15695508628237],\"institute for economics and peace\":[-378.79887214641985,-333.11533438888273],\"institute for international economic studies\":[350.20426258009786,-887.8843177922236],\"institute for international law of peace and armed conflict\":[-412.2969845841843,-103.20418586283947],\"institute for political studies \\u2013 catholic university of portugal\":[581.8775619512235,74.06534468132976],\"institution\":[62.26901372027439,162.76766708577165],\"institutional analysis\":[-143.57080413857145,-608.7453663821249],\"institutional trust (social sciences)\":[-43.6753298463591,312.59759133572925],\"institutionalist political economy\":[17.572782215583867,-601.6829555253704],\"instituts d'\\u00e9tudes politiques\":[634.0679701223669,-97.70762542895632],\"instrumental and intrinsic value\":[-272.02595345870617,21.356434046776222],\"instrumental and value rationality\":[-240.2082110877269,-2.410146574778476],\"instrumental and value-rational action\":[-151.9912161885078,110.36215384693652],\"instrumentalism\":[-216.2655674232008,13.031371383606281],\"intelligence\":[-261.2833664138228,415.6472916303397],\"intelligence quotient\":[-303.0397982598578,346.7476229825476],\"intensity of preference\":[-373.1075781434438,-194.4492352631689],\"inter-municipal cooperation\":[327.6541032821695,-816.9881504844756],\"interactionism\":[-161.68665243385104,386.75212700088184],\"intergenerational policy\":[265.77750908259804,205.60602454378636],\"intergovernmentalism\":[-65.64035398541381,-61.194165453010626],\"intergroup anxiety\":[-415.7901218042881,658.2283642824455],\"internal family systems model\":[-406.5649642924942,644.7918278919826],\"internality\":[-334.67144060055125,-626.4196328751115],\"international area studies review\":[202.13312694035005,468.3323307226054],\"international association of art critics\":[-291.2483211857279,-245.69578085275083],\"international centre for black sea studies\":[720.3128500713091,-243.82844405034453],\"international conference on theory and practice of electronic governance\":[485.5735772567085,-47.778275603523674],\"international convention concerning the use of broadcasting in the cause of peace\":[-270.7916493225947,66.47220373694883],\"international council for science\":[398.8807152324528,533.197336854009],\"international economics\":[-9.609015656608587,-690.9815767195445],\"international energy agency\":[-412.4028608624712,-426.9310423921462],\"international ethics\":[-79.42946324727224,19.557266988739155],\"international general medical society for psychotherapy\":[-749.154067407186,803.1354464903868],\"international isolation\":[-117.28231901694933,-153.59885478250314],\"international journal of intelligence and counterintelligence\":[152.38547539267776,282.6388928881284],\"international journal of public opinion research\":[-449.38737760212587,0.7542767692356266],\"international law\":[-302.50529311395246,-72.60785889948843],\"international peacekeeping\":[-44.111125649095385,-199.73022372991784],\"international political science association\":[525.0021073228085,-80.20852050157417],\"international political sociology (ips)\":[51.14216423911222,-25.205638740248393],\"international relations and security network\":[541.502059220149,-166.42165443010228],\"international review of the red cross\":[556.7501482180751,88.01196919694968],\"international sanctions\":[-227.05767837126243,-190.98543213925262],\"international security\":[-26.084612888878855,41.44145489658036],\"international society of political psychology\":[106.9386179732162,-47.40852675407354],\"international sociological association\":[429.2536777072039,364.4030710786421],\"international workers' day\":[456.5893869047115,-246.79743657605772],\"interpersonal neurobiology\":[-183.68380914702888,413.68649743961697],\"interprovincial migration in canada\":[-445.1116528642297,102.28440963135502],\"intertemporal choice\":[-115.89725115984331,-799.9382393975711],\"intertemporal equilibrium\":[-167.25182593443807,-790.7708385133685],\"interventionism (politics)\":[-41.75600070653838,-427.1713687963266],\"interviewer effect\":[-450.64528251152814,-5.299752312034219],\"inventory bounce\":[-57.503232046434285,-868.7724624616269],\"investment arbitration\":[-734.3947282997005,-483.9159392147106],\"ioana marinescu\":[414.52705974042055,-404.0353063647706],\"ipm (software)\":[-690.458543073675,-2.4015044465530906],\"ipse dixit\":[-144.5551637136247,1106.6626606483187],\"iron cage\":[273.6852594981665,139.14304899713298],\"is the glass half empty or half full?\":[-319.6339201818154,394.5646529705214],\"isaiah berlin\":[0.9181358510974154,-65.71077214387523],\"ishraga mustafa hamid\":[563.2470125252416,96.78568819449787],\"islam and children\":[-301.8081530313963,309.39463531031663],\"islamic funeral\":[-176.1690241073376,732.4259635910566],\"islamic sexual jurisprudence\":[-248.36526605016957,587.9187759361843],\"islamic toilet etiquette\":[-208.2256632946402,461.9696874022222],\"island mentality\":[-143.03032250619924,1089.778714360566],\"istihlal\":[-525.475068978068,237.05649083201234],\"istv\\u00e1n hont\":[314.59910988382217,-340.47489792985186],\"is\\u2013lm model\":[-43.10915661861441,-650.3948212418018],\"ithaca hours\":[73.22493025492055,-676.7844507274269],\"iza institute of labor economics\":[181.56731729782112,-256.4532834340724],\"j curve\":[548.655552710699,73.6878334813726],\"jacob hollander\":[-245.81886325491237,-667.5977624154423],\"jacqueline rose\":[-215.9582400617582,634.3668433557763],\"james tully (philosopher)\":[333.27610475678784,90.29457063908878],\"james\\u2013lange theory\":[-604.4000073764748,602.584144421101],\"jamiat-e islami\":[10.398074296080205,19.743946332393886],\"jane duckett\":[458.5171448966541,122.43535932400346],\"jane semeleer\":[315.9119503358932,-715.547922898206],\"janet ajzenstat\":[560.6379492687815,93.26939804598587],\"jean bethke elshtain\":[569.8712627640056,51.38109278119008],\"jel classification codes\":[5.188676464621537,-716.6472947557133],\"jenkins activity survey\":[-554.1851151144812,266.0928215414678],\"jensen prize\":[-298.0711197155831,-926.4940993464246],\"jerzy adam kowalski\":[557.398429355287,67.85366256225744],\"jewish-palestinian living room dialogue group\":[-549.4621469665775,207.01378720547618],\"jhai foundation\":[-282.494794761784,-704.988821485022],\"jihad satire\":[-494.78731195477553,1487.4478039463188],\"joan roughgarden\":[-196.32153172411083,980.1100653655405],\"job cohen\":[-377.3774160310469,139.28309769749936],\"joe biden (the onion)\":[-367.4254184186172,-32.31089544949478],\"johann friedrich herbart\":[-441.18515226698867,635.6013412738929],\"john beddoe\":[255.19820064046294,1100.593706394132],\"john coakley\":[526.0320972192678,-92.18296574628442],\"john harsanyi\":[-300.3024037574068,-582.1639429370772],\"john hicks\":[-60.829741126719824,-692.5944975501212],\"john murray cuddihy\":[-200.63412681871208,535.8811653955909],\"john rawls\":[-73.04399329568767,-88.04750240376718],\"john roemer\":[230.38149693207268,-301.8299593613762],\"johnson cult\":[342.0423113930059,624.2715970572297],\"joint attention\":[-197.46893063542686,482.60026621401124],\"joint organisations data initiative\":[-506.11639868279826,-487.11043569498133],\"joint product pricing\":[-121.4552810540744,-834.4910660302244],\"joseph rowntree foundation\":[-315.25078894786367,-154.5073032488036],\"joseph schumpeter\":[-46.27294169437344,-472.4114276703576],\"josepha laroche\":[543.1900273924797,77.64113537359995],\"journal of behavioral and experimental economics\":[-171.71264184296453,-725.7814700105118],\"journal of current chinese affairs\":[589.8891618937776,79.66951558166234],\"journal of current southeast asian affairs\":[564.2943260135382,55.45028808887349],\"journal of democracy\":[565.6392249596668,-40.36432776852564],\"journal of ethnic and migration studies\":[562.4794080899765,71.97667176374127],\"journal of ethnobiology\":[435.8787155871707,494.89284723227956],\"journal of european integration\":[570.7006680933521,61.90029632576416],\"journal of european social policy\":[546.2799200136056,89.87339354561873],\"journal of lesbian studies\":[-75.24905145495843,790.1854517429142],\"journal of policy history\":[500.5194963126313,259.0835396998902],\"journal of political ideologies\":[567.7314986989517,70.88056064811684],\"journal of public economics\":[-155.38479890178417,-708.7970495279894],\"journal of sociology\":[10.029832749530867,132.40424758438488],\"journal of the american psychoanalytic association\":[-705.4576445273938,664.6055935769598],\"journal of the european economic association\":[188.89917201938968,-878.8976697174643],\"journal of theoretical politics\":[558.3233385861572,-102.00723048955103],\"julia's on broadway\":[-28.011940578943836,1008.4990255326203],\"julius stone\":[-393.87566713178654,-17.478601596336212],\"jurisprudence\":[-205.23754389761515,135.6528969744389],\"jurisprudence of concepts\":[449.77981287660464,-221.30583542003976],\"jus commune\":[-492.68520409635227,45.95276018930583],\"just-noticeable difference\":[-479.0624637639658,243.25746481684547],\"kaarlo juho st\\u00e5hlberg\":[-473.8200162602592,-120.81453489524206],\"kalahari debate\":[108.13449631865163,-182.23931433699897],\"kalergi plan\":[-61.794821872362945,133.30987753841575],\"kansas city preventive patrol experiment\":[113.98171627396897,855.4946468600643],\"karl deutsch award\":[526.3809748488546,-109.2884140619524],\"karl schwedler\":[-214.59819255415718,45.56377977691969],\"katharine hayhoe\":[387.03113824804404,-47.37161061338709],\"keep indy indie\":[-546.4695966108816,141.0638013543589],\"kenneth arrow\":[-184.30003089737488,-610.7529233042179],\"kenneth boulding's evolutionary perspective\":[580.4114762969778,507.4966312144105],\"keynesian cross\":[-24.701175492083067,-660.3489415903989],\"keynes\\u2013ramsey rule\":[-82.60598802820112,-800.2149273734747],\"kim campbell\":[524.8952688040422,-403.158636671917],\"kinder, k\\u00fcche, kirche\":[300.6502902826551,54.570901896711305],\"kindness\":[-367.1545689955836,680.9462149601729],\"kissinger lecture\":[557.6682329770392,62.656045459932365],\"kiyotaki\\u2013moore model\":[-53.6421816182666,-799.5046514806015],\"kluet people\":[667.1888033003406,1462.027231853908],\"knowledge assessment methodology\":[22.293115776869627,-627.4891173481311],\"knowledge economy\":[-43.3304625168732,-530.0485927334532],\"knowledge gap hypothesis\":[486.31583478097923,-163.86076177882975],\"knowledge of the holocaust in nazi germany and german-occupied europe\":[-97.39331995357526,463.14646837330474],\"koestler parapsychology unit\":[-379.4705649934926,354.8559903587275],\"koteka\":[649.1157488863632,1422.7907134705158],\"kremlinology\":[-356.52394683484397,-136.16861427157502],\"kriza j\\u00e1nos ethnographic society\":[-59.99460796187746,556.8855447402011],\"kshatriya\":[83.71991931850785,265.20193419339984],\"kurt heinrich wolff\":[541.4693579147197,422.71125437403725],\"kurt koffka medal\":[-326.6856924121972,534.6583651281705],\"kuznets curve\":[-368.7569036194308,-1009.519088545772],\"kyklos\":[158.01428967139753,-4.471525145160184],\"k\\u00e4the leichter\":[554.6559589860101,71.40416546594],\"l'ann\\u00e9e sociologique\":[140.52704840901157,347.07877442291374],\"l'empire de la honte\":[186.4865683465466,185.64136698949386],\"la borde clinic\":[-538.7845765798775,17.2653662842772],\"label (sociology)\":[-72.49814716517632,307.0143821114678],\"labor theory of property\":[-8.432281687419438,-343.6754991399306],\"labour voucher\":[182.06411910733277,-449.44837127084975],\"lady wonder\":[-391.72579424546956,346.7189529315832],\"lag operator\":[-623.2390912324164,-407.07096300444675],\"lambda alpha\":[226.10260879102356,664.307832954141],\"land consolidation\":[394.644559194443,-219.58506676844468],\"land management\":[-333.3927675646442,36.13567982295391],\"language\":[38.98796700198119,315.63015570817413],\"late trading\":[-581.7333186794464,-1265.4481324659264],\"laterality\":[-194.34615272745418,506.02778237579787],\"latin american public opinion project\":[-703.788781982571,25.9156022431253],\"laura boulton\":[270.1756055552117,740.2160710650721],\"law and order\":[27.90859746952488,-23.596608818667974],\"law of effect\":[-459.69799393989825,540.3131447175178],\"law of equal liberty\":[113.56325086475344,-328.9386230402179],\"law of increasing costs\":[-14.836681988717507,-739.1860120407682],\"law of rent\":[-6.2448427470375245,-388.69650114362696],\"law of supply\":[-17.02040463229871,-769.7649326100867],\"law of the instrument\":[-321.34579014478476,197.6411246369587],\"law of the jungle\":[-105.28959253722276,104.68671775996098],\"law without the state\":[-159.11949844890512,39.033045005201195],\"lawrence summers\":[-117.7873869096856,-549.9287071737197],\"learning\":[-338.98242355839426,405.8487195813015],\"learning economy\":[27.29839984559137,-630.395165029134],\"least developed countries\":[-337.8476337819565,-228.10001586195486],\"least-cost theory\":[377.8286465677081,220.709709776851],\"lectures on jurisprudence\":[-72.79262122743862,-269.7216021209437],\"left communism\":[278.66197979175536,-215.1243073496581],\"left group of finnish workers\":[-189.57098831437355,-151.2780350898976],\"left-wing politics\":[228.42910197042963,-184.27497060942483],\"left-wing populism\":[214.73929865785726,-109.79066238088986],\"left\\u2013right political spectrum\":[193.56851192309216,-144.70627899728365],\"legal naturalism\":[307.2668549627581,-158.46320664103183],\"legal norm\":[-296.54518109051065,198.15848445975976],\"legalism (chinese philosophy)\":[-3.7296485137871924,48.46290619161111],\"legitimation crisis\":[-69.30830775404348,116.89629384032793],\"leipzig school (sociology)\":[295.48417998842933,57.29909923729816],\"leonid kantorovich\":[-295.34342645267674,-615.5082571354618],\"leontief paradox\":[-196.4302446331464,-663.79813899742],\"leontief production function\":[162.15785252152418,-772.9851669528],\"lerner paradox\":[-370.37546049866944,-457.3166699689636],\"les ma\\u00eetres fous\":[277.23533328461565,757.148340319972],\"leslie green (philosopher)\":[-286.79599963586907,76.16121369014819],\"lesser of two evils principle\":[-505.49338588858205,125.40493885111017],\"leveling mechanism\":[335.4323581172761,716.9605450257377],\"levitation (paranormal)\":[-327.8340252162323,378.08336227079843],\"liberal conservatism\":[76.67039651725669,-194.07463937805065],\"liberal corporatism\":[26.732978653843595,-130.20215072715337],\"liberal democratic basic order\":[-192.83783222760428,-236.03204139128692],\"liberal international order\":[-112.31277460977667,-175.37109778946746],\"liberal legalism\":[-55.9786606583037,-343.4431908710315],\"liberal social movement (portugal)\":[16.91494602867877,-177.92760733394633],\"liberalism and conservatism in latin america\":[3.66114680176525,-137.12449226629658],\"liechtenstein institute on self-determination\":[297.99256544602014,-13.572747488599328],\"liesbet hooghe\":[527.8939168894783,-170.34996534927723],\"life and how to survive it\":[-718.8749857684,691.751124829232],\"life chances\":[267.8202310492054,179.45468665615013],\"life-process model of addiction\":[-433.240659909328,515.220089751337],\"lila: an inquiry into morals\":[-147.47062014396911,636.0765421800312],\"limitarianism (ethical)\":[404.8864776450358,-478.27816043116326],\"lingeer\":[-94.06062867503586,575.1513988318868],\"lingeer ngon\\u00e9 di\\u00e8ye\":[-103.08811948291186,565.9363340541269],\"linguistic anthropology\":[66.61018699889625,508.75375206517674],\"linguistic description\":[54.647166189805176,542.0215536891128],\"linguistic linked open data\":[6.339811270534155,542.4433532134243],\"linguistic relativity\":[-26.19788933298534,431.88836803398516],\"linguistic system\":[-48.800511164332995,496.3099157144658],\"linguistics\":[21.22267205515591,426.2294431397498],\"linguistics in science fiction\":[15.21016215178709,347.98337496174736],\"linked fate\":[544.4680127136465,61.27512995228488],\"lipstick index\":[-70.70236977803012,-889.6418091190553],\"liquidity premium\":[-355.2986412755872,-1086.8293248463544],\"list of animals displaying homosexual behavior\":[-232.5262184504531,797.8871529338661],\"list of anthropologists\":[311.7429469710942,702.783075207122],\"list of birds displaying homosexual behavior\":[-207.97434282389867,779.5429370371437],\"list of bordering countries with greatest relative differences in gdp (ppp) per capita\":[-358.2579108498471,-275.38875770979564],\"list of cognitive biases\":[-472.03354684133717,130.8585672918635],\"list of countries by inequality-adjusted income\":[-372.8488353058198,-285.3900095580967],\"list of countries by labour force\":[-430.73889677954276,-321.6474545272817],\"list of countries by share of income of the richest one percent\":[-377.008819833939,-279.3189733463778],\"list of credentials in psychology\":[-600.0416572103942,449.25444155657607],\"list of cycles\":[-470.04183440940267,494.7881714575429],\"list of economics films\":[-368.82655687638066,-17.103149870808064],\"list of enlightened despots\":[79.20790578651497,-149.12467249271194],\"list of environmental ministries\":[-633.8910971081264,-212.91105051913317],\"list of financial economists\":[-334.3821171018109,-707.8017338398541],\"list of food labeling regulations\":[599.2657791691564,-207.8922798397154],\"list of futurama characters\":[-154.97814120985623,59.255065703266006],\"list of important publications in economics\":[-28.72174367514748,-612.8102753091775],\"list of jewish american economists\":[-350.3006627628543,-484.06049956674804],\"list of left-wing internationals\":[286.41955047336916,-260.99829635914034],\"list of liberal theorists\":[24.745151823812595,-218.51417453145615],\"list of mammals displaying homosexual behavior\":[-201.42681987900707,784.5685816212754],\"list of matrilineal or matrilocal societies\":[175.47287420558476,616.1593640935855],\"list of mental disorders\":[-675.3716965283324,557.7730856276033],\"list of mnemonics\":[-541.0534548625013,448.86544877241687],\"list of national independence days\":[-106.75301165325268,-145.9421143706935],\"list of national legal systems\":[-61.14987153785404,181.88796794005586],\"list of neurological conditions and disorders\":[-655.956257437106,591.4930072376013],\"list of production functions\":[84.39963017383712,-813.153787017257],\"list of psychiatric medications\":[-649.2777698255832,549.1266659036161],\"list of psychiatric medications by condition treated\":[-664.050220687545,544.6260064117056],\"list of psychological research methods\":[-378.6140742723019,246.5745483153979],\"list of psychological schools\":[-371.99107898554576,346.33804875773507],\"list of psychology awards\":[-211.16100935033748,673.3534424105464],\"list of psychology organizations\":[-341.24763227325536,289.55913361200885],\"list of public works ministries\":[-1114.5199920951518,-316.88389833070767],\"list of rugrats characters\":[-257.89993502378707,947.282247601519],\"list of schools of psychoanalysis\":[-683.5827389768681,638.4281050974156],\"list of scientific occupations\":[-89.88397327870769,798.335587906086],\"list of social democratic parties\":[254.51764583291705,-263.5100304434516],\"list of sociologists\":[189.63558430429075,260.0599811914253],\"list of sociology journals\":[127.41110460065522,195.68750272024636],\"list of special economic zones\":[-286.1501400111533,-53.39624867992379],\"list of stateless societies\":[117.2200558569212,-185.36355117930694],\"list of timothy asch films\":[486.8002374367106,1080.086550560621],\"list of unsolved problems in economics\":[-253.5907308430609,-740.8975627785946],\"list of visual anthropology films\":[330.653116131983,813.1460195257282],\"list of women anthropologists\":[319.69360937268647,604.7778927921354],\"list of years in anthropology\":[133.50820907015049,597.273439004426],\"literacy\":[-304.41510347668753,437.24139205264055],\"little albert experiment\":[-466.7587163104605,556.0925173142414],\"live free or die\":[-445.2985984755978,34.596383085820555],\"ljiljana radoni\\u0107\":[533.319630989157,108.03910901600513],\"lloyd\\u2013la follette act\":[-365.57462793880023,-60.037803543133485],\"local multiplier effect\":[-100.76357725310272,-1387.4296915988673],\"local service delivery\":[270.2199911116756,-724.0429480713582],\"logical form (linguistics)\":[-76.85473249969003,485.5594305816019],\"logology (science)\":[-151.65328820600618,205.3601196600944],\"logophonetic\":[68.96717115350066,404.56807498354846],\"london school of economics\":[361.57284340427077,-288.6171005291993],\"long-run cost curve\":[78.1017236863269,-733.1564397303414],\"loopco\":[-8.526851114401252,-869.016577514216],\"lorena parini\":[544.356028818241,98.21214157950168],\"lorenz curve\":[-449.8292543856158,-742.3417345315218],\"louise dandurand\":[558.618273157491,56.02200749983786],\"low-volatility anomaly\":[-354.099200699125,-931.85644523068],\"lowell l. bennion\":[-588.1927715878884,-253.43023180991375],\"lump-sum tax\":[-227.75759769273998,-540.6703477375523],\"maceration (bone)\":[-253.7612441816208,714.4273434798982],\"macroeconomic model\":[-86.39994836055975,-660.9293455025025],\"macroeconomic regulation and control\":[-849.9528093455141,-320.65809278194905],\"mad pride\":[-529.9176577285335,624.7845401867351],\"maddaddam\":[-524.9221507426436,1.1552810625098362],\"madhhab\":[-557.2856356551205,230.25312668057856],\"magical death\":[443.62939139089195,1006.715995507131],\"magna carta for philippine internet freedom\":[434.0502645918402,543.4218920932157],\"magnate\":[157.31894889304078,154.66416513420674],\"mahr\":[-228.2498103597155,655.5017627472157],\"mainstream economics\":[3.315797986996374,-663.3121571979577],\"major depressive disorder\":[-597.8072408239959,481.9961069800536],\"majoritarianism\":[55.20794741844037,-10.128696748243213],\"making democracy work\":[570.0100360076373,55.884390549414064],\"making peace\":[-342.8234303949555,328.940017506361],\"maladministration\":[59.482137061054125,-176.85492347801767],\"male state\":[5.1417726367954195,14.973922901008235],\"malikism in algeria\":[-623.2516182340136,262.1226302046317],\"malinda s. smith\":[394.2668457510373,24.685508543631382],\"maloca\":[209.85585642060698,668.2187188142601],\"managerialism\":[-107.12567641298229,32.92229726972155],\"mandailing people\":[625.6268339635669,1378.977393801891],\"mandeville's paradox\":[-221.95739589296468,-397.5854544763438],\"mania\":[-613.4664845957091,541.0554939186859],\"manifest and latent functions and dysfunctions\":[-10.703097292214657,167.78416753389766],\"manorialism\":[95.7739937158128,-349.45850362917855],\"mapping controversies\":[-286.4521465314758,161.8957205933943],\"marc lynch\":[196.96118446608068,-229.78859764966953],\"marcellina (gnostic)\":[-459.6289669630788,635.2836046442452],\"marco tarchi\":[389.3965343449937,-16.20136499398191],\"margaret clark (political scientist)\":[567.6429616019336,65.02297340243774],\"marginal factor cost\":[228.54987205201013,-674.6110064736514],\"marginal propensity to consume\":[-109.17207973536016,-857.4693873661639],\"marginal propensity to import\":[-116.60179369791457,-970.5051882756235],\"marginal rate of substitution\":[-102.75531471277951,-843.2553650383988],\"marginal rate of transformation\":[37.556197633268596,-756.2832141715731],\"marginal return\":[-194.29043448239236,-842.1676962666807],\"marginalism\":[-6.634476235590462,-595.5324047584036],\"marian van landingham\":[553.040448856631,50.03173005881332],\"marie-christine kessler\":[636.4922083249397,-28.74359191194626],\"marie-louise von franz\":[-679.75060727304,739.7547242588735],\"marija gimbutas\":[215.50005882948233,526.5662009859285],\"maritza montero\":[363.95942436525064,9.69084902664787],\"mariya gabriel\":[-623.2052995820495,-318.7014562891461],\"market allocation scheme\":[73.24349568627407,-584.1477664607299],\"market anomaly\":[-481.8593214575433,-1107.5861205212898],\"market for corporate control\":[-405.34981201029683,-1323.3163198909435],\"market mechanism\":[88.10187948942684,-661.7771250920458],\"market microstructure\":[-272.32722837098527,-927.3873959853528],\"market rate\":[57.6337462831946,-761.8757233352397],\"market trend\":[-567.9899884309568,-1210.0881942336237],\"market-based valuation\":[-349.72026050358807,-1088.8563795871519],\"market-dominant minority\":[-380.441799733535,-116.14106379822398],\"marlon bundo\":[-606.3430209396022,-193.1234958595512],\"marriage of the virgin\":[-96.78577824056332,489.87626794636844],\"mars needs moms\":[-460.3812197093119,641.397776733057],\"martens centre\":[-470.8235150924165,-255.6250993917312],\"martial race\":[226.32082109252303,971.0048954543072],\"martin hellwig\":[151.1447238322545,-931.5715335054248],\"martine-anstett award\":[-413.37838822451226,-109.87083629619013],\"martti olavi siirala\":[-614.5429859050797,639.3075166638037],\"marxist sociology\":[263.80949079903536,35.08397584490994],\"mass action (sociology)\":[236.86472264753772,229.39558215417458],\"mass media and american politics\":[526.5274463788467,-323.7502144852118],\"master of public administration\":[479.88254570840957,-97.28338022719198],\"master of public policy\":[566.9945457792551,24.717473047705813],\"masters in agricultural economics\":[985.9623907985782,-266.96079765278756],\"material flow analysis\":[421.5803813813945,-45.932286868557256],\"maternalism\":[17.778822692759782,-115.64975490095145],\"matrilocal residence\":[148.9071854302785,600.3137691948691],\"matrix management\":[-387.3674731955224,190.9323638600605],\"matrix of domination\":[-32.49486068720998,298.97306860833964],\"maturity transformation\":[-258.54261215425106,-1084.2875208543699],\"max scheler\":[-202.2763608750141,403.68756191637345],\"maxims of islamic law\":[-568.8691785825504,310.07330201049166],\"maya research program\":[282.94879901492106,441.085287385969],\"mccourt school of public policy\":[725.9622754418386,3.9285858242738616],\"media circus\":[-136.3495753057999,-195.8806156435282],\"media linguistics\":[41.55247139557805,451.37965477999774],\"median voter theorem\":[-130.06823915926662,-444.7389297989027],\"mediations (journal)\":[564.0932625210099,48.8617709420812],\"medical anthropology\":[245.4133392519842,551.1370420777749],\"medical psychology\":[-375.6817232306933,274.848980859618],\"medical sociologist\":[87.3208729227316,404.7242297956453],\"medicalization\":[-317.57546090010806,505.2591648389633],\"mediumship\":[-404.15904793974613,399.6650582152413],\"memory space (social science)\":[-162.95873041852232,614.746913390755],\"men who have sex with men\":[-259.11245301629526,794.8252877135325],\"men's underwear index\":[-67.76536651353976,-1112.1019336727873],\"menninger foundation\":[-770.6914892281453,672.9274958993802],\"menstruation in islam\":[-200.9391646980187,714.2012822025849],\"mental environment\":[-218.28526833488434,284.61462284246034],\"mentalization\":[-819.0907187263825,-513.541029611014],\"merger simulation\":[-297.21434600833817,-760.440813541263],\"mesoeconomics\":[-102.77327188162585,-779.0010013209086],\"mesosociology\":[134.3768962733426,417.0019630131365],\"meta learning\":[-737.9064415787861,-471.4486238301087],\"metalanguage\":[27.477320222120156,365.20631506687727],\"metanoia (psychology)\":[-744.5764010681872,807.5580280739267],\"metcalfe's law\":[-98.10328212616801,-1490.677491777928],\"methodology of econometrics\":[-66.81336918155235,-983.5705947746907],\"michael albert\":[203.53459239952818,-363.8006635957303],\"michael l. gross (ethicist)\":[568.6721373687692,97.65374476066623],\"michael spence\":[-232.68044630817826,-673.0712246044305],\"michael thrasher\":[849.398704092457,-266.7535934187052],\"michelle rosaldo book prize\":[179.6865026017604,793.596924737997],\"microexpression\":[-185.40630375492879,631.4945809209],\"microgeneration\":[-193.5203479447657,-466.84145285788753],\"microsociology\":[80.3527069827488,338.62525295498443],\"middle-range theory (sociology)\":[-491.8752247845155,-827.9037469842049],\"middlebrow\":[40.350253736189,232.25022822846483],\"might makes right\":[63.543173881894035,0.8978365136305579],\"militarized interstate dispute\":[-185.17883815509128,-69.33779590086024],\"military policy\":[338.54058602655715,-90.20432415949162],\"minangkabau people\":[644.4373935452536,1413.7044883999636],\"mindfreedom international\":[-554.1078808002636,604.43686383227],\"minimal effects hypothesis\":[579.3575651925443,85.8366035053347],\"ministry of housing and works (pakistan)\":[-1344.132354807064,-385.09553092674145],\"ministry of infrastructure (ukraine)\":[413.34644392808644,163.34893124622485],\"ministry of infrastructure and water management\":[-567.1237398174733,-110.0453234745521],\"ministry of land, infrastructure, transport and tourism\":[-1187.4133126579316,-335.4274776310905],\"ministry of magic\":[359.0108666023449,76.7324804867454],\"minsky's burlesque\":[-310.0809255816427,-434.87683328777115],\"moana (1926 film)\":[388.52516045295744,919.4028071240434],\"models of abnormality\":[-316.0930228659785,330.8970765308293],\"moderation theory\":[-184.42790983737052,-367.82118787223715],\"modern liberalism in the united states\":[71.60074539856912,-110.6731796525163],\"modernity\":[54.11647829907511,223.8235617749943],\"modular cognition framework\":[63.30361906355944,408.7288884693385],\"molon labe\":[-359.95563242886817,-304.1602366513588],\"momentum (finance)\":[-566.6631184891273,-1230.796132764953],\"moor's head (heraldry)\":[248.13099574889327,247.49427425635798],\"moral emotions\":[-396.2559195346415,761.7881693177126],\"moral entrepreneur\":[135.55077362821487,312.17501888465074],\"moralia\":[-509.98463229458014,691.4763608735223],\"morphological freedom\":[-89.86073288389176,449.48695093686314],\"mortido\":[-637.4904864825234,669.6601335057697],\"mosuo women\":[115.77679613536176,646.5210085503618],\"motivational salience\":[-798.2721425376324,572.6893646727714],\"mourning and melancholia\":[-728.2288379981744,665.9190104817093],\"moving anthropology student network\":[199.96191286368352,658.2841465973584],\"mudsill theory\":[65.7670362988391,216.091063381657],\"muhammad taqi usmani\":[-745.0573536565382,337.4509368499571],\"multi-level governance\":[386.6542479459086,-77.8778653853186],\"multidimensional aptitude battery ii\":[-414.83808981051897,389.59476691570603],\"multiliteracy\":[-371.6806689862649,513.7738859878206],\"multimodal anthropology\":[262.2333851000333,704.1567326815467],\"multistakeholder governance\":[-332.1122848740306,-435.0617848339575],\"mummy of san andr\\u00e9s\":[577.8305121256473,388.1136726239787],\"mundell\\u2013tobin effect\":[-57.618914065716766,-793.1429207425014],\"murfee\":[263.3129487620505,107.49558607656947],\"murray's hypocycloidal engine\":[1383.4050686495796,-381.8395345184659],\"museo de antropolog\\u00eda de xalapa\":[296.50964325762345,741.1920854691485],\"museo nacional de antropolog\\u00eda (madrid)\":[225.83344318045727,642.665068712241],\"museu da lourinh\\u00e3\":[292.4646389787136,437.2128328473662],\"museum of archaeology and anthropology, university of cambridge\":[306.7697011508825,758.2472942862713],\"museum of mankind\":[132.87642415214717,630.1951100782285],\"museum of world culture\":[-315.0674787040881,774.907012783712],\"music and political warfare\":[-42.0506197000921,-22.244975535159494],\"music psychology\":[-341.0524037404634,311.21946534737145],\"mus\\u00e9e de l'homme\":[303.79778337460255,837.7425765189784],\"mus\\u00e9e des confluences\":[204.96950639399157,672.1974541906591],\"muted group theory\":[-11.660925209263016,446.55219453686084],\"myron scholes\":[-250.85404988431242,-685.7374189923719],\"names for the human species\":[-99.20520756969664,247.15750822417692],\"nancy program\":[358.5252918939895,-406.78891701353933],\"nanook of the north\":[310.5408039492935,783.6114041534624],\"nanosocialism\":[276.73535243864484,-251.1817160214331],\"nation state\":[203.93657659038678,174.38709082409042],\"nation-building\":[329.8739799846183,463.3831845434524],\"national agrarian party\":[98.07334445253012,50.91932976062752],\"national agricultural policy center\":[68.93911761775084,-771.7016038406424],\"national association of school psychologists\":[-462.0730444193218,319.57783791820356],\"national average salary\":[-145.8589364302974,-279.31161336036433],\"national communism\":[338.3830108607847,-62.72218609661758],\"national conservatism\":[147.08007881915435,37.61703032106599],\"national crime victimization survey\":[80.81301519153202,692.7002036570728],\"national equities exchange and quotations\":[-762.7066122828646,-287.9657195005906],\"national forum (georgia)\":[-77.44873283553034,-162.8853407316213],\"national liberalism\":[17.147820421117572,-73.53398412306757],\"national power\":[17.127809045278333,-201.1976785658796],\"national question (quebec)\":[-166.76474333771577,457.85476568662614],\"national student survey\":[479.07925480363514,-369.4327719499503],\"nations and iq\":[-397.78088646162126,251.6481806448304],\"natural capital\":[143.53776370699106,-352.5194301341221],\"naturalistic disease theories\":[41.20649648683333,638.8952840735283],\"naturalistic observation\":[-268.1282734964526,567.8737126723086],\"nava ashraf\":[-165.4066744950431,-330.8766862309473],\"nayakrishi\":[227.40596248478576,-465.0237921027104],\"nazism\":[185.46287360732782,16.864161602415628],\"necropolitics\":[-525.9493937310342,721.6447286044994],\"neglect\":[-421.06850069316556,726.4186422792862],\"negroid\":[241.4902939470299,1072.1329494053775],\"neil maccormick\":[-286.03684429709244,67.94977374991987],\"neo-capitalism\":[128.2041476161248,-442.23931315278793],\"neo-nationalism\":[102.11382900171598,9.577175035462671],\"neo-ricardianism\":[41.47967676503214,-592.0780782813106],\"neoauthoritarianism (china)\":[136.8414152716755,-193.6299544782614],\"neoclassical liberalism\":[19.78428397754355,-320.14785989740915],\"neolinguistics\":[9.613160621220388,536.9391489340758],\"neosocialism\":[165.80491286023513,-68.82102495167172],\"net national product\":[307.783973517241,-482.3265181246237],\"net worth\":[-384.0403529784027,-352.70038093658997],\"netnography\":[335.93047409673767,485.78804293136574],\"network effect\":[-101.16817069958503,-1116.0753387006673],\"neural adaptation\":[15.199723815023713,539.1532454183126],\"neuroanthropology\":[-21.73537052104734,464.1628756905854],\"neurophilosophy\":[-282.6395086831119,313.1000293828848],\"neutral stimulus\":[-538.0610961383579,649.5931751420734],\"new aspects of politics\":[249.08719822208434,63.54133143857503],\"new institutional economics\":[-72.26382502248791,-482.85894234074516],\"new left review\":[409.18945493470204,-136.25889105801483],\"new political economy (journal)\":[640.7983481097209,-10.53965622104642],\"new social movements\":[313.1828299740152,-129.85758757168608],\"new york state sociological association\":[210.3882980734923,662.1398345591883],\"ngo-ization\":[-63.154971900609766,-205.3041889996555],\"niamh reilly\":[574.8823515953783,90.00650343792724],\"nicole bacharan\":[692.9758476453112,-176.6380643466463],\"nigel simmonds\":[-280.8607035454226,73.13295845754169],\"night-watchman state\":[43.59160969015855,-274.93154391304375],\"no war but the class war\":[385.5457910843166,3.5639298740512033],\"no war, no peace\":[-499.8647745139419,-193.50930709650027],\"nobody nowhere\":[-495.57647133523864,555.7922874451858],\"noel ignatiev\":[270.75240170339254,609.2077550734185],\"nolan chart\":[208.15289682372838,-131.23861890438891],\"nomadic pastoralism\":[252.0284887399433,525.6144593239216],\"nomads of the longbow\":[256.4753139041759,704.5017091355551],\"nominal yield\":[-300.72800201986684,-1795.0964767231417],\"nominate (scaling method)\":[-340.96839733104406,-104.46027749743766],\"nominative determinism\":[-459.0579585127694,-573.6881274216059],\"non-governmental organization\":[-197.23644555933393,-192.26184354198773],\"non-interventionism\":[-33.379908575168116,-303.140808741329],\"non-representational theory\":[-49.48708920541238,438.4087904362998],\"non-sampling error\":[-629.8879852909284,19.80678424468504],\"non-state actor\":[-232.2611409656539,-26.238783733881945],\"nonkilling global political science\":[645.9499043739645,66.337553382236],\"nonna mayer\":[598.1251586774065,-54.76455031033422],\"nonpartisanism\":[48.459259205902256,-141.2403145931692],\"nonprofit and voluntary sector quarterly\":[537.532176420512,216.10712622920022],\"noosphere\":[483.5584480478217,443.41806673958513],\"norm entrepreneur\":[228.51582891036153,387.81607425771205],\"normalcy bias\":[-309.55732343442094,91.63203828187599],\"normalization process theory\":[-262.76258342415304,159.46535586746882],\"norman chester\":[537.0484412497339,-34.997896635099174],\"norwegian journal of sociology\":[605.8049355812099,515.4338042020975],\"norwegian paradox\":[-114.20085752610812,-245.81379803129278],\"norwegian sociological association\":[509.14261961112663,454.84765441492834],\"norwegian sociology canon\":[559.3094246815907,-21.014415722422058],\"notary (catholic canon law)\":[-476.0974842384943,59.137980029731416],\"note verbale\":[-421.94638274929764,-58.52789361813738],\"nudity\":[-333.39690884496474,888.8561087052516],\"numbers (vancouver)\":[537.3507170323367,-143.55838205257191],\"nur f\\u00fcr deutsche\":[127.43023241513443,47.55870821104133],\"nurturant parent model\":[-356.38889517966834,483.2831458960603],\"nutritional anthropology\":[200.99447850422933,532.7706055008849],\"nw 39th street enclave\":[259.8724702849813,114.68462199218813],\"n\\u01c3ai, the story of a \\u01c3kung woman\":[294.95242217558314,756.251131929566],\"object relations theory\":[-605.4693997760052,586.1149270857517],\"obliviousness\":[-553.2668486946762,674.1856630020496],\"obreption and subreption (catholic canon law)\":[-468.8796989890496,56.45182544091896],\"obscurantism\":[-331.78227786220316,189.28683285498246],\"obshchestvovedeniye\":[557.87472884865,79.51720115806555],\"obshchina\":[202.31622263769913,199.76148960648766],\"obtundation\":[-604.8284722139301,751.0472358123706],\"occupatio\":[-353.241070680949,-28.00191358980889],\"occupational closure\":[-516.7387753474852,247.41667229242384],\"occupational health psychology\":[-306.1675573200614,44.34261458377575],\"off the verandah\":[484.04154643656506,-788.2658705373135],\"official bilingualism in the public service of canada\":[-171.24538964823418,508.99612774319263],\"official cantonese translations of english names for british officials\":[94.39253174054079,182.09468547956178],\"ogilvie professor of human geography\":[-480.97400902613424,387.3833761124896],\"oikofobie. de angst voor het eigene\":[107.75298769032075,700.8714577607384],\"oligarchy\":[158.18495047962753,17.993708210199063],\"oliver lepsius\":[-314.55876892451863,131.5622774551691],\"olivier ihl\":[491.0603526785111,-34.33176847681491],\"on narcissism\":[-743.7382914832018,621.951929945834],\"on the principles of political economy and taxation\":[53.79298684473748,-647.7618990068611],\"one man, one vote\":[-406.2730804501761,-135.14772776614367],\"one-party state\":[258.7053582218576,-86.13932224405595],\"online ethnography\":[283.0639404062363,549.7060043129145],\"online research methods\":[401.31646307099714,655.9481562287616],\"open economy\":[46.022179053844916,-484.16185547928677],\"open energy system databases\":[-543.430080505638,-434.38363239726306],\"open field (animal test)\":[-298.004933740342,817.8593120522853],\"open music model\":[-663.6840255304647,-69.89949012957156],\"open philanthropy (doctrine)\":[316.95614101297423,586.6931169705758],\"open-mindedness\":[-509.67679878977935,-7.91116926654051],\"openness\":[-557.9116039151597,-48.77465351218491],\"opinion leadership\":[-165.00202810505036,46.956522443742784],\"opinion poll\":[-578.3810378462074,12.968318496961036],\"opportunity cost\":[-114.56677313961413,-726.612431268228],\"oppression\":[4.138176250089316,248.05378271010235],\"option screener\":[-203.22562537784546,-1129.242217485139],\"ordoliberalism\":[67.72332122005317,-355.15395094809617],\"organicism\":[87.37308496153071,80.54306719914929],\"organigraph\":[559.522769533313,-63.816437176739434],\"organization & environment\":[362.56706585421705,-263.1192095815799],\"organizational adaptation\":[190.46394313526636,135.08626780521342],\"organizational space\":[-194.74926131497747,-134.70024753351044],\"organizational theory\":[206.57374376137327,117.15337117912004],\"orthograde posture\":[215.96624429084585,670.900216668356],\"oryx and crake\":[-410.68208992428896,18.45015329540099],\"oskar pfister award\":[-225.849609006434,789.3015482496374],\"osteology\":[244.30410815176486,638.0695557732411],\"otto kirchheimer\":[-52.44922792961868,114.4451752213804],\"out-of-body experience\":[-496.2388124392771,578.0592638634878],\"outline of anarchism\":[106.98540362280052,-162.37922015074042],\"outline of autism\":[-417.6151077754013,488.98110370607327],\"outline of culture\":[105.87423072254971,540.4480697304655],\"outline of globalization\":[-84.40531075871996,-182.07682913409025],\"outline of psychology\":[-488.72228409228035,426.29484811916535],\"outline of thought\":[-429.28323863136177,428.20641997922064],\"output elasticity\":[-135.75906323875319,-817.8432348666246],\"outworker\":[-601.891651510577,-28.671674059079464],\"overlapping consensus\":[-91.22163699977493,75.89545805587471],\"overview of 21st-century propaganda\":[-286.0770850826212,47.266467076001014],\"paid survey\":[-747.1965817870358,57.13062177169269],\"pakistan public works department\":[-1279.5418829609953,-365.75226749580935],\"pal lahara state\":[589.2817691193962,62.095832821966304],\"paleoanthropology\":[49.08763192492145,594.3259200649626],\"paleopathology\":[321.02888743242056,628.9335891669355],\"paleoradiology\":[433.7555280331093,763.0911327069738],\"paola giuliano\":[234.08342161689774,-984.2926909353449],\"paradox of prosperity\":[-361.18070548534337,-466.68120616384914],\"paradox of thrift\":[-136.90151159748225,-491.4571069810441],\"paradox of value\":[-206.54804537125855,-551.7884387901518],\"paradoxical intention\":[-313.1428195933461,245.89044437301501],\"parallel state\":[568.705133063515,59.93891372448341],\"parliamentary debate\":[-672.5811039053723,-134.58721902273604],\"parliamentary procedure\":[-632.2758133459338,-90.64190264269733],\"parochial political culture\":[647.980685161056,483.7588157425528],\"parochialism\":[532.0483989252199,277.2402685246502],\"participatory theory\":[-438.80723934868837,446.93090214960137],\"participism\":[169.4685200827245,-311.2811283961771],\"particracy\":[190.16544370329973,-10.60794209706243],\"party identification\":[-46.223525055987785,-239.56037726671357],\"party platform\":[260.38372560634105,-299.90935589031653],\"party political broadcast\":[-280.8767285463759,-145.21282211129014],\"party system\":[242.15753402325004,-102.32466620278036],\"party-state capitalism\":[-368.38323974562763,210.67882437077338],\"passing (sociology)\":[-103.54456538077292,505.48582580955537],\"passing on the right\":[287.3128314728019,152.11816997551912],\"pathognomy\":[-376.9802261489099,757.031372305933],\"pathos\":[-396.63163574170426,683.3023788224781],\"patient participation\":[544.5004515893347,251.20141402260762],\"patrilocal residence\":[110.56328785126104,677.5120400226748],\"pattern recognition (psychology)\":[-241.05112697610988,447.0314846784896],\"paul de grauwe\":[231.37948558508768,-570.2819584304245],\"paul ferdinand schilder\":[-531.7788784407215,386.8936612810898],\"paul milgrom\":[-299.3666145647862,-645.4089833797066],\"paul romer\":[-245.50210268450172,-596.5081478115208],\"paul van riper (political scientist)\":[489.55763770239867,59.846621363843596],\"pauline barrieu\":[474.5686763573253,-371.20733250346586],\"pay it forward\":[-87.59121214848707,367.1857103574738],\"payment for ecosystem services\":[309.7617541067036,242.92578919724488],\"peace and conflict studies\":[65.34565439375277,-90.87170018510086],\"peace dividend\":[300.0319968684111,-485.6259172096265],\"peace journalism\":[-65.83399893130904,-254.2718444744607],\"peace through strength\":[-365.1717617226787,-173.28021211875787],\"peace\\u2013industrial complex\":[351.99859654314014,-14.883350746058577],\"peak wheat\":[-222.83935120481198,-873.2532331479994],\"peasant\":[101.24025600402388,212.49888699311796],\"peasant economics\":[246.44797179282287,497.6859212380812],\"peelian principles\":[119.78026055789192,885.1409228839103],\"peer pressure\":[-118.48566107660848,197.25965457436007],\"pensions crisis\":[79.45284339620018,-590.6013842413738],\"people\":[156.8135280416263,68.67553559071222],\"people power\":[-2.3641064067901274,73.65344530863892],\"people's democracy (marxism\\u2013leninism)\":[373.735640167863,-179.38091172222795],\"per capita personal income in the united states\":[-56.541081504591254,151.03868229716824],\"perestroika\":[245.37368702930826,-71.85057680492133],\"perestroika movement (political science)\":[439.5754358828688,-13.300780731370486],\"performance\":[-188.64464453959533,211.58936861620188],\"performance studies\":[114.73887575505601,632.3942147660518],\"performative activism\":[-99.95097793925049,658.4619864659968],\"performative interval\":[-105.72208772959085,656.4459956454485],\"performativity\":[-86.56203124607764,540.2001505961036],\"perpetual bond\":[-293.62176837787723,-1797.9486215526595],\"perpetual war\":[98.01128214158753,-20.08245560321066],\"persistent vegetative state\":[-473.5018441894041,625.966006210993],\"person\":[-73.10040671670495,516.4846899650847],\"person of color\":[-181.293339799453,225.8256449967515],\"personal life\":[247.4247361094644,212.09693009689207],\"personhood\":[-166.65681450180534,358.99326529681184],\"peruvian nitrate monopoly\":[833.4211663111586,397.0815004818843],\"peso problem (finance)\":[-470.84488624432043,-1065.279659082742],\"peter jaeckel\":[-405.00620076800516,-793.312849777735],\"peter sloterdijk\":[-308.84864918941406,290.63085930745063],\"petition of right\":[-907.6608349657328,-176.39591562179945],\"petitions of right (ireland) act 1873\":[-996.7902679558957,-197.26203058745313],\"philip converse\":[277.06117889499825,-397.83069052843786],\"philip oxhorn\":[577.2573432054583,94.1570355143164],\"phillip blond\":[852.5873022521287,150.39461186206503],\"phillips curve\":[-83.78717705063313,-562.7785460490562],\"philosophical analysis\":[-232.85414675553073,230.13157588710314],\"philosophy of life\":[-91.85068445643257,204.1332035185727],\"philosophy of max stirner\":[25.104489780570436,-140.65140653920608],\"philosophy of sex\":[-76.96149123916612,-15.893883298693037],\"philosophy, theology, and fundamental theory of catholic canon law\":[-402.8173909699542,43.06085577132883],\"pi sigma alpha\":[583.1238611855434,69.12589954016339],\"piaget's theory of cognitive development\":[-309.70602528668974,408.6845996064764],\"pickens plan\":[-318.82463432234476,-696.4666601952208],\"pierre-andr\\u00e9 chiappori\":[137.7260229091238,-893.3421245961495],\"pilar calveiro\":[567.8515410820106,75.31744909085235],\"pippa norris\":[340.38843649687243,-240.8102272296899],\"pit of despair\":[-220.41317045045668,704.4910610044927],\"pitt rivers museum\":[79.89841274538067,610.8267172269315],\"plenary power\":[-500.9866268748269,-428.95825798863643],\"plurinationalism\":[207.30186231205843,101.59807168902621],\"podom\":[219.61745876822238,646.5144448096032],\"poker\":[-243.0109636270048,827.9332578374205],\"polarized pluralism\":[562.9066774279472,67.04970348715058],\"policy sciences\":[29.542500130713183,-937.3176928788761],\"policy sociology\":[316.11600440394926,361.45032555988803],\"policy studies journal\":[578.0765297546706,64.66175245691952],\"politeia (journal)\":[496.59198763559533,61.58427052612915],\"political alienation\":[576.0537026382764,55.78810990134544],\"political cartoon\":[319.2169658405448,-461.3163085115122],\"political communication\":[324.01488874143837,1.6104387852212694],\"political criticism\":[463.6100240265917,-1.8661165612966906],\"political culture of germany\":[678.3868232609173,506.39757746588816],\"political culture of the united states\":[506.5944911591772,389.22583242306064],\"political geography (journal)\":[564.3026865357683,88.62928138230596],\"political groups of the european parliament\":[-169.67987350829648,-132.5141175882787],\"political journalism\":[584.3016395321991,-171.65928386190308],\"political jurisprudence\":[-151.8664596802559,25.857206991996804],\"political man\":[760.0412685457713,61.512470436324875],\"political methodology\":[554.6101518944884,61.5547004484104],\"political party\":[-105.29221163673613,-100.74918649082478],\"political repression\":[226.553334676374,-125.96088223370693],\"political research associates\":[283.11325202860615,-4.800836140542383],\"political risk\":[-391.1640544138115,-837.6963519280068],\"political science\":[433.97043040450086,54.60807449555027],\"political socialization\":[-59.44651688446632,19.462924583083684],\"political studies (journal)\":[620.1188501639465,-77.51922422853508],\"political studies association\":[606.535016061988,-186.7794764263581],\"political studies review\":[575.4999141969897,-244.9847091886841],\"politico-media complex\":[44.502044161796235,-163.64468255020054],\"politics (academic journal)\":[621.2226261413841,-83.79222086358186],\"politics of memory\":[-135.59718243273622,546.6871327533165],\"politics, philosophy & economics\":[559.3796117619722,51.356933970296865],\"politique africaine\":[568.5570031552361,46.1954574667678],\"polyarchy\":[210.2182447006505,-75.92019536321507],\"polygyny\":[-38.99424302352003,680.1160125219885],\"poppet\":[1118.2865719381025,-339.9982680714351],\"popular socialism\":[270.3324632372808,-329.25974382698513],\"population and development review\":[-63.35498322559473,-3.0627595751501384],\"population health\":[476.7463781058992,410.4964798714283],\"population health policies and interventions\":[470.0668364183708,444.37953119395735],\"populism\":[161.74753968922087,-106.9848818342158],\"pork barrel\":[524.1214607410255,139.79744657381468],\"pork cycle\":[-68.15319788359128,-717.2311127615565],\"porter hypothesis\":[347.52775235306484,435.3912495816353],\"possible world\":[-192.90820458884485,362.29101841019076],\"post-behavioralism\":[-150.13753652893502,137.69172268573095],\"post-cognitivist psychology\":[-823.1235747269683,387.4665453676482],\"post-politics\":[45.6913222657984,-104.28901822488729],\"post-truth politics\":[-355.15462688054487,-0.8448112445279631],\"post-work society\":[480.1544220589916,-207.38020969076786],\"postfunctionalism\":[304.4801945878073,-137.15158846676883],\"postinternationalism\":[-116.41565835791674,35.31953569513922],\"postmodernist anthropology\":[190.9218613336406,500.37530926409306],\"postpartum confinement\":[-709.3193771288147,508.671086993523],\"poverty class\":[-212.14945386127258,-114.48111879804539],\"power-to-x\":[-403.4229964720396,-673.7101301546318],\"powering past coal alliance\":[-456.08469225687804,-683.659898699666],\"prague conference\":[-218.0858659767165,54.88064636359755],\"praxis: the fletcher journal of human security\":[568.280762252257,92.34451196348581],\"precautionary demand\":[-142.27605644652297,-847.7797564163916],\"preclusive purchasing\":[-83.40045579088094,-959.1059044269127],\"preconscious\":[-661.3117272700432,608.8589958773789],\"prediction market\":[-242.26608770934595,-164.95514057555897],\"predictive policing\":[-354.96456193586084,114.69875559400285],\"preference theory\":[-195.38450245523399,-1019.6437708930873],\"prenatal hormones and sexual orientation\":[-190.8248848723866,858.5713868761072],\"preselection\":[252.2936323317429,-28.418535750647067],\"present age\":[-482.24361733883575,701.9937836123764],\"price index\":[-184.13328360991736,-825.5502791834601],\"price support\":[-35.98560907290113,-902.6610407110571],\"pricing kernel\":[-217.46858691945337,-898.0896107778699],\"prickly paradigm press\":[335.10480656318737,768.1539726223375],\"pride\":[-318.02642606925383,662.1942331116347],\"primakov readings\":[-135.0761691365296,-171.78540115178683],\"primary market\":[-524.5218255404072,-1161.020796160186],\"primitivism\":[239.21864738348037,-295.0496216506709],\"princeton school of public and international affairs\":[452.02494699477114,-180.10097108047876],\"principle of inalienability of the public domain\":[352.3461609287873,933.001142352658],\"principle-policy puzzle\":[321.78239325552795,65.45754233535635],\"principles of economics (marshall book)\":[50.04993450383878,-612.8898222382411],\"principles of political economy\":[290.22996737863605,-613.4196412122757],\"principles of political economy (malthus book)\":[224.155268650885,-710.4193167432818],\"print capitalism\":[572.0397299032652,94.17035227236788],\"private highway\":[-112.49634097105118,-448.12984174438213],\"private military company\":[81.22273015826708,-329.6110291512017],\"private property\":[107.10864502074253,-299.10272372456285],\"private sphere\":[153.84811140241226,1063.356836792968],\"privatism\":[75.84507435506076,-371.7027377546302],\"priya kurian\":[586.7409982196508,47.493604216729324],\"proactive law\":[-277.3584408934045,-177.7569370031858],\"proactive policing\":[109.86655319395922,843.2023692987615],\"probability matching\":[-590.1408445481874,134.54210532765777],\"problem-oriented policing\":[116.9611793255995,842.5191571422454],\"problems with economic models\":[-86.31652769526386,-795.3978942374681],\"proclamation by the crown act 1539\":[-991.2542979579739,-201.44639649665712],\"procreative beneficence\":[-212.6937260490632,393.08532881832923],\"production for profit\":[390.9402852139436,-198.98717490009145],\"production\\u2013possibility frontier\":[34.981499549217574,-784.3595777343971],\"productive capacity\":[-55.4136681571281,-863.9016835165452],\"programme for economic advancement and community empowerment\":[-419.4122174057905,-561.3069281647311],\"prohibition of dying\":[-495.02167433849564,685.1930625886448],\"proletarian nation\":[227.12896108488556,-56.766444142481106],\"proletarian revolution\":[337.8638846890641,-185.2106743293068],\"promiscuity\":[-196.57988619398847,678.1027199345165],\"promulgation (catholic canon law)\":[-477.53301587844,65.11681787572077],\"propaganda\":[-123.23557570459944,64.34966293546962],\"proportionality bias\":[-535.8773708854862,165.2594367495221],\"proposed national unification promotion law\":[-192.9305320588055,16.2615999704264],\"proprietary community\":[100.86213356133506,-479.1857054167418],\"protest cycle\":[207.0547406720255,220.05240010966486],\"proto-industrialization\":[-347.40288204210674,19.283966370037934],\"proto-malay\":[521.7002559209205,1187.3725664533042],\"proverb\":[-56.01742061804991,572.4963566988561],\"proverbial phrase\":[-49.55149869590426,564.9100584236296],\"pseudodysphagia\":[-359.37501978902225,461.7923339431105],\"psycho-oncology\":[-722.934751850758,587.44611533917],\"psychoanalysis\":[-538.534216624383,553.9518091943002],\"psychoanalytic theory\":[-490.1117615131386,475.48824785225867],\"psychogeography\":[188.47702724689572,115.14273601286797],\"psychohistory\":[-254.16299486449194,311.29971717306717],\"psychoinformatics\":[-552.8293698286083,271.8608099068652],\"psychological evaluation\":[-640.029824573369,645.4188649446428],\"psychological nativism\":[-190.98217375779288,304.14286473229464],\"psychological resistance\":[-744.8502827948639,604.1031339232613],\"psychological statistics\":[-510.1674891114742,262.10051027601145],\"psychological trauma\":[-349.5591434487585,567.9550153853851],\"psychometrics\":[-435.181121794716,250.26470481137588],\"psychomotor retardation\":[-738.8993325293692,554.2099657271201],\"psychonautics\":[-515.1829885733362,482.6165119556337],\"public administration\":[343.29327312261756,32.24514334862286],\"public affairs quarterly\":[5.409102857409439,5.50697284747754],\"public budgeting\":[254.47107699767523,-293.1743973192574],\"public comment\":[-74.30646754411319,-157.19048771050404],\"public consultation\":[22.66831196453342,-92.14747766753894],\"public economics\":[-48.026920281750854,-627.1210867900606],\"public engagement\":[-238.84545358316427,-284.0476225743747],\"public image of cristina fern\\u00e1ndez de kirchner\":[331.2148554440586,-114.90709362667154],\"public image of narendra modi\":[230.13581943805386,-110.73836421030659],\"public morality\":[-94.8050551442089,374.208070629225],\"public opinion and activism in the terri schiavo case\":[-552.8994964609867,720.3903212348913],\"public opinion on climate change\":[-181.38426156022936,-389.13183165891877],\"public opinion on nuclear issues\":[-262.115479943308,-448.3315077409605],\"public opinion quarterly\":[-330.8466278549659,19.494292511513063],\"public policy doctrine\":[223.3802491919874,78.05881496203193],\"public policy school\":[531.8672238711721,-2.756411632839951],\"public property\":[-3.9606939762279922,-410.41208499639146],\"publicity stunt\":[-217.08892619400856,-254.0737470741608],\"purchasing power parity\":[-148.69291219229495,-543.5824787244492],\"p\\u0131nar selek\":[442.5588587143184,213.54984173087846],\"qazi syed inayatullah\":[-730.2562547989111,335.01075301565965],\"qem\":[852.3350748758047,-227.04665426312135],\"quadrilateral security dialogue\":[-536.7103871383454,-88.4656449518787],\"quantitative psychological research\":[-364.5752776284752,247.6839368808553],\"quantitative research\":[-291.7645430501605,278.1033142699539],\"quaternary sector of the economy\":[376.7861731566682,368.7381803545154],\"queer ecology\":[161.77857461138382,288.7484510501703],\"quiet revolution\":[-140.52083273464487,263.9400444334958],\"race and intelligence\":[-319.8572932664341,267.36253060228006],\"racial literacy\":[-379.02652207380214,514.3435065089488],\"racial threat\":[241.01121608035646,390.9874654921163],\"radical egalitarianism\":[466.91620888055127,-203.3272292139415],\"radical psychology network\":[-549.4108780405116,612.6912898792912],\"radicalization\":[-127.2480234802537,-206.8997551117054],\"rage (emotion)\":[-421.8468911149149,772.4344054138385],\"raisons politiques\":[599.2270432419377,-62.104759234809485],\"rajputisation\":[156.43686150600624,299.23361427827217],\"ralph borsodi\":[80.5112683644278,-710.7095998731809],\"ramsey\\u2013cass\\u2013koopmans model\":[-44.246692075399864,-593.3154514927461],\"randy david\":[301.3756993771057,325.41910533852024],\"raptio\":[15.281362810810515,836.8667913854083],\"rasma k\\u0101rkli\\u0146a\":[579.8531921573182,53.55048999779522],\"rat race\":[119.9400284183347,-516.0303927918274],\"rate of return\":[-405.8381252195862,-1029.228658042837],\"ratification\":[-556.160735618363,-17.73729167703754],\"rationalism\":[-183.0731682994465,101.72219274058341],\"reactionary\":[137.91441341357822,-36.89882429968593],\"real economy\":[-275.0452897971479,-837.865955846239],\"real socialism\":[299.4011600263179,-186.25246316992096],\"real-time economy\":[-317.22152271768465,-935.2272094834311],\"real-world economics review\":[358.8042576421008,-328.4409731768541],\"reality distortion field\":[-353.56288981764527,295.9460339799477],\"reasoned action approach\":[-427.51766537789723,517.7218686540747],\"rebound effect (conservation)\":[273.4235841399138,-380.26149869049243],\"recent human evolution\":[-258.7027346879139,196.80670774234463],\"reciprocity (cultural anthropology)\":[172.8837815521031,402.34015378588265],\"recuperation (politics)\":[150.80839705286613,-82.47846176503792],\"red wall (us politics)\":[610.7049191391912,443.6826945029868],\"reductionism\":[-170.04694871213536,201.79862111658025],\"reed's law\":[-106.86391831981429,-1204.7439639799748],\"reflexive modernization\":[115.92872656617179,-45.740913580394455],\"reflexivity (social theory)\":[41.76703788669898,503.62612079306683],\"regional autonomy\":[310.13336792606384,232.3202414975817],\"regional hegemony\":[209.63093039203505,-25.24971631232918],\"regional power\":[149.83883340781387,-17.768514120259887],\"regionalisation\":[13.901676940146878,545.3542922931264],\"regionalism (international relations)\":[-135.1373073276762,9.131805090252287],\"regulation of science\":[-248.56279660112472,166.97913326903247],\"regulatory competition\":[-155.06787892814327,-415.38060154174894],\"regulatory economics\":[46.24526856995131,-528.5034090290444],\"reichsministerium des innern\":[-369.8850777924474,-68.01777171899418],\"relational developmental systems\":[-271.0693259750221,573.6378910966893],\"relational sociology\":[137.73155674514697,332.3914730501948],\"relative gain (international relations)\":[-117.95782613294853,24.074419851730458],\"relative income hypothesis\":[-168.52412612873647,-954.2224520984051],\"releasing the spirits: a balinese ceremony\":[5.579356855064462,1221.7671892241478],\"reliability (statistics)\":[-709.1644480023828,302.5351842852412],\"religion\":[-42.41401343739887,231.9867589027508],\"religious communism\":[301.9686775566837,-117.7059980895203],\"religious literacy\":[-96.71515654252958,316.9162749650258],\"religious socialism\":[265.6370921957275,-201.70286188803468],\"rena dourou\":[387.6335251478558,-57.570974438884164],\"renata salecl\":[-125.60934477278485,132.76714980530303],\"renewable energy transition\":[-398.04978279184115,-504.4428835131391],\"rent extraction\":[-57.0491348556352,-237.8927645860777],\"rent-setting\":[-36.730686056404366,-230.4855695412041],\"rentier state\":[131.44439087262123,-346.7650424073936],\"ren\\u00e9-k\\u00f6nig-gesellschaft\":[536.5036987593348,427.9746941190757],\"repeatability\":[-768.4598779369745,337.493468283032],\"repertory grid\":[-341.5445920755459,241.35352053217417],\"reproduction (economics)\":[346.80397484140616,-233.60841852108567],\"requisite organization\":[-388.8269165874735,185.15341185282267],\"res publica christiana\":[-346.5955900353965,45.77635167109493],\"research excellence framework\":[463.1401489348568,-378.7973196483643],\"research in social stratification and mobility\":[534.6678735159746,421.24006850454253],\"research papers in economics\":[7.781563943130173,-815.5664506596294],\"resentment\":[-406.83928762297256,698.2178747754307],\"resocialization\":[-93.69561271135815,356.16110304326725],\"resource conservation and recovery act\":[-831.4315942533857,-28.08129010495427],\"resource curse\":[-131.86926174825325,-366.024599972624],\"resource justice\":[-214.82846978043364,-424.90156442169655],\"responsibility\":[-8.999872466898827,332.5018723429689],\"responsibility to protect\":[-213.1781155747283,-189.35749406454696],\"ressentiment\":[-376.3589405828619,497.3186826407651],\"reterritorialization\":[-422.1126445256973,26.96330484472091],\"rethinking economics\":[77.28237754472428,-1082.7790614414068],\"returns (economics)\":[-226.16313832956428,-860.4970831994875],\"revealed preference\":[-176.77710920911989,-914.684168864591],\"review of international political economy\":[646.7102987650456,-69.19262663396204],\"revisionist school of islamic studies\":[285.7097705581849,435.8030672606756],\"revolutionary students federation\":[413.87869870593414,1480.715741394935],\"revolutions of 1989\":[270.2940671640507,-108.6003041044836],\"riane eisler\":[272.56993019251337,462.39151129264206],\"ricardian equivalence\":[-7.583988497084461,-817.4637922962014],\"richard dawkins\":[-84.13919796552698,394.60888772122195],\"richard gaskin\":[-3.470573521760278,236.4871594773954],\"richard koo\":[411.14756507549447,-93.97180936197866],\"richard rottenburg\":[207.7968515828086,650.57450625536],\"richard timberlake\":[-55.870477918091964,-447.11733346984954],\"richard wiseman\":[-405.5553828599818,503.49363516967213],\"right to development\":[-242.49255600564786,-45.39323799965449],\"right to exist\":[15.010287203189623,13.3721191697008],\"right to the city\":[548.6813424393782,-180.55494861229585],\"right-wing politics\":[138.8008726798108,-77.55202035295403],\"risk factor (finance)\":[-418.9072405141896,-1006.0189281721669],\"risk management agency\":[-205.48233112009797,-1681.2640139136774],\"risk premium\":[-320.92058727736696,-999.487585617841],\"risk, hazards & crisis in public policy\":[541.3739131875964,84.58497511705563],\"rivers state civil service\":[-374.69448937063993,-62.151596878315125],\"robert christison\":[295.23769618501416,1224.1745759220523],\"robert ekelund\":[279.49969524714135,-549.1583716057877],\"robert f. wagner graduate school of public service\":[500.1207962920436,-95.50309991040115],\"robert heilbroner\":[88.21016822933869,-626.5714284314885],\"robert kent gooch\":[547.6612109818752,81.37129213393945],\"robert m. la follette school of public affairs\":[462.4831417146911,202.12150947531447],\"robin hood effect\":[-286.4759390302187,-952.7451564948691],\"robinson crusoe economy\":[61.37485304961357,-555.065203626582],\"rodney tiffen\":[552.9357534082785,66.471524690477],\"rogers brubaker\":[122.13711573023086,141.38795699985198],\"role ethics\":[-98.14894360453013,-3.132456613970574],\"roll-geske-whaley\":[-271.23754331244163,-1070.3995176984845],\"roman agrarian history and its significance for public and private law\":[404.1270289579709,219.40305585048563],\"roman question\":[360.0532818993081,490.54512891520415],\"ronen palan\":[-73.33451488671885,-303.25387258151744],\"roper center for public opinion research\":[-690.4254527864116,3.5347814314401624],\"rosa brooks\":[-138.54842875172375,-149.0703818829527],\"rosa luxemburg foundation\":[-562.9510838696278,-365.2177165072845],\"rossville points\":[107.89049451054429,364.26813716604005],\"rowman & littlefield award in innovative teaching\":[56.1316942496155,-23.314451750877215],\"rudolf virchow award\":[283.5106004603234,643.903465236257],\"rumor\":[-418.1232198141392,292.80827734808656],\"sacralism\":[277.8475994241173,190.82843209138395],\"safety-valve institution\":[-298.6192654963218,708.1826387006496],\"sailing ship effect\":[-94.65816610209295,-1209.2089617806434],\"salvador minguij\\u00f3n adri\\u00e1n\":[-319.8860887952226,132.8003246387034],\"sam potolicchio\":[836.1542372064675,-2.5251485125374002],\"samuel von pufendorf\":[-125.93595673969321,-131.90757481330843],\"samuelson condition\":[-129.21813837650723,-819.5826125689576],\"sanford school of public policy\":[508.0627250343474,-188.1730926114424],\"sarnoff a. mednick\":[-405.92054381750455,272.5937218151446],\"sascha altman dubrul\":[-539.8044374622074,607.155240480342],\"saskia wieringa\":[303.8944334000471,319.0523155918894],\"say's political economy\":[69.20824762780926,-594.982041822278],\"scale analysis (statistics)\":[-648.4869423718501,101.3193989003202],\"scare\":[-374.01516387056637,656.0709072715057],\"schadenfreude\":[-435.1617971069813,796.3407271526632],\"schar school of policy and government\":[464.28588560733635,-271.27331215117437],\"schelling's segregation model\":[-253.78450633386592,-575.0718457297558],\"schizotypy\":[-566.7018524756963,428.7583168286879],\"school of diplomacy\":[-105.06927523680885,2.692003632352927],\"school of international and public affairs, columbia university\":[466.26044577892606,-98.86747714054198],\"school of political and social sciences, unam\":[384.16224605428266,246.00097172743256],\"school of politics and international relations, university of nottingham\":[691.6934561070946,-292.5813139157223],\"school of public policy at central european university\":[626.0096192380379,-47.46118834916527],\"science & diplomacy\":[-143.3941873785217,-59.77072757395035],\"science & society\":[585.6246210233528,83.08240778074703],\"science as a vocation\":[355.09776159687425,217.08427001249265],\"science capital\":[219.68559400840016,282.2737245585408],\"science diplomacy\":[-303.1431583098977,80.46547162126608],\"science in action (book)\":[-404.6168187950787,162.5823233818166],\"sciences po\":[567.4645505744327,-144.17912880187802],\"scientific man versus power politics\":[-93.71515890140647,18.05674172328983],\"scientocracy\":[-149.5275835315519,97.88549318333801],\"scitovsky paradox\":[-365.84136697525184,-464.8741413732438],\"scotland's future\":[-752.5433033345423,-615.1827214310331],\"scottish index of multiple deprivation\":[-340.95027713503606,-210.09424408887577],\"seasonal affective disorder\":[-704.1858984155949,545.345245878446],\"seasoned equity offering\":[-383.4893235514828,-1249.1193342413985],\"secession\":[-38.87675698597628,-170.07707945804955],\"second-order election\":[566.1547320684891,84.5567959926181],\"secondary deviance\":[-108.04499451613461,352.5255937537434],\"sectoral balances\":[174.98061637050705,-462.59861295164404],\"sectoral output\":[-211.8905205418679,-940.5026379565812],\"secular variation\":[-277.3224978568336,43.779900657424584],\"security of tenure\":[47.307239347506844,-213.95935625666863],\"security sector governance and reform\":[-131.21817940538952,-53.82910024772131],\"security studies\":[163.60722884373135,-12.610328035954566],\"security studies (journal)\":[268.37169169885783,53.83432348130858],\"security, territory, population\":[48.40442381221528,130.0309135512897],\"sedentism\":[272.64196270636216,513.0523067456625],\"seek truth from facts\":[462.44997843578784,-145.61762276294755],\"selectorate theory\":[-181.57351196867845,-64.97671187486581],\"self-assessment\":[-317.51237588185734,869.5413465907274],\"self-awareness\":[-295.07828991709766,512.6427786748067],\"self-criticism\":[367.64312574818996,-109.30792094367986],\"self-deception\":[-286.59995306422627,335.6343001293605],\"self-defeating prophecy\":[-233.88871596379582,-334.6634572166807],\"self-hypnosis\":[-722.0159317400879,606.7331375573604],\"semiotic anthropology\":[67.80805198766346,599.6278436747258],\"sensory threshold\":[-477.7723230685336,236.90534974507528],\"sequential game\":[-318.8452642385649,-550.3696135824512],\"sequential probability ratio test\":[-390.96046694310394,280.5559115983371],\"serer maternal clans\":[-102.2986458862467,574.2615603764189],\"serer people\":[-78.75828054889776,563.0001445862109],\"serer-ndut people\":[-95.02462711330688,566.8274321511487],\"serfdom\":[105.7248408587751,131.38036789066146],\"serfdom in tibet controversy\":[96.7733438344458,200.5162084236432],\"service economy\":[17.59760924752119,-567.3763473550147],\"sex and gender distinction\":[-34.61472963494131,609.153971304774],\"sex and reason\":[-276.76906405280357,222.91162631688792],\"sexual inversion (sexology)\":[-105.99868952051077,678.4721338883111],\"sexual jihad\":[-273.3229489025006,695.1247934596696],\"shadow (psychology)\":[-602.1996809503312,625.7139187669034],\"shale band\":[-187.89253970029566,-224.0912409302706],\"sharon oster\":[-376.54441297955105,-740.3192001457397],\"shell money\":[231.94048699491555,517.0984717333295],\"shock value\":[-28.30671501574374,189.68521593868346],\"shrunken head\":[-95.12541498773287,766.5290405707202],\"sid parnes\":[-401.65675304274845,268.95757928040416],\"silence=death project\":[-80.94065116525545,298.6030595048606],\"simulation modeling\":[70.27540730747417,-981.3437316749519],\"singleton (global governance)\":[-98.89630836488335,-449.3909380970682],\"sinodonty and sundadonty\":[249.08630750481467,1083.6572635627592],\"siobhan o'sullivan\":[-1.2151849398522263,555.559243864277],\"sissyphobia: gay men and effeminate behavior\":[-128.48817975040095,679.3159337747906],\"situationist international\":[241.7141497967674,-158.76953202875652],\"skew\":[-248.67726441033753,-1098.9002005955251],\"skhul and qafzeh hominins\":[-154.49825948184812,420.5605445141888],\"slain in the spirit\":[-427.2028160433824,375.2307867255646],\"slapsoftware\":[777.2302285491252,29.702025560519093],\"slavery\":[-79.50582152692462,43.85999353895074],\"sleep and learning\":[-625.3785833372298,546.5604497001631],\"sleep-learning\":[-642.2256679151442,531.0557216523298],\"slogan\":[-471.08053407005747,80.99931483911082],\"small government\":[60.82164308438983,-260.128564675746],\"small media, big revolution\":[589.5694954033685,53.689067265056615],\"small office/home office\":[-169.70940625746144,-839.415829296402],\"snackwell effect\":[366.24350992788675,-479.89848956241525],\"social actions\":[-33.927980921137134,151.78253336296635],\"social balance theory\":[29.231433049878827,232.7034030868263],\"social cognition and interaction training\":[-497.6545439339266,394.08305493156473],\"social complexity\":[109.39800904451383,270.61840223999246],\"social conflict\":[112.82656096663081,287.25795401291913],\"social conservatism\":[204.4549859331157,-9.774935053121723],\"social construction of the body\":[-76.09472009769742,296.21834233029756],\"social corporatism\":[169.63898239623492,-165.06788692682898],\"social cost\":[-64.69819562182622,-604.0564274690865],\"social death\":[-162.85061316328344,19.247885913672132],\"social degeneration\":[90.46678761006187,593.3717488479741],\"social dominance orientation\":[-191.73442533537374,346.7969259136286],\"social experiment\":[24.495340318711797,285.5766786576028],\"social geometry\":[-77.9331027106203,-319.7222118148066],\"social impact entertainment\":[312.76084560494513,591.2690522946801],\"social imperialism\":[342.63671219762875,-128.64228354402172],\"social integration\":[74.21611446082218,196.55031751603715],\"social invisibility\":[-89.86414628359586,-1688.4499424875241],\"social liberalism\":[59.029338512651925,-126.92468461548984],\"social media in the 2016 united states presidential election\":[265.8106868553329,-396.05605100996894],\"social media in the 2020 united states presidential election\":[351.25017307279484,-498.5040162087184],\"social media use by donald trump\":[318.78498442950837,-318.66831240520844],\"social media use in african politics\":[378.7001223200192,-466.26464085162996],\"social media use in politics\":[288.18061446188335,-365.9494547827261],\"social model of disability\":[-94.30990958441379,344.013256152266],\"social multiplier effect\":[-100.63864063409477,-1312.1157829217773],\"social order\":[176.88177625757066,-22.06100140642857],\"social organism\":[370.56806628262035,307.6852339475802],\"social organization\":[162.26126556679773,107.36056719272142],\"social patriotism\":[470.31545687383493,-63.79232162543502],\"social phenomenon\":[-301.5285087150743,489.9352126585818],\"social policy\":[292.8124828544422,117.44622520610584],\"social reality\":[-93.60064760785025,185.49841904099608],\"social reproduction\":[119.8610486198899,223.30400543449716],\"social revolution\":[326.15626607689626,-160.10459606013922],\"social rights (social contract theory)\":[76.07817177668325,-481.7373808434041],\"social risk positions\":[23.424600786190844,234.3050280112691],\"social rule system theory\":[-87.56650346161797,90.78827213331125],\"social service review\":[467.60861693173064,178.90621390540414],\"social situation in the french suburbs\":[-156.66461612873815,-136.73819576431688],\"social system\":[105.89074243209582,156.06684390726787],\"social threefolding\":[-53.460026770350325,-29.882631467811716],\"social transformation\":[257.3685579114951,166.56696316373052],\"social vulnerability\":[-363.3832309108112,-247.6457081006762],\"social welfare in luxembourg\":[-426.9370424808287,-326.0711944347223],\"socialist campaign group\":[569.5448505937943,125.14927722175352],\"socialist realism\":[88.93018399195898,-85.40643849462371],\"societal attitudes towards abortion\":[-97.14473482753866,212.7101702831932],\"society for economic anthropology\":[-125.86383487655002,-566.6487436403609],\"society for medical anthropology\":[279.94860013109655,623.7916658296334],\"society for philosophy and psychology\":[-404.44320526842125,430.9210153471149],\"society of anthropology of paris\":[-10.41529464001332,557.8752891619583],\"sociological imagination\":[-176.2618114221905,404.14586565374333],\"sociological insight\":[230.76594133272155,256.7490789872975],\"sociological naturalism\":[-78.55493891489223,161.6301932699747],\"sociological positivism\":[-134.9968191114705,187.12291496313884],\"sociologists for women in society\":[-81.27177653056712,303.6560697705219],\"sociologists without borders\":[-229.68819794922234,-136.51948675295134],\"sociology in japan\":[100.91744192629353,298.4778706340846],\"sociology in poland\":[214.72087448601877,243.14276801608557],\"sociology of manchester\":[271.91138621380946,105.42194555237367],\"sociology of morality\":[85.60302386390715,292.7391955815887],\"sociology of punishment\":[103.64673691298067,348.6216599324475],\"sociology of scientific ignorance\":[-205.54213303812244,209.61798043855723],\"sociology of the world religions\":[394.2620990083248,205.39263055764613],\"sociometric status\":[-290.66855993769474,756.3096487746493],\"sociotechnology\":[-270.17766183794066,167.04234425595936],\"sock puppet account\":[-123.10998694064806,621.2569683681437],\"sodality (social anthropology)\":[219.58174968344005,665.4217172568772],\"sofr\":[755.7962001655903,681.2681626760594],\"soft despotism\":[214.64723856431507,-96.83149668300844],\"solano people\":[214.36778813288947,664.7355343189296],\"solitary confinement\":[-51.833024690357966,307.1526058216127],\"solow\\u2013swan model\":[-64.64604075921157,-657.9633676810465],\"songun\":[-24.706819879109656,-283.45390505112493],\"sonnenschein\\u2013mantel\\u2013debreu theorem\":[29.894353977814404,-744.0782227917828],\"sophomore surge\":[557.286840485814,39.77943695706096],\"sopor (sleep)\":[-594.6215076892518,738.1613750117842],\"soul\":[-389.62066068081697,553.0453787002308],\"soul dualism\":[-59.19969738900096,707.3123934041047],\"sovereignty of puerto rico during the cold war\":[296.9793226636647,-167.0406546895945],\"sovereignty of the philippines\":[-359.5589029101805,-116.56034440151868],\"spatial justice\":[-67.93784834341453,83.18133220203875],\"spatial politics\":[242.57565230978742,-125.68792516787569],\"spearman medal\":[-229.54611460099005,784.0928557167298],\"special relationship (international relations)\":[-298.90502981465085,-105.06343862399602],\"specialist in psychology\":[-264.58545671115996,576.252140621908],\"spin room\":[-371.04342324344753,-59.21864777642303],\"spirituality\":[-236.39498904390476,428.4363654463856],\"split labor market theory\":[25.147097767425137,213.065718534035],\"squib (writing)\":[3.517583587035944,535.464631857386],\"squirrel (debate)\":[-771.7349442766115,-156.97466076879797],\"st. petersburg paradox\":[-278.44644390298106,-580.2411637298967],\"stakeholder (corporate)\":[-146.98115593965815,-137.98836830042777],\"standard cross-cultural sample\":[132.61980909971243,615.5398444732853],\"starve the beast\":[-82.40891988421822,-414.88952048433714],\"state decoration\":[797.3268217046865,46.95329829120501],\"state of affairs (sociology)\":[-251.27699780710392,469.9250889025109],\"state order\":[800.1211085733198,41.72027485378026],\"state price density\":[-221.14526691303377,-903.7763856300619],\"statecraft (political science)\":[552.8845085805465,80.90841619940173],\"statism\":[136.0448167412663,-100.97024055041061],\"statistical inference\":[-493.33218122990996,93.01285446564067],\"status attainment\":[311.581365185636,204.77389108688584],\"status group\":[75.13895196872618,233.1659979059615],\"status quo state\":[-78.99592633119704,-120.57793912763128],\"status\\u2013income disequilibrium\":[287.2526305834315,228.8750126971076],\"stein rokkan\":[417.7122241830382,-7.741497374458458],\"stephanos bibas\":[-517.417846726701,-65.69436252974126],\"stephen barber\":[590.2578662654867,74.63497139117803],\"steven b. smith (professor)\":[577.9280665898696,69.47579564855553],\"steven n. s. cheung\":[-176.3209293257562,-421.5979855897791],\"stimulation\":[-406.22867197669405,744.5210981427255],\"stochastic investment model\":[-286.3534947016942,-1680.8011149546244],\"strategic choice theory\":[329.0268480557912,169.7076418356894],\"strategy of tension\":[-322.2207307404125,106.74722631305067],\"strict father model\":[-361.8628385814209,531.0768470102827],\"structural discrimination\":[-17.285013428064246,276.21600052040804],\"structural endogamy\":[-97.19676382500137,-1686.4040370475748],\"structural estimation\":[-74.08815417464419,-1042.6704824810504],\"structural inequality\":[199.25388977946736,-678.74025116043],\"structural violence\":[94.49378131723935,117.26447625057305],\"structuration theory\":[-101.06843835097231,268.38586145995845],\"structure and agency\":[150.2273551540323,271.3786471524065],\"stylized fact\":[90.45853826013061,-757.3614436963096],\"subconscious\":[-515.3250900549752,466.5275975529277],\"sublimation (psychology)\":[-346.88873487477406,812.7356628432439],\"subsidy\":[-97.81640996297601,-985.3253606255282],\"substitutes for leadership theory\":[-427.0015785489664,512.4269431912342],\"substitution effect\":[-103.44318448368121,-751.1703308170705],\"successor ideology\":[242.7825504936942,-18.728598538761965],\"summerhill (book)\":[589.7500884111116,220.3061549005492],\"sunk cost\":[-246.4926246934586,-403.8589204307944],\"superiority complex\":[-742.6784833006126,498.25568302966315],\"superpower collapse\":[34.533950853949364,-102.58689336341772],\"superrationality\":[13.242746129345223,-522.6268573133937],\"supply and demand\":[8.21986819094443,-636.4059971600736],\"supreme court economic review\":[195.12420777008387,-537.0504881014735],\"supreme court of justice of colombia\":[-71.27589248703129,298.9878095204939],\"surplus labour\":[324.6995782670899,-199.76799053445188],\"surplus value\":[220.26040240761714,-324.81109329801546],\"survey data collection\":[-634.3964187179529,60.708209975410824],\"survey on household income and wealth\":[279.01546464306995,-426.88234565890343],\"sustainability and environmental management\":[198.29914918606252,-555.6937795142738],\"sustainability standards and certification\":[374.359883756493,-453.24696019081733],\"sustainable business\":[330.1173555920725,-383.33697765157757],\"sustainable development goal 11\":[-446.9816008635303,-277.7710395564791],\"sustainable development goal 12\":[-548.220303521295,670.8958086776911],\"sustainable development goal 14\":[-445.3632292127515,-271.4923659028833],\"sustainable development goal 17\":[-440.57513620836727,-277.33426285881296],\"sustainable energy\":[-322.8580870497373,-491.11663591214244],\"susto\":[-264.00227936565244,547.7655668957796],\"suzanne kessler\":[-28.445503702948738,793.6005813216614],\"svetlana tatunts\":[388.6585857646544,-51.771971897073286],\"svoboda ili smart\":[430.2683349085572,548.2285019086588],\"swanson, nolan and pelham teacher and parent rating scale\":[-354.3236519600482,243.98934872574262],\"swiss neutrality\":[-65.30559633935128,-48.838627731228414],\"sybil (schreiber book)\":[-664.1587358984095,510.8539767529731],\"syed hayatullah\":[-780.4749903318021,345.7508325643731],\"symbol\":[146.4906449927238,185.58855525299887],\"symbolic power\":[205.3516638938916,71.73485253861514],\"symbolic religiosity\":[90.16955743585399,280.26459700302775],\"sympathetic magic\":[684.8031861473718,-262.22036602523116],\"synarchism\":[113.97208908916836,45.08401856466551],\"systems theory in political science\":[233.53092501436655,114.0211510760888],\"taboo (2002 tv series)\":[-638.1722508782572,201.545835532539],\"tactical voting\":[-309.6665442125026,-251.3524580175436],\"taftian theory\":[190.203847023753,-238.91742506586473],\"task analysis\":[-611.5184047202949,505.2959881675066],\"task force\":[-184.43007390904805,327.0207225970887],\"taste (sociology)\":[-506.2565580010158,386.6578564132422],\"tax-allocation district\":[-102.13307598341828,-1083.7678401151925],\"taxation in uruguay\":[-9.9144249885073,-8.954379824675694],\"technical change\":[-256.86883186530605,132.93184673254655],\"technical indicator\":[-634.4503463873203,-1326.8334645897748],\"technobiophilia\":[333.96965290221596,357.06374072128324],\"technocracy\":[84.2604932400852,-31.43485404213937],\"technocracy movement\":[-110.31649223820634,-152.0564340979716],\"technoliberalism\":[60.15772200805325,-241.69597637827334],\"term (time)\":[-210.21044287557547,-171.64168086934203],\"territorialisation of carbon governance\":[99.51475510523242,-457.17847846294484],\"terry karl\":[526.9178788931558,-26.26451214564988],\"thawri\":[-629.8544461564005,257.62944178175775],\"the american journal of economics and sociology\":[200.82235601206654,-443.6421100062401],\"the birth of biopolitics\":[-0.9310415871491421,-86.25871129921455],\"the castle (novel)\":[-535.2218142532471,788.2272818536891],\"the civic culture\":[660.7919187870931,503.1721204322137],\"the concept of anxiety\":[-480.9237302736527,667.4894163039834],\"the counter-revolution of science\":[11.493459294800282,-364.8027050034867],\"the crisis of democracy\":[243.42011573788818,-214.32588951866435],\"the culture of narcissism\":[-794.8670191573275,538.4046462977275],\"the democratic paradox\":[-147.55767302744874,-131.68628765174552],\"the elephant curve\":[-519.1479965804393,-814.4556595025165],\"the emperor's new mind\":[-495.51378244124163,542.2217909721662],\"the end of liberalism\":[581.3849405022187,66.06414291862534],\"the engineering of consent\":[-265.5388648617673,282.9401320567751],\"the establishment (pakistan)\":[-81.1890504442549,267.1268112975095],\"the final days (2000 film)\":[-136.26447722797135,-317.9615874745725],\"the freudian coverup\":[-843.1425681969982,734.8246234483408],\"the good society\":[588.8893712468998,69.3006920159107],\"the good soldier \\u0161vejk\":[-461.6909747449973,-568.3600423207307],\"the great transformation (book)\":[139.44543849170913,159.67090699245128],\"the hebrew goddess\":[55.778516129792266,814.7189007664217],\"the hidden hand: middle east fears of conspiracy\":[574.4246526661552,51.10041863111587],\"the hunters (1957 film)\":[289.24123891260274,744.5406967810942],\"the independent review\":[-26.010582281420447,166.26974357853032],\"the indian struggle\":[313.72207550183253,-22.83179413815375],\"the journal of political philosophy\":[369.90243323562964,-405.6798165110156],\"the journal of politics\":[-3.4378485709632813,26.653797323621355],\"the lexus and the olive tree\":[-205.26250848517344,-93.90717784479857],\"the machiavellian moment\":[309.3247594206576,20.92107181254048],\"the morals of chess\":[-129.542526883032,525.4129067330709],\"the permanent revolution and results and prospects\":[510.95859285493424,-58.675607557535386],\"the protestant ethic and the spirit of capitalism\":[314.9051311276295,161.81433885309153],\"the province of jurisprudence determined\":[-315.67203584450647,139.56420799420002],\"the reformation in economics\":[7.09492553983666,10.773214675217135],\"the revolution of everyday life\":[280.35908199686355,40.858595238134164],\"the rich get richer and the poor get poorer\":[181.5487993755686,167.4173648015243],\"the road to serfdom\":[140.7275474046026,-221.81968255549987],\"the soldier and the state\":[229.58278656956125,-150.49249766512165],\"the state (book)\":[222.6613490775925,-389.3228369285167],\"the theory of interstellar trade\":[-97.62545224866432,-582.0668864935913],\"the triple revolution\":[215.4710416150808,-668.0424813988841],\"the twenty years' crisis\":[-148.1784235115792,-8.408290116770733],\"the white goddess\":[-86.16378209926727,889.6345723103877],\"the witch-cult in western europe\":[-89.3126523530844,995.5342374397754],\"theatre state\":[344.2592268353148,687.7454052940249],\"theories of humor\":[-397.7234035467775,858.4276275366694],\"theories of poverty\":[-291.7321556678284,-269.2956266066162],\"theory of change\":[221.28947579308686,486.71058215517843],\"theory of language\":[-6.357030654285538,464.7185327962673],\"theory x and theory y\":[120.32489457897555,71.23667432527212],\"theta criterion\":[-3.476448420356733,524.0469919856702],\"they shall not pass\":[-500.6854338503704,-136.32824865371586],\"third way\":[110.10460728020661,-212.66342979799765],\"third-person effect\":[-301.0295744102625,9.119800057690252],\"this machine kills fascists\":[-161.72310602776713,13.660710621880789],\"thomas schelling\":[-252.06100063121323,-545.8940455308317],\"thucydides trap\":[184.99614685356858,-133.47935205022765],\"thumos\":[-426.56523040907405,328.6284650243546],\"tibor\":[757.3585890312083,674.3089410653864],\"time & society\":[202.11225265009267,663.8807860321941],\"time series\":[-526.5628891829273,-364.9066976998249],\"time value of money\":[-247.6813033369831,-507.07330894096447],\"time warp edit distance\":[-618.2930882607288,-410.11794223510276],\"time-use research\":[233.07907776002995,984.7687978167775],\"timeline of psychology\":[-405.75533460660404,451.4729612706285],\"timeline of psychotherapy\":[-528.4215053094132,517.8967009509796],\"timeline of voting rights in the united states\":[-438.64260211095797,-188.5971944300637],\"timo ter\\u00e4svirta\":[-439.7267328588624,-622.0141563563529],\"timocracy\":[231.38207407184584,-11.913265451628016],\"tiocfaidh \\u00e1r l\\u00e1\":[-585.5483294848384,77.80082330760912],\"titicut follies\":[1.5206242573974817,-22.84483464276093],\"tobacco-free pharmacy\":[-165.48411178256742,-59.357946480870496],\"toloy\":[61.29124316325979,467.1905508005342],\"tonograph\":[11.5045861965155,531.3034185488239],\"toothpaste tube theory\":[-148.4248668182645,-770.4955979115203],\"topic and comment\":[-30.363885432521162,585.039943663474],\"tore ellingsen\":[467.02561212227965,-383.8140041797391],\"tortured artist\":[-584.952255509672,606.0555570176305],\"total institution\":[-161.50946137003,399.656590240444],\"total survey error\":[-577.2847138827028,50.16358483203605],\"totalitarianism\":[188.71476311620924,-51.04773644381326],\"tractatus politicus\":[-381.3077727483747,129.6756230567473],\"trait ascription bias\":[-413.7184924985027,209.24772216376647],\"transcultural nursing\":[105.6208384256895,578.0536794745999],\"transfer (propaganda)\":[-306.24068276442915,174.26641335965184],\"transformation processes (media systems)\":[375.4850563571743,-87.42291407409137],\"transitology\":[357.91486903877444,265.7375097858784],\"transliminality\":[-513.1571380563026,357.4426112753924],\"transnational progressivism\":[73.77056311052218,425.61590138017095],\"transpersonal psychology\":[-377.8563937010223,389.47873836464765],\"trash doves\":[-1.6365851952682025,95.79908165642988],\"travel behavior\":[198.58670090399588,887.5474291290947],\"triangle model\":[-142.44324844750898,-675.0404193270625],\"triangular diplomacy\":[299.00714792132874,-236.25852122259943],\"tripartite classification of authority\":[356.0395914821299,147.13112692184416],\"tripartite consultation (international labour standards) convention, 1976\":[-666.6463253396663,-35.97364803565245],\"trobriand islands\":[187.58553112767876,545.0008617647331],\"tropical geography\":[-281.77337833170805,6.273895714785503],\"trusteeship (gandhism)\":[579.0553455329979,47.50578917073441],\"trygve haavelmo\":[-253.47457152234395,-641.6758536175395],\"tryph\\u00e9\":[649.8386065215662,79.26320978356914],\"tschandala\":[-448.6705268641168,572.3081046785857],\"twitter diplomacy\":[421.18463656300077,-412.6913591041422],\"two-factor theory of emotion\":[-522.5997858706735,534.6185913834368],\"two-level game theory\":[-250.22832289336947,-483.41098098911993],\"two-sided matching\":[-122.30669695418656,-1040.1335747776764],\"typology (anthropology)\":[237.08772465808445,1013.3581187087406],\"tyranny of the majority\":[113.16350205202083,-20.41025802171103],\"ucla luskin school of public affairs\":[257.56078937306734,110.50460373895216],\"uk heo\":[559.4838123175106,100.11229208658314],\"un-energy\":[-422.7624514127593,-565.3953102357357],\"underclass\":[76.31377082820217,131.9290606909648],\"unearned income\":[89.18231374981707,-481.9775278814105],\"unevenly spaced time series\":[-625.9019681203272,-413.1690577686995],\"unipolar mania\":[-722.2166641889758,595.8655157140756],\"unitarian universalism\":[-94.06418255604943,296.29978354303046],\"united federal workers of america\":[520.0911262883402,258.25010987172516],\"united nations office on drugs and crime\":[-488.90353229584144,-262.5407928445862],\"united nations parliamentary assembly\":[-212.0009266167226,-222.73489205076325],\"united states farm bill\":[-157.76470229638505,-1175.829397406459],\"universal basic income\":[312.5819743280667,-382.0632048462471],\"universe (economics)\":[-181.33799882281366,-856.0565653759188],\"university of chicago institute of politics\":[269.30666777279566,108.8572522610997],\"university of san diego\":[220.91460187990842,927.5858654980299],\"university of tennessee anthropological research facility\":[272.1699369456914,886.3357929929479],\"unplanned economies\":[130.05924618629336,-405.5410266234546],\"unsaid\":[-138.39987017267018,700.2877741076696],\"upper class\":[183.56228990937058,198.48772840475596],\"urban legend\":[-309.625086755568,262.2343679378955],\"urban metabolism\":[281.7454083709919,128.54598869907457],\"urban revolution\":[207.40735346636922,291.806320924669],\"urban village\":[93.93771505293752,-678.201054985629],\"ursula apitzsch\":[438.78501180246957,404.97656049756523],\"usc center for visual anthropology\":[204.27244439756967,655.5647982668534],\"usul fiqh in ja'fari school\":[-321.81890224398614,157.95075731276685],\"utility\":[-124.38922124391566,-657.6756599063822],\"utinahica\":[205.89830268154924,664.0910829563821],\"v-dem institute\":[-86.90191306212158,-316.0871660261957],\"vacatio legis\":[-497.40087279794943,53.64260948646043],\"valence issue\":[-32.06964160554667,-571.5585932268393],\"valerie bryson\":[86.92285870283779,254.20128619574726],\"value judgment\":[-129.81783387623938,335.975526164547],\"value product\":[321.2474344100452,-240.3123200038333],\"value-added theory\":[129.45572974243686,238.63863288312677],\"values modes\":[-455.2883520552353,-63.63417580688723],\"val\\u00e9rie igounet\":[553.1103885049683,93.24571679237414],\"vanua\":[228.54266646126086,652.2815388084817],\"variable rate debt obligation\":[-301.9332154289193,-1837.112449415177],\"vaticanology\":[-522.2386854613396,-193.5298492587551],\"vent for surplus\":[201.92212836810543,-630.9848556905702],\"venture capital in spaceflight\":[252.04032244286452,263.46766394449105],\"verbal behavior\":[-247.15148922918547,383.04009602100666],\"verbal self-defense\":[394.341789881591,-450.47573701682876],\"vernon l. smith\":[-188.67610282645225,-634.3844145315807],\"vertical farming\":[311.22856450232445,-931.3834019515893],\"vertical mobility\":[183.65464026299637,151.76034908669254],\"victim study\":[63.94402474875693,664.4501379438083],\"viking fund medal\":[239.91819659468229,511.70215908162044],\"village head\":[223.65490184022775,652.3253541092467],\"viola klein\":[518.1219749701982,-392.13429311030893],\"violence peace and peace research\":[-22.78412147989429,25.24913971448329],\"violent non-state actor\":[-228.48825069719547,-122.43478030288048],\"violent non-state actors at sea\":[-157.4963206841291,-276.1584316596179],\"virtue jurisprudence\":[-207.70255972894446,26.96478521517295],\"visible hand (economics)\":[67.77174906934658,-515.4208257404072],\"visible minority\":[-128.68552563665975,401.32888607149744],\"vocabulary development\":[-193.93952872212606,557.2574281223001],\"vocational panel\":[-361.8620590812369,-63.72685435394632],\"volatility clustering\":[-375.68338619414266,-846.2397387820582],\"volume index\":[-512.1714841768227,-178.05522551791267],\"voluntary sector\":[543.5250075460574,331.9518506099592],\"voluntary society\":[53.17303661625619,-377.3215422785952],\"voter turnout\":[-120.19046869978804,-218.05967508866667],\"voting rights in the united states\":[-379.1663000626881,-217.75330312920735],\"vulnerable adult\":[-489.9280342107611,855.7477266458008],\"w. kip viscusi\":[-243.32696046088876,-729.276488857773],\"w. meredith bacon\":[578.8748134060967,74.42052327310135],\"waga sculpture\":[218.45742370260743,661.1409205291352],\"wakefulness\":[-598.3402369239936,662.8189513104348],\"waking the tiger\":[-408.08027927154643,649.7343279898471],\"wallace neutrality\":[10.976562622329922,-943.6821432274755],\"walras's law\":[65.80721678222231,-865.2716473972326],\"walter f. dodd\":[261.176180320353,-450.2733750940228],\"warren miller (political scientist)\":[228.6783942024334,-510.7748848715147],\"warrior\":[19.41574913404546,223.05409584338537],\"warrior (character class)\":[2.852308504587358,308.4969850500652],\"we don't coast\":[-441.2577282172867,197.13504280387576],\"we shall overcome\":[624.5302145135389,108.61210258601928],\"weak and strong sustainability\":[150.84258469403403,-412.3847746182686],\"wedding\":[-39.23825297667006,891.1041271761975],\"wedding reception\":[26.695991842319888,1039.245914921876],\"wedding vow renewal ceremony\":[19.414608728098557,1061.7233394705463],\"weighted average cost of capital\":[-325.5704442914251,-1058.2514514853665],\"weighted network\":[-91.48601774209143,-1727.4311538085076],\"welfare culture\":[64.82913117286208,485.9531374940676],\"werturteilsstreit\":[16.02960208264076,96.40097599153567],\"west pride\":[-363.07857470073566,941.7972185111423],\"western cape department of transport and public works\":[-1184.7813457395928,-340.6142181897935],\"weston a. price foundation\":[-215.4515020285377,-38.28653640851904],\"westphalian sovereignty\":[-248.17189350378345,-79.44915718388185],\"whiggism\":[44.98217060009962,-191.77502278023445],\"white paper\":[-568.48298322204,-492.42312990195643],\"white power music\":[43.05224903959453,189.267787983361],\"white wedding\":[19.46555845618843,1038.4517821728582],\"who moved my cheese?\":[-220.59928687314724,47.66306050929252],\"why zebras don't get ulcers\":[-431.40863683882975,675.2824529137048],\"wilhelm windelband\":[-346.4176352770214,544.8145029070564],\"william a. niskanen\":[-103.58157132599273,-566.3534073946045],\"william frankena\":[-134.77103067914047,27.93744743949544],\"william james booth\":[555.1270261663934,83.63317921737001],\"william vickrey\":[-251.8287359828655,-619.2904196507427],\"wilson doctrine (economics)\":[-384.8245769398534,-665.8893792905875],\"wilson\\u2013patterson conservatism scale\":[577.4492979548393,101.9326435672814],\"winner-take-all politics\":[75.53219865373174,-597.9339611371622],\"wisconsin school (diplomatic history)\":[427.8128330512017,318.7313128462718],\"woman, culture, and society\":[182.47359982605087,700.5621302078579],\"women who have sex with women\":[-247.21057936440548,795.1790561894641],\"women's week provincetown\":[-71.0438516643706,792.8790148015405],\"women-are-wonderful effect\":[-151.78120301213642,331.36510814967824],\"womyn's land\":[-69.94654058741365,612.7730760300639],\"wood industry\":[-294.67805759959697,14.257870007868728],\"woolrich electrical generator\":[1493.6826557543793,-397.8718874489828],\"word gap\":[-374.50161054937723,519.4039703166918],\"work, employment & society\":[408.87730767608303,-473.6645675859214],\"worker cooperative\":[332.5918808221316,-287.72972435963266],\"workplace democracy\":[218.11798709524436,-251.14997113633476],\"world economy\":[-130.185619603561,-299.2354961846941],\"world politics\":[300.68941975580725,-104.90215097203098],\"world revolution\":[377.05349584769596,-153.65502639696527],\"world values survey\":[-337.84240398026503,-36.766770874318226],\"world3\":[27.857175264722358,86.96487922993151],\"worldwide influence of the constitution of the united states\":[-435.7859759706106,-381.5712545588152],\"worshipful company of butchers\":[-66.07236838155288,-157.74527322744132],\"writ\":[-570.1149249162265,304.3269240369785],\"wyn grant\":[687.1457711735203,-228.60702775788323],\"xeira\":[412.4937721735638,1493.3955210051072],\"xuanchuan\":[-295.1234388093346,59.11469567040124],\"yakama manty jones\":[625.5987334066474,230.14377352226518],\"yehuda zvi blum\":[-436.96446536679616,-66.97762048080996],\"yelyzaveta yasko\":[565.8293934732519,157.20179468566653],\"you have two cows\":[302.16490771091975,48.5449725433018],\"zombie liberalism\":[109.9618692492373,-267.60459393445075],\"zooarchaeology\":[320.46532000788415,505.33652392957083],\"zur geschichte der handelsgesellschaften im mittelalter\":[391.9995477083957,214.6881012546843],\"\\u00bfpor qu\\u00e9 no te callas?\":[208.63207861987087,-227.39346486915275],\"\\u00e5land islands peace institute\":[-421.0265154339755,-104.19794765350166],\"\\u00fcmit cizre\":[561.7189517600635,89.23376928615056]}},\"id\":\"1076\",\"type\":\"StaticLayoutProvider\"},{\"attributes\":{\"end\":1000,\"start\":-1000},\"id\":\"1035\",\"type\":\"Range1d\"},{\"attributes\":{\"data\":{\"end\":[\"deployment management\",\"developmental psychology\",\"journal of political ideologies\",\"friendly fascism (book)\",\"base and superstructure\",\"horseshoe theory\",\"stephen barber\",\"risk, hazards & crisis in public policy\",\"grenoble institute of political studies\",\"security of tenure\",\"ideology\",\"human terrain system\",\"energy research & social science\",\"the journal of politics\",\"uk heo\",\"margaret clark (political scientist)\",\"journal of current southeast asian affairs\",\"history of propaganda\",\"rowman & littlefield award in innovative teaching\",\"institut d'\\u00e9tudes politiques de toulouse\",\"democracy and security\",\"quantitative research\",\"katharine hayhoe\",\"british journal of politics and international relations\",\"international ethics\",\"andr\\u00e9 du pisani\",\"the road to serfdom\",\"politics, philosophy & economics\",\"marie-christine kessler\",\"experimental political science\",\"polarized pluralism\",\"k\\u00e4the leichter\",\"political journalism\",\"rasma k\\u0101rkli\\u0146a\",\"preselection\",\"political geography (journal)\",\"feminist theory\",\"second-order election\",\"how voters feel\",\"public opinion quarterly\",\"public policy doctrine\",\"p\\u0131nar selek\",\"australian journal of political science\",\"social order\",\"boosterism\",\"inclusion and democracy\",\"the end of liberalism\",\"critical security studies\",\"east european politics\",\"demonstration effect\",\"journal of democracy\",\"lorena parini\",\"outline of globalization\",\"security, territory, population\",\"computational politics\",\"australian quarterly\",\"anthropology\",\"faculty of political science, chulalongkorn university\",\"the hidden hand: middle east fears of conspiracy\",\"ishraga mustafa hamid\",\"andrew westmoreland\",\"social patriotism\",\"postmodernist anthropology\",\"triangular diplomacy\",\"sacralism\",\"raisons politiques\",\"brigitte young\",\"modernity\",\"index of sociology articles\",\"civic political culture\",\"human ecology\",\"steven b. smith (professor)\",\"journal of european integration\",\"jean bethke elshtain\",\"alexandra goujon\",\"election law journal\",\"post-work society\",\"catherine wihtol de wenden\",\"theory of change\",\"ljiljana radoni\\u0107\",\"campaign finance\",\"bonai state\",\"political alienation\",\"security studies (journal)\",\"democracies: patterns of majoritarian & consensus government in twenty-one countries\",\"the machiavellian moment\",\"canadian public policy\",\"philip oxhorn\",\"w. meredith bacon\",\"econtalk\",\"politics (academic journal)\",\"biology and political orientation\",\"comparative politics\",\"historical sociology\",\"terry karl\",\"paul van riper (political scientist)\",\"pi sigma alpha\",\"fascism: a warning\",\"rentier state\",\"anthropology of art\",\"security studies\",\"new political economy (journal)\",\"malinda s. smith\",\"nonkilling global political science\",\"german university of administrative sciences speyer\",\"china university of political science and law\",\"trusteeship (gandhism)\",\"journal of theoretical politics\",\"journal of european social policy\",\"elinor ostrom\",\"critique: journal of socialist theory\",\"transitology\",\"a call to action: women, religion, violence, and power\",\"linguistics\",\"international journal of intelligence and counterintelligence\",\"polyarchy\",\"european union studies association\",\"peace\\u2013industrial complex\",\"gwendolen m. carter\",\"principle-policy puzzle\",\"philip converse\",\"peace and conflict studies\",\"public policy school\",\"the good society\",\"two-level game theory\",\"list of national legal systems\",\"clientelism\",\"niamh reilly\",\"priya kurian\",\"bureaucratic drift\",\"kissinger lecture\",\"robert m. la follette school of public affairs\",\"linked fate\",\"pal lahara state\",\"alternatives: turkish journal of international relations\",\"political methodology\",\"school of political and social sciences, unam\",\"school of international and public affairs, columbia university\",\"evolutionary psychology\",\"michael l. gross (ethicist)\",\"structure and agency\",\"horace campbell\",\"small media, big revolution\",\"logology (science)\",\"marian van landingham\",\"yelyzaveta yasko\",\"systems theory in political science\",\"multi-level governance\",\"constitutional autochthony\",\"political man\",\"median voter theorem\",\"making democracy work\",\"sophomore surge\",\"transformation processes (media systems)\",\"wilson\\u2013patterson conservatism scale\",\"digest of middle east studies\",\"behavioralism\",\"nanosocialism\",\"political studies review\",\"nation state\",\"journal of policy history\",\"political science\",\"new aspects of politics\",\"al-ahram center for political and strategic studies\",\"grey room\",\"cleavage (politics)\",\"journal of ethnic and migration studies\",\"josepha laroche\",\"anthony downs\",\"world politics\",\"regional power\",\"jerzy adam kowalski\",\"donatella della porta\",\"pippa norris\",\"institute for political studies \\u2013 catholic university of portugal\",\"indian sociological society\",\"val\\u00e9rie igounet\",\"david e. campbell (political scientist)\",\"\\u00fcmit cizre\",\"elif shafak\",\"louise dandurand\",\"minimal effects hypothesis\",\"bush school of government and public service\",\"j curve\",\"technocracy\",\"archaeology\",\"essence of decision\",\"edward j. bloustein school of planning and public policy\",\"james tully (philosopher)\",\"charg\\u00e9 de mission\",\"environmental politics (journal)\",\"insight turkey\",\"alex brillantes jr.\",\"public administration\",\"afke schaart\",\"the birth of biopolitics\",\"cultural liberalism\",\"domestic analogy\",\"abnormal psychology\",\"friedrich hayek\",\"criticism of capitalism\",\"high and low politics\",\"the independent review\",\"robert kent gooch\",\"journal of current chinese affairs\",\"critical review (journal)\",\"science & society\",\"print capitalism\",\"voter turnout\",\"olivier ihl\",\"neuroanthropology\",\"american journal of political science\",\"international review of the red cross\",\"siobhan o'sullivan\",\"history of political science\",\"clarita carlos\",\"sociological positivism\",\"cand.scient.pol.\",\"henry habib\",\"reactionary\",\"behavioral public administration\",\"social policy\",\"contemporary voices\",\"janet ajzenstat\",\"participism\",\"tryph\\u00e9\",\"politique africaine\",\"populism\",\"maritza montero\",\"behavioral neuroscience\",\"praxis: the fletcher journal of human security\",\"marco tarchi\",\"rodney tiffen\",\"elective dictatorship\",\"review of international political economy\",\"foreign policy\",\"political communication\",\"biological anthropology\",\"fiscal capacity\",\"implementation\",\"american political thought\",\"jane duckett\",\"sciences po\",\"cube root rule\",\"party system\",\"antinaturalism (politics)\",\"donald e. stokes\",\"institution\",\"helen margetts\",\"her majesty's government (term)\",\"karl deutsch award\",\"effective number of parties\",\"statecraft (political science)\",\"obshchestvovedeniye\",\"statism\",\"international political science association\",\"perestroika movement (political science)\",\"fred w. riggs\",\"india quarterly\",\"william james booth\",\"big man (political science)\",\"managerialism\",\"e-government\",\"passing on the right\",\"area studies\",\"politeia (journal)\",\"rena dourou\",\"walter f. dodd\",\"political studies (journal)\",\"nonna mayer\",\"dyab abou jahjah\",\"the permanent revolution and results and prospects\",\"democratic recession\",\"mediations (journal)\",\"parallel state\",\"cultural anthropology\",\"pilar calveiro\",\"berkeley school of political theory\",\"jurisprudence\",\"svetlana tatunts\",\"policy studies journal\",\"australian journal of political science\",\"global terrorism index\",\"polyarchy\",\"democracies: patterns of majoritarian & consensus government in twenty-one countries\",\"composite index of national capability\",\"technocracy\",\"ideology\",\"clientelism\",\"public administration\",\"hannah arendt institute for totalitarianism studies\",\"stein rokkan\",\"global politics\",\"biology and political orientation\",\"chua beng huat\",\"john coakley\",\"ap comparative government and politics\",\"historical sociology\",\"e-government\",\"comparative historical research\",\"terry karl\",\"foreign policy\",\"political communication\",\"preselection\",\"high and low politics\",\"comparing media systems\",\"otto kirchheimer\",\"carl joachim friedrich\",\"pippa norris\",\"horace campbell\",\"democracy-dictatorship index\",\"party system\",\"carles boix\",\"public policy doctrine\",\"gladstone professor of government\",\"european master of public administration consortium\",\"nation state\",\"organizational theory\",\"ideology\",\"human resource management in public administration\",\"behavioral public administration\",\"social policy\",\"anthony downs\",\"biology and political orientation\",\"master of public administration\",\"historical sociology\",\"london school of economics\",\"paul van riper (political scientist)\",\"asu college of public service & community solutions\",\"foreign policy\",\"political communication\",\"preselection\",\"military policy\",\"nonprofit and voluntary sector quarterly\",\"german university of administrative sciences speyer\",\"sciences po\",\"elinor ostrom\",\"maladministration\",\"party system\",\"norman chester\",\"public policy doctrine\",\"linguistics\",\"polyarchy\",\"helen margetts\",\"health policy\",\"technocracy\",\"archaeology\",\"united federal workers of america\",\"public policy school\",\"william a. niskanen\",\"public budgeting\",\"fred w. riggs\",\"clientelism\",\"public administration\",\"security, territory, population\",\"anthropology\",\"public economics\",\"faculty of political science, chulalongkorn university\",\"e-government\",\"area studies\",\"politeia (journal)\",\"digital era governance\",\"civil service\",\"school of political and social sciences, unam\",\"blavatnik school of government\",\"high and low politics\",\"master of public policy\",\"human ecology\",\"electronic process of law\",\"jurisprudence\",\"crown servant\",\"hardline\",\"antipositivism\",\"list of social democratic parties\",\"scientocracy\",\"cyberocracy\",\"social liberalism\",\"nanosocialism\",\"nation state\",\"sociological positivism\",\"ideology\",\"technocracy movement\",\"reactionary\",\"neo-nationalism\",\"technical change\",\"list of left-wing internationals\",\"biology and political orientation\",\"populism\",\"whiggism\",\"regional power\",\"double hermeneutic\",\"foreign policy\",\"political communication\",\"preselection\",\"totalitarianism\",\"feminist theory\",\"christian communism\",\"donor class\",\"neoauthoritarianism (china)\",\"great power\",\"left-wing politics\",\"constitutional dictatorship\",\"party system\",\"history of democratic socialism\",\"science diplomacy\",\"public policy doctrine\",\"polyarchy\",\"particracy\",\"regulation of science\",\"bankocracy\",\"technocracy\",\"industrial democracy\",\"oligarchy\",\"literacy\",\"religious socialism\",\"statism\",\"history of science policy\",\"futarchy\",\"clientelism\",\"workplace democracy\",\"civilization state\",\"corporate republic\",\"dependent territory\",\"cultural liberalism\",\"edinburgh university socialist society\",\"ecoauthoritarianism\",\"e-government\",\"economics of science\",\"civil service\",\"night-watchman state\",\"mapping controversies\",\"criticism of capitalism\",\"high and low politics\",\"neosocialism\",\"ethical socialism\",\"sociotechnology\",\"modern liberalism in the united states\",\"post-politics\",\"real socialism\",\"logology (science)\",\"right-wing politics\",\"sociology of scientific ignorance\",\"legalism (chinese philosophy)\",\"crown servant\",\"normalization process theory\",\"autonomous communities of spain\",\"bolivarian revolution\",\"science & diplomacy\",\"clarita carlos\",\"thomas schelling\",\"schelling's segregation model\",\"language\",\"ideology\",\"centre for health and international relations\",\"the crisis of democracy\",\"authoritarian left\",\"neo-nationalism\",\"english votes for english laws\",\"full spectrum diplomacy\",\"biology and political orientation\",\"rosa brooks\",\"i did not have sexual relations with that woman\",\"the soldier and the state\",\"katharine hayhoe\",\"social media use by donald trump\",\"list of futurama characters\",\"third way\",\"national power\",\"foreign policy\",\"political communication\",\"preselection\",\"security studies\",\"cato institute\",\"resource curse\",\"daniel kahneman\",\"party system\",\"american university school of international service\",\"public policy doctrine\",\"the final days (2000 film)\",\"australian journal of political science\",\"polyarchy\",\"per capita personal income in the united states\",\"bric\",\"health policy\",\"public policy school\",\"authoritarian capitalism\",\"non-interventionism\",\"marc lynch\",\"taftian theory\",\"thucydides trap\",\"grab em by the pussy\",\"clientelism\",\"johnson cult\",\"e-government\",\"rena dourou\",\"appeasement\",\"school of international and public affairs, columbia university\",\"political party\",\"american recovery and reinvestment act of 2009\",\"high and low politics\",\"political groups of the european parliament\",\"princeton school of public and international affairs\",\"average joe\",\"\\u00bfpor qu\\u00e9 no te callas?\",\"arab barometer\",\"svetlana tatunts\",\"i like ike\",\"populism\",\"e-government\",\"hardline\",\"polyarchy\",\"third way\",\"social imperialism\",\"horseshoe theory\",\"nolan chart\",\"evolutionary psychology\",\"left\\u2013right political spectrum\",\"totalitarianism\",\"political communication\",\"preselection\",\"high and low politics\",\"ideology\",\"nazism\",\"reactionary\",\"authoritarian left\",\"clientelism\",\"party system\",\"public policy doctrine\",\"serfdom\",\"index of social and political philosophy articles\",\"echo chamber (media)\",\"hardline\",\"majoritarianism\",\"blood and soil\",\"base and superstructure\",\"slavery\",\"horseshoe theory\",\"self-deception\",\"brainwashing\",\"peter sloterdijk\",\"filter bubble\",\"nation state\",\"ideology\",\"linguistic anthropology\",\"marxist sociology\",\"neo-nationalism\",\"jamiat-e islami\",\"legal naturalism\",\"unitarian universalism\",\"the reformation in economics\",\"social threefolding\",\"public affairs quarterly\",\"identity (philosophy)\",\"third way\",\"preselection\",\"social reality\",\"freedom\",\"left-wing politics\",\"surplus value\",\"an economic theory of democracy\",\"democratic party for a new society\",\"abilene paradox\",\"public policy doctrine\",\"superpower collapse\",\"social order\",\"civil libertarianism\",\"ilminism\",\"contest mobility\",\"dictatorship of the proletariat\",\"private property\",\"national agrarian party\",\"world revolution\",\"anthropology\",\"left communism\",\"social actions\",\"role ethics\",\"violent non-state actor\",\"situationist international\",\"political socialization\",\"high and low politics\",\"index of sociology articles\",\"cultural movement\",\"hedonism\",\"male state\",\"right-wing politics\",\"deviationism\",\"surplus labour\",\"medicalization\",\"william frankena\",\"sociological positivism\",\"nazism\",\"john rawls\",\"creativity\",\"history of social democracy\",\"reactionary\",\"populism\",\"reductionism\",\"propaganda\",\"collective effervescence\",\"ideocracy\",\"political communication\",\"totalitarianism\",\"perestroika\",\"hotelling's law\",\"world values survey\",\"new social movements\",\"cognitive archaeology\",\"psychoanalytic theory\",\"f\\u00fchrer\",\"party system\",\"intelligence\",\"emotivism\",\"religion\",\"polyarchy\",\"frente despertar\",\"institution\",\"socialist campaign group\",\"principle-policy puzzle\",\"peace and conflict studies\",\"social integration\",\"public opinion on climate change\",\"self-awareness\",\"statism\",\"clientelism\",\"public economics\",\"managerialism\",\"e-government\",\"rationalism\",\"bibliography of works about communism\",\"constitutionalism\",\"peer pressure\",\"radicalization\",\"burmese way to socialism\",\"jurisprudence\",\"value product\",\"london school of economics\",\"cura annonae\",\"siobhan o'sullivan\",\"health policy\",\"index of sociology articles\",\"public policy school\",\"ministry of infrastructure (ukraine)\",\"language\",\"statism\",\"jane duckett\",\"energy research & social science\",\"authoritarian left\",\"robert m. la follette school of public affairs\",\"global social policy\",\"psychometrics\",\"social actions\",\"the birth of biopolitics\",\"public policy doctrine\",\"intergenerational policy\",\"behavioralism\",\"area studies\",\"international political science association\",\"donald e. stokes\",\"warren miller (political scientist)\",\"walter f. dodd\",\"elinor ostrom\",\"emmette redford\",\"carl joachim friedrich\",\"henry e. brady\",\"international society of political psychology\",\"darwinian anthropology\",\"developmental psychology\",\"paleoanthropology\",\"cognitive bias\",\"human behavioral ecology\",\"utility\",\"language\",\"piaget's theory of cognitive development\",\"outline of culture\",\"reactionary\",\"steven n. s. cheung\",\"authoritarian left\",\"harry harlow\",\"psychometrics\",\"quantitative research\",\"unitarian universalism\",\"spirituality\",\"scare\",\"behavioral neuroscience\",\"reductionism\",\"biological anthropology\",\"accelerator effect\",\"new institutional economics\",\"ethnic religion\",\"richard dawkins\",\"cato institute\",\"psychological nativism\",\"daniel kahneman\",\"law of the jungle\",\"elinor ostrom\",\"intelligence\",\"democratic peace theory\",\"religion\",\"human universals\",\"list of psychological schools\",\"archaeology\",\"nava ashraf\",\"social dominance orientation\",\"people\",\"outline of psychology\",\"cultural group selection\",\"instrumentalism\",\"recent human evolution\",\"anthropology\",\"timeline of psychology\",\"computational theory of mind\",\"human ethology\",\"religious literacy\",\"evolutionary game theory\",\"friedrich hayek\",\"hiding hand principle\",\"biophilia hypothesis\",\"soul\",\"evolutionary psychology\",\"ecological psychology\",\"shadow (psychology)\",\"promiscuity\",\"georg weizs\\u00e4cker\",\"berkeley school of political theory\",\"fight-or-flight response\",\"mental environment\",\"biosocial criminology\",\"tactical voting\",\"experimental economics\",\"voter turnout\",\"national liberalism\",\"religion\",\"critique of modernity\",\"social liberalism\",\"modernity\",\"john murray cuddihy\",\"the protestant ethic and the spirit of capitalism\",\"index of sociology articles\",\"heterosociality\",\"ecomodernism\",\"andean civilizations\",\"reflexive modernization\",\"early modern human\",\"modern liberalism in the united states\",\"outline of anarchism\",\"right-wing politics\",\"attachment parenting\",\"chiara bottici\",\"decoloniality\",\"cultural liberalism\",\"national liberalism\",\"online ethnography\",\"particracy\",\"antemurale myth\",\"ethnobiology\",\"balkanization\",\"netnography\",\"oligarchy\",\"literacy\",\"ethnozoology\",\"nazism\",\"authoritarian left\",\"roman question\",\"enemy of the people (albania)\",\"neo-nationalism\",\"law without the state\",\"security, territory, population\",\"history of propaganda\",\"equal opportunity\",\"anthropology\",\"plurinationalism\",\"civilization state\",\"the birth of biopolitics\",\"secession\",\"dependent territory\",\"coercion, capital, and european states, ad 990\\u20131992\",\"ethnoichthyology\",\"regional power\",\"nation-building\",\"ethnoarchaeology\",\"enemy of the people\",\"index of sociology articles\",\"totalitarianism\",\"degrowth\",\"ethnic religion\",\"economic nationalism\",\"ethnosymbolism\",\"regional autonomy\",\"ethnomuseology\",\"westphalian sovereignty\",\"right to exist\",\"constitutional patriotism\",\"national conservatism\",\"eco-nationalism\",\"national communism\",\"great power\",\"ethnomedicine\",\"identity (social science)\",\"cultural nationalism\",\"superpower collapse\",\"interactionism\",\"dyad (sociology)\",\"reflexivity (social theory)\",\"international sociological association\",\"base and superstructure\",\"agency (sociology)\",\"instrumental and value-rational action\",\"ideal type\",\"figurational sociology\",\"action theory (sociology)\",\"social actions\",\"structuration theory\",\"theatre state\",\"darwinian anthropology\",\"echo chamber (media)\",\"emic and etic\",\"paleoanthropology\",\"developmental psychology\",\"base and superstructure\",\"slavery\",\"theory of language\",\"alliance theory\",\"feminist anthropology\",\"waga sculpture\",\"woman, culture, and society\",\"linguistic description\",\"language\",\"laura boulton\",\"heritage commodification\",\"linguistic anthropology\",\"human terrain system\",\"diane bell (anthropologist)\",\"outline of culture\",\"bibliography of anthropology\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"energy research & social science\",\"marxist sociology\",\"quantitative research\",\"classificatory kinship\",\"peasant economics\",\"unitarian universalism\",\"sociology of punishment\",\"solano people\",\"les ma\\u00eetres fous\",\"ecofeminism\",\"digging stick\",\"feminist legal theory\",\"lila: an inquiry into morals\",\"rudolf virchow award\",\"usc center for visual anthropology\",\"feminist theory\",\"development anthropology\",\"social reality\",\"urban revolution\",\"barbara rogoff\",\"richard dawkins\",\"linguistic relativity\",\"podom\",\"matrilocal residence\",\"indian sociological society\",\"reflexivity (social theory)\",\"moving anthropology student network\",\"identity (social science)\",\"polygyny\",\"anthropology of institutions\",\"ferdinand de saussure\",\"online ethnography\",\"museum of mankind\",\"nutritional anthropology\",\"transpersonal psychology\",\"human universals\",\"ethnobiology\",\"archaeology\",\"circumscription theory\",\"performance studies\",\"netnography\",\"critical security studies\",\"performativity\",\"ethnozoology\",\"collective memory\",\"das mutterrecht\",\"cultural group selection\",\"kriza j\\u00e1nos ethnographic society\",\"anthropology\",\"faculty of political science, chulalongkorn university\",\"human ethology\",\"civilization state\",\"ethnoichthyology\",\"religious literacy\",\"abnormal psychology\",\"naturalistic disease theories\",\"critical medical anthropology\",\"postmodernist anthropology\",\"anthropological criminology\",\"family disruption\",\"nanook of the north\",\"soul\",\"historical behaviour studies\",\"mus\\u00e9e de l'homme\",\"1910s in anthropology\",\"index of sociology articles\",\"1990s in anthropology\",\"museo nacional de antropolog\\u00eda (madrid)\",\"ethnosymbolism\",\"human ecology\",\"master of public policy\",\"exocannibalism\",\"cultural movement\",\"forensic facial reconstruction\",\"time & society\",\"challengeaccepted\",\"influence: science and practice\",\"history of anthropometry\",\"person\",\"ethnomedicine\",\"astrosociology\",\"gotai\",\"anthropological index online\",\"biosocial criminology\",\"cognitive anthropology\",\"vanua\",\"gustave le bon\",\"neuroanthropology\",\"age set\",\"human behavioral ecology\",\"society for medical anthropology\",\"educational anthropology\",\"grave goods\",\"constantin noica\",\"anthrobotics\",\"interpersonal neurobiology\",\"applied anthropology research methods\",\"utinahica\",\"americanoid\",\"list of anthropologists\",\"toloy\",\"spirituality\",\"typology (anthropology)\",\"historical sociology\",\"semiotic anthropology\",\"behavioral neuroscience\",\"apuli\",\"the hebrew goddess\",\"biological anthropology\",\"orthograde posture\",\"anthropology of art\",\"degrowth\",\"transcultural nursing\",\"ethnic religion\",\"psychohistory\",\"new york state sociological association\",\"ethnomuseology\",\"village head\",\"soul dualism\",\"1890s in anthropology\",\"maloca\",\"nomadic pastoralism\",\"list of years in anthropology\",\"faye v. harrison\",\"affect (psychology)\",\"ethnoscape\",\"viking fund medal\",\"medical sociologist\",\"osteology\",\"religion\",\"linguistics\",\"frustration\\u2013aggression hypothesis\",\"institution\",\"prickly paradigm press\",\"f. g. bailey\",\"zooarchaeology\",\"shell money\",\"peace and conflict studies\",\"georg pfeffer\",\"standard cross-cultural sample\",\"list of important publications in economics\",\"deep history\",\"hau (anthropology)\",\"encyclopedia of anthropology\",\"list of matrilineal or matrilocal societies\",\"list of national legal systems\",\"mus\\u00e9e des confluences\",\"gaonburha\",\"2000s in anthropology\",\"ecological anthropology\",\"women-are-wonderful effect\",\"social organization\",\"culture theory\",\"biocultural anthropology\",\"lambda alpha\",\"disability anthropology\",\"bibliography of sociology\",\"area studies\",\"ethnopediatrics\",\"sodality (social anthropology)\",\"l'ann\\u00e9e sociologique\",\"cultural mapping\",\"nation-building\",\"contrast set\",\"school of political and social sciences, unam\",\"heel\\u2013ball index\",\"leveling mechanism\",\"edvard westermarck\",\"cultural relativism\",\"medical anthropology\",\"cornell-peru project\",\"cultural anthropology\",\"logology (science)\",\"international council for science\",\"jurisprudence\",\"pitt rivers museum\",\"richard rottenburg\",\"society of anthropology of paris\",\"hunter-gatherer\",\"developmental psychology\",\"neuroanthropology\",\"base and superstructure\",\"feminist anthropology\",\"arthur evans\",\"grave goods\",\"outline of culture\",\"applied anthropology research methods\",\"venture capital in spaceflight\",\"bibliography of anthropology\",\"marxist sociology\",\"legal naturalism\",\"historical sociology\",\"behavioral neuroscience\",\"apuli\",\"argentine forensic anthropology team\",\"digging stick\",\"feminist legal theory\",\"ecofeminism\",\"ethnoarchaeology\",\"data editing\",\"biological anthropology\",\"anthropology of art\",\"feminist theory\",\"urban revolution\",\"fiscal policy of the philippines\",\"matrilocal residence\",\"indian sociological society\",\"cha\\u00eene op\\u00e9ratoire\",\"glossary of economics\",\"cognitive archaeology\",\"list of psychology awards\",\"surplus value\",\"list of years in anthropology\",\"rossville points\",\"cultural radicalism\",\"viking fund medal\",\"paleopathology\",\"osteology\",\"religion\",\"linguistics\",\"zooarchaeology\",\"ethnobiology\",\"archaeology\",\"deep history\",\"list of matrilineal or matrilocal societies\",\"list of national legal systems\",\"dictatorship of the proletariat\",\"revisionist school of islamic studies\",\"women-are-wonderful effect\",\"world revolution\",\"left communism\",\"cultural resource management\",\"abnormal psychology\",\"area studies\",\"postmodernist anthropology\",\"maya research program\",\"blavatnik school of government\",\"index of sociology articles\",\"direct historical approach\",\"bibliography of works about communism\",\"human ecology\",\"cultural anthropology\",\"forensic facial reconstruction\",\"logology (science)\",\"challengeaccepted\",\"museu da lourinh\\u00e3\",\"jurisprudence\",\"pitt rivers museum\",\"surplus labour\",\"value product\",\"anthropological index online\",\"linguistic linked open data\",\"developmental psychology\",\"neuroanthropology\",\"theory of language\",\"linguistic description\",\"language\",\"marija gimbutas\",\"interpersonal neurobiology\",\"human terrain system\",\"linguistic anthropology\",\"creativity\",\"theta criterion\",\"outline of thought\",\"topic and comment\",\"possible world\",\"historical sociology\",\"unsaid\",\"media linguistics\",\"behavioral neuroscience\",\"propaganda\",\"displacement (linguistics)\",\"political communication\",\"biological anthropology\",\"gloss (annotation)\",\"anthropology of art\",\"feminist theory\",\"proverbial phrase\",\"perestroika\",\"linguistic relativity\",\"indian sociological society\",\"facial expression\",\"squib (writing)\",\"neural adaptation\",\"harvest hills cooperative community\",\"metalanguage\",\"ferdinand de saussure\",\"institution\",\"tonograph\",\"linguistics in science fiction\",\"ethnobiology\",\"communicative dynamism\",\"literacy\",\"performativity\",\"deep history\",\"logical form (linguistics)\",\"ethnozoology\",\"neolinguistics\",\"revolutions of 1989\",\"list of national legal systems\",\"kriza j\\u00e1nos ethnographic society\",\"task force\",\"abnormal psychology\",\"area studies\",\"heel\\u2013ball index\",\"school of international and public affairs, columbia university\",\"music psychology\",\"index of sociology articles\",\"list of unsolved problems in economics\",\"human ecology\",\"symbol\",\"cultural anthropology\",\"forensic facial reconstruction\",\"regionalisation\",\"logology (science)\",\"comprehension approach\",\"bertrand russell\",\"verbal behavior\",\"jurisprudence\",\"microexpression\",\"proverb\",\"anthropological index online\",\"index of social and political philosophy articles\",\"echo chamber (media)\",\"developmental psychology\",\"neil maccormick\",\"commodity form theory\",\"neuroanthropology\",\"slavery\",\"job cohen\",\"salvador minguij\\u00f3n adri\\u00e1n\",\"nigel simmonds\",\"philosophy of sex\",\"sociological positivism\",\"code of hammurabi\",\"john rawls\",\"inquisitorial system\",\"law without the state\",\"brocard (law)\",\"islam and children\",\"historical sociology\",\"behavioral neuroscience\",\"injustice\",\"confucian classes\",\"feminist legal theory\",\"liechtenstein institute on self-determination\",\"jus commune\",\"ahl al-hadith\",\"oliver lepsius\",\"madhhab\",\"biological anthropology\",\"samuel von pufendorf\",\"anthropology of art\",\"legal norm\",\"social reality\",\"executive order\",\"early social changes under islam\",\"history of the legal profession\",\"indian sociological society\",\"maternalism\",\"islamic sexual jurisprudence\",\"virtue jurisprudence\",\"islamic toilet etiquette\",\"history of the american legal profession\",\"vacatio legis\",\"fiqh\",\"istihlal\",\"national liberalism\",\"religion\",\"exequatur\",\"institution\",\"isaiah berlin\",\"usul fiqh in ja'fari school\",\"asabiyyah\",\"predictive policing\",\"list of national legal systems\",\"constitutional economics\",\"political jurisprudence\",\"grazing rights\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"obreption and subreption (catholic canon law)\",\"people power\",\"international law\",\"abnormal psychology\",\"area studies\",\"friedrich hayek\",\"muted group theory\",\"promulgation (catholic canon law)\",\"rationalism\",\"political party\",\"custom (catholic canon law)\",\"leslie green (philosopher)\",\"index of sociology articles\",\"adam smith\",\"constitutionalism\",\"the province of jurisprudence determined\",\"human ecology\",\"cultural movement\",\"cultural anthropology\",\"logology (science)\",\"stephanos bibas\",\"notary (catholic canon law)\",\"bertrand russell\",\"gary l. francione\",\"jurisprudence\",\"julius stone\",\"legalism (chinese philosophy)\",\"imperium\",\"index of sociopolitical thinkers\",\"developmental psychology\",\"neuroanthropology\",\"east european politics\",\"outline of culture\",\"list of national legal systems\",\"international area studies review\",\"historical sociology\",\"abnormal psychology\",\"area studies\",\"behavioral neuroscience\",\"biological anthropology\",\"index of sociology articles\",\"anthropology of art\",\"human ecology\",\"indian sociological society\",\"cultural anthropology\",\"logology (science)\",\"transitology\",\"decoloniality\",\"religion\",\"developmental psychology\",\"neuroanthropology\",\"classical realism (international relations)\",\"critical security studies\",\"postinternationalism\",\"scientific man versus power politics\",\"relative gain (international relations)\",\"language\",\"people\",\"intergovernmentalism\",\"list of national legal systems\",\"international sociological association\",\"marxist sociology\",\"stein rokkan\",\"social complexity\",\"international ethics\",\"sociology of punishment\",\"abnormal psychology\",\"comparative historical research\",\"behavioral neuroscience\",\"family disruption\",\"social experiment\",\"biological anthropology\",\"index of sociology articles\",\"anthropology of art\",\"psychohistory\",\"human ecology\",\"indian sociological society\",\"cultural anthropology\",\"logology (science)\",\"regionalism (international relations)\",\"astrosociology\",\"bananas, beaches and bases\",\"idealism in international relations\",\"democratic peace theory\",\"medical sociologist\",\"developmental psychology\",\"natural capital\",\"neuroanthropology\",\"biological organisation\",\"ethnolichenology\",\"human behavioral ecology\",\"noosphere\",\"aparna rao\",\"porter hypothesis\",\"behavioral neuroscience\",\"reductionism\",\"ecofeminism\",\"ethnoarchaeology\",\"biological anthropology\",\"degrowth\",\"anthropology of art\",\"indian sociological society\",\"ethnoornithology\",\"greenwashing\",\"urban metabolism\",\"zooarchaeology\",\"ethnobiology\",\"ethnozoology\",\"personal life\",\"list of national legal systems\",\"bioregionalism\",\"ecological anthropology\",\"outline of globalization\",\"wisconsin school (diplomatic history)\",\"index of urban sociology articles\",\"robert m. la follette school of public affairs\",\"ethnoichthyology\",\"bibliography of sociology\",\"abnormal psychology\",\"payment for ecosystem services\",\"index of sociology articles\",\"human ecology\",\"cultural anthropology\",\"logology (science)\",\"ethnomedicine\",\"populism\",\"religion\",\"coverage error\",\"values modes\",\"survey data collection\",\"comparative study of electoral systems\",\"opinion poll\",\"total survey error\",\"reflexive modernization\",\"authoritarian left\",\"global citizenship\",\"afrobarometer\",\"outline of globalization\",\"non-sampling error\",\"left-wing politics\",\"psychometrics\",\"statistical inference\",\"joseph schumpeter\",\"serfdom\",\"developmental psychology\",\"matrix of domination\",\"emic and etic\",\"majoritarianism\",\"paleoanthropology\",\"the rich get richer and the poor get poorer\",\"base and superstructure\",\"slavery\",\"status group\",\"alliance theory\",\"serer people\",\"ego integrity\",\"self-deception\",\"brainwashing\",\"term (time)\",\"flashback (psychology)\",\"development geography\",\"linguistic anthropology\",\"bibliography of anthropology\",\"marxist sociology\",\"equal opportunity\",\"agency (philosophy)\",\"social complexity\",\"hong kong honours system\",\"sociology of punishment\",\"philosophy of max stirner\",\"social threefolding\",\"list of futurama characters\",\"identity (philosophy)\",\"psychogeography\",\"ecofeminism\",\"third way\",\"models of abnormality\",\"social reality\",\"richard dawkins\",\"andean civilizations\",\"solitary confinement\",\"mainstream economics\",\"identity (social science)\",\"conditioned emotional response\",\"first world\",\"abilene paradox\",\"public policy doctrine\",\"supreme court of justice of colombia\",\"social order\",\"nutritional anthropology\",\"paradoxical intention\",\"transpersonal psychology\",\"health geography\",\"jel classification codes\",\"cultural group selection\",\"clustering (demographics)\",\"geography of media and communication\",\"levitation (paranormal)\",\"timeline of psychology\",\"social actions\",\"international law\",\"neoclassical liberalism\",\"serfdom in tibet controversy\",\"postmodernist anthropology\",\"family disruption\",\"sacralism\",\"visible minority\",\"situationist international\",\"index of sociology articles\",\"ecomodernism\",\"equality before the law\",\"cultural movement\",\"concentrated disadvantage\",\"hedonism\",\"outline of anarchism\",\"structural violence\",\"bertrand russell\",\"verbal behavior\",\"oppression\",\"sociology of scientific ignorance\",\"time value of money\",\"collective mental state\",\"id\\u00e9e fixe (psychology)\",\"proto-industrialization\",\"business magnate\",\"proletarian revolution\",\"biosocial criminology\",\"serer-ndut people\",\"administrative divisions of portugal\",\"agency (sociology)\",\"technoliberalism\",\"an anarchist faq\",\"social model of disability\",\"organizational theory\",\"liberal corporatism\",\"creativity\",\"administrative divisions of peru\",\"swanson, nolan and pelham teacher and parent rating scale\",\"toloy\",\"environmental policy of the european union\",\"psychometrics\",\"cognitivism (psychology)\",\"semiotic anthropology\",\"label (sociology)\",\"dyad (sociology)\",\"reductionism\",\"propaganda\",\"encyclopedia of women and islamic cultures\",\"the protestant ethic and the spirit of capitalism\",\"anthropology of art\",\"ethnic religion\",\"perestroika\",\"ethnomuseology\",\"philosophy of life\",\"queer ecology\",\"national conservatism\",\"lingeer\",\"psychoanalytic theory\",\"f\\u00fchrer\",\"democratic liberalism\",\"rossville points\",\"intelligence\",\"cultural radicalism\",\"social reproduction\",\"medical sociologist\",\"religion\",\"isaiah berlin\",\"list of psychological schools\",\"group threat theory\",\"social integration\",\"garveyism\",\"standard cross-cultural sample\",\"quantitative psychological research\",\"swiss neutrality\",\"upper class\",\"official cantonese translations of english names for british officials\",\"emotional reasoning\",\"communal reinforcement\",\"list of psychological research methods\",\"atlanticism\",\"liberal conservatism\",\"action theory (sociology)\",\"cultural relativism\",\"constitutionalism\",\"structural discrimination\",\"mudsill theory\",\"magnate\",\"taxation in uruguay\",\"anarcho-capitalism\",\"autonomous communities of spain\",\"interactionism\",\"intelligence quotient\",\"blood and soil\",\"cognitive bias\",\"democratic capitalism\",\"digest of middle east studies\",\"philosophy of sex\",\"feminist anthropology\",\"filter bubble\",\"linguistic description\",\"religious communism\",\"manifest and latent functions and dysfunctions\",\"passing (sociology)\",\"unitarian universalism\",\"whiggism\",\"comparative historical research\",\"kalergi plan\",\"consensus democracy\",\"control theory (sociology)\",\"trait ascription bias\",\"development anthropology\",\"european sociological association\",\"fiscal policy of the philippines\",\"societal attitudes towards abortion\",\"dark figure of crime\",\"indian sociological society\",\"daniel kahneman\",\"reflexivity (social theory)\",\"donor class\",\"microsociology\",\"freedom\",\"left-wing politics\",\"benevolence and the mandate of heaven\",\"anthropology of institutions\",\"relational sociology\",\"national liberalism\",\"online ethnography\",\"museum of mankind\",\"civil libertarianism\",\"regulation of science\",\"science as a vocation\",\"oligarchy\",\"detection theory\",\"collective memory\",\"gestalt psychology\",\"white power music\",\"culture hero\",\"private property\",\"sociology in poland\",\"cultural liberalism\",\"religious literacy\",\"abnormal psychology\",\"overlapping consensus\",\"discouraged worker\",\"soul\",\"criticism of capitalism\",\"sociology in japan\",\"morphological freedom\",\"grave candle\",\"gaia philosophy\",\"political groups of the european parliament\",\"business oligarch\",\"average joe\",\"computational sociology\",\"list of psychology organizations\",\"astrosociology\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"sociologists for women in society\",\"social construction of the body\",\"imperium\",\"legalism (chinese philosophy)\",\"law of equal liberty\",\"psychological statistics\",\"cognitive anthropology\",\"interprovincial migration in canada\",\"neuroanthropology\",\"social liberalism\",\"list of sociologists\",\"bumiputera (malaysia)\",\"silence=death project\",\"list of liberal theorists\",\"sociological positivism\",\"hunting hypothesis\",\"marija gimbutas\",\"constantin noica\",\"non-representational theory\",\"nazism\",\"interpersonal neurobiology\",\"john rawls\",\"authoritarian left\",\"inner peace\",\"dang guo\",\"harry harlow\",\"participism\",\"figurational sociology\",\"spirituality\",\"behavioral neuroscience\",\"poverty class\",\"apuli\",\"collective effervescence\",\"occupational health psychology\",\"norwegian paradox\",\"medical psychology\",\"liberalism and conservatism in latin america\",\"consummation\",\"biological anthropology\",\"german model\",\"psychohistory\",\"social cognition and interaction training\",\"serer maternal clans\",\"early modern human\",\"sociology of morality\",\"list of years in anthropology\",\"moral entrepreneur\",\"symbolic religiosity\",\"field theory (sociology)\",\"gochisosama\",\"institution\",\"social system\",\"per capita personal income in the united states\",\"eurosphere\",\"asabiyyah\",\"social conflict\",\"revolutions of 1989\",\"social dominance orientation\",\"personhood\",\"ecological anthropology\",\"women-are-wonderful effect\",\"conservative liberalism\",\"value-added theory\",\"discrimination against autistic people\",\"culture theory\",\"fragmentation (sociology)\",\"tobacco-free pharmacy\",\"ordoliberalism\",\"bibliography of sociology\",\"list of sociology journals\",\"rogers brubaker\",\"social experiment\",\"rationalism\",\"music psychology\",\"christian privilege\",\"adam smith\",\"medical anthropology\",\"modern liberalism in the united states\",\"cultural anthropology\",\"peer pressure\",\"burmese way to socialism\",\"repertory grid\",\"arif ahmed (philosopher)\",\"consumer class\",\"hardline\",\"history of communism\",\"list of social democratic parties\",\"base and superstructure\",\"communism and lgbt rights\",\"horseshoe theory\",\"nanosocialism\",\"nazism\",\"religious communism\",\"reactionary\",\"authoritarian left\",\"marxist sociology\",\"neo-nationalism\",\"far-right politics\",\"list of left-wing internationals\",\"eastern bloc\",\"legal naturalism\",\"populism\",\"whiggism\",\"organization & environment\",\"third way\",\"social imperialism\",\"nolan chart\",\"left\\u2013right political spectrum\",\"degrowth\",\"totalitarianism\",\"feminist theory\",\"christian communism\",\"new social movements\",\"national communism\",\"surplus value\",\"party system\",\"first world\",\"zombie liberalism\",\"history of democratic socialism\",\"microgeneration\",\"crypto-communism\",\"privatism\",\"global justice movement\",\"industrial democracy\",\"religious socialism\",\"statism\",\"communist era\",\"dictatorship of the proletariat\",\"decolonization\",\"world revolution\",\"left communism\",\"workplace democracy\",\"edinburgh university socialist society\",\"ecoauthoritarianism\",\"spatial politics\",\"criticism of capitalism\",\"comunismo a la tica\",\"left-wing populism\",\"bibliography of works about communism\",\"constitutionalism\",\"ethical socialism\",\"social revolution\",\"modern liberalism in the united states\",\"real socialism\",\"right-wing politics\",\"surplus labour\",\"value product\",\"proletarian revolution\",\"law of equal liberty\",\"consumer class\",\"life chances\",\"john hicks\",\"werturteilsstreit\",\"democratic capitalism\",\"population and development review\",\"thomas schelling\",\"economic model\",\"schelling's segregation model\",\"utility\",\"macroeconomic model\",\"keynesian cross\",\"nazism\",\"history of capitalist theory\",\"creativity\",\"paul romer\",\"participism\",\"anthony downs\",\"attention economy\",\"economic indicator\",\"populism\",\"robert heilbroner\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"norwegian paradox\",\"third way\",\"elhanan helpman\",\"index of economics articles\",\"international economics\",\"accelerator effect\",\"tripartite classification of authority\",\"new institutional economics\",\"daniel mcfadden\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"democracy-dictatorship index\",\"surplus value\",\"mainstream economics\",\"cournot competition\",\"marginalism\",\"anglo-saxon model\",\"joseph schumpeter\",\"economic transformation\",\"privatism\",\"civil libertarianism\",\"neo-capitalism\",\"financial economics\",\"supply and demand\",\"service economy\",\"is\\u2013lm model\",\"industrial democracy\",\"list of important publications in economics\",\"authoritarian capitalism\",\"pork cycle\",\"non-interventionism\",\"history of microeconomics\",\"private property\",\"iron cage\",\"bengt holmstr\\u00f6m\",\"enlightened absolutism\",\"social actions\",\"ramsey\\u2013cass\\u2013koopmans model\",\"experimental economics\",\"99ers\",\"ordoliberalism\",\"neoclassical liberalism\",\"jacob hollander\",\"friedrich hayek\",\"social cost\",\"night-watchman state\",\"visible hand (economics)\",\"criticism of capitalism\",\"capitalist peace\",\"purchasing power parity\",\"adam smith\",\"econophysics\",\"william vickrey\",\"eco-capitalism\",\"kenneth arrow\",\"phillips curve\",\"implicit cost\",\"ideal type\",\"anarcho-capitalism\",\"law of equal liberty\",\"trygve haavelmo\",\"coverage error\",\"total survey error\",\"survey data collection\",\"afrobarometer\",\"comparative study of electoral systems\",\"opinion poll\",\"survey data collection\",\"afrobarometer\",\"comparative study of electoral systems\",\"opinion poll\",\"total survey error\",\"intelligence quotient\",\"developmental psychology\",\"survey data collection\",\"ego integrity\",\"opinion poll\",\"cognitive bias\",\"flashback (psychology)\",\"creativity\",\"interpersonal neurobiology\",\"reliability (statistics)\",\"swanson, nolan and pelham teacher and parent rating scale\",\"afrobarometer\",\"harry harlow\",\"nations and iq\",\"psychometrics\",\"quantitative research\",\"cognitivism (psychology)\",\"arbitrage pricing theory\",\"behavioral neuroscience\",\"jenkins activity survey\",\"race and intelligence\",\"occupational health psychology\",\"medical psychology\",\"trait ascription bias\",\"models of abnormality\",\"psychohistory\",\"social cognition and interaction training\",\"daniel kahneman\",\"index of psychometrics articles\",\"psychoanalytic theory\",\"statistical inference\",\"intelligence\",\"conditioned emotional response\",\"paradoxical intention\",\"comparative study of electoral systems\",\"data collection system\",\"transpersonal psychology\",\"list of psychological schools\",\"detection theory\",\"quantitative psychological research\",\"collective memory\",\"social dominance orientation\",\"outline of psychology\",\"accuracy and precision\",\"gestalt psychology\",\"women-are-wonderful effect\",\"psychoinformatics\",\"timeline of psychology\",\"emotional reasoning\",\"abnormal psychology\",\"social experiment\",\"list of psychological research methods\",\"music psychology\",\"total survey error\",\"verbal behavior\",\"classical test theory\",\"learning\",\"time series\",\"list of psychology organizations\",\"id\\u00e9e fixe (psychology)\",\"repertory grid\",\"psychological statistics\",\"cultural mapping\",\"antipositivism\",\"survey data collection\",\"social experiment\",\"comparative study of electoral systems\",\"data collection system\",\"opinion poll\",\"total survey error\",\"afrobarometer\",\"time series\",\"statistical inference\",\"ipm (software)\",\"survey data collection\",\"social experiment\",\"comparative study of electoral systems\",\"data collection system\",\"total survey error\",\"tactical voting\",\"afrobarometer\",\"time series\",\"archibald crossley\",\"roper center for public opinion research\",\"survey data collection\",\"comparative study of electoral systems\",\"political party\",\"latin american public opinion project\",\"total survey error\",\"survey data collection\",\"total survey error\",\"populism\",\"slavery\",\"political party\",\"human development index\",\"anthony downs\",\"tactical voting\",\"voting rights in the united states\",\"voter turnout\",\"arrow's impossibility theorem\",\"voting rights in the united states\",\"political party\",\"party political broadcast\",\"status group\",\"effective number of parties\",\"predictive policing\",\"one-party state\",\"party identification\",\"blanquism\",\"list of national legal systems\",\"inquisitorial system\",\"left group of finnish workers\",\"decolonization\",\"cleavage (politics)\",\"clientelism\",\"nonpartisanism\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"international law\",\"populism\",\"security sector governance and reform\",\"consensus democracy\",\"london school of economics\",\"bloc party (politics)\",\"feminist legal theory\",\"left\\u2013right political spectrum\",\"multistakeholder governance\",\"preselection\",\"index of sociology articles\",\"bad governance\",\"otto kirchheimer\",\"executive order\",\"history of the legal profession\",\"cato institute\",\"party platform\",\"diminishing returns\",\"non-governmental organization\",\"history of the american legal profession\",\"party system\",\"fiqh\",\"synarchism\",\"democratic party for a new society\",\"hunter-gatherer\",\"serfdom\",\"echo chamber (media)\",\"labor theory of property\",\"history of communism\",\"majoritarianism\",\"gold-collar worker\",\"civilizing the economy\",\"slavery\",\"bumiputera (malaysia)\",\"self-deception\",\"brainwashing\",\"public morality\",\"social model of disability\",\"right to development\",\"filter bubble\",\"language\",\"code of hammurabi\",\"creativity\",\"this machine kills fascists\",\"warrior\",\"equal opportunity\",\"islam and children\",\"unitarian universalism\",\"identity (philosophy)\",\"reductionism\",\"propaganda\",\"occupational health psychology\",\"collective effervescence\",\"race and intelligence\",\"georgism\",\"index of economics articles\",\"list of economics films\",\"political culture of the united states\",\"liberalism and conservatism in latin america\",\"the great transformation (book)\",\"we shall overcome\",\"biological anthropology\",\"ahl al-hadith\",\"person of color\",\"social reality\",\"nominate (scaling method)\",\"early social changes under islam\",\"cato institute\",\"constitutional patriotism\",\"islamic sexual jurisprudence\",\"solitary confinement\",\"islamic toilet etiquette\",\"elinor ostrom\",\"(don't) touch me on my studio\",\"fiqh\",\"intelligence\",\"national average salary\",\"law of rent\",\"abilene paradox\",\"socialist realism\",\"public policy doctrine\",\"androcentrism\",\"usul fiqh in ja'fari school\",\"social integration\",\"social death\",\"garveyism\",\"public property\",\"lectures on jurisprudence\",\"list of national legal systems\",\"personhood\",\"white power music\",\"kshatriya\",\"private property\",\"underclass\",\"grazing rights\",\"black tax\",\"air rights\",\"discrimination against autistic people\",\"social actions\",\"99ers\",\"international law\",\"discouraged worker\",\"rationalism\",\"enemy of the people\",\"criticism of capitalism\",\"christian privilege\",\"adam smith\",\"constitutionalism\",\"equality before the law\",\"peasant\",\"anti-psychiatry\",\"mudsill theory\",\"cultural movement\",\"hedonism\",\"structural discrimination\",\"peer pressure\",\"phillips curve\",\"oppression\",\"person\",\"antimilitarism\",\"surplus labour\",\"anarcho-capitalism\",\"imperium\",\"business magnate\",\"global terrorism index\",\"poverty class\",\"bric\",\"list of countries by inequality-adjusted income\",\"index of economics articles\",\"list of countries by share of income of the richest one percent\",\"social vulnerability\",\"human development index\",\"literacy\",\"development geography\",\"least developed countries\",\"list of countries by labour force\",\"diminishing returns\",\"social welfare in luxembourg\",\"nations and iq\",\"list of bordering countries with greatest relative differences in gdp (ppp) per capita\",\"theories of poverty\",\"first world\",\"heavily indebted poor countries\",\"purchasing power parity\",\"scottish index of multiple deprivation\",\"median voter theorem\",\"myron scholes\",\"bryan caplan\",\"eugene fama\",\"william a. niskanen\",\"steven n. s. cheung\",\"david laidler\",\"downs\\u2013thomson paradox\",\"public economics\",\"an economic theory of democracy\",\"intergovernmentalism\",\"eurosphere\",\"civil service\",\"london school of economics\",\"coppieters foundation\",\"martens centre\",\"civil service\",\"per capita personal income in the united states\",\"development bureau\",\"lloyd\\u2013la follette act\",\"petition of right\",\"quiet revolution\",\"german university of administrative sciences speyer\",\"rivers state civil service\",\"history of science policy\",\"average joe\",\"vocational panel\",\"crown servant\",\"reichsministerium des innern\",\"ioana marinescu\",\"john hicks\",\"viola klein\",\"schar school of policy and government\",\"lawrence summers\",\"instituts d'\\u00e9tudes politiques\",\"ernest barker\",\"national student survey\",\"kim campbell\",\"neo-nationalism\",\"charlie bean (economist)\",\"ronen palan\",\"stein rokkan\",\"benjamin moll\",\"andr\\u00e9 du pisani\",\"the road to serfdom\",\"master of public administration\",\"tore ellingsen\",\"populism\",\"carmen a. mir\\u00f3\",\"london school of economics\",\"third way\",\"renata salecl\",\"the protestant ethic and the spirit of capitalism\",\"pippa norris\",\"cato institute\",\"sciences po\",\"journal of theoretical politics\",\"bureau-shaping model\",\"francesco caselli\",\"beatrice heuser\",\"perpetual war\",\"universal basic income\",\"bush school of government and public service\",\"george hilton (historian)\",\"colin hughes\",\"eric helleiner\",\"helen margetts\",\"research excellence framework\",\"nava ashraf\",\"people\",\"pauline barrieu\",\"fabrizio zilibotti\",\"graduate school of public policy, university of tokyo\",\"david laidler\",\"anti-gender movement\",\"friedrich hayek\",\"edvard westermarck\",\"left-wing populism\",\"boris maciejovsky\",\"ethnosymbolism\",\"sanford school of public policy\",\"paul de grauwe\",\"princeton school of public and international affairs\",\"bertrand russell\",\"cyranoid\",\"georg weizs\\u00e4cker\",\"equality before the law\",\"intergovernmentalism\",\"rationalism\",\"environmental policy of the european union\",\"international law\",\"astrology\",\"energy community\",\"constitutionalism\",\"frente despertar\",\"multi-level governance\",\"third way\",\"rationalism\",\"classical realism (international relations)\",\"capitalist peace\",\"critical security studies\",\"authoritarian capitalism\",\"postinternationalism\",\"scientific man versus power politics\",\"relative gain (international relations)\",\"global citizenship\",\"environmental policy of the european union\",\"regionalism (international relations)\",\"bananas, beaches and bases\",\"international ethics\",\"postfunctionalism\",\"zombie liberalism\",\"idealism in international relations\",\"democratic peace theory\",\"index of social and political philosophy articles\",\"warren miller (political scientist)\",\"walter f. dodd\",\"emmette redford\",\"totalitarianism\",\"international political science association\",\"kremlinology\",\"elinor ostrom\",\"henry e. brady\",\"index of sociopolitical thinkers\",\"norwegian sociology canon\",\"comparative historical research\",\"international sociological association\",\"international political science association\",\"cleavage (politics)\",\"left\\u2013right political spectrum\",\"party system\",\"instituts d'\\u00e9tudes politiques\",\"multi-level governance\",\"legitimation crisis\",\"antipositivism\",\"critical medical anthropology\",\"privatism\",\"critical security studies\",\"psychoanalysis\",\"people\",\"social experiment\",\"astrosociology\",\"social complexity\",\"language\",\"regional power\",\"global terrorism index\",\"bric\",\"democracy-dictatorship index\",\"great power\",\"national power\",\"economic power\",\"v-dem institute\",\"superpower collapse\",\"energy superpower\",\"global terrorism index\",\"v-dem institute\",\"institute for economics and peace\",\"v-dem institute\",\"antipositivism\",\"werturteilsstreit\",\"instrumentalism\",\"rationalism\",\"berkeley school of political theory\",\"systems theory in political science\",\"post-behavioralism\",\"structuration theory\",\"sociological positivism\",\"political studies association\",\"karl deutsch award\",\"norman chester\",\"john coakley\",\"developmental psychology\",\"nurturant parent model\",\"attachment parenting\",\"developmental psychology\",\"creativity\",\"attachment parenting\",\"naturalistic observation\",\"developmental psychology\",\"child behavior checklist\",\"sociometric status\",\"ego integrity\",\"list of psychological schools\",\"piaget's theory of cognitive development\",\"outline of psychology\",\"interpersonal neurobiology\",\"kurt koffka medal\",\"harry harlow\",\"quantitative research\",\"behavioral neuroscience\",\"specialist in psychology\",\"ecological psychology\",\"relational developmental systems\",\"barbara rogoff\",\"moral emotions\",\"daniel kahneman\",\"list of psychology awards\",\"learning\",\"attachment parenting\",\"intelligence\",\"crying\",\"implicit-association test\",\"right-wing politics\",\"british psychotherapy foundation\",\"eustress\",\"harry harlow\",\"object relations theory\",\"intelligence\",\"crying\",\"psychohistory\",\"psychoanalysis\",\"intelligence quotient\",\"echo chamber (media)\",\"transpersonal psychology\",\"utility\",\"sid parnes\",\"fourteen words\",\"piaget's theory of cognitive development\",\"nazism\",\"creativity\",\"taste (sociology)\",\"white power music\",\"paul romer\",\"neo-nationalism\",\"geography of antisemitism\",\"nations and iq\",\"far-right politics\",\"outline of thought\",\"mania\",\"collaboration\",\"transliminality\",\"henri poincar\\u00e9\",\"sarnoff a. mednick\",\"major depressive disorder\",\"ambidexterity\",\"kalergi plan\",\"race and intelligence\",\"basket of deplorables\",\"music psychology\",\"creativity and mental health\",\"conceptual economy\",\"social reality\",\"shadow (psychology)\",\"linguistic relativity\",\"cultural movement\",\"logology (science)\",\"learning\",\"psychoanalytic theory\",\"preconscious\",\"intelligence\",\"schizotypy\",\"list of national legal systems\",\"material flow analysis\",\"social system\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"complex adaptive system\",\"dynamical system\",\"urban metabolism\",\"social integration\",\"legitimation crisis\",\"index of sociology articles\",\"antipositivism\",\"constitutionalism\",\"worldwide influence of the constitution of the united states\",\"echo chamber (media)\",\"hardline\",\"civil libertarianism\",\"one man, one vote\",\"revolutions of 1989\",\"non-interventionism\",\"statism\",\"reactionary\",\"authoritarian left\",\"constitutional economics\",\"liberal legalism\",\"neo-nationalism\",\"participism\",\"international law\",\"neoclassical liberalism\",\"ecoauthoritarianism\",\"populism\",\"whiggism\",\"bryan caplan\",\"night-watchman state\",\"rationalism\",\"atlanticism\",\"feminist theory\",\"social reality\",\"cato institute\",\"equality before the law\",\"cultural movement\",\"right-wing politics\",\"virtue jurisprudence\",\"anarcho-capitalism\",\"proto-industrialization\",\"astrology\",\"law of equal liberty\",\"first world\",\"l'ann\\u00e9e sociologique\",\"androcentrism\",\"collective effervescence\",\"immigrant-host model\",\"enemy of the people\",\"bumiputera (malaysia)\",\"christian privilege\",\"social model of disability\",\"language\",\"revolutions of 1989\",\"structural discrimination\",\"white power music\",\"oppression\",\"discrimination against autistic people\",\"intergenerational policy\",\"lawrence summers\",\"filter bubble\",\"communal reinforcement\",\"echo chamber (media)\",\"propaganda\",\"post-truth politics\",\"balkanization\",\"social reality\",\"cultural movement\",\"counterpropaganda\",\"strategy of tension\",\"open-mindedness\",\"e-government\",\"helen margetts\",\"cyberocracy\",\"debate\",\"joe biden (the onion)\",\"extemporaneous speaking\",\"renewable energy transition\",\"appeasement\",\"debate chamber\",\"debate\",\"cognitive bias\",\"parliamentary debate\",\"parliamentary procedure\",\"stephanos bibas\",\"spin room\",\"argumentation and advocacy\",\"marlon bundo\",\"edinburgh university socialist society\",\"australian journal of political science\",\"journal of theoretical politics\",\"british journal of politics and international relations\",\"e-government\",\"regional power\",\"particracy\",\"great power\",\"totalitarianism\",\"oligarchy\",\"dependent territory\",\"e-government\",\"regional power\",\"particracy\",\"electronic authentication\",\"totalitarianism\",\"oligarchy\",\"politico-media complex\",\"international conference on theory and practice of electronic governance\",\"great power\",\"dependent territory\",\"elinor ostrom\",\"labor theory of property\",\"john hicks\",\"thomas schelling\",\"economic model\",\"schelling's segregation model\",\"utility\",\"clive granger\",\"organizational theory\",\"macroeconomic model\",\"eugene fama\",\"keynesian cross\",\"steven n. s. cheung\",\"paul romer\",\"attention economy\",\"economic indicator\",\"warren miller (political scientist)\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"index of economics articles\",\"international economics\",\"the great transformation (book)\",\"accelerator effect\",\"new institutional economics\",\"pippa norris\",\"cato institute\",\"daniel mcfadden\",\"daniel kahneman\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"michael spence\",\"fritz w. scharpf\",\"elinor ostrom\",\"mainstream economics\",\"leonid kantorovich\",\"henry e. brady\",\"law of rent\",\"john harsanyi\",\"economic transformation\",\"financial economics\",\"service economy\",\"is\\u2013lm model\",\"list of important publications in economics\",\"public property\",\"nava ashraf\",\"history of microeconomics\",\"paul milgrom\",\"private property\",\"instrumentalism\",\"bengt holmstr\\u00f6m\",\"public economics\",\"grazing rights\",\"air rights\",\"ramsey\\u2013cass\\u2013koopmans model\",\"experimental economics\",\"99ers\",\"myron scholes\",\"friedrich hayek\",\"walter f. dodd\",\"social cost\",\"hiding hand principle\",\"emmette redford\",\"adam smith\",\"econophysics\",\"william vickrey\",\"kenneth arrow\",\"georg weizs\\u00e4cker\",\"phillips curve\",\"implicit cost\",\"vernon l. smith\",\"purchasing power parity\",\"trygve haavelmo\",\"perestroika\",\"barracks communism\",\"history of communism\",\"propaganda\",\"triangular diplomacy\",\"democratic capitalism\",\"totalitarianism\",\"perestroika\",\"revolutions of 1989\",\"sovereignty of puerto rico during the cold war\",\"socialist realism\",\"gar alperovitz\",\"eastern bloc\",\"political repression\",\"superpower collapse\",\"party system\",\"left\\u2013right political spectrum\",\"one-party state\",\"party identification\",\"party platform\",\"statism\",\"authoritarian left\",\"right-wing politics\",\"cleavage (politics)\",\"far-right politics\",\"nonpartisanism\",\"electronic media\",\"symbol\",\"transformation processes (media systems)\",\"marco tarchi\",\"propaganda\",\"knowledge gap hypothesis\",\"how voters feel\",\"social media use in politics\",\"political criticism\",\"social media use in african politics\",\"social media in the 2016 united states presidential election\",\"politico-media complex\",\"global politics\",\"social media use by donald trump\",\"mass media and american politics\",\"attention economy\",\"reality distortion field\",\"echo chamber (media)\",\"consumer class\",\"friendly fascism (book)\",\"blood and soil\",\"gustave le bon\",\"asch conformity experiments\",\"rumor\",\"antemurale myth\",\"post-truth politics\",\"brainwashing\",\"list of cognitive biases\",\"cover-up\",\"nazism\",\"prague conference\",\"reactionary\",\"strategy of tension\",\"blacklisting\",\"enemy of the people (albania)\",\"dang guo\",\"history of propaganda\",\"eastern bloc\",\"the engineering of consent\",\"spin room\",\"proposed national unification promotion law\",\"who moved my cheese?\",\"globalization and women in china\",\"propaganda\",\"xuanchuan\",\"tyranny of the majority\",\"totalitarianism\",\"social reality\",\"donor class\",\"law of the jungle\",\"media circus\",\"aromanian question\",\"songun\",\"reterritorialization\",\"overview of 21st-century propaganda\",\"authoritarian democracy\",\"f\\u00fchrer\",\"urban legend\",\"christian fascism\",\"corporate anniversary\",\"socialist realism\",\"shock value\",\"proletarian nation\",\"international convention concerning the use of broadcasting in the cause of peace\",\"law and order\",\"revolutions of 1989\",\"politico-media complex\",\"demonizing the enemy\",\"security, territory, population\",\"gish gallop\",\"karl schwedler\",\"oryx and crake\",\"people power\",\"all animals are equal, but some animals are more equal than others\",\"communal reinforcement\",\"obscurantism\",\"corporate statism\",\"general semantics\",\"enemy of the people\",\"political socialization\",\"criticism of capitalism\",\"influence of mass media\",\"transfer (propaganda)\",\"gerschenkron effect\",\"neosocialism\",\"third-person effect\",\"cultural movement\",\"counterpropaganda\",\"nur f\\u00fcr deutsche\",\"symbol\",\"corporate communication\",\"peer pressure\",\"music and political warfare\",\"recuperation (politics)\",\"philosophical analysis\",\"slogan\",\"national liberalism\",\"ferdinand de saussure\",\"flourish of approval\",\"antemurale myth\",\"enemy of the people\",\"index of sociology articles\",\"left-wing populism\",\"economic nationalism\",\"ethnosymbolism\",\"language\",\"linguistic relativity\",\"symbol\",\"moor's head (heraldry)\",\"constitutional patriotism\",\"national conservatism\",\"bertrand russell\",\"enemy of the people (albania)\",\"neo-nationalism\",\"eco-nationalism\",\"national communism\",\"learning\",\"plurinationalism\",\"cultural nationalism\",\"metalanguage\",\"serfdom\",\"peasant\",\"social system\",\"serfdom\",\"manorialism\",\"echo chamber (media)\",\"obshchina\",\"feoffment\",\"the protestant ethic and the spirit of capitalism\",\"social reality\",\"peasant\",\"cultural movement\",\"mudsill theory\",\"reactionary\",\"magnate\",\"kshatriya\",\"oppression\",\"underclass\",\"warrior\",\"enlightened absolutism\",\"business magnate\",\"the road to serfdom\",\"social system\",\"digital ecosystem\",\"religious socialism\",\"language\",\"social dominance orientation\",\"people\",\"religious communism\",\"manifest and latent functions and dysfunctions\",\"value-added theory\",\"protest cycle\",\"grotesque body\",\"social complexity\",\"patrilocal residence\",\"social experiment\",\"index of sociology articles\",\"feminist theory\",\"early social changes under islam\",\"social rule system theory\",\"christian communism\",\"glossary of economics\",\"computational sociology\",\"control (management)\",\"astrosociology\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"ideal type\",\"urban metabolism\",\"world3\",\"manorialism\",\"poverty class\",\"confucian classes\",\"feoffment\",\"status group\",\"vertical mobility\",\"index of sociology articles\",\"literacy\",\"rajputisation\",\"peasant\",\"nazism\",\"mosuo women\",\"mudsill theory\",\"personhood\",\"kshatriya\",\"upper class\",\"underclass\",\"warrior\",\"peasant economics\",\"business magnate\",\"international law\",\"index of social and political philosophy articles\",\"yehuda zvi blum\",\"wood industry\",\"comparative criminal justice\",\"international sanctions\",\"grey-zone (international relations)\",\"henry habib\",\"inquisitorial system\",\"rosa brooks\",\"contingent sovereignty\",\"border control\",\"feminist legal theory\",\"regulatory competition\",\"samuel von pufendorf\",\"glossary of international relations terms\",\"executive order\",\"occupatio\",\"responsibility to protect\",\"history of the legal profession\",\"solitary confinement\",\"history of the american legal profession\",\"fiqh\",\"first world\",\"idealism in international relations\",\"list of environmental ministries\",\"united nations parliamentary assembly\",\"ecocide\",\"non-state actor\",\"predictive policing\",\"institute for international law of peace and armed conflict\",\"people\",\"non-interventionism\",\"list of national legal systems\",\"outline of globalization\",\"kaarlo juho st\\u00e5hlberg\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"dualism (law)\",\"international law\",\"implied powers\",\"dominium maris baltici\",\"appeasement\",\"violent non-state actor\",\"rationalism\",\"atlanticism\",\"\\u00e5land islands peace institute\",\"equality before the law\",\"westphalian sovereignty\",\"martine-anstett award\",\"non-governmental organization\",\"julius stone\",\"proto-industrialization\",\"astrology\",\"populism\",\"hardline\",\"political research associates\",\"spatial politics\",\"third way\",\"social imperialism\",\"horseshoe theory\",\"nolan chart\",\"left\\u2013right political spectrum\",\"totalitarianism\",\"left-wing populism\",\"nazism\",\"reactionary\",\"authoritarian left\",\"right-wing politics\",\"far-right politics\",\"bolivarian revolution\",\"index of social and political philosophy articles\",\"hardline\",\"friendly fascism (book)\",\"blood and soil\",\"communism and lgbt rights\",\"scientocracy\",\"new left review\",\"peter sloterdijk\",\"one-party state\",\"nazism\",\"reactionary\",\"authoritarian left\",\"far-right politics\",\"eastern bloc\",\"the road to serfdom\",\"philosophy of max stirner\",\"regional power\",\"third way\",\"tyranny of the majority\",\"nolan chart\",\"total institution\",\"left\\u2013right political spectrum\",\"totalitarianism\",\"normalcy bias\",\"donor class\",\"great power\",\"constitutional dictatorship\",\"psychoanalytic theory\",\"f\\u00fchrer\",\"authoritarian democracy\",\"christian fascism\",\"political repression\",\"socialist realism\",\"christian corporatism\",\"proletarian nation\",\"social order\",\"polyarchy\",\"people's democracy (marxism\\u2013leninism)\",\"particracy\",\"linguistics in science fiction\",\"bankocracy\",\"authoritarian capitalism\",\"oligarchy\",\"ilminism\",\"revolutions of 1989\",\"statism\",\"communist front\",\"futarchy\",\"soft despotism\",\"hannah arendt institute for totalitarianism studies\",\"enlightened absolutism\",\"civilization state\",\"corporate republic\",\"all animals are equal, but some animals are more equal than others\",\"dependent territory\",\"ecoauthoritarianism\",\"friedrich hayek\",\"spatial politics\",\"triangular diplomacy\",\"night-watchman state\",\"index of sociology articles\",\"bibliography of works about communism\",\"neosocialism\",\"proletarian revolution\",\"social revolution\",\"the indian struggle\",\"real socialism\",\"nur f\\u00fcr deutsche\",\"sovereignty of puerto rico during the cold war\",\"bertrand russell\",\"right-wing politics\",\"burmese way to socialism\",\"legalism (chinese philosophy)\",\"synarchism\",\"dictablanda\",\"index of social and political philosophy articles\",\"olivier ihl\",\"liberal international order\",\"hardline\",\"majoritarianism\",\"democratic capitalism\",\"one-party state\",\"nazism\",\"reactionary\",\"authoritarian left\",\"neo-nationalism\",\"far-right politics\",\"eastern bloc\",\"whiggism\",\"high culture\",\"consensus democracy\",\"marco tarchi\",\"third way\",\"tyranny of the majority\",\"nolan chart\",\"left\\u2013right political spectrum\",\"feminist theory\",\"pippa norris\",\"new social movements\",\"authoritarian democracy\",\"history of democratic socialism\",\"christian fascism\",\"abilene paradox\",\"democratic peace theory\",\"proletarian nation\",\"polyarchy\",\"garveyism\",\"industrial democracy\",\"people\",\"statism\",\"white power music\",\"workplace democracy\",\"ecoauthoritarianism\",\"rogers brubaker\",\"spatial politics\",\"associationalism\",\"left-wing populism\",\"economic power\",\"neosocialism\",\"post-politics\",\"right-wing politics\",\"deviationism\",\"bolivarian revolution\",\"social liberalism\",\"criticism of capitalism\",\"popular socialism\",\"left\\u2013right political spectrum\",\"language\",\"modern liberalism in the united states\",\"nazism\",\"public image of cristina fern\\u00e1ndez de kirchner\",\"constitutional patriotism\",\"antimilitarism\",\"cultural liberalism\",\"hardline\",\"spatial politics\",\"third way\",\"social imperialism\",\"nolan chart\",\"cato institute\",\"nazism\",\"reactionary\",\"authoritarian left\",\"private property\",\"right-wing politics\",\"freedom\",\"far-right politics\",\"equal opportunity\",\"hardline\",\"spatial politics\",\"third way\",\"social imperialism\",\"gun control\",\"nazism\",\"statism\",\"reactionary\",\"authoritarian left\",\"right-wing politics\",\"far-right politics\",\"far-right politics\",\"consumer class\",\"hardline\",\"world economy\",\"list of social democratic parties\",\"social liberalism\",\"democratic capitalism\",\"technoliberalism\",\"political studies review\",\"list of liberal theorists\",\"liberal corporatism\",\"reflexive modernization\",\"one-party state\",\"nazism\",\"history of capitalist theory\",\"history of social democracy\",\"john rawls\",\"john roemer\",\"reactionary\",\"authoritarian left\",\"frankfurt declaration\",\"neo-nationalism\",\"far-right politics\",\"equal opportunity\",\"whiggism\",\"reductionism\",\"third way\",\"social imperialism\",\"liberalism and conservatism in latin america\",\"feminist theory\",\"new institutional economics\",\"richard dawkins\",\"constitutional patriotism\",\"freedom\",\"surplus value\",\"marginalism\",\"democratic liberalism\",\"anglo-saxon model\",\"zombie liberalism\",\"social corporatism\",\"history of democratic socialism\",\"national liberalism\",\"frente despertar\",\"privatism\",\"isaiah berlin\",\"civil libertarianism\",\"neo-capitalism\",\"supply and demand\",\"industrial democracy\",\"authoritarian capitalism\",\"people\",\"statism\",\"private property\",\"impeachment\",\"conservative liberalism\",\"cultural liberalism\",\"ordoliberalism\",\"neoclassical liberalism\",\"ecoauthoritarianism\",\"friedrich hayek\",\"spatial politics\",\"visible hand (economics)\",\"liberal conservatism\",\"criticism of capitalism\",\"adam smith\",\"ethical socialism\",\"real socialism\",\"modern liberalism in the united states\",\"equality before the law\",\"eco-capitalism\",\"bertrand russell\",\"right-wing politics\",\"anarcho-capitalism\",\"law of equal liberty\",\"hardline\",\"blood and soil\",\"friendly fascism (book)\",\"antemurale myth\",\"one-party state\",\"reactionary\",\"authoritarian left\",\"enemy of the people (albania)\",\"neo-nationalism\",\"geography of antisemitism\",\"far-right politics\",\"plurinationalism\",\"the soldier and the state\",\"the road to serfdom\",\"kalergi plan\",\"tyranny of the majority\",\"leipzig school (sociology)\",\"franz oppenheimer\",\"economic nationalism\",\"constitutional patriotism\",\"national conservatism\",\"eco-nationalism\",\"national communism\",\"constitutional dictatorship\",\"authoritarian democracy\",\"perpetual war\",\"f\\u00fchrer\",\"ministry of magic\",\"drang nach osten\",\"cultural nationalism\",\"christian fascism\",\"national liberalism\",\"proletarian nation\",\"you have two cows\",\"social order\",\"oligarchy\",\"authoritarian capitalism\",\"alphons silbermann\",\"ilminism\",\"people\",\"statism\",\"soft despotism\",\"private property\",\"white power music\",\"hannah arendt institute for totalitarianism studies\",\"organicism\",\"enlightened absolutism\",\"left communism\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"corporate republic\",\"ordoliberalism\",\"ecoauthoritarianism\",\"holocaust trivialization\",\"eugen relgis\",\"anti-gender movement\",\"kinder, k\\u00fcche, kirche\",\"spatial politics\",\"enemy of the people\",\"ethnosymbolism\",\"neosocialism\",\"nur f\\u00fcr deutsche\",\"right-wing politics\",\"radicalization\",\"pride\",\"synarchism\",\"dictablanda\",\"barracks communism\",\"proletarian nation\",\"hardline\",\"people's democracy (marxism\\u2013leninism)\",\"base and superstructure\",\"seek truth from facts\",\"reactionary\",\"authoritarian left\",\"dictatorship of the proletariat\",\"enemy of the people (albania)\",\"far-right politics\",\"world revolution\",\"social patriotism\",\"spatial politics\",\"enemy of the people\",\"bibliography of works about communism\",\"proletarian revolution\",\"real socialism\",\"social revolution\",\"commanding heights of the economy\",\"right-wing politics\",\"surplus value\",\"surplus labour\",\"production for profit\",\"worker cooperative\",\"self-criticism\",\"transnational progressivism\",\"index of social and political philosophy articles\",\"hardline\",\"backlash (sociology)\",\"gustave le bon\",\"balkanization\",\"fourteen words\",\"statism\",\"history of social democracy\",\"reactionary\",\"authoritarian left\",\"dictatorship of the proletariat\",\"neo-nationalism\",\"far-right politics\",\"conservative liberalism\",\"conservative corporatism\",\"social conservatism\",\"ecoauthoritarianism\",\"whiggism\",\"kalergi plan\",\"small government\",\"spatial politics\",\"social transformation\",\"liberalism and conservatism in latin america\",\"basket of deplorables\",\"liberal conservatism\",\"feminist theory\",\"national conservatism\",\"right-wing politics\",\"neoauthoritarianism (china)\",\"successor ideology\",\"whiggism\",\"spatial politics\",\"ideocracy\",\"feminist theory\",\"statism\",\"authoritarian left\",\"right-wing politics\",\"neo-nationalism\",\"far-right politics\",\"ecoauthoritarianism\",\"collective memory\",\"flashback (psychology)\",\"cultural memory\",\"memory space (social science)\",\"flashback (psychology)\",\"cultural memory\",\"transnational progressivism\",\"high culture\",\"cultural mapping\",\"cultural practice\",\"cultural radicalism\",\"bioculture\",\"cultural relativism\",\"transcultural nursing\",\"flashback (psychology)\",\"cultural movement\",\"cultural anthropology\",\"outline of culture\",\"culturgen\",\"welfare culture\",\"culture hero\",\"social degeneration\",\"identity (social science)\",\"culture theory\",\"cultural nationalism\",\"cultural liberalism\",\"supply and demand\",\"gun control\",\"consumer class\",\"ceteris paribus\",\"john hicks\",\"democratic capitalism\",\"economic model\",\"utility\",\"history of capitalist theory\",\"indifference curve\",\"methodology of econometrics\",\"giffen good\",\"assume a can opener\",\"economic graph\",\"dynamic pricing\",\"georgism\",\"international economics\",\"index of economics articles\",\"national agricultural policy center\",\"new institutional economics\",\"cato institute\",\"glossary of economics\",\"surplus value\",\"mainstream economics\",\"cournot competition\",\"marginalism\",\"anglo-saxon model\",\"microgeneration\",\"peak wheat\",\"privatism\",\"mesoeconomics\",\"neo-capitalism\",\"principles of economics (marshall book)\",\"jel classification codes\",\"law of supply\",\"authoritarian capitalism\",\"intertemporal choice\",\"cumulative process\",\"private property\",\"demand curve\",\"public economics\",\"forward exchange market\",\"experimental economics\",\"ordoliberalism\",\"market mechanism\",\"friedrich hayek\",\"social cost\",\"price support\",\"visible hand (economics)\",\"criticism of capitalism\",\"cash crop\",\"adam smith\",\"economic power\",\"opportunity cost\",\"william vickrey\",\"market rate\",\"eco-capitalism\",\"cobweb model\",\"anarcho-capitalism\",\"free-market healthcare\",\"substitution effect\",\"modern liberalism in the united states\",\"molon labe\",\"economic stimulus appropriations act of 1977\",\"fiscal policy of the united states\",\"i did not have sexual relations with that woman\",\"nominate (scaling method)\",\"international centre for black sea studies\",\"international relations and security network\",\"security studies\",\"freedom\",\"national liberalism\",\"national forum (georgia)\",\"isaiah berlin\",\"civil libertarianism\",\"democratic capitalism\",\"social liberalism\",\"emotivism\",\"technoliberalism\",\"brainwashing\",\"give peace a chance\",\"public consultation\",\"william frankena\",\"list of liberal theorists\",\"liberal corporatism\",\"revolutions of 1989\",\"history of capitalist theory\",\"john rawls\",\"authoritarian left\",\"private property\",\"far-right politics\",\"conservative liberalism\",\"participism\",\"equal opportunity\",\"worshipful company of butchers\",\"the road to serfdom\",\"unitarian universalism\",\"spirituality\",\"cultural liberalism\",\"social threefolding\",\"religious literacy\",\"ordoliberalism\",\"whiggism\",\"middlebrow\",\"neoclassical liberalism\",\"role ethics\",\"liberalism and conservatism in latin america\",\"soul\",\"liberal conservatism\",\"criticism of capitalism\",\"adam smith\",\"ethnic religion\",\"modern liberalism in the united states\",\"equality before the law\",\"philosophy of life\",\"freedom\",\"democratic liberalism\",\"philosophical analysis\",\"anarcho-capitalism\",\"indonesian village law\",\"law of equal liberty\",\"live free or die\",\"theory of change\",\"learning\",\"culture theory\",\"social impact entertainment\",\"online ethnography\",\"nation-building\",\"ethnoarchaeology\",\"ethnobiology\",\"netnography\",\"ethnozoology\",\"ethnic religion\",\"language\",\"ethnomuseology\",\"constitutional patriotism\",\"ethnomedicine\",\"identity (social science)\",\"civilization state\",\"ethnoichthyology\",\"hunter-gatherer\",\"interactionism\",\"paleoanthropology\",\"majoritarianism\",\"base and superstructure\",\"theory of language\",\"status group\",\"philosophy of sex\",\"linguistic description\",\"development geography\",\"language\",\"linguistic anthropology\",\"manifest and latent functions and dysfunctions\",\"gallowglass\",\"enemy of the people (albania)\",\"neo-nationalism\",\"marxist sociology\",\"freelancer\",\"agency (philosophy)\",\"social complexity\",\"sociology of punishment\",\"media linguistics\",\"psychogeography\",\"displacement (linguistics)\",\"control theory (sociology)\",\"social reality\",\"european sociological association\",\"fiscal policy of the philippines\",\"economic nationalism\",\"dark figure of crime\",\"linguistic relativity\",\"richard dawkins\",\"psychological nativism\",\"categorical perception\",\"constitutional patriotism\",\"microsociology\",\"national communism\",\"identity (social science)\",\"cultural nationalism\",\"public policy doctrine\",\"relational sociology\",\"richard gaskin\",\"national liberalism\",\"ferdinand de saussure\",\"health geography\",\"jel classification codes\",\"health policy\",\"literacy\",\"performativity\",\"white power music\",\"cultural group selection\",\"bicameral mentality\",\"logophonetic\",\"geography of media and communication\",\"human ethology\",\"c. d. broad\",\"sociology in poland\",\"visible minority\",\"enemy of the people\",\"index of sociology articles\",\"sociology in japan\",\"gaia philosophy\",\"concentrated disadvantage\",\"comprehension approach\",\"greek withdrawal from the eurozone\",\"hedonism\",\"structural violence\",\"bertrand russell\",\"average joe\",\"oppression\",\"computational sociology\",\"sociology of scientific ignorance\",\"collective mental state\",\"astrosociology\",\"legalism (chinese philosophy)\",\"biosocial criminology\",\"wood industry\",\"quaternary sector of the economy\",\"agency (sociology)\",\"list of sociologists\",\"bumiputera (malaysia)\",\"antemurale myth\",\"pattern recognition (psychology)\",\"educational anthropology\",\"organizational theory\",\"hunting hypothesis\",\"sociological positivism\",\"constantin noica\",\"non-representational theory\",\"outline of thought\",\"plurinationalism\",\"skhul and qafzeh hominins\",\"figurational sociology\",\"friction of distance\",\"dyad (sociology)\",\"reductionism\",\"apuli\",\"biological anthropology\",\"military policy\",\"german model\",\"early modern human\",\"philosophy of life\",\"galician student league\",\"emotive (sociology)\",\"national conservatism\",\"eco-nationalism\",\"sociology of morality\",\"aromanian question\",\"cognitive archaeology\",\"moral entrepreneur\",\"symbolic religiosity\",\"field theory (sociology)\",\"intelligence\",\"social reproduction\",\"metalanguage\",\"medical sociologist\",\"laterality\",\"institution\",\"per capita personal income in the united states\",\"androcentrism\",\"modular cognition framework\",\"isaiah berlin\",\"group threat theory\",\"industry (economics)\",\"australian institute of aboriginal and torres strait islander studies\",\"asabiyyah\",\"public policy school\",\"cultural survival\",\"social conflict\",\"value-added theory\",\"david chalmers\",\"discrimination against autistic people\",\"culture theory\",\"eonia\",\"task force\",\"fragmentation (sociology)\",\"bibliography of sociology\",\"list of sociology journals\",\"social experiment\",\"rationalism\",\"action theory (sociology)\",\"christian privilege\",\"psychonautics\",\"structural discrimination\",\"mudsill theory\",\"east turkestan\",\"logology (science)\",\"names for the human species\",\"philosophical analysis\",\"national liberalism\",\"social liberalism\",\"antemurale myth\",\"private property\",\"enemy of the people (albania)\",\"neo-nationalism\",\"conservative liberalism\",\"plurinationalism\",\"neoclassical liberalism\",\"liberal conservatism\",\"enemy of the people\",\"criticism of capitalism\",\"adam smith\",\"economic nationalism\",\"cultural nationalism\",\"national conservatism\",\"eco-nationalism\",\"national communism\",\"democratic liberalism\",\"anarcho-capitalism\",\"zombie liberalism\",\"law of equal liberty\",\"osteology\",\"online ethnography\",\"zooarchaeology\",\"ethnobiology\",\"ethnolichenology\",\"netnography\",\"ethnozoology\",\"arthur evans\",\"ecological anthropology\",\"civilization state\",\"ethnoichthyology\",\"nation-building\",\"direct historical approach\",\"ethnic religion\",\"ethnomuseology\",\"ethnomedicine\",\"identity (social science)\",\"ethnoornithology\",\"paleopathology\",\"osteology\",\"online ethnography\",\"journal of ethnobiology\",\"natural capital\",\"zooarchaeology\",\"ethnobiology\",\"ethnolichenology\",\"netnography\",\"ethnozoology\",\"ecological anthropology\",\"porter hypothesis\",\"civilization state\",\"ethnoichthyology\",\"greenwashing\",\"hawaiian ethnobiology\",\"nation-building\",\"urban metabolism\",\"ecofeminism\",\"payment for ecosystem services\",\"degrowth\",\"ethnic religion\",\"biocultural diversity\",\"ethnomuseology\",\"cultural anthropology\",\"ethnomedicine\",\"identity (social science)\",\"ethnoornithology\",\"online ethnography\",\"nation-building\",\"zooarchaeology\",\"ethnolichenology\",\"netnography\",\"ethnic religion\",\"ethnomuseology\",\"cultural anthropology\",\"ecological anthropology\",\"ethnomedicine\",\"identity (social science)\",\"civilization state\",\"ethnoichthyology\",\"ethnoornithology\",\"online ethnography\",\"nation-building\",\"ethnic religion\",\"ethnomuseology\",\"ethnomedicine\",\"identity (social science)\",\"civilization state\",\"ethnoichthyology\",\"online ethnography\",\"cognitive anthropology\",\"nutritional anthropology\",\"zooarchaeology\",\"ethnolichenology\",\"society for medical anthropology\",\"ecological anthropology\",\"civilization state\",\"ethnoichthyology\",\"critical medical anthropology\",\"nation-building\",\"ethnic religion\",\"medical anthropology\",\"ethnomuseology\",\"cultural anthropology\",\"identity (social science)\",\"ethnoornithology\",\"online ethnography\",\"emic and etic\",\"nation-building\",\"alliance theory\",\"cultural relativism\",\"performance studies\",\"ethnic religion\",\"identity (social science)\",\"culture theory\",\"civilization state\",\"anthropology of institutions\",\"ethnoichthyology\",\"online ethnography\",\"nation-building\",\"civilization state\",\"identity (social science)\",\"unitarian universalism\",\"spirituality\",\"ethnoichthyology\",\"online ethnography\",\"svoboda ili smart\",\"decolonization\",\"magna carta for philippine internet freedom\",\"identity (social science)\",\"civilization state\",\"ethnoichthyology\",\"median voter theorem\",\"radicalization\",\"arrow's impossibility theorem\",\"hotelling's law\",\"curvilinear disparity\",\"journal of public economics\",\"an economic theory of democracy\",\"sunk cost\",\"violent non-state actor\",\"tryph\\u00e9\",\"scale analysis (statistics)\",\"classical test theory\",\"guttman scale\",\"build\\u2013operate\\u2013transfer\",\"journal of theoretical politics\",\"peace and conflict studies\",\"appeasement\",\"peace journalism\",\"international security\",\"give peace a chance\",\"critical security studies\",\"security studies\",\"conflict resolution research\",\"responsibility to protect\",\"non-interventionism\",\"sciences po\",\"center on conscience & war\",\"structural violence\",\"antimilitarism\",\"international political sociology (ips)\",\"heterotopia (space)\",\"friedrich hayek\",\"anti-psychiatry\",\"security, territory, population\",\"homo economicus\",\"adam smith\",\"ordoliberalism\",\"consumer class\",\"privatism\",\"neo-capitalism\",\"democratic capitalism\",\"social liberalism\",\"authoritarian capitalism\",\"list of liberal theorists\",\"history of capitalist theory\",\"private property\",\"whiggism\",\"friedrich hayek\",\"austerity: the history of a dangerous idea\",\"visible hand (economics)\",\"liberal conservatism\",\"criticism of capitalism\",\"adam smith\",\"german model\",\"new institutional economics\",\"eco-capitalism\",\"surplus value\",\"marginalism\",\"anglo-saxon model\",\"anarcho-capitalism\",\"labour voucher\",\"market allocation scheme\",\"civilizing the economy\",\"pensions crisis\",\"democratic capitalism\",\"philosophy of sex\",\"economic model\",\"development geography\",\"keynesian cross\",\"unearned income\",\"import substitution industrialization\",\"equal opportunity\",\"the road to serfdom\",\"assume a can opener\",\"whiggism\",\"paradox of thrift\",\"consumer sovereignty\",\"solow\\u2013swan model\",\"georgism\",\"international economics\",\"index of economics articles\",\"the great transformation (book)\",\"economic nationalism\",\"inframarginal analysis\",\"cato institute\",\"knowledge economy\",\"surplus value\",\"mainstream economics\",\"say's political economy\",\"marginalism\",\"john harsanyi\",\"national liberalism\",\"economic transformation\",\"privatism\",\"neo-capitalism\",\"financial economics\",\"jel classification codes\",\"lectures on jurisprudence\",\"e. f. schumacher\",\"constitutional economics\",\"private property\",\"grazing rights\",\"air rights\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"friedrich hayek\",\"big push model\",\"visible hand (economics)\",\"criticism of capitalism\",\"reciprocity (cultural anthropology)\",\"institutionalist political economy\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"econophysics\",\"eco-capitalism\",\"istv\\u00e1n hont\",\"kenneth arrow\",\"convergence (economics)\",\"implicit cost\",\"labor theory of property\",\"consumer class\",\"john hicks\",\"list of sociologists\",\"homo economicus\",\"technoliberalism\",\"utility\",\"winner-take-all politics\",\"list of liberal theorists\",\"ak model\",\"macroeconomic model\",\"organizational theory\",\"how are we to live?\",\"history of capitalist theory\",\"steven n. s. cheung\",\"consumer debt\",\"econtalk\",\"dynamic density\",\"attention economy\",\"financial innovation\",\"economic indicator\",\"returns (economics)\",\"reductionism\",\"robert heilbroner\",\"index (economics)\",\"diamond-water paradox\",\"rentier state\",\"samuel von pufendorf\",\"accelerator effect\",\"paradox of value\",\"the protestant ethic and the spirit of capitalism\",\"new institutional economics\",\"mandeville's paradox\",\"the counter-revolution of science\",\"glossary of economics\",\"diminishing returns\",\"interventionism (politics)\",\"anglo-saxon model\",\"law of rent\",\"fei\\u2013ranis model of economic growth\",\"vent for surplus\",\"on the principles of political economy and taxation\",\"blue economy\",\"institution\",\"law of increasing costs\",\"excess burden of taxation\",\"service economy\",\"law of supply\",\"is\\u2013lm model\",\"list of important publications in economics\",\"authoritarian capitalism\",\"public property\",\"history of microeconomics\",\"information economics\",\"circular flow of income\",\"public economics\",\"enlightened absolutism\",\"experimental economics\",\"social cost\",\"rationalism\",\"liberal conservatism\",\"adam smith\",\"opportunity cost\",\"factors of production\",\"phillips curve\",\"anarcho-capitalism\",\"purchasing power parity\",\"index of social and political philosophy articles\",\"conservative research department\",\"democratic capitalism\",\"philosophy of sex\",\"economic model\",\"keynesian cross\",\"anarcho-capitalism\",\"equal opportunity\",\"the road to serfdom\",\"paradox of thrift\",\"solow\\u2013swan model\",\"georgism\",\"index of economics articles\",\"international economics\",\"cato institute\",\"daniel kahneman\",\"knowledge economy\",\"surplus value\",\"mainstream economics\",\"marginalism\",\"national liberalism\",\"equality of outcome\",\"economic transformation\",\"privatism\",\"civil libertarianism\",\"neo-capitalism\",\"financial economics\",\"global justice movement\",\"richard timberlake\",\"e. f. schumacher\",\"non-interventionism\",\"paul milgrom\",\"constitutional economics\",\"dictatorship of the proletariat\",\"private property\",\"cultural group selection\",\"dispersed knowledge\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"neoclassical liberalism\",\"friedrich hayek\",\"visible hand (economics)\",\"criticism of capitalism\",\"econophysics\",\"eco-capitalism\",\"free migration\",\"kenneth arrow\",\"implicit cost\",\"regulatory economics\",\"law of equal liberty\",\"consumer class\",\"john hicks\",\"social liberalism\",\"lawrence summers\",\"utility\",\"ak model\",\"list of liberal theorists\",\"macroeconomic model\",\"sociological positivism\",\"history of capitalist theory\",\"paul romer\",\"consumer debt\",\"participism\",\"attention economy\",\"economic indicator\",\"poverty class\",\"robert heilbroner\",\"index (economics)\",\"accelerator effect\",\"new institutional economics\",\"the counter-revolution of science\",\"glossary of economics\",\"diminishing returns\",\"anglo-saxon model\",\"zombie liberalism\",\"free market fairness\",\"frente despertar\",\"the american journal of economics and sociology\",\"service economy\",\"is\\u2013lm model\",\"list of important publications in economics\",\"authoritarian capitalism\",\"people\",\"history of microeconomics\",\"information economics\",\"bengt holmstr\\u00f6m\",\"public economics\",\"experimental economics\",\"social cost\",\"prediction market\",\"night-watchman state\",\"rationalism\",\"atlanticism\",\"william vickrey\",\"phillips curve\",\"vernon l. smith\",\"finance & development\",\"purchasing power parity\",\"trygve haavelmo\",\"index of sociopolitical thinkers\",\"evolutionary game theory\",\"efficiency wage\",\"consumer sovereignty\",\"index of economics articles\",\"financial economics\",\"sequential game\",\"reciprocity (cultural anthropology)\",\"homo economicus\",\"thomas schelling\",\"feminist theory\",\"list of unsolved problems in economics\",\"superrationality\",\"arrow's impossibility theorem\",\"daniel kahneman\",\"cultural anthropology\",\"induced consumption\",\"autonomous consumption\",\"paul milgrom\",\"william vickrey\",\"names for the human species\",\"kenneth arrow\",\"consumer debt\",\"ideal type\",\"john harsanyi\",\"people\",\"heterotopia (space)\",\"anti-psychiatry\",\"heterotopia (space)\",\"sascha altman dubrul\",\"medicalization\",\"list of psychological schools\",\"harvey jackins\",\"mad pride\",\"american association for the abolition of involuntary mental hospitalization\",\"social model of disability\",\"psychoanalysis\",\"law of the instrument\",\"eating disorder\",\"list of psychiatric medications by condition treated\",\"dsm-iv codes\",\"timeline of psychology\",\"list of neurological conditions and disorders\",\"crazy therapies\",\"list of psychiatric medications\",\"radical psychology network\",\"total institution\",\"hong kong college of psychiatrists\",\"the independent review\",\"anti-psychiatry\",\"mindfreedom international\",\"list of mental disorders\",\"learning\",\"psychoanalytic theory\",\"timeline of psychotherapy\",\"autonomous communities of spain\",\"interactionism\",\"list of social democratic parties\",\"the rich get richer and the poor get poorer\",\"base and superstructure\",\"blood and soil\",\"status group\",\"nanosocialism\",\"keynesian cross\",\"religious communism\",\"outline of culture\",\"anarcho-capitalism\",\"venture capital in spaceflight\",\"manifest and latent functions and dysfunctions\",\"frankfurt declaration\",\"marxist sociology\",\"list of left-wing internationals\",\"university of chicago institute of politics\",\"foreclosure rescue\",\"social complexity\",\"hong kong honours system\",\"legal naturalism\",\"sociology of punishment\",\"womyn's land\",\"social media use by donald trump\",\"psychogeography\",\"solow\\u2013swan model\",\"ecofeminism\",\"enterprise theory\",\"control theory (sociology)\",\"feminist theory\",\"social reality\",\"european sociological association\",\"sociology of manchester\",\"richard dawkins\",\"dark figure of crime\",\"ucla luskin school of public affairs\",\"donor class\",\"microsociology\",\"solitary confinement\",\"national communism\",\"surplus value\",\"marginalism\",\"production for profit\",\"identity (social science)\",\"reproduction (economics)\",\"relational sociology\",\"shale band\",\"crypto-communism\",\"oligarchy\",\"edward j. bloustein school of planning and public policy\",\"sedentism\",\"dictatorship of the proletariat\",\"cultural group selection\",\"robert f. wagner graduate school of public service\",\"world revolution\",\"left communism\",\"social service review\",\"workplace democracy\",\"ramsey\\u2013cass\\u2013koopmans model\",\"sociology in poland\",\"edinburgh university socialist society\",\"anthropological criminology\",\"visible hand (economics)\",\"situationist international\",\"criticism of capitalism\",\"comunismo a la tica\",\"blavatnik school of government\",\"index of sociology articles\",\"sociology in japan\",\"google finance\",\"ethical socialism\",\"concentrated disadvantage\",\"outline of anarchism\",\"business oligarch\",\"nur f\\u00fcr deutsche\",\"challengeaccepted\",\"structural violence\",\"bertrand russell\",\"average joe\",\"computational sociology\",\"sociology of scientific ignorance\",\"person\",\"collective mental state\",\"surplus labour\",\"daphne dorman\",\"proletarian revolution\",\"business magnate\",\"astrosociology\",\"nw 39th street enclave\",\"biosocial criminology\",\"consumer class\",\"history of communism\",\"communism and lgbt rights\",\"john hicks\",\"administrative divisions of portugal\",\"agency (sociology)\",\"evolutionary studies institute\",\"broken windows theory\",\"an anarchist faq\",\"macroeconomic model\",\"organizational theory\",\"sociological positivism\",\"john rawls\",\"history of social democracy\",\"consumer debt\",\"figurational sociology\",\"social conservatism\",\"scare\",\"dyad (sociology)\",\"biological anthropology\",\"accelerator effect\",\"degrowth\",\"christian communism\",\"housing affordability index\",\"aromanian question\",\"sociology of morality\",\"moral entrepreneur\",\"f\\u00fchrer\",\"symbolic religiosity\",\"field theory (sociology)\",\"cultural radicalism\",\"social reproduction\",\"social corporatism\",\"history of democratic socialism\",\"ethnoornithology\",\"microgeneration\",\"medical sociologist\",\"gochisosama\",\"institution\",\"per capita personal income in the united states\",\"group threat theory\",\"is\\u2013lm model\",\"asabiyyah\",\"industrial democracy\",\"murfee\",\"religious socialism\",\"social conflict\",\"people\",\"communist era\",\"sex and gender distinction\",\"grab em by the pussy\",\"upper class\",\"voluntary society\",\"value-added theory\",\"international energy agency\",\"official cantonese translations of english names for british officials\",\"bibliography of sociology\",\"list of sociology journals\",\"causes of transsexuality\",\"social experiment\",\"action theory (sociology)\",\"bibliography of works about communism\",\"sanford school of public policy\",\"real socialism\",\"concession (contract)\",\"mudsill theory\",\"magnate\",\"phillips curve\",\"recuperation (politics)\",\"taxation in uruguay\",\"value product\",\"research papers in economics\",\"jel classification codes\",\"policy sciences\",\"eugene fama\",\"indian economic and social history review\",\"michael spence\",\"oligarchy\",\"intelligence\",\"index of social and political philosophy articles\",\"majoritarianism\",\"the rich get richer and the poor get poorer\",\"scientocracy\",\"list of liberal theorists\",\"one-party state\",\"history of social democracy\",\"ethnarch\",\"regional power\",\"tyranny of the majority\",\"hoi polloi\",\"kyklos\",\"donor class\",\"great power\",\"constitutional dictatorship\",\"authoritarian democracy\",\"polyarchy\",\"particracy\",\"bankocracy\",\"oligarchy\",\"authoritarian capitalism\",\"statism\",\"business magnate\",\"futarchy\",\"soft despotism\",\"upper class\",\"iron cage\",\"enlightened absolutism\",\"civilization state\",\"corporate republic\",\"dependent territory\",\"ecoauthoritarianism\",\"night-watchman state\",\"criticism of capitalism\",\"index of sociology articles\",\"business oligarch\",\"magnate\",\"timocracy\",\"legalism (chinese philosophy)\",\"synarchism\",\"dictablanda\",\"intelligence quotient\",\"interactionism\",\"echo chamber (media)\",\"paleoanthropology\",\"acceptance\",\"biology and sexual orientation\",\"gratitude\",\"rage (emotion)\",\"general knowledge\",\"pattern recognition (psychology)\",\"resentment\",\"flashback (psychology)\",\"high policing\",\"piaget's theory of cognitive development\",\"hunting hypothesis\",\"hereditarianism\",\"cogito, ergo sum\",\"hermann lotze\",\"pathos\",\"swanson, nolan and pelham teacher and parent rating scale\",\"david marks (psychologist)\",\"dang guo\",\"harry harlow\",\"warrior\",\"outline of thought\",\"equal opportunity\",\"skhul and qafzeh hominins\",\"cognitivism (psychology)\",\"stimulation\",\"ernst mally\",\"scare\",\"list of futurama characters\",\"behavioral neuroscience\",\"identity (philosophy)\",\"race and intelligence\",\"occupational health psychology\",\"medical psychology\",\"homo faber\",\"confusion\",\"biological anthropology\",\"military policy\",\"security studies\",\"legal norm\",\"social reality\",\"psychohistory\",\"richard dawkins\",\"social cognition and interaction training\",\"early modern human\",\"daniel kahneman\",\"cognitive archaeology\",\"psychoanalytic theory\",\"affect (psychology)\",\"perpetual war\",\"intelligence\",\"conditioned emotional response\",\"organizational space\",\"human genetic variation\",\"bush school of government and public service\",\"pathognomy\",\"international journal of intelligence and counterintelligence\",\"per capita personal income in the united states\",\"cat intelligence\",\"transpersonal psychology\",\"list of psychological schools\",\"detection theory\",\"quantitative psychological research\",\"border outpost\",\"outline of psychology\",\"self-awareness\",\"gestalt psychology\",\"cultural group selection\",\"emotional selection\",\"women-are-wonderful effect\",\"david chalmers\",\"timeline of psychology\",\"computational theory of mind\",\"c. d. broad\",\"emotions in virtual communication\",\"task force\",\"hierarchical organization\",\"ethnoichthyology\",\"emotional reasoning\",\"abnormal psychology\",\"anguish\",\"emotionality\",\"list of psychological research methods\",\"music psychology\",\"schadenfreude\",\"wilhelm windelband\",\"index of sociology articles\",\"amusement\",\"moral emotions\",\"cultural movement\",\"logology (science)\",\"hostility\",\"bertrand russell\",\"average joe\",\"kindness\",\"pride\",\"learning\",\"history of anthropometry\",\"list of psychology organizations\",\"appraisal theory\",\"repertory grid\",\"synarchism\",\"biosocial criminology\",\"ceteris paribus\",\"natural capital\",\"john hicks\",\"economic base analysis\",\"economic model\",\"utility\",\"market anomaly\",\"robin hood effect\",\"joint product pricing\",\"import substitution industrialization\",\"indifference curve\",\"giffen good\",\"subsidy\",\"economic indicator\",\"assume a can opener\",\"economic graph\",\"consumer sovereignty\",\"georgism\",\"international economics\",\"economics terminology that differs from common usage\",\"arrow's impossibility theorem\",\"hotelling's law\",\"knowledge economy\",\"glossary of economics\",\"differentiated bertrand competition\",\"surplus value\",\"mainstream economics\",\"cournot competition\",\"marginalism\",\"ithaca hours\",\"edgeworth box\",\"fractional-reserve banking\",\"network effect\",\"identity economics\",\"harris\\u2013todaro model\",\"excess burden of taxation\",\"financial economics\",\"jel classification codes\",\"marginal rate of substitution\",\"intertemporal choice\",\"universe (economics)\",\"e. f. schumacher\",\"information economics\",\"intertemporal equilibrium\",\"appropriate technology\",\"public economics\",\"dispersed knowledge\",\"experimental economics\",\"social cost\",\"big push model\",\"ricardian equivalence\",\"cash crop\",\"gerschenkron effect\",\"list of unsolved problems in economics\",\"list of production functions\",\"factors of production\",\"opportunity cost\",\"risk premium\",\"kenneth arrow\",\"merger simulation\",\"phillips curve\",\"lorenz curve\",\"cobweb model\",\"purchasing power parity\",\"substitution effect\",\"labour voucher\",\"blue economy\",\"john hicks\",\"law of increasing costs\",\"financial economics\",\"principles of economics (marshall book)\",\"jel classification codes\",\"law of supply\",\"service economy\",\"economic model\",\"list of important publications in economics\",\"macroeconomic model\",\"keynesian cross\",\"e. f. schumacher\",\"information economics\",\"constitutional economics\",\"public economics\",\"economics (textbook)\",\"experimental economics\",\"economic indicator\",\"assume a can opener\",\"georgism\",\"big push model\",\"international economics\",\"charles henry hull\",\"institutionalist political economy\",\"feminist theory\",\"new institutional economics\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"inframarginal analysis\",\"opportunity cost\",\"knowledge economy\",\"factors of production\",\"glossary of economics\",\"kenneth arrow\",\"phillips curve\",\"diminishing returns\",\"convergence (economics)\",\"marginalism\",\"neo-ricardianism\",\"paradox of thrift\",\"fei\\u2013ranis model of economic growth\",\"labour voucher\",\"john hicks\",\"balassa\\u2013samuelson effect\",\"international sanctions\",\"economic model\",\"ak model\",\"macroeconomic model\",\"keynesian cross\",\"import substitution industrialization\",\"consumer debt\",\"leontief paradox\",\"economic indicator\",\"assume a can opener\",\"solow\\u2013swan model\",\"georgism\",\"international economics\",\"regulatory competition\",\"accelerator effect\",\"new institutional economics\",\"inframarginal analysis\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"impossible trinity\",\"marginalism\",\"communications management\",\"giancarlo corsetti\",\"american university school of international service\",\"organizational space\",\"bush school of government and public service\",\"fei\\u2013ranis model of economic growth\",\"blue economy\",\"law of increasing costs\",\"financial economics\",\"jel classification codes\",\"law of supply\",\"is\\u2013lm model\",\"service economy\",\"list of important publications in economics\",\"e. f. schumacher\",\"information economics\",\"outline of globalization\",\"public economics\",\"ramsey\\u2013cass\\u2013koopmans model\",\"experimental economics\",\"99ers\",\"big push model\",\"visible hand (economics)\",\"institutionalist political economy\",\"list of unsolved problems in economics\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"paul de grauwe\",\"opportunity cost\",\"kenneth arrow\",\"phillips curve\",\"convergence (economics)\",\"labour voucher\",\"blue economy\",\"john hicks\",\"law of increasing costs\",\"financial economics\",\"service economy\",\"law of supply\",\"economic model\",\"list of important publications in economics\",\"information economics\",\"public economics\",\"experimental economics\",\"economic indicator\",\"assume a can opener\",\"simulation modeling\",\"georgism\",\"big push model\",\"economics handbooks\",\"institutionalist political economy\",\"new institutional economics\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"inframarginal analysis\",\"opportunity cost\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"convergence (economics)\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"labour voucher\",\"john hicks\",\"economic model\",\"utility\",\"macroeconomic model\",\"keynesian cross\",\"attention economy\",\"economic indicator\",\"assume a can opener\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"accelerator effect\",\"new institutional economics\",\"inframarginal analysis\",\"daniel kahneman\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"cournot competition\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"blue economy\",\"journal of behavioral and experimental economics\",\"economic transformation\",\"law of increasing costs\",\"financial economics\",\"law of supply\",\"is\\u2013lm model\",\"service economy\",\"list of important publications in economics\",\"e. f. schumacher\",\"history of microeconomics\",\"information economics\",\"public economics\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"evolutionary game theory\",\"social cost\",\"big push model\",\"institutionalist political economy\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"econophysics\",\"opportunity cost\",\"logology (science)\",\"kenneth arrow\",\"behavior\",\"phillips curve\",\"economic data\",\"convergence (economics)\",\"georg weizs\\u00e4cker\",\"implicit cost\",\"vernon l. smith\",\"purchasing power parity\",\"labour voucher\",\"john hicks\",\"economic model\",\"utility\",\"macroeconomic model\",\"keynesian cross\",\"ronen palan\",\"attention economy\",\"journal of public economics\",\"eric french (professor)\",\"economic indicator\",\"assume a can opener\",\"bryan caplan\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"accelerator effect\",\"new institutional economics\",\"inframarginal analysis\",\"beatrice cherrier\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"marginalism\",\"communications management\",\"organizational space\",\"fei\\u2013ranis model of economic growth\",\"blue economy\",\"economic transformation\",\"law of increasing costs\",\"financial economics\",\"law of supply\",\"is\\u2013lm model\",\"service economy\",\"list of important publications in economics\",\"history of microeconomics\",\"information economics\",\"ramsey\\u2013cass\\u2013koopmans model\",\"secession\",\"99ers\",\"economics of science\",\"social cost\",\"big push model\",\"institutionalist political economy\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"econophysics\",\"opportunity cost\",\"william vickrey\",\"phillips curve\",\"convergence (economics)\",\"implicit cost\",\"purchasing power parity\",\"labour voucher\",\"john hicks\",\"lawrence summers\",\"economic model\",\"bowley's law\",\"ak model\",\"utility\",\"macroeconomic model\",\"keynesian cross\",\"paul romer\",\"consumer debt\",\"attention economy\",\"economic indicator\",\"hicks-tinbergen award\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"accelerator effect\",\"new institutional economics\",\"inframarginal analysis\",\"daniel kahneman\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"blue economy\",\"economic transformation\",\"law of increasing costs\",\"financial economics\",\"hicks-neutral technical change\",\"law of supply\",\"is\\u2013lm model\",\"service economy\",\"list of important publications in economics\",\"e. f. schumacher\",\"history of microeconomics\",\"paul milgrom\",\"information economics\",\"bengt holmstr\\u00f6m\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"social cost\",\"big push model\",\"visible hand (economics)\",\"institutionalist political economy\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"econophysics\",\"opportunity cost\",\"william vickrey\",\"kenneth arrow\",\"phillips curve\",\"convergence (economics)\",\"implicit cost\",\"vernon l. smith\",\"purchasing power parity\",\"trygve haavelmo\",\"substitution effect\",\"labour voucher\",\"blue economy\",\"law of increasing costs\",\"financial economics\",\"law of supply\",\"service economy\",\"economic model\",\"list of important publications in economics\",\"information economics\",\"economic indicator\",\"georgism\",\"big push model\",\"institutionalist political economy\",\"new institutional economics\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"inframarginal analysis\",\"opportunity cost\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"convergence (economics)\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"renewable energy transition\",\"el centro integrado de technologia appropriada\",\"community-supported agriculture\",\"degrowth\",\"index of sociology articles\",\"e. f. schumacher\",\"jhai foundation\",\"glossary of economics\",\"capital cost\",\"appropriate technology\",\"centre for appropriate technology (australia)\",\"bipu\",\"sustainable energy\",\"microgeneration\",\"evolutionary game theory\",\"intensity of preference\",\"sequential game\",\"thomas schelling\",\"bertrand competition\",\"two-level game theory\",\"john rawls\",\"daniel kahneman\",\"hedonism\",\"paul milgrom\",\"william vickrey\",\"glossary of economics\",\"kenneth arrow\",\"catch-22\",\"bertrand paradox (economics)\",\"cournot competition\",\"giffen good\",\"john harsanyi\",\"glossary of economics\",\"open economy\",\"fei\\u2013ranis model of economic growth\",\"least developed countries\",\"decolonization\",\"index of sociology articles\",\"cash crop\",\"tobacco-free pharmacy\",\"price index\",\"ceteris paribus\",\"glossary of economics\",\"social geometry\",\"diminishing returns\",\"marginalism\",\"accelerator effect\",\"long-run cost curve\",\"utility\",\"substitution effect\",\"history of microeconomics\",\"economic model\",\"pork cycle\",\"induced consumption\",\"autonomous consumption\",\"dollar voting\",\"consumer debt\",\"evolutionary game theory\",\"daniel kahneman\",\"paul milgrom\",\"william vickrey\",\"kenneth arrow\",\"bertrand paradox (economics)\",\"merger simulation\",\"sequential game\",\"thomas schelling\",\"bertrand competition\",\"john harsanyi\",\"bertrand competition\",\"bertrand paradox (economics)\",\"merger simulation\",\"the counter-revolution of science\",\"the road to serfdom\",\"dollar voting\",\"index (economics)\",\"georgism\",\"lipstick index\",\"hemline index\",\"e. f. schumacher\",\"price index\",\"base period\",\"glossary of economics\",\"kenneth arrow\",\"economic data\",\"marginalism\",\"kiyotaki\\u2013moore model\",\"solow\\u2013swan model\",\"georgism\",\"financial economics\",\"michael albert\",\"is\\u2013lm model\",\"economic model\",\"macroeconomic model\",\"e. f. schumacher\",\"glossary of economics\",\"heckscher\\u2013ohlin model\",\"kenneth arrow\",\"phillips curve\",\"problems with economic models\",\"loopco\",\"marginalism\",\"ramsey\\u2013cass\\u2013koopmans model\",\"opportunity cost\",\"factors of production\",\"demand curve\",\"marginal propensity to consume\",\"robinson crusoe economy\",\"kenneth arrow\",\"edgeworth paradox\",\"self-defeating prophecy\",\"georgism\",\"ronen palan\",\"abilene paradox\",\"lump-sum tax\",\"leontief production function\",\"production\\u2013possibility frontier\",\"net national product\",\"solow\\u2013swan model\",\"base and superstructure\",\"bibliography of works about communism\",\"list of production functions\",\"history of microeconomics\",\"factors of production\",\"knowledge economy\",\"glossary of economics\",\"dictatorship of the proletariat\",\"diminishing returns\",\"heckscher\\u2013ohlin model\",\"marxist sociology\",\"circular flow of income\",\"marginal rate of transformation\",\"surplus value\",\"world revolution\",\"value product\",\"left communism\",\"long-run cost curve\",\"surplus labour\",\"marginal factor cost\",\"legal naturalism\",\"fei\\u2013ranis model of economic growth\",\"financial economics\",\"skew\",\"list of financial economists\",\"lawrence summers\",\"political risk\",\"utility\",\"equity premium puzzle\",\"marginal rate of substitution\",\"clive granger\",\"eugene fama\",\"e. f. schumacher\",\"binomial options pricing model\",\"risk factor (finance)\",\"pricing kernel\",\"arbitrage pricing theory\",\"volatility clustering\",\"forward premium anomaly\",\"contingent claim analysis\",\"jensen prize\",\"myron scholes\",\"real economy\",\"georgism\",\"low-volatility anomaly\",\"fischer black prize\",\"market microstructure\",\"glossary of economics\",\"equity home bias puzzle\",\"risk premium\",\"fama\\u2013french three-factor model\",\"kenneth arrow\",\"concentration risk\",\"st. petersburg paradox\",\"marginalism\",\"financial models with long-tailed distributions and volatility clustering\",\"state price density\",\"electronic funds transfer\",\"maturity transformation\",\"excess reserves\",\"hunter-gatherer\",\"labor theory of property\",\"natural capital\",\"democratic capitalism\",\"utility\",\"macroeconomic model\",\"keynesian cross\",\"participism\",\"attention economy\",\"manorialism\",\"bryan caplan\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"the great transformation (book)\",\"charles henry hull\",\"franz oppenheimer\",\"degrowth\",\"accelerator effect\",\"new institutional economics\",\"economic humanitarianism (ra\\u00eblianism)\",\"inframarginal analysis\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"theories of poverty\",\"marginalism\",\"neo-ricardianism\",\"law of rent\",\"economic transformation\",\"the american journal of economics and sociology\",\"civil libertarianism\",\"principles of economics (marshall book)\",\"service economy\",\"is\\u2013lm model\",\"list of important publications in economics\",\"public property\",\"in kind\",\"non-interventionism\",\"history of microeconomics\",\"constitutional economics\",\"private property\",\"grazing rights\",\"air rights\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"neoclassical liberalism\",\"corporatization\",\"social cost\",\"night-watchman state\",\"ralph borsodi\",\"econophysics\",\"law of equal liberty\",\"william vickrey\",\"eco-capitalism\",\"bertrand russell\",\"phillips curve\",\"implicit cost\",\"anarcho-capitalism\",\"purchasing power parity\",\"economic transformation\",\"purchasing power parity\",\"diamond-water paradox\",\"paradox of value\",\"lerner paradox\",\"history of microeconomics\",\"scitovsky paradox\",\"resource curse\",\"hedonism\",\"mandeville's paradox\",\"paradox of prosperity\",\"bertrand paradox (economics)\",\"catch-22\",\"indifference curve\",\"fenno's paradox\",\"downs\\u2013thomson paradox\",\"st. petersburg paradox\",\"icarus paradox\",\"paradox of thrift\",\"leontief paradox\",\"edgeworth paradox\",\"abilene paradox\",\"substitution effect\",\"bertrand paradox (economics)\",\"balassa\\u2013samuelson effect\",\"heckscher\\u2013ohlin model\",\"infant industry argument\",\"leontief paradox\",\"domestic trade\",\"economic nationalism\",\"convex preferences\",\"sunk cost\",\"utility\",\"marginal rate of substitution\",\"history of microeconomics\",\"opportunity cost\",\"information economics\",\"glossary of economics\",\"corner solution\",\"demand curve\",\"marginalism\",\"substitution effect\",\"utility\",\"intertemporal choice\",\"glossary of economics\",\"michael spence\",\"vernon l. smith\",\"network effect\",\"substitution effect\",\"keynes\\u2013ramsey rule\",\"history of microeconomics\",\"opportunity cost\",\"glossary of economics\",\"demand curve\",\"sunk cost\",\"utility\",\"marginal rate of substitution\",\"marginal propensity to consume\",\"utility\",\"labour voucher\",\"glossary of economics\",\"hunter-gatherer\",\"manorialism\",\"corporatization\",\"knowledge assessment methodology\",\"service economy\",\"conceptual economy\",\"in kind\",\"openness\",\"e. f. schumacher\",\"learning economy\",\"knowledge economy\",\"private property\",\"kenneth arrow\",\"marginalism\",\"communications management\",\"attention economy\",\"organizational space\",\"feldstein\\u2013horioka puzzle\",\"equity home bias puzzle\",\"revealed preference\",\"equity premium puzzle\",\"backus\\u2013kehoe\\u2013kydland puzzle\",\"net worth\",\"the elephant curve\",\"consumption distribution\",\"lorenz curve\",\"convex preferences\",\"production\\u2013possibility frontier\",\"utility\",\"marginal rate of transformation\",\"pricing kernel\",\"marginalism\",\"revealed preference\",\"fei\\u2013ranis model of economic growth\",\"robinson crusoe economy\",\"samuelson condition\",\"state price density\",\"substitution effect\",\"consumer class\",\"democratic capitalism\",\"utility\",\"macroeconomic model\",\"keynesian cross\",\"history of capitalist theory\",\"attention economy\",\"solow\\u2013swan model\",\"index (economics)\",\"diamond-water paradox\",\"charles henry hull\",\"accelerator effect\",\"paradox of value\",\"degrowth\",\"new institutional economics\",\"inframarginal analysis\",\"cato institute\",\"glossary of economics\",\"diminishing returns\",\"surplus value\",\"neo-ricardianism\",\"anglo-saxon model\",\"economic transformation\",\"privatism\",\"neo-capitalism\",\"principles of economics (marshall book)\",\"service economy\",\"is\\u2013lm model\",\"list of important publications in economics\",\"authoritarian capitalism\",\"history of microeconomics\",\"constitutional economics\",\"private property\",\"voluntary society\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"social cost\",\"visible hand (economics)\",\"criticism of capitalism\",\"econophysics\",\"opportunity cost\",\"eco-capitalism\",\"phillips curve\",\"st. petersburg paradox\",\"implicit cost\",\"anarcho-capitalism\",\"purchasing power parity\",\"momentum (finance)\",\"rate of return\",\"primary market\",\"low-volatility anomaly\",\"equity premium puzzle\",\"growth stock\",\"extended-hours trading\",\"risk factor (finance)\",\"arbitrage pricing theory\",\"alpha (finance)\",\"market trend\",\"natural capital\",\"rebound effect (conservation)\",\"sustainability and environmental management\",\"payment for ecosystem services\",\"degrowth\",\"ecological economics (journal)\",\"nayakrishi\",\"econophysics\",\"e. f. schumacher\",\"ecodynamics\",\"resource curse\",\"weak and strong sustainability\",\"eco-capitalism\",\"ecological anthropology\",\"circular flow of income\",\"cycle of poverty\",\"metcalfe's law\",\"heckscher\\u2013ohlin model\",\"social multiplier effect\",\"reed's law\",\"sailing ship effect\",\"utility\",\"beckstrom's law\",\"coal phase-out\",\"abnormal profit\",\"sunk cost\",\"is\\u2013lm model\",\"excess reserves\",\"utility\",\"guns versus butter model\",\"production\\u2013possibility frontier\",\"weighted average cost of capital\",\"efficiency wage\",\"consequentialist justifications of the state\",\"social cost\",\"opportunity cost\",\"glossary of economics\",\"diminishing returns\",\"media circus\",\"marginal rate of transformation\",\"implicit cost\",\"precautionary demand\",\"substitution effect\",\"proactive law\",\"beveridge curve\",\"gold-collar worker\",\"is\\u2013lm model\",\"ak model\",\"macroeconomic model\",\"keynesian cross\",\"e. f. schumacher\",\"consumer debt\",\"equal opportunity\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"discouraged worker\",\"solow\\u2013swan model\",\"occupational health psychology\",\"visible hand (economics)\",\"triangle model\",\"accelerator effect\",\"kenneth arrow\",\"national average salary\",\"world economy\",\"real economy\",\"poverty class\",\"balassa\\u2013samuelson effect\",\"bric\",\"index (economics)\",\"index of sociology articles\",\"economic power\",\"development geography\",\"e. f. schumacher\",\"price index\",\"glossary of economics\",\"kenneth arrow\",\"heckscher\\u2013ohlin model\",\"wallace neutrality\",\"lawrence summers\",\"benjamin moll\",\"mesoeconomics\",\"weighted average cost of capital\",\"liquidity premium\",\"market-based valuation\",\"impossible trinity\",\"economic puzzle\",\"pricing kernel\",\"state price density\",\"equity premium puzzle\",\"arbitrage pricing theory\",\"kuznets curve\",\"social cost\",\"index of sociology articles\",\"e. f. schumacher\",\"kenneth arrow\",\"fei\\u2013ranis model of economic growth\",\"price support\",\"tax-allocation district\",\"rebound effect (conservation)\",\"sunk cost\",\"backward bending supply curve of labour\",\"list of important publications in economics\",\"utility\",\"history of microeconomics\",\"glossary of economics\",\"demand curve\",\"barracks communism\",\"consumer class\",\"history of communism\",\"base and superstructure\",\"democratic capitalism\",\"unearned income\",\"history of capitalist theory\",\"anarcho-capitalism\",\"john roemer\",\"marxist sociology\",\"enemy of the people (albania)\",\"new institutional economics\",\"commanding heights of the economy\",\"anglo-saxon model\",\"production for profit\",\"reproduction (economics)\",\"social order\",\"people's democracy (marxism\\u2013leninism)\",\"real-world economics review\",\"privatism\",\"neo-capitalism\",\"authoritarian capitalism\",\"dictatorship of the proletariat\",\"private property\",\"circular flow of income\",\"world revolution\",\"left communism\",\"visible hand (economics)\",\"criticism of capitalism\",\"enemy of the people\",\"index of sociology articles\",\"real socialism\",\"eco-capitalism\",\"surplus labour\",\"value product\",\"proletarian revolution\",\"sunk cost\",\"essence of decision\",\"list of important publications in economics\",\"detection theory\",\"e. f. schumacher\",\"superrationality\",\"economic satiation\",\"history of microeconomics\",\"heritage commodification\",\"demand curve\",\"reed's law\",\"pricing kernel\",\"workplace democracy\",\"samuelson condition\",\"ramsey\\u2013cass\\u2013koopmans model\",\"small office/home office\",\"dynamic pricing\",\"backward bending supply curve of labour\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"econophysics\",\"daniel kahneman\",\"glossary of economics\",\"kenneth arrow\",\"problems with economic models\",\"st. petersburg paradox\",\"revealed preference\",\"worker cooperative\",\"state price density\",\"convex preferences\",\"ap microeconomics\",\"law of increasing costs\",\"law of supply\",\"average fixed cost\",\"is\\u2013lm model\",\"service economy\",\"marginal propensity to consume\",\"e. f. schumacher\",\"guido tabellini\",\"base period\",\"price index\",\"circular flow of income\",\"demand curve\",\"equal opportunity\",\"average variable cost\",\"inventory bounce\",\"productive capacity\",\"autonomous consumption\",\"diminishing returns\",\"kenneth arrow\",\"capital cost\",\"deflator\",\"implicit cost\",\"time value of money\",\"leontief production function\",\"hicks-neutral technical change\",\"consumer class\",\"economic transformation\",\"service economy\",\"is\\u2013lm model\",\"list of important publications in economics\",\"macroeconomic model\",\"keynesian cross\",\"e. f. schumacher\",\"history of microeconomics\",\"white paper\",\"attention economy\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"solow\\u2013swan model\",\"index (economics)\",\"accelerator effect\",\"degrowth\",\"econophysics\",\"diminishing returns\",\"implicit cost\",\"worker cooperative\",\"microgeneration\",\"intensity of preference\",\"lawrence summers\",\"bertrand competition\",\"ak model\",\"list of liberal theorists\",\"macroeconomic model\",\"keynesian cross\",\"paul romer\",\"harry harlow\",\"attention economy\",\"solow\\u2013swan model\",\"index (economics)\",\"elhanan helpman\",\"accelerator effect\",\"daniel mcfadden\",\"daniel kahneman\",\"michael spence\",\"diminishing returns\",\"john harsanyi\",\"economists for peace and security\",\"economic transformation\",\"sequential game\",\"service economy\",\"is\\u2013lm model\",\"list of important publications in economics\",\"two-level game theory\",\"history of microeconomics\",\"paul milgrom\",\"bengt holmstr\\u00f6m\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"evolutionary game theory\",\"american recovery and reinvestment act of 2009\",\"w. kip viscusi\",\"econophysics\",\"william vickrey\",\"kenneth arrow\",\"bertrand paradox (economics)\",\"implicit cost\",\"vernon l. smith\",\"trygve haavelmo\",\"emic and etic\",\"paleoanthropology\",\"cognitive anthropology\",\"neuroanthropology\",\"asch conformity experiments\",\"alliance theory\",\"feminist anthropology\",\"linguistic description\",\"outline of culture\",\"linguistic anthropology\",\"culturgen\",\"applied anthropology research methods\",\"bibliography of anthropology\",\"value judgment\",\"henri poincar\\u00e9\",\"semiotic anthropology\",\"high culture\",\"cultural practice\",\"bioculture\",\"biological anthropology\",\"anthropology of art\",\"development anthropology\",\"transcultural nursing\",\"linguistic relativity\",\"reflexivity (social theory)\",\"welfare culture\",\"list of years in anthropology\",\"cultural nationalism\",\"cultural radicalism\",\"emotivism\",\"anthropology of institutions\",\"implicit-association test\",\"transnational progressivism\",\"online ethnography\",\"museum of mankind\",\"frustration\\u2013aggression hypothesis\",\"nutritional anthropology\",\"standard cross-cultural sample\",\"performance studies\",\"culture hero\",\"ecological anthropology\",\"culture theory\",\"cultural liberalism\",\"postmodernist anthropology\",\"cultural mapping\",\"index of sociology articles\",\"medical anthropology\",\"oikofobie. de angst voor het eigene\",\"cultural movement\",\"cultural anthropology\",\"social degeneration\",\"online ethnography\",\"paleoanthropology\",\"cognitive anthropology\",\"museum of mankind\",\"nutritional anthropology\",\"neuroanthropology\",\"alliance theory\",\"feminist anthropology\",\"standard cross-cultural sample\",\"performance studies\",\"linguistic description\",\"linguistic anthropology\",\"bibliography of anthropology\",\"ecological anthropology\",\"culture theory\",\"semiotic anthropology\",\"postmodernist anthropology\",\"biological anthropology\",\"anthropology of art\",\"development anthropology\",\"medical anthropology\",\"cultural anthropology\",\"reflexivity (social theory)\",\"behavior\",\"list of years in anthropology\",\"anthropology of institutions\",\"online ethnography\",\"paleoanthropology\",\"cognitive anthropology\",\"museum of mankind\",\"neuroanthropology\",\"nutritional anthropology\",\"chinese kinship\",\"feminist anthropology\",\"standard cross-cultural sample\",\"performance studies\",\"linguistic description\",\"psychoanalysis\",\"list of matrilineal or matrilocal societies\",\"mosuo women\",\"linguistic anthropology\",\"diane bell (anthropologist)\",\"bibliography of anthropology\",\"ecological anthropology\",\"classificatory kinship\",\"culture theory\",\"semiotic anthropology\",\"postmodernist anthropology\",\"patrilocal residence\",\"reciprocity (cultural anthropology)\",\"biological anthropology\",\"anthropology of art\",\"development anthropology\",\"medical anthropology\",\"australian aboriginal kinship\",\"anthropology of institutions\",\"matrilocal residence\",\"cultural anthropology\",\"reflexivity (social theory)\",\"list of years in anthropology\",\"polygyny\",\"paleoanthropology\",\"cognitive anthropology\",\"neuroanthropology\",\"feminist anthropology\",\"linguistic description\",\"non-representational theory\",\"development geography\",\"outline of culture\",\"linguistic anthropology\",\"culturgen\",\"bibliography of anthropology\",\"semiotic anthropology\",\"high culture\",\"psychogeography\",\"cultural practice\",\"bioculture\",\"biological anthropology\",\"anthropology of art\",\"development anthropology\",\"transcultural nursing\",\"reflexivity (social theory)\",\"das argument\",\"welfare culture\",\"list of years in anthropology\",\"cultural nationalism\",\"cultural radicalism\",\"anthropology of institutions\",\"transnational progressivism\",\"online ethnography\",\"museum of mankind\",\"nutritional anthropology\",\"health geography\",\"standard cross-cultural sample\",\"performance studies\",\"culture hero\",\"ecological anthropology\",\"geography of media and communication\",\"cultural liberalism\",\"postmodernist anthropology\",\"cultural mapping\",\"medical anthropology\",\"cultural movement\",\"cultural anthropology\",\"social degeneration\",\"culture 21\",\"university of san diego\",\"online ethnography\",\"paleoanthropology\",\"cognitive anthropology\",\"museum of mankind\",\"neuroanthropology\",\"nutritional anthropology\",\"feminist anthropology\",\"standard cross-cultural sample\",\"performativity\",\"linguistic description\",\"psychoanalysis\",\"linguistic anthropology\",\"bibliography of anthropology\",\"ecological anthropology\",\"semiotic anthropology\",\"performance\",\"postmodernist anthropology\",\"biological anthropology\",\"anthropology of art\",\"development anthropology\",\"medical anthropology\",\"cultural anthropology\",\"reflexivity (social theory)\",\"list of years in anthropology\",\"anthropology of institutions\",\"theatre state\",\"paleoanthropology\",\"nomads of the longbow\",\"feminist anthropology\",\"human terrain system\",\"outline of culture\",\"culturgen\",\"diane bell (anthropologist)\",\"mosuo women\",\"bibliography of anthropology\",\"heritage commodification\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"marxist sociology\",\"classificatory kinship\",\"peasant economics\",\"sociology of punishment\",\"cultural practice\",\"the great transformation (book)\",\"bioculture\",\"development anthropology\",\"proverbial phrase\",\"matrilocal residence\",\"indian sociological society\",\"welfare culture\",\"cultural nationalism\",\"polygyny\",\"transnational progressivism\",\"nutritional anthropology\",\"human universals\",\"circumscription theory\",\"sedentism\",\"culture hero\",\"human ethology\",\"list of visual anthropology films\",\"johnson cult\",\"cultural liberalism\",\"critical medical anthropology\",\"muted group theory\",\"museo de antropolog\\u00eda de xalapa\",\"museum of archaeology and anthropology, university of cambridge\",\"family disruption\",\"nanook of the north\",\"historical behaviour studies\",\"reciprocity (cultural anthropology)\",\"museo nacional de antropolog\\u00eda (madrid)\",\"cultural movement\",\"social degeneration\",\"history of anthropometry\",\"astrosociology\",\"anthropological index online\",\"ceremonial pole\",\"cognitive anthropology\",\"age set\",\"chinese kinship\",\"society for medical anthropology\",\"aparna rao\",\"the hunters (1957 film)\",\"high culture\",\"patrilocal residence\",\"anthropology of art\",\"transcultural nursing\",\"australian aboriginal kinship\",\"emotive (sociology)\",\"eco-nationalism\",\"nomadic pastoralism\",\"cultural radicalism\",\"anthropological survey of india\",\"medical sociologist\",\"f. g. bailey\",\"shell money\",\"standard cross-cultural sample\",\"list of matrilineal or matrilocal societies\",\"ecological anthropology\",\"multimodal anthropology\",\"biocultural anthropology\",\"disability anthropology\",\"cultural resource management\",\"obscurantism\",\"cultural mapping\",\"leveling mechanism\",\"medical anthropology\",\"cultural anthropology\",\"logology (science)\",\"semiotic anthropology\",\"performance\",\"theory of language\",\"linguistic relativity\",\"bibliography of anthropology\",\"identity (social science)\",\"osteology\",\"paleoanthropology\",\"cognitive anthropology\",\"zooarchaeology\",\"craig stanford\",\"human behavioral ecology\",\"bibliography of anthropology\",\"cultural group selection\",\"biocultural anthropology\",\"heel\\u2013ball index\",\"medical anthropology\",\"richard dawkins\",\"secular variation\",\"forensic facial reconstruction\",\"cha\\u00eene op\\u00e9ratoire\",\"history of anthropometry\",\"fordisc\",\"paleopathology\",\"hunter-gatherer\",\"modern liberalism in the united states\",\"institution\",\"collective effervescence\",\"social organization\",\"social liberalism\",\"nanosocialism\",\"blau space\",\"cultural liberalism\",\"museo de antropolog\\u00eda de xalapa\",\"museum of archaeology and anthropology, university of cambridge\",\"nanook of the north\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"the hunters (1957 film)\",\"list of visual anthropology films\",\"laura boulton\",\"museo de antropolog\\u00eda de xalapa\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"museum of archaeology and anthropology, university of cambridge\",\"the hunters (1957 film)\",\"nanook of the north\",\"moana (1926 film)\",\"list of visual anthropology films\",\"museo de antropolog\\u00eda de xalapa\",\"museum of archaeology and anthropology, university of cambridge\",\"the hunters (1957 film)\",\"list of visual anthropology films\",\"nutritional anthropology\",\"shell money\",\"the great transformation (book)\",\"reciprocity (cultural anthropology)\",\"development anthropology\",\"sedentism\",\"heritage commodification\",\"decolonization\",\"nomadic pastoralism\",\"peasant economics\",\"sedentism\",\"heritage commodification\",\"nutritional anthropology\",\"shell money\",\"the great transformation (book)\",\"reciprocity (cultural anthropology)\",\"peasant economics\",\"nutritional anthropology\",\"shell money\",\"the great transformation (book)\",\"reciprocity (cultural anthropology)\",\"sedentism\",\"heritage commodification\",\"sedentism\",\"heritage commodification\",\"nutritional anthropology\",\"shell money\",\"reciprocity (cultural anthropology)\",\"the great transformation (book)\",\"code of hammurabi\",\"intelligence quotient\",\"cognitive anthropology\",\"critical medical anthropology\",\"the great transformation (book)\",\"reciprocity (cultural anthropology)\",\"society for medical anthropology\",\"medical anthropology\",\"sedentism\",\"heritage commodification\",\"food sovereignty\",\"travel behavior\",\"the great transformation (book)\",\"reciprocity (cultural anthropology)\",\"sedentism\",\"honeymoon\",\"list of birds displaying homosexual behavior\",\"female promiscuity\",\"chinese kinship\",\"international security\",\"feminist anthropology\",\"human behavioral ecology\",\"bay'ah\",\"homosexual behavior in animals\",\"raptio\",\"list of matrilineal or matrilocal societies\",\"mosuo women\",\"diane bell (anthropologist)\",\"classificatory kinship\",\"menstruation in islam\",\"patrilocal residence\",\"family disruption\",\"list of mammals displaying homosexual behavior\",\"index of sociology articles\",\"heterosociality\",\"islamic funeral\",\"australian aboriginal kinship\",\"early social changes under islam\",\"matrilocal residence\",\"promiscuity\",\"wedding\",\"islamic sexual jurisprudence\",\"islamic toilet etiquette\",\"fiqh\",\"mahr\",\"polygyny\",\"ecofeminism\",\"patrilocal residence\",\"chinese kinship\",\"michelle rosaldo book prize\",\"feminist theory\",\"woman, culture, and society\",\"australian aboriginal kinship\",\"matrilocal residence\",\"list of matrilineal or matrilocal societies\",\"mosuo women\",\"diane bell (anthropologist)\",\"classificatory kinship\",\"valerie bryson\",\"gender essentialism\",\"jacqueline rose\",\"psychoanalysis\",\"statism\",\"sex and gender distinction\",\"women-are-wonderful effect\",\"anti-gender movement\",\"muted group theory\",\"ecofeminism\",\"feminist legal theory\",\"feminist theory\",\"challengeaccepted\",\"right-wing politics\",\"oppression\",\"pride\",\"critical medical anthropology\",\"society for medical anthropology\",\"medical anthropology\",\"security studies\",\"society for medical anthropology\",\"medical anthropology\",\"rudolf virchow award\",\"medical anthropology\",\"naturalistic disease theories\",\"medicalization\",\"health policy\",\"rudolf virchow award\",\"critical security studies\",\"population health policies and interventions\",\"population health\",\"health system\",\"food processing\",\"ecological anthropology\",\"medical sociologist\",\"disability anthropology\",\"participatory theory\",\"behavioral neuroscience\",\"list of psychological schools\",\"altered state of consciousness\",\"psychoanalysis\",\"gaia philosophy\",\"outline of psychology\",\"daniel kahneman\",\"harry harlow\",\"history of psychotherapy\",\"quantitative research\",\"levitation (paranormal)\",\"timeline of psychology\",\"spirituality\",\"theatre state\",\"f. g. bailey\",\"leveling mechanism\",\"circumscription theory\",\"johnson cult\",\"theatre state\",\"f. g. bailey\",\"circumscription theory\",\"johnson cult\",\"f. g. bailey\",\"roman question\",\"circumscription theory\",\"johnson cult\",\"f. g. bailey\",\"johnson cult\",\"johnson cult\",\"zooarchaeology\",\"ethnolichenology\",\"porter hypothesis\",\"ethnoichthyology\",\"greenwashing\",\"psychogeography\",\"ecofeminism\",\"urban metabolism\",\"biophilia hypothesis\",\"payment for ecosystem services\",\"degrowth\",\"ecomodernism\",\"queer ecology\",\"ethnoornithology\",\"soul\",\"ceremonial pole\",\"biocultural diversity\",\"biosocial criminology\",\"osteology\",\"maceration (bone)\",\"zooarchaeology\",\"arthur evans\",\"forensic facial reconstruction\",\"behavioral pharmacology\",\"paleopathology\",\"evolutionary game theory\",\"darwinian anthropology\",\"microsociology\",\"human universals\",\"learning\",\"richard dawkins\",\"list of women anthropologists\",\"prickly paradigm press\",\"human universals\",\"edvard westermarck\",\"the protestant ethic and the spirit of capitalism\",\"richard dawkins\",\"deep play: notes on the balinese cockfight\",\"the hebrew goddess\",\"transnational progressivism\",\"high culture\",\"cultural mapping\",\"cultural practice\",\"cultural radicalism\",\"transcultural nursing\",\"cultural movement\",\"outline of culture\",\"culturgen\",\"welfare culture\",\"culture hero\",\"social degeneration\",\"cultural nationalism\",\"cultural liberalism\",\"transnational progressivism\",\"antipositivism\",\"sociological positivism\",\"outline of culture\",\"culturgen\",\"culture hero\",\"quantitative research\",\"cultural liberalism\",\"high culture\",\"social experiment\",\"cultural practice\",\"transcultural nursing\",\"cultural movement\",\"cultural nationalism\",\"welfare culture\",\"social degeneration\",\"cultural radicalism\",\"transnational progressivism\",\"high culture\",\"cultural practice\",\"cultural movement\",\"outline of culture\",\"culturgen\",\"cultural nationalism\",\"welfare culture\",\"social degeneration\",\"cultural radicalism\",\"cultural liberalism\",\"transnational progressivism\",\"shock value\",\"cultural radicalism\",\"general knowledge\",\"outline of culture\",\"culturgen\",\"culture hero\",\"upper class\",\"collaboration\",\"cultural liberalism\",\"middlebrow\",\"high culture\",\"cultural practice\",\"hoi polloi\",\"cultural movement\",\"welfare culture\",\"social degeneration\",\"cultural nationalism\",\"transnational progressivism\",\"cultural radicalism\",\"cultural movement\",\"outline of culture\",\"culturgen\",\"welfare culture\",\"culture hero\",\"social degeneration\",\"cultural nationalism\",\"cultural liberalism\",\"transnational progressivism\",\"civil libertarianism\",\"social liberalism\",\"list of liberal theorists\",\"outline of culture\",\"culturgen\",\"private property\",\"culture hero\",\"social conservatism\",\"whiggism\",\"modern liberalism in the united states\",\"cultural movement\",\"cultural nationalism\",\"welfare culture\",\"social degeneration\",\"cultural radicalism\",\"transnational progressivism\",\"noel ignatiev\",\"outline of culture\",\"culturgen\",\"culture hero\",\"neo-nationalism\",\"plurinationalism\",\"cultural movement\",\"welfare culture\",\"national conservatism\",\"social degeneration\",\"cultural radicalism\",\"transnational progressivism\",\"cultural movement\",\"outline of culture\",\"culturgen\",\"welfare culture\",\"culture hero\",\"social degeneration\",\"transnational progressivism\",\"echo chamber (media)\",\"majoritarianism\",\"self-deception\",\"brainwashing\",\"outline of culture\",\"culturgen\",\"culture hero\",\"social actions\",\"unitarian universalism\",\"identity (philosophy)\",\"reductionism\",\"collective effervescence\",\"rationalism\",\"social reality\",\"hedonism\",\"welfare culture\",\"peer pressure\",\"social degeneration\",\"we don't coast\",\"abilene paradox\",\"transnational progressivism\",\"outline of culture\",\"culturgen\",\"welfare culture\",\"social degeneration\",\"transnational progressivism\",\"richard dawkins\",\"outline of culture\",\"welfare culture\",\"social degeneration\",\"transnational progressivism\",\"lawrence summers\",\"outline of culture\",\"social degeneration\",\"cycle of poverty\",\"wedding reception\",\"family disruption\",\"consummation\",\"white wedding\",\"heterosociality\",\"raptio\",\"wedding\",\"wedding vow renewal ceremony\",\"ceremony\",\"fiqh\",\"gate crashing\",\"mahr\",\"honeymoon\",\"security sector governance and reform\",\"the twenty years' crisis\",\"violent non-state actor\",\"security studies (journal)\",\"groupism\",\"international security\",\"high and low politics\",\"security studies\",\"democratic peace theory\",\"high policing\",\"primakov readings\",\"patrilocal residence\",\"zooarchaeology\",\"paleoradiology\",\"arthur evans\",\"endocast\",\"history of anthropometry\",\"hunting hypothesis\",\"ferdinand de saussure\",\"reductionism\",\"theory of language\",\"gaia philosophy\",\"sex and gender distinction\",\"bertrand russell\",\"cultural group selection\",\"bicameral mentality\",\"cosmos and psyche\",\"learning\",\"richard wiseman\",\"complex adaptive system\",\"biosocial criminology\",\"evolutionary game theory\",\"the counter-revolution of science\",\"asch conformity experiments\",\"joint attention\",\"the road to serfdom\",\"biosocial criminology\",\"intelligence quotient\",\"kalergi plan\",\"hereditarianism\",\"david marks (psychologist)\",\"far-right politics\",\"nations and iq\",\"learning\",\"human genetic variation\",\"evolutionary game theory\",\"human genetic clustering\",\"early modern human\",\"recent human evolution\",\"intelligence quotient\",\"index of psychometrics articles\",\"nations and iq\",\"multidimensional aptitude battery ii\",\"learning\",\"index of sociology articles\",\"sleep and learning\",\"behavioural despair test\",\"altered state of consciousness\",\"awareness\",\"kurt koffka medal\",\"nations and iq\",\"outline of thought\",\"cognitivism (psychology)\",\"hierarchical organization\",\"behavioral neuroscience\",\"music psychology\",\"jewish-palestinian living room dialogue group\",\"categorical perception\",\"learning\",\"organizational space\",\"wedding vow renewal ceremony\",\"wedding reception\",\"consummation\",\"honeymoon\",\"wedding vow renewal ceremony\",\"ceremony\",\"releasing the spirits: a balinese ceremony\",\"wedding vow renewal ceremony\",\"consummation\",\"honeymoon\",\"muhammad taqi usmani\",\"usul fiqh in ja'fari school\",\"bay'ah\",\"predictive policing\",\"malikism in algeria\",\"list of national legal systems\",\"inquisitorial system\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"thawri\",\"ghazi (warrior)\",\"islam and children\",\"awza'i\",\"feminist legal theory\",\"ahl al-hadith\",\"madhhab\",\"history of the legal profession\",\"syed hayatullah\",\"islamic sexual jurisprudence\",\"qazi syed inayatullah\",\"history of the american legal profession\",\"writ\",\"fiqh\",\"maxims of islamic law\",\"astrology\",\"mahr\",\"istihlal\",\"travel behavior\",\"wedding vow renewal ceremony\",\"consummation\",\"wedding vow renewal ceremony\",\"hunter-gatherer\",\"promiscuity\",\"list of birds displaying homosexual behavior\",\"female promiscuity\",\"homosexual behavior in animals\",\"islamic sexual jurisprudence\",\"men who have sex with men\",\"list of mammals displaying homosexual behavior\",\"edvard westermarck\",\"women who have sex with women\",\"sublimation (psychology)\",\"histrionic personality disorder\",\"eating disorder\",\"list of mental disorders\",\"emotionality\",\"pride\",\"psychoanalytic theory\",\"dsm-iv codes\",\"self-deception\",\"psychological evaluation\",\"prenatal hormones and sexual orientation\",\"men who have sex with men\",\"mania\",\"women who have sex with women\",\"fallen woman\",\"history of communism\",\"open economy\",\"zooarchaeology\",\"unplanned economies\",\"democratic capitalism\",\"service economy\",\"in kind\",\"grave goods\",\"list of stateless societies\",\"hunting hypothesis\",\"private property\",\"dynamic density\",\"robinson crusoe economy\",\"attention economy\",\"manorialism\",\"corporatization\",\"digging stick\",\"sympathetic magic\",\"index of sociology articles\",\"psychohistory\",\"urban revolution\",\"structural violence\",\"anglo-saxon model\",\"kalahari debate\",\"list of sociologists\",\"timeline of psychology\",\"women who have sex with women\",\"sublimation (psychology)\",\"islamic sexual jurisprudence\",\"biology and sexual orientation\",\"islamic sexual jurisprudence\",\"sublimation (psychology)\",\"life chances\",\"list of birds displaying homosexual behavior\",\"institution\",\"cat intelligence\",\"auditory hallucination\",\"aversives\",\"cognitive bias\",\"list of animals displaying homosexual behavior\",\"altered state of consciousness\",\"civic virtue\",\"substitutes for leadership theory\",\"reasoned action approach\",\"outline of psychology\",\"demonstration effect\",\"eating disorder\",\"outline of thought\",\"social actions\",\"hierarchical organization\",\"subconscious\",\"character computing\",\"abnormal psychology\",\"list of mammals displaying homosexual behavior\",\"confusion\",\"soul\",\"ecological psychology\",\"amusement\",\"hostility\",\"behavior\",\"communications management\",\"life-process model of addiction\",\"organizational space\",\"ferdinand de saussure\",\"theta criterion\",\"organicism\",\"communicative dynamism\",\"complex adaptive system\",\"literacy\",\"linguistic description\",\"logical form (linguistics)\",\"ferdinand de saussure\",\"general semantics\",\"linguistics in science fiction\",\"linguistic description\",\"bicameral mentality\",\"bertrand russell\",\"task force\",\"metalanguage\",\"land management\",\"music psychology\",\"control (management)\",\"communications management\",\"collaboration\",\"performativity\",\"organizational space\",\"hierarchical organization\",\"managerialism\",\"identity (philosophy)\",\"social experiment\",\"identity crisis\",\"responsibility\",\"collective mental state\",\"social complexity\",\"astrosociology\",\"identity (social science)\",\"general semantics\",\"public policy school\",\"edward j. bloustein school of planning and public policy\",\"population health policies and interventions\",\"cato institute\",\"health system\",\"population health\",\"personal life\",\"patient participation\",\"food processing\",\"health policy in bangladesh\",\"frank batten school of leadership and public policy\",\"multi-level governance\",\"robert m. la follette school of public affairs\",\"public policy doctrine\",\"population health\",\"food processing\",\"population health policies and interventions\",\"food processing\",\"blavatnik school of government\",\"population health policies and interventions\",\"soul\",\"shrunken head\",\"civilization in transition\",\"gratitude\",\"altered state of consciousness\",\"awareness\",\"out-of-body experience\",\"mars needs moms\",\"self-awareness\",\"cogito, ergo sum\",\"personhood\",\"hermann lotze\",\"inner peace\",\"answer to job\",\"david chalmers\",\"aion: researches into the phenomenology of the self\",\"unitarian universalism\",\"spirituality\",\"major depressive disorder\",\"ernst mally\",\"reductionism\",\"astrology\",\"identity (philosophy)\",\"british psychotherapy foundation\",\"soul\",\"moralia\",\"shadow (psychology)\",\"alchemical studies\",\"bertrand russell\",\"kindness\",\"global workspace theory\",\"marcellina (gnostic)\",\"marie-louise von franz\",\"gotai\",\"contemplation\",\"pitt rivers museum\",\"poverty class\",\"confucian classes\",\"status group\",\"warrior (character class)\",\"vertical mobility\",\"mudsill theory\",\"personhood\",\"kshatriya\",\"upper class\",\"underclass\",\"hoplology\",\"business magnate\",\"poverty class\",\"confucian classes\",\"status group\",\"vertical mobility\",\"rajputisation\",\"mudsill theory\",\"personhood\",\"kshatriya\",\"upper class\",\"underclass\",\"census of india prior to independence\",\"martial race\",\"business magnate\",\"poverty class\",\"confucian classes\",\"social experiment\",\"status group\",\"vertical mobility\",\"personhood\",\"upper class\",\"underclass\",\"astrosociology\",\"social complexity\",\"business magnate\",\"poverty class\",\"confucian classes\",\"the rich get richer and the poor get poorer\",\"status group\",\"vertical mobility\",\"business oligarch\",\"personhood\",\"magnate\",\"upper class\",\"underclass\",\"business magnate\",\"pitt rivers museum\",\"decoloniality\",\"grave goods\",\"hunting hypothesis\",\"serer people\",\"spirituality\",\"hunting hypothesis\",\"religious literacy\",\"obscurantism\",\"contemplation\",\"consumer class\",\"museum of world culture\",\"flow (psychology)\",\"gratitude\",\"ecofeminism\",\"wilhelm windelband\",\"heide g\\u00f6ttner-abendroth\",\"awareness\",\"mediumship\",\"gaia philosophy\",\"bertrand russell\",\"kindness\",\"inner peace\",\"levitation (paranormal)\",\"workplace democracy\",\"dark triad\",\"timeline of psychotherapy\",\"astrology\",\"unitarian universalism\",\"naturalistic disease theories\",\"psychological trauma\",\"auspicious wedding dates\",\"urban legend\",\"scare\",\"neglect\",\"medicalization\",\"confusion\",\"destabilisation\",\"internal family systems model\",\"emotional abuse\",\"creativity and mental health\",\"psychoanalysis\",\"social dominance orientation\",\"blacklisting\",\"oppression\",\"waking the tiger\",\"urban legend\",\"shock value\",\"communal reinforcement\",\"kalergi plan\",\"proverb\",\"rumor\",\"transfer (propaganda)\",\"cover-up\",\"mediumship\",\"lady wonder\",\"slogan\",\"media circus\",\"history of propaganda\",\"levitation (paranormal)\",\"automatic writing\",\"astrology\",\"urban legend\",\"people power\",\"interactionism\",\"autogenic training\",\"civilization in transition\",\"antipositivism\",\"information metabolism\",\"ernest jones\",\"sex and reason\",\"peter sloterdijk\",\"acceptance and commitment therapy\",\"feeling good: the new mood therapy\",\"martti olavi siirala\",\"list of psychiatric medications by condition treated\",\"dsm-iv codes\",\"chiara bottici\",\"list of neurological conditions and disorders\",\"major depressive disorder\",\"helene deutsch\",\"list of schools of psychoanalysis\",\"entitlement\",\"british psychotherapy foundation\",\"renata salecl\",\"hong kong college of psychiatrists\",\"psychohistory\",\"chaining\",\"social cognition and interaction training\",\"id, ego and super-ego\",\"mortido\",\"list of mental disorders\",\"psychological resistance\",\"psychoanalytic theory\",\"egosyntonic and egodystonic\",\"ferdinand de saussure\",\"conversational model\",\"list of psychological schools\",\"jacqueline rose\",\"performativity\",\"behaviour therapy\",\"psychoanalysis\",\"outline of psychology\",\"on narcissism\",\"eating disorder\",\"hypnosis\",\"journal of the american psychoanalytic association\",\"timeline of psychology\",\"aion: researches into the phenomenology of the self\",\"structuration theory\",\"list of psychiatric medications\",\"catharsis\",\"shadow (psychology)\",\"defence mechanism\",\"freud's seduction theory\",\"adlerian\",\"object relations theory\",\"preconscious\",\"history of psychotherapy\",\"psychological evaluation\",\"making peace\",\"mourning and melancholia\",\"university of san diego\",\"franciscan school of theology\",\"ecological psychology\",\"literacy\",\"multiliteracy\",\"acceptance\",\"interprovincial migration in canada\",\"antipositivism\",\"gratitude\",\"scientocracy\",\"rage (emotion)\",\"sociological positivism\",\"resentment\",\"development geography\",\"least developed countries\",\"pathos\",\"nations and iq\",\"the engineering of consent\",\"word gap\",\"quiet revolution\",\"stimulation\",\"scare\",\"double hermeneutic\",\"confusion\",\"conceptual economy\",\"psychological nativism\",\"affect (psychology)\",\"science diplomacy\",\"pathognomy\",\"regulation of science\",\"literacy\",\"history of science policy\",\"decolonization\",\"kriza j\\u00e1nos ethnographic society\",\"emotional selection\",\"emotions in virtual communication\",\"proactive law\",\"cycle of poverty\",\"emotional reasoning\",\"anguish\",\"economics of science\",\"history of dyslexia research\",\"mapping controversies\",\"emotionality\",\"schadenfreude\",\"wilhelm windelband\",\"index of sociology articles\",\"amusement\",\"moral emotions\",\"sociotechnology\",\"logology (science)\",\"hostility\",\"kindness\",\"sociology of scientific ignorance\",\"pride\",\"appraisal theory\",\"racial literacy\",\"normalization process theory\",\"vocabulary development\",\"outline of psychology\",\"task analysis\",\"list of psychological schools\",\"poppet\",\"consumer class\",\"list of matrilineal or matrilocal societies\",\"gender and development\",\"women-are-wonderful effect\",\"levitation (paranormal)\",\"ecoauthoritarianism\",\"greenwashing\",\"psychogeography\",\"ecofeminism\",\"feminist legal theory\",\"biophilia hypothesis\",\"degrowth\",\"riane eisler\",\"ecomodernism\",\"gaia philosophy\",\"matrilocal residence\",\"queer ecology\",\"eco-capitalism\",\"eco-nationalism\",\"oppression\",\"gary l. francione\",\"microgeneration\",\"consensus democracy\",\"biophilia hypothesis\",\"situationist international\",\"the revolution of everyday life\",\"psychohistory\",\"non-representational theory\",\"ecomodernism\",\"social revolution\",\"queer ecology\",\"participism\",\"recuperation (politics)\",\"world revolution\",\"left communism\",\"anarcho-capitalism\",\"technobiophilia\",\"queer ecology\",\"ecomodernism\",\"ethnolichenology\",\"ethnoornithology\",\"zooarchaeology\",\"ethnoornithology\",\"zooarchaeology\",\"arthur evans\",\"food processing\",\"murray's hypocycloidal engine\",\"poppet\",\"situationist international\",\"participism\",\"industrial democracy\",\"socialist realism\",\"michael albert\",\"index of social and political philosophy articles\",\"brandalism\",\"consensus democracy\",\"new left review\",\"collaboration\",\"situationist international\",\"industrial democracy\",\"an anarchist faq\",\"the revolution of everyday life\",\"blanquism\",\"social revolution\",\"outline of anarchism\",\"proletarian revolution\",\"participism\",\"eastern bloc\",\"world revolution\",\"recuperation (politics)\",\"left communism\",\"list of left-wing internationals\",\"anarcho-capitalism\",\"worker cooperative\",\"socialist realism\",\"real socialism\",\"index of social and political philosophy articles\",\"social order\",\"socialist realism\",\"music and political warfare\",\"history of propaganda\",\"eastern bloc\",\"mandailing people\",\"koteka\",\"angkola people\",\"kluet people\",\"proto-malay\",\"minangkabau people\",\"resource curse\",\"ariane chebel d'appollonia\",\"international political sociology (ips)\",\"critical security studies\",\"security studies (journal)\",\"thomas schelling\",\"security studies\",\"malinda s. smith\",\"sedentism\",\"la borde clinic\",\"history of anthropometry\",\"john beddoe\",\"sinodonty and sundadonty\",\"negroid\",\"bertil lundman\",\"sinodonty and sundadonty\",\"history of anthropometry\",\"john beddoe\",\"martial race\",\"bertil lundman\",\"sinodonty and sundadonty\",\"history of anthropometry\",\"john beddoe\",\"martial race\",\"bertil lundman\",\"robert christison\",\"history of anthropometry\",\"martial race\",\"bertil lundman\",\"history of anthropometry\",\"martial race\",\"anthropological criminology\",\"anthropometric history\",\"cephalic index\",\"martial race\",\"liberal international order\",\"regional power\",\"bric\",\"liberalism and conservatism in latin america\",\"list of national independence days\",\"balkanization\",\"democratic peace theory\",\"food sovereignty\",\"least developed countries\",\"decolonization\",\"eastern bloc\",\"first world\",\"decoloniality\",\"secession\",\"heavily indebted poor countries\",\"superpower collapse\",\"bishop\\u2013cannings theorem\",\"biosocial criminology\",\"evolutionary game theory\",\"human genetic clustering\",\"sequential game\",\"thomas schelling\",\"bertrand competition\",\"two-level game theory\",\"daniel kahneman\",\"paul milgrom\",\"william vickrey\",\"bertrand paradox (economics)\",\"recent human evolution\",\"complex adaptive system\",\"john harsanyi\",\"online research methods\",\"mandailing people\",\"bumiputera (malaysia)\",\"minangkabau people\",\"social invisibility\",\"metcalfe's law\",\"assortative mixing\",\"weighted network\",\"social invisibility\",\"metcalfe's law\",\"weighted network\",\"metcalfe's law\",\"weighted network\",\"behavioral neuroscience\",\"detection theory\",\"neurophilosophy\",\"interpersonal neurobiology\",\"cognized environment\",\"eating disorder\",\"biological organisation\",\"list of psychological schools\",\"detection theory\",\"quantitative psychological research\",\"flashback (psychology)\",\"outline of psychology\",\"neurophilosophy\",\"interpersonal neurobiology\",\"gestalt psychology\",\"eating disorder\",\"swanson, nolan and pelham teacher and parent rating scale\",\"women-are-wonderful effect\",\"harry harlow\",\"quantitative research\",\"cognitivism (psychology)\",\"abnormal psychology\",\"occupational health psychology\",\"medical psychology\",\"list of psychological research methods\",\"music psychology\",\"models of abnormality\",\"psychohistory\",\"social cognition and interaction training\",\"daniel kahneman\",\"psychoanalytic theory\",\"list of psychology organizations\",\"repertory grid\",\"conditioned emotional response\",\"reductionism\",\"rationalism\",\"wilhelm windelband\",\"detection theory\",\"interpersonal neurobiology\",\"eating disorder\",\"bertrand russell\",\"instrumentalism\",\"sociology of scientific ignorance\",\"david chalmers\",\"henri poincar\\u00e9\",\"philosophical analysis\",\"computational theory of mind\",\"c. d. broad\",\"just-noticeable difference\",\"daniel kahneman\",\"interpersonal neurobiology\",\"eating disorder\",\"harry harlow\",\"sensory threshold\",\"quantitative research\",\"biosocial criminology\",\"pathognomy\",\"bibliography of sociology\",\"enterprise theory\",\"broken windows theory\",\"dark figure of crime\",\"solitary confinement\",\"recent human evolution\",\"acceptance\",\"gratitude\",\"rage (emotion)\",\"resentment\",\"pathos\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"neglect\",\"confusion\",\"emotionality\",\"schadenfreude\",\"wilhelm windelband\",\"amusement\",\"moral emotions\",\"facial expression\",\"hostility\",\"kindness\",\"pride\",\"affect (psychology)\",\"appraisal theory\",\"university of tennessee anthropological research facility\",\"exocannibalism\",\"public opinion quarterly\",\"linguistics in science fiction\",\"arthur evans\",\"garden of allah (cabaret)\",\"cooper do-nuts riot\",\"arthur evans\",\"high-altitude adaptation in humans\",\"andean civilizations\",\"early modern human\",\"recent human evolution\",\"kalergi plan\",\"blood and soil\",\"basket of deplorables\",\"service economy\",\"fourteen words\",\"statism\",\"trash doves\",\"national conservatism\",\"right-wing politics\",\"far-right politics\",\"plurinationalism\",\"manorialism\",\"corporatization\",\"conjoint analysis\",\"in kind\",\"private property\",\"underclass\",\"urban village\",\"transnational progressivism\",\"kalergi plan\",\"blood and soil\",\"law and order\",\"rationalism\",\"fourteen words\",\"white power music\",\"right-wing politics\",\"oppression\",\"far-right politics\",\"national communism\",\"organicism\",\"f\\u00fchrer\",\"christian fascism\",\"social conservatism\",\"social order\",\"law and order\",\"eurasianism\",\"ilminism\",\"one-party state\",\"maternalism\",\"private property\",\"right-wing politics\",\"national agrarian party\",\"plurinationalism\",\"social conservatism\",\"national liberalism\",\"enemy of the people\",\"antemurale myth\",\"economic nationalism\",\"eco-nationalism\",\"enemy of the people (albania)\",\"national communism\",\"social order\",\"statism\",\"authoritarian left\",\"conservative liberalism\",\"organicism\",\"conservative corporatism\",\"social conservatism\",\"ecoauthoritarianism\",\"whiggism\",\"public image of narendra modi\",\"small government\",\"spatial politics\",\"liberalism and conservatism in latin america\",\"liberal conservatism\",\"neoauthoritarianism (china)\",\"authoritarian capitalism\",\"one-party state\",\"soft despotism\",\"eastern bloc\",\"enlightened absolutism\",\"the road to serfdom\",\"corporate republic\",\"philosophy of max stirner\",\"ecoauthoritarianism\",\"whiggism\",\"fukoku ky\\u014dhei\",\"small government\",\"night-watchman state\",\"tyranny of the majority\",\"capitalist peace\",\"outline of anarchism\",\"corporate communication\",\"constitutional dictatorship\",\"authoritarian democracy\",\"dictablanda\",\"kalergi plan\",\"blood and soil\",\"basket of deplorables\",\"bumiputera (malaysia)\",\"fourteen words\",\"nur f\\u00fcr deutsche\",\"authoritarian democracy\",\"organicism\",\"f\\u00fchrer\",\"kalergi plan\",\"trash doves\",\"basket of deplorables\",\"communal reinforcement\",\"trash doves\",\"basket of deplorables\",\"trash doves\",\"mummy of san andr\\u00e9s\",\"upper class\",\"social order\",\"history of communism\",\"the rich get richer and the poor get poorer\",\"correspondence principle (sociology)\",\"vertical mobility\",\"garveyism\",\"index of sociology articles\",\"donor class\",\"business oligarch\",\"magnate\",\"social reproduction\",\"early modern human\",\"matrilocal residence\",\"self-awareness\",\"vocabulary development\",\"communal reinforcement\",\"shock value\",\"frustration\\u2013aggression hypothesis\",\"asch conformity experiments\",\"tyranny of the majority\",\"enemy of the people\",\"brainwashing\",\"index of sociology articles\",\"social dominance orientation\",\"blacklisting\",\"peer pressure\",\"enemy of the people (albania)\",\"timeline of psychology\",\"argument from authority\",\"people power\",\"implicit-association test\",\"biology and sexual orientation\",\"homosexual behavior in animals\",\"abnormal psychology\",\"bipolar i disorder\",\"auditory hallucination\",\"unipolar mania\",\"psychomotor retardation\",\"altered state of consciousness\",\"seasonal affective disorder\",\"anhedonia\",\"eating disorder\",\"list of mental disorders\",\"timeline of psychology\",\"mania\",\"timeline of psychotherapy\",\"major depressive disorder\",\"dysthymia\",\"biblical patriarchy\",\"christian egalitarianism\",\"bibliography of sociology\",\"least-cost theory\",\"mass action (sociology)\",\"life chances\",\"sociology of the world religions\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"science as a vocation\",\"tripartite classification of authority\",\"commercialism\",\"christian communism\",\"international sociological association\",\"iron cage\",\"ideal type\",\"roman agrarian history and its significance for public and private law\",\"1990s in anthropology\",\"early modern human\",\"major depressive disorder\",\"self-criticism\",\"bipolar i disorder\",\"occupational health psychology\",\"auditory hallucination\",\"psychomotor retardation\",\"creativity and mental health\",\"altered state of consciousness\",\"seasonal affective disorder\",\"anhedonia\",\"eating disorder\",\"list of mental disorders\",\"list of psychiatric medications by condition treated\",\"dsm-iv codes\",\"dysthymia\",\"paleoradiology\",\"armchair theorizing\",\"the american journal of economics and sociology\",\"abnormal psychology\",\"list of schools of psychoanalysis\",\"list of psychiatric medications\",\"occupational health psychology\",\"medical psychology\",\"music psychology\",\"list of psychological research methods\",\"outline of autism\",\"list of credentials in psychology\",\"list of mnemonics\",\"gestalt psychology\",\"list of mental disorders\",\"list of psychiatric medications by condition treated\",\"dsm-iv codes\",\"list of psychology organizations\",\"timeline of psychology\",\"outline of thought\",\"timeline of psychotherapy\",\"pseudodysphagia\",\"models of abnormality\",\"seasonal affective disorder\",\"daniel kahneman\",\"hypnosis\",\"harry harlow\",\"psychoanalytic theory\",\"quantitative research\",\"history of psychotherapy\",\"egosyntonic and egodystonic\",\"daniel kahneman\",\"quantitative research\",\"harry harlow\",\"gestalt psychology\",\"daniel kahneman\",\"music psychology\",\"harry harlow\",\"quantitative research\",\"injustice\",\"discouraged worker\",\"gold-collar worker\",\"list of psychological research methods\",\"daniel kahneman\",\"harry harlow\",\"equal opportunity\",\"quantitative research\",\"national average salary\",\"99ers\",\"gestalt theoretical psychotherapy\",\"list of psychological schools\",\"paul ferdinand schilder\",\"index of sociology articles\",\"pattern recognition (psychology)\",\"gestaltzerfall\",\"daniel kahneman\",\"field theory (psychology)\",\"kurt koffka medal\",\"harry harlow\",\"outline of thought\",\"quantitative research\",\"timeline of psychology\",\"law of effect\",\"gustave le bon\",\"little albert experiment\",\"identity crisis\",\"gay, straight, and the reason why\",\"the concept of anxiety\",\"daniel kahneman\",\"hermann lotze\",\"verbal behavior\",\"harry harlow\",\"object relations theory\",\"two-factor theory of emotion\",\"timeline of psychotherapy\",\"ernest jones\",\"daniel kahneman\",\"harry harlow\",\"quantitative research\",\"quantitative psychological research\",\"outline of thought\",\"eating disorder\",\"bipolar i disorder\",\"hong kong college of psychiatrists\",\"psycho-oncology\",\"anhedonia\",\"eating disorder\",\"bipolar i disorder\",\"hong kong college of psychiatrists\",\"psycho-oncology\",\"list of neurological conditions and disorders\",\"dysthymia\",\"social model of disability\",\"nobody nowhere\",\"list of psychiatric medications by condition treated\",\"hong kong college of psychiatrists\",\"eating disorder\",\"psycho-oncology\",\"eating disorder\",\"hong kong college of psychiatrists\",\"psycho-oncology\",\"dysthymia\",\"menninger foundation\",\"ernest jones\",\"british psychotherapy foundation\",\"shadow (psychology)\",\"defence mechanism\",\"id, ego and super-ego\",\"adlerian\",\"mortido\",\"psychoanalytic theory\",\"object relations theory\",\"preconscious\",\"helene deutsch\",\"daniel kahneman\",\"european federation of psychologists' associations\",\"harry harlow\",\"national association of school psychologists\",\"quantitative research\",\"international society of political psychology\",\"list of national legal systems\",\"marriage of the virgin\",\"code of hammurabi\",\"marriage of the virgin\",\"manorialism\",\"requisite organization\",\"outline of anarchism\",\"matrix management\",\"corporatization\",\"feoffment\",\"open economy\",\"unplanned economies\",\"democratic capitalism\",\"private property\",\"robinson crusoe economy\",\"anglo-saxon model\",\"attention economy\",\"yehuda zvi blum\",\"index of social and political philosophy articles\",\"history of the american legal profession\",\"executive order\",\"history of the legal profession\",\"index of social and political philosophy articles\",\"maternalism\",\"list of national legal systems\",\"john rawls\",\"neil maccormick\",\"law without the state\",\"leslie green (philosopher)\",\"nigel simmonds\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"legalism (chinese philosophy)\",\"legal norm\",\"national liberalism\",\"index of social and political philosophy articles\",\"liberal international order\",\"equality of outcome\",\"isaiah berlin\",\"instrumental and value rationality\",\"social liberalism\",\"philosophy of sex\",\"emotivism\",\"william frankena\",\"list of liberal theorists\",\"spatial justice\",\"john rawls\",\"john roemer\",\"the democratic paradox\",\"constitutional economics\",\"frankfurt declaration\",\"private property\",\"equal opportunity\",\"david chalmers\",\"deliberation\",\"c. d. broad\",\"overlapping consensus\",\"whiggism\",\"reductionism\",\"role ethics\",\"ethical socialism\",\"stakeholder (corporate)\",\"modern liberalism in the united states\",\"post-politics\",\"free market fairness\",\"agonism\",\"bertrand russell\",\"philosophical analysis\",\"social corporatism\",\"index of sociopolitical thinkers\",\"guido tabellini\",\"public budgeting\",\"liberal legalism\",\"regulatory economics\",\"institutionalist political economy\",\"degrowth\",\"new institutional economics\",\"public property\",\"economic law\",\"index of social and political philosophy articles\",\"list of national legal systems\",\"inquisitorial system\",\"history of the american legal profession\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"predictive policing\",\"executive order\",\"list of national legal systems\",\"inquisitorial system\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"predictive policing\",\"executive order\",\"border control\",\"list of national legal systems\",\"inquisitorial system\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"predictive policing\",\"federal law\",\"index of social and political philosophy articles\",\"whiggism\",\"confucian classes\",\"isaiah berlin\",\"liberal conservatism\",\"social liberalism\",\"philosophy of sex\",\"samuel von pufendorf\",\"list of liberal theorists\",\"bertrand russell\",\"private property\",\"conservative liberalism\",\"anarcho-capitalism\",\"people power\",\"index of sociopolitical thinkers\",\"index of social and political philosophy articles\",\"reductionism\",\"confucian classes\",\"isaiah berlin\",\"rationalism\",\"samuel von pufendorf\",\"bertrand russell\",\"people power\",\"index of sociopolitical thinkers\",\"regional power\",\"polyarchy\",\"scientocracy\",\"night-watchman state\",\"bankocracy\",\"one-party state\",\"donor class\",\"futarchy\",\"great power\",\"constitutional dictatorship\",\"legalism (chinese philosophy)\",\"civilization state\",\"corporate republic\",\"dependent territory\",\"autonomous communities of spain\",\"polyarchy\",\"scientocracy\",\"bankocracy\",\"futarchy\",\"corporative federalism\",\"hong kong honours system\",\"civilization state\",\"corporate republic\",\"secession\",\"dependent territory\",\"regional power\",\"night-watchman state\",\"autonomous administrative division\",\"donor class\",\"home rule\",\"great power\",\"constitutional dictatorship\",\"legalism (chinese philosophy)\",\"polyarchy\",\"scientocracy\",\"night-watchman state\",\"bankocracy\",\"regional hegemony\",\"donor class\",\"futarchy\",\"great power\",\"constitutional dictatorship\",\"legalism (chinese philosophy)\",\"civilization state\",\"corporate republic\",\"superpower collapse\",\"polyarchy\",\"status quo state\",\"scientocracy\",\"night-watchman state\",\"bankocracy\",\"regional hegemony\",\"sciences po\",\"donor class\",\"thucydides trap\",\"futarchy\",\"eastern bloc\",\"constitutional dictatorship\",\"legalism (chinese philosophy)\",\"civilization state\",\"corporate republic\",\"superpower collapse\",\"list of national independence days\",\"balkanization\",\"cato institute\",\"autonomous administrative division\",\"bioregionalism\",\"private property\",\"home rule\",\"corporative federalism\",\"proposed national unification promotion law\",\"burmese way to socialism\",\"anarcho-capitalism\",\"secession\",\"social situation in the french suburbs\",\"westphalian sovereignty\",\"majoritarianism\",\"corporative federalism\",\"balkanization\",\"westphalian sovereignty\",\"violent non-state actor\",\"sovereignty of the philippines\",\"contingent sovereignty\",\"proletarian nation\",\"friendly fascism (book)\",\"christian fascism\",\"kyklos\",\"donor class\",\"corporate republic\",\"one-party state\",\"tyranny of the majority\",\"authoritarian capitalism\",\"one-party state\",\"soft despotism\",\"authoritarian democracy\",\"enlightened absolutism\",\"dictablanda\",\"corporate republic\",\"ecoauthoritarianism\",\"corporatization\",\"corporate statism\",\"tyranny of the majority\",\"authoritarian capitalism\",\"one-party state\",\"donor class\",\"soft despotism\",\"authoritarian democracy\",\"enlightened absolutism\",\"dictablanda\",\"ecoauthoritarianism\",\"tyranny of the majority\",\"authoritarian capitalism\",\"one-party state\",\"soft despotism\",\"authoritarian democracy\",\"enlightened absolutism\",\"ecoauthoritarianism\",\"proletarian nation\",\"people's democracy (marxism\\u2013leninism)\",\"friendly fascism (book)\",\"communism and lgbt rights\",\"authoritarian capitalism\",\"communist front\",\"soft despotism\",\"white power music\",\"dictatorship of the proletariat\",\"eastern bloc\",\"enlightened absolutism\",\"chua beng huat\",\"social conservatism\",\"ecoauthoritarianism\",\"tyranny of the majority\",\"bibliography of works about communism\",\"economic nationalism\",\"real socialism\",\"national communism\",\"burmese way to socialism\",\"authoritarian democracy\",\"christian fascism\",\"frente despertar\",\"privatism\",\"economic mobility\",\"history of capitalist theory\",\"soft despotism\",\"private property\",\"participism\",\"enlightened absolutism\",\"ecoauthoritarianism\",\"tyranny of the majority\",\"criticism of capitalism\",\"authoritarian democracy\",\"first world\",\"zombie liberalism\",\"political repression\",\"proletarian nation\",\"polyarchy\",\"majoritarianism\",\"social order\",\"democratic capitalism\",\"soft despotism\",\"enlightened absolutism\",\"ecoauthoritarianism\",\"tyranny of the majority\",\"neosocialism\",\"nur f\\u00fcr deutsche\",\"perpetual war\",\"f\\u00fchrer\",\"christian fascism\",\"soft despotism\",\"enlightened absolutism\",\"tyranny of the majority\",\"queer ecology\",\"eco-capitalism\",\"eco-nationalism\",\"greenwashing\",\"reductionism\",\"werturteilsstreit\",\"rationalism\",\"tyranny of the majority\",\"samuel von pufendorf\",\"ethnarch\",\"soft despotism\",\"list of enlightened despots\",\"tyranny of the majority\",\"index of social and political philosophy articles\",\"majoritarianism\",\"democratic capitalism\",\"brainwashing\",\"list of liberal theorists\",\"blacklisting\",\"enemy of the people (albania)\",\"philosophy of max stirner\",\"consensus democracy\",\"elective dictatorship\",\"tyranny of the majority\",\"democratic peace theory\",\"shock value\",\"polyarchy\",\"public consultation\",\"industrial democracy\",\"dictatorship of the proletariat\",\"workplace democracy\",\"people power\",\"communal reinforcement\",\"associationalism\",\"enemy of the people\",\"christian privilege\",\"peer pressure\",\"oppression\",\"donor class\",\"business oligarch\",\"magnate\",\"the rich get richer and the poor get poorer\",\"donor class\",\"business oligarch\",\"status\\u2013income disequilibrium\",\"obscurantism\",\"gustave le bon\",\"demonizing the enemy\",\"appeasement\",\"xuanchuan\",\"international convention concerning the use of broadcasting in the cause of peace\",\"history of propaganda\",\"slogan\",\"gish gallop\",\"ratification\",\"counterpropaganda\",\"campaign finance\",\"strategy of tension\",\"gevald campaign\",\"strategy of tension\",\"destabilisation\",\"obscurantism\",\"lesser of two evils principle\",\"gish gallop\",\"slogan\",\"obscurantism\",\"lesser of two evils principle\",\"slogan\",\"obscurantism\",\"lesser of two evils principle\",\"bertrand russell\",\"cover-up\",\"slogan\",\"they shall not pass\",\"fukoku ky\\u014dhei\",\"keep indy indie\",\"tiocfaidh \\u00e1r l\\u00e1\",\"we don't coast\",\"one man, one vote\",\"lesser of two evils principle\",\"slogan\",\"free newfoundland\",\"shock value\",\"barracks communism\",\"people's democracy (marxism\\u2013leninism)\",\"base and superstructure\",\"androcentrism\",\"brainwashing\",\"blacklisting\",\"dictatorship of the proletariat\",\"no war but the class war\",\"white power music\",\"world revolution\",\"people power\",\"communal reinforcement\",\"christian privilege\",\"proletarian revolution\",\"real socialism\",\"social revolution\",\"commanding heights of the economy\",\"peer pressure\",\"oppression\",\"surplus labour\",\"production for profit\",\"worker cooperative\",\"self-criticism\",\"communal reinforcement\",\"shock value\",\"destabilisation\",\"emotional abuse\",\"brainwashing\",\"social dominance orientation\",\"blacklisting\",\"peer pressure\",\"enemy of the people (albania)\",\"people power\",\"reality distortion field\",\"communal reinforcement\",\"echo chamber (media)\",\"destabilisation\",\"emotional abuse\",\"brainwashing\",\"index of sociology articles\",\"social reality\",\"mediumship\",\"lady wonder\",\"peer pressure\",\"hypnosis\",\"enemy of the people (albania)\",\"solitary confinement\",\"levitation (paranormal)\",\"astrology\",\"automatic writing\",\"people power\",\"communal reinforcement\",\"shock value\",\"echo chamber (media)\",\"acceptance\",\"collective effervescence\",\"civil libertarianism\",\"slain in the spirit\",\"social reality\",\"eating disorder\",\"people power\",\"enemy of the people (albania)\",\"abilene paradox\",\"shock value\",\"echo chamber (media)\",\"social phenomenon\",\"mediumship\",\"lady wonder\",\"enemy of the people (albania)\",\"levitation (paranormal)\",\"automatic writing\",\"astrology\",\"people power\",\"white power music\",\"enemy of the people (albania)\",\"people power\",\"knowledge of the holocaust in nazi germany and german-occupied europe\",\"f\\u00fchrer\",\"caudillo\",\"bolivarian revolution\",\"social revolution\",\"proletarian revolution\",\"oppression\",\"(don't) touch me on my studio\",\"revolutions of 1989\",\"history of democratic socialism\",\"might makes right\",\"index of social and political philosophy articles\",\"list of social democratic parties\",\"nanosocialism\",\"sex and reason\",\"sociological positivism\",\"cogito, ergo sum\",\"hermann lotze\",\"frankfurt declaration\",\"list of left-wing internationals\",\"henri poincar\\u00e9\",\"possible world\",\"ernst mally\",\"reductionism\",\"identity (philosophy)\",\"michael albert\",\"christian communism\",\"direct and indirect realism\",\"universal basic income\",\"social corporatism\",\"emotivism\",\"metalanguage\",\"history of democratic socialism\",\"richard gaskin\",\"ferdinand de saussure\",\"isaiah berlin\",\"better red than dead\",\"altered state of consciousness\",\"industrial democracy\",\"james tully (philosopher)\",\"religious socialism\",\"instrumentalism\",\"david chalmers\",\"workplace democracy\",\"c. d. broad\",\"task force\",\"edinburgh university socialist society\",\"appeasement\",\"rationalism\",\"criticism of capitalism\",\"ethical socialism\",\"real socialism\",\"logology (science)\",\"global workspace theory\",\"sociology of scientific ignorance\",\"philosophical analysis\",\"paradox of thrift\",\"index of sociopolitical thinkers\",\"real socialism\",\"right to the city\",\"base and superstructure\",\"proletarian nation\",\"social order\",\"friendly fascism (book)\",\"ilminism\",\"bibliography of works about communism\",\"neosocialism\",\"perpetual war\",\"christian fascism\",\"first world\",\"friendly fascism (book)\",\"christian fascism\",\"liberal conservatism\",\"thomas schelling\",\"index of sociology articles\",\"catonism\",\"neosocialism\",\"structural violence\",\"iron cage\",\"conservative liberalism\",\"symbolic power\",\"friendly fascism (book)\",\"liberal conservatism\",\"christian fascism\",\"rumor\",\"subconscious\",\"after saturday comes sunday\",\"proverbial phrase\",\"trobriand islands\",\"master of public administration\",\"fundacion manantiales\",\"sociologists without borders\",\"ngo-ization\",\"politico-media complex\",\"international association of art critics\",\"non-governmental organization\",\"united nations parliamentary assembly\",\"friedrich naumann foundation\",\"cultural survival\",\"responsibility to protect\",\"rosa luxemburg foundation\",\"non-interventionism\",\"contingent sovereignty\",\"clientelism\",\"informal social control\",\"solitary confinement\",\"proactive policing\",\"community policing\",\"broken windows theory\",\"problem-oriented policing\",\"dark figure of crime\",\"solitary confinement\",\"enterprise theory\",\"resocialization\",\"peelian principles\",\"proactive policing\",\"kansas city preventive patrol experiment\",\"asu college of public service & community solutions\",\"problem-oriented policing\",\"national crime victimization survey\",\"predictive policing\",\"private sphere\",\"peelian principles\",\"peelian principles\",\"non-interventionism\",\"maternalism\",\"bryan caplan\",\"private property\",\"civil libertarianism\",\"night-watchman state\",\"participism\",\"eurasianism\",\"anarcho-capitalism\",\"law of equal liberty\",\"neoclassical liberalism\",\"bryan caplan\",\"civil libertarianism\",\"global justice movement\",\"cato institute\",\"non-interventionism\",\"anarcho-capitalism\",\"free migration\",\"participism\",\"voluntary society\",\"antimilitarism\",\"freedom of contract\",\"law of equal liberty\",\"neoclassical liberalism\",\"people's democracy (marxism\\u2013leninism)\",\"communism and lgbt rights\",\"land consolidation\",\"democratic capitalism\",\"revolutions of 1989\",\"communist front\",\"history of social democracy\",\"dictatorship of the proletariat\",\"gar alperovitz\",\"sociology in poland\",\"border control\",\"bloc party (politics)\",\"international workers' day\",\"triangular diplomacy\",\"liberal conservatism\",\"bibliography of works about communism\",\"real socialism\",\"commanding heights of the economy\",\"sovereignty of puerto rico during the cold war\",\"names for the human species\",\"oppression\",\"dizzy with success\",\"first world\",\"history of democratic socialism\",\"self-criticism\",\"superpower collapse\",\"influence of mass media\",\"christian fascism\",\"democratic peace theory\",\"neosocialism\",\"transnational progressivism\",\"polyarchy\",\"majoritarianism\",\"selectorate theory\",\"democratic globalization\",\"democratic capitalism\",\"international sanctions\",\"classical realism (international relations)\",\"critical security studies\",\"postinternationalism\",\"scientific man versus power politics\",\"relative gain (international relations)\",\"history of capitalist theory\",\"violence peace and peace research\",\"international ethics\",\"market-dominant minority\",\"rationalism\",\"capitalist peace\",\"glossary of international relations terms\",\"militarized interstate dispute\",\"regionalism (international relations)\",\"bananas, beaches and bases\",\"idealism in international relations\",\"third-person effect\",\"social media in the 2016 united states presidential election\",\"elihu katz\",\"echo chamber (media)\",\"consumer class\",\"manifest and latent functions and dysfunctions\",\"media circus\",\"hypodermic needle model\",\"recuperation (politics)\",\"degrowth\",\"microgeneration\",\"opinion leadership\",\"christian corporatism\",\"index of social and political philosophy articles\",\"social liberalism\",\"eurasianism\",\"public morality\",\"index of sociology articles\",\"ethical socialism\",\"blue labour\",\"maternalism\",\"christian communism\",\"private property\",\"social conservatism\",\"bolivarian revolution\",\"labor theory of property\",\"consumer class\",\"base and superstructure\",\"democratic capitalism\",\"social liberalism\",\"technoliberalism\",\"list of liberal theorists\",\"liberal corporatism\",\"religious communism\",\"history of capitalist theory\",\"history of social democracy\",\"marxist sociology\",\"participism\",\"equal opportunity\",\"value product\",\"robinson crusoe economy\",\"legal naturalism\",\"attention economy\",\"philosophy of max stirner\",\"whiggism\",\"bryan caplan\",\"liberalism and conservatism in latin america\",\"new institutional economics\",\"party platform\",\"christian communism\",\"neoauthoritarianism (china)\",\"democratic liberalism\",\"anglo-saxon model\",\"zombie liberalism\",\"law of rent\",\"frente despertar\",\"open economy\",\"privatism\",\"civil libertarianism\",\"neo-capitalism\",\"unplanned economies\",\"isaiah berlin\",\"public property\",\"in kind\",\"religious socialism\",\"dictatorship of the proletariat\",\"private property\",\"conservative liberalism\",\"voluntary society\",\"world revolution\",\"left communism\",\"conservative corporatism\",\"neoclassical liberalism\",\"corporatization\",\"visible hand (economics)\",\"liberal conservatism\",\"criticism of capitalism\",\"bibliography of works about communism\",\"ethical socialism\",\"modern liberalism in the united states\",\"equality before the law\",\"outline of anarchism\",\"eco-capitalism\",\"surplus labour\",\"anarcho-capitalism\",\"law of equal liberty\",\"neoauthoritarianism (china)\",\"liberalism and conservatism in latin america\",\"atlanticism\",\"conservative liberalism\",\"liberal conservatism\",\"conservative corporatism\",\"neoauthoritarianism (china)\",\"liberalism and conservatism in latin america\",\"conservative liberalism\",\"liberal conservatism\",\"conservative corporatism\",\"blue labour\",\"phillip blond\",\"independent labour publications\",\"socialist campaign group\",\"index of social and political philosophy articles\",\"whiggism\",\"isaiah berlin\",\"liberal conservatism\",\"social liberalism\",\"index of sociology articles\",\"list of liberal theorists\",\"ethical socialism\",\"modern liberalism in the united states\",\"authoritarian left\",\"conservative liberalism\",\"equal opportunity\",\"anarcho-capitalism\",\"liberal social movement (portugal)\",\"christian communism\",\"organicism\",\"religious socialism\",\"ethical socialism\",\"index of social and political philosophy articles\",\"equality of outcome\",\"history of communism\",\"labour voucher\",\"list of social democratic parties\",\"nanosocialism\",\"industrial democracy\",\"he who does not work, neither shall he eat\",\"religious socialism\",\"blanquism\",\"religious communism\",\"dictatorship of the proletariat\",\"participism\",\"crimes against humanity under communist regimes\",\"world revolution\",\"equal opportunity\",\"left communism\",\"list of left-wing internationals\",\"workplace democracy\",\"edinburgh university socialist society\",\"criticism of capitalism\",\"bibliography of works about communism\",\"ethical socialism\",\"proletarian revolution\",\"social revolution\",\"real socialism\",\"national communism\",\"worker cooperative\",\"history of democratic socialism\",\"christian fascism\",\"christian egalitarianism\",\"equality of outcome\",\"history of communism\",\"labour voucher\",\"list of social democratic parties\",\"rationalism\",\"nanosocialism\",\"criticism of capitalism\",\"industrial democracy\",\"blanquism\",\"history of social democracy\",\"frankfurt declaration\",\"dictatorship of the proletariat\",\"participism\",\"equal opportunity\",\"left communism\",\"workplace democracy\",\"proletarian revolution\",\"social corporatism\",\"public policy school\",\"persistent vegetative state\",\"military policy\",\"freedom of contract\",\"master of public administration\",\"schar school of policy and government\",\"blavatnik school of government\",\"military policy\",\"institut d'\\u00e9tudes politiques d'aix-en-provence\",\"edward j. bloustein school of planning and public policy\",\"master of public policy\",\"sanford school of public policy\",\"sciences po\",\"princeton school of public and international affairs\",\"graduate program in public management\",\"robert f. wagner graduate school of public service\",\"graduate school of public policy, university of tokyo\",\"mccourt school of public policy\",\"institut d'\\u00e9tudes politiques de toulouse\",\"frank batten school of leadership and public policy\",\"robert m. la follette school of public affairs\",\"public opinion quarterly\",\"nancy program\",\"american journal of political science\",\"knowledge gap hypothesis\",\"henry e. brady\",\"futarchy\",\"public opinion quarterly\",\"abilene paradox\",\"decentralized autonomous organization\",\"hypodermic needle model\",\"total survey error\",\"international journal of public opinion research\",\"interviewer effect\",\"institution\",\"base and superstructure\",\"social experiment\",\"institutionalist political economy\",\"index of sociology articles\",\"astrosociology\",\"social complexity\",\"institutional trust (social sciences)\",\"social actions\",\"sociology of punishment\",\"interactionism\",\"base and superstructure\",\"status group\",\"agency (sociology)\",\"group threat theory\",\"list of sociologists\",\"asabiyyah\",\"sociological positivism\",\"organizational theory\",\"social conflict\",\"manifest and latent functions and dysfunctions\",\"marxist sociology\",\"value-added theory\",\"index of urban sociology articles\",\"quantitative research\",\"figurational sociology\",\"sociology of punishment\",\"sociology in poland\",\"bibliography of sociology\",\"list of sociology journals\",\"dyad (sociology)\",\"social experiment\",\"field theory (sociology)\",\"control theory (sociology)\",\"index of sociology articles\",\"action theory (sociology)\",\"sociology in japan\",\"social reality\",\"european sociological association\",\"econophysics\",\"dark figure of crime\",\"concentrated disadvantage\",\"structural violence\",\"microsociology\",\"sociology of morality\",\"computational sociology\",\"sociology of scientific ignorance\",\"moral entrepreneur\",\"collective mental state\",\"astrosociology\",\"symbolic religiosity\",\"complex adaptive system\",\"social reproduction\",\"relational sociology\",\"medical sociologist\",\"interactionism\",\"base and superstructure\",\"status group\",\"agency (sociology)\",\"group threat theory\",\"list of sociologists\",\"asabiyyah\",\"sociological positivism\",\"organizational theory\",\"social conflict\",\"manifest and latent functions and dysfunctions\",\"marxist sociology\",\"value-added theory\",\"figurational sociology\",\"sociology of punishment\",\"sociology in poland\",\"bibliography of sociology\",\"list of sociology journals\",\"dyad (sociology)\",\"social experiment\",\"control theory (sociology)\",\"index of sociology articles\",\"action theory (sociology)\",\"sociology in japan\",\"social reality\",\"european sociological association\",\"dark figure of crime\",\"concentrated disadvantage\",\"structural violence\",\"microsociology\",\"sociology of morality\",\"computational sociology\",\"sociology of scientific ignorance\",\"moral entrepreneur\",\"collective mental state\",\"symbolic religiosity\",\"field theory (sociology)\",\"social reproduction\",\"relational sociology\",\"medical sociologist\",\"interactionism\",\"antipositivism\",\"base and superstructure\",\"status group\",\"cognitive bias\",\"agency (sociology)\",\"group threat theory\",\"list of sociologists\",\"asabiyyah\",\"sociological positivism\",\"organizational theory\",\"social conflict\",\"manifest and latent functions and dysfunctions\",\"marxist sociology\",\"value-added theory\",\"quantitative research\",\"figurational sociology\",\"sociology of punishment\",\"sociology in poland\",\"bibliography of sociology\",\"sequential probability ratio test\",\"list of sociology journals\",\"dyad (sociology)\",\"field theory (sociology)\",\"control theory (sociology)\",\"index of sociology articles\",\"action theory (sociology)\",\"sociology in japan\",\"social reality\",\"european sociological association\",\"dark figure of crime\",\"concentrated disadvantage\",\"structural violence\",\"microsociology\",\"sociology of morality\",\"computational sociology\",\"sociology of scientific ignorance\",\"moral entrepreneur\",\"collective mental state\",\"symbolic religiosity\",\"social reproduction\",\"relational sociology\",\"medical sociologist\",\"index of sociology articles\",\"barracks communism\",\"history of communism\",\"people's democracy (marxism\\u2013leninism)\",\"dictatorship of the proletariat\",\"enemy of the people (albania)\",\"marxist sociology\",\"world revolution\",\"value product\",\"left communism\",\"legal naturalism\",\"index of sociology articles\",\"bibliography of works about communism\",\"real socialism\",\"social revolution\",\"worker cooperative\",\"commanding heights of the economy\",\"surplus labour\",\"production for profit\",\"proletarian revolution\",\"self-criticism\",\"new institutional economics\",\"vaticanology\",\"kremlinology\",\"master of public administration\",\"princeton school of public and international affairs\",\"graduate school of public policy, university of tokyo\",\"mccourt school of public policy\",\"blavatnik school of government\",\"school of public policy at central european university\",\"robert f. wagner graduate school of public service\",\"school of international and public affairs, columbia university\",\"school of public policy at central european university\",\"european master of public administration consortium\",\"schar school of policy and government\",\"school of international and public affairs, columbia university\",\"qem\",\"raisons politiques\",\"nonna mayer\",\"nicole bacharan\",\"instituts d'\\u00e9tudes politiques\",\"european school of political and social sciences\",\"german university of administrative sciences speyer\",\"sanford school of public policy\",\"ariane chebel d'appollonia\",\"princeton school of public and international affairs\",\"graduate school of public policy, university of tokyo\",\"alexandra goujon\",\"american university school of international service\",\"liesbet hooghe\",\"bush school of government and public service\",\"ideocracy\",\"bric\",\"national power\",\"energy superpower\",\"asabiyyah\",\"economic power\",\"implementation\",\"cipp evaluation model\",\"polyarchy\",\"majoritarianism\",\"privatism\",\"industrial democracy\",\"list of liberal theorists\",\"in kind\",\"revolutions of 1989\",\"economic mobility\",\"history of capitalist theory\",\"participism\",\"workplace democracy\",\"neoclassical liberalism\",\"corporatization\",\"whiggism\",\"consensus democracy\",\"triangular diplomacy\",\"associationalism\",\"criticism of capitalism\",\"sovereignty of puerto rico during the cold war\",\"echo chamber (media)\",\"polyarchy\",\"consensus democracy\",\"eternity clause\",\"associationalism\",\"industrial democracy\",\"social reality\",\"workplace democracy\",\"polyarchy\",\"consensus democracy\",\"associationalism\",\"index of sociology articles\",\"industrial democracy\",\"workplace democracy\",\"classical realism (international relations)\",\"critical security studies\",\"postinternationalism\",\"international ethics\",\"scientific man versus power politics\",\"relative gain (international relations)\",\"the lexus and the olive tree\",\"idealism in international relations\",\"clientelism\",\"regionalism (international relations)\",\"bananas, beaches and bases\",\"rationalism\",\"classical realism (international relations)\",\"postinternationalism\",\"scientific man versus power politics\",\"relative gain (international relations)\",\"regionalism (international relations)\",\"bananas, beaches and bases\",\"international political sociology (ips)\",\"international ethics\",\"idealism in international relations\",\"echo chamber (media)\",\"antipositivism\",\"werturteilsstreit\",\"postinternationalism\",\"scientific man versus power politics\",\"sociological positivism\",\"constantin noica\",\"cogito, ergo sum\",\"causa sui\",\"authoritarian left\",\"agency (philosophy)\",\"international ethics\",\"henri poincar\\u00e9\",\"reductionism\",\"madhhab\",\"social reality\",\"tractatus politicus\",\"psychological nativism\",\"philosophy of life\",\"direct and indirect realism\",\"bananas, beaches and bases\",\"first world\",\"idealism in international relations\",\"classical realism (international relations)\",\"relative gain (international relations)\",\"instrumentalism\",\"max scheler\",\"c. d. broad\",\"structuration theory\",\"task force\",\"ressentiment\",\"rationalism\",\"atlanticism\",\"wilhelm windelband\",\"post-behavioralism\",\"gaia philosophy\",\"equality before the law\",\"logology (science)\",\"hedonism\",\"sociology of scientific ignorance\",\"regionalism (international relations)\",\"philosophical analysis\",\"legalism (chinese philosophy)\",\"proto-industrialization\",\"astrology\",\"classical realism (international relations)\",\"postinternationalism\",\"scientific man versus power politics\",\"relative gain (international relations)\",\"regionalism (international relations)\",\"bananas, beaches and bases\",\"idealism in international relations\",\"maritza montero\",\"warren miller (political scientist)\",\"emmette redford\",\"henry e. brady\",\"warren miller (political scientist)\",\"henry e. brady\",\"warren miller (political scientist)\",\"designing social inquiry\",\"hypodermic needle model\",\"elihu katz\",\"echo chamber (media)\",\"manifest and latent functions and dysfunctions\",\"echo chamber (media)\",\"manifest and latent functions and dysfunctions\",\"list of sociologists\",\"hypodermic needle model\",\"echo chamber (media)\",\"antipositivism\",\"werturteilsstreit\",\"scientocracy\",\"regulation of science\",\"sociological positivism\",\"instrumentalism\",\"technical change\",\"quantitative research\",\"henri poincar\\u00e9\",\"structuration theory\",\"task force\",\"c. d. broad\",\"reductionism\",\"economics of science\",\"double hermeneutic\",\"mapping controversies\",\"wilhelm windelband\",\"post-behavioralism\",\"index of sociology articles\",\"sociotechnology\",\"sociological naturalism\",\"sociology of scientific ignorance\",\"normalization process theory\",\"humanistic sociology\",\"privatism\",\"werturteilsstreit\",\"scientocracy\",\"regulation of science\",\"history of science policy\",\"instrumentalism\",\"technical change\",\"quantitative research\",\"structuration theory\",\"dyad (sociology)\",\"economics of science\",\"double hermeneutic\",\"mapping controversies\",\"post-behavioralism\",\"index of sociology articles\",\"sociotechnology\",\"sociological naturalism\",\"logology (science)\",\"sociology of scientific ignorance\",\"ideal type\",\"science diplomacy\",\"normalization process theory\",\"werturteilsstreit\",\"instrumentalism\",\"structuration theory\",\"werturteilsstreit\",\"instrumental and value rationality\",\"instrumental and value-rational action\",\"essence of decision\",\"nava ashraf\",\"law of the instrument\",\"steven n. s. cheung\",\"c. d. broad\",\"henri poincar\\u00e9\",\"structuration theory\",\"reductionism\",\"hiding hand principle\",\"wilhelm windelband\",\"accelerator effect\",\"new institutional economics\",\"social rule system theory\",\"daniel kahneman\",\"emotive (sociology)\",\"logology (science)\",\"georg weizs\\u00e4cker\",\"sociology of scientific ignorance\",\"instrumental and intrinsic value\",\"philosophical analysis\",\"werturteilsstreit\",\"health geography\",\"action theory (sociology)\",\"reflexivity (social theory)\",\"duality of structure\",\"generative actor\",\"ideal type\",\"life chances\",\"tripartite classification of authority\",\"iron cage\",\"ideal type\",\"social actions\",\"index of social and political philosophy articles\",\"organizational adaptation\",\"strategic choice theory\",\"anti-modernization\",\"chester barnard\",\"organizational theory\",\"yelyzaveta yasko\",\"yakama manty jones\",\"european master of public administration consortium\",\"schar school of policy and government\",\"robert f. wagner graduate school of public service\",\"autonomous administrative division\",\"right to exist\",\"social situation in the french suburbs\",\"home rule\",\"right to exist\",\"autonomous communities of spain\",\"autonomous administrative division\",\"voting rights in the united states\",\"kremlinology\",\"astrology\",\"isaiah berlin\",\"civil libertarianism\",\"technoliberalism\",\"liberal corporatism\",\"conservative liberalism\",\"equal opportunity\",\"the road to serfdom\",\"neoclassical liberalism\",\"whiggism\",\"liberalism and conservatism in latin america\",\"liberal conservatism\",\"modern liberalism in the united states\",\"equality before the law\",\"democratic liberalism\",\"anarcho-capitalism\",\"law of equal liberty\",\"isaiah berlin\",\"civil libertarianism\",\"technoliberalism\",\"liberal corporatism\",\"conservative liberalism\",\"equal opportunity\",\"neoclassical liberalism\",\"liberalism and conservatism in latin america\",\"liberal conservatism\",\"cato institute\",\"modern liberalism in the united states\",\"equality before the law\",\"democratic liberalism\",\"anarcho-capitalism\",\"law of equal liberty\",\"equality of outcome\",\"gold-collar worker\",\"labour voucher\",\"list of social democratic parties\",\"nanosocialism\",\"industrial democracy\",\"religious socialism\",\"blanquism\",\"economic mobility\",\"john roemer\",\"conservative liberalism\",\"participism\",\"equal opportunity\",\"list of left-wing internationals\",\"against equality of opportunity\",\"workplace democracy\",\"99ers\",\"edinburgh university socialist society\",\"discouraged worker\",\"popular socialism\",\"criticism of capitalism\",\"modern liberalism in the united states\",\"equality before the law\",\"real socialism\",\"great gatsby curve\",\"oppression\",\"national average salary\",\"history of democratic socialism\",\"law of equal liberty\",\"index of social and political philosophy articles\",\"history of social democracy\",\"conservative liberalism\",\"political studies association\",\"index of social and political philosophy articles\",\"isaiah berlin\",\"index of sociopolitical thinkers\",\"index of social and political philosophy articles\",\"labor theory of property\",\"privatism\",\"civil libertarianism\",\"global justice movement\",\"an anarchist faq\",\"non-interventionism\",\"voluntary society\",\"participism\",\"conservative liberalism\",\"freedom of contract\",\"private military company\",\"philosophy of max stirner\",\"neoclassical liberalism\",\"bryan caplan\",\"consensus democracy\",\"liberal conservatism\",\"criticism of capitalism\",\"franz oppenheimer\",\"cato institute\",\"outline of anarchism\",\"donor class\",\"free migration\",\"antimilitarism\",\"democratic liberalism\",\"proletarian revolution\",\"zombie liberalism\",\"law of equal liberty\",\"index of social and political philosophy articles\",\"law and order\",\"feeding the chooks\",\"criticism of capitalism\",\"conservative liberalism\",\"democratic liberalism\",\"zombie liberalism\",\"law of equal liberty\",\"neoclassical liberalism\",\"communication university of china\",\"communication university of china\",\"barracks communism\",\"people's democracy (marxism\\u2013leninism)\",\"communism and lgbt rights\",\"seek truth from facts\",\"bibliography of works about communism\",\"real socialism\",\"communist front\",\"commanding heights of the economy\",\"dictatorship of the proletariat\",\"enemy of the people (albania)\",\"world revolution\",\"surplus labour\",\"production for profit\",\"proletarian revolution\",\"self-criticism\",\"world revolution\",\"no war but the class war\",\"index of social and political philosophy articles\",\"people's democracy (marxism\\u2013leninism)\",\"proletarian revolution\",\"real socialism\",\"social revolution\",\"commanding heights of the economy\",\"dictatorship of the proletariat\",\"enemy of the people (albania)\",\"world revolution\",\"surplus labour\",\"production for profit\",\"worker cooperative\",\"history of communism\",\"list of social democratic parties\",\"nanosocialism\",\"history of social democracy\",\"enemy of the people (albania)\",\"marxist sociology\",\"list of left-wing internationals\",\"the road to serfdom\",\"legal naturalism\",\"commanding heights of the economy\",\"production for profit\",\"worker cooperative\",\"history of democratic socialism\",\"democratic marxism\",\"people's democracy (marxism\\u2013leninism)\",\"industrial democracy\",\"religious socialism\",\"dictatorship of the proletariat\",\"world revolution\",\"left communism\",\"workplace democracy\",\"collaboration\",\"edinburgh university socialist society\",\"criticism of capitalism\",\"bibliography of works about communism\",\"class traitor\",\"real socialism\",\"social revolution\",\"deviationism\",\"surplus labour\",\"value product\",\"proletarian revolution\",\"history of communism\",\"people's democracy (marxism\\u2013leninism)\",\"list of social democratic parties\",\"nanosocialism\",\"industrial democracy\",\"religious socialism\",\"blanquism\",\"enemy of the people (albania)\",\"marxist sociology\",\"list of left-wing internationals\",\"world revolution\",\"value product\",\"left communism\",\"workplace democracy\",\"legal naturalism\",\"people power\",\"edinburgh university socialist society\",\"consensus democracy\",\"bevanism\",\"criticism of capitalism\",\"bibliography of works about communism\",\"social revolution\",\"real socialism\",\"worker cooperative\",\"commanding heights of the economy\",\"new social movements\",\"national communism\",\"surplus labour\",\"production for profit\",\"proletarian revolution\",\"history of democratic socialism\",\"history of communism\",\"people's democracy (marxism\\u2013leninism)\",\"communism and lgbt rights\",\"crypto-communism\",\"blanquism\",\"revolutions of 1989\",\"religious communism\",\"communist era\",\"enemy of the people (albania)\",\"marxist sociology\",\"crimes against humanity under communist regimes\",\"world revolution\",\"left communism\",\"legal naturalism\",\"comunismo a la tica\",\"the permanent revolution and results and prospects\",\"bibliography of works about communism\",\"social revolution\",\"real socialism\",\"commanding heights of the economy\",\"national communism\",\"recuperation (politics)\",\"surplus labour\",\"production for profit\",\"value product\",\"worker cooperative\",\"people's democracy (marxism\\u2013leninism)\",\"communism and lgbt rights\",\"bevanism\",\"bibliography of works about communism\",\"domestic trade\",\"real socialism\",\"social revolution\",\"communist front\",\"enemy of the people (albania)\",\"surplus labour\",\"production for profit\",\"worker cooperative\",\"history of communism\",\"people's democracy (marxism\\u2013leninism)\",\"communism and lgbt rights\",\"crypto-communism\",\"neo-capitalism\",\"industrial democracy\",\"religious communism\",\"communist era\",\"enemy of the people (albania)\",\"participism\",\"workplace democracy\",\"michael albert\",\"community-supported agriculture\",\"comunismo a la tica\",\"bibliography of works about communism\",\"real socialism\",\"national communism\",\"surplus labour\",\"production for profit\",\"law of equal liberty\",\"index of social and political philosophy articles\",\"equality of outcome\",\"history of communism\",\"labour voucher\",\"people's democracy (marxism\\u2013leninism)\",\"nanosocialism\",\"industrial democracy\",\"revolutions of 1989\",\"blanquism\",\"enemy of the people (albania)\",\"participism\",\"left communism\",\"workplace democracy\",\"criticism of capitalism\",\"social revolution\",\"surplus labour\",\"production for profit\",\"history of communism\",\"people's democracy (marxism\\u2013leninism)\",\"communism and lgbt rights\",\"crypto-communism\",\"an anarchist faq\",\"blanquism\",\"religious communism\",\"communist era\",\"history of social democracy\",\"enemy of the people (albania)\",\"participism\",\"left communism\",\"quiet revolution\",\"people power\",\"consensus democracy\",\"criticism of capitalism\",\"comunismo a la tica\",\"bibliography of works about communism\",\"outline of anarchism\",\"national communism\",\"surplus labour\",\"production for profit\",\"law of equal liberty\",\"marie-christine kessler\",\"institut d'\\u00e9tudes politiques de toulouse\",\"institut d'\\u00e9tudes politiques d'aix-en-provence\",\"grenoble institute of political studies\",\"princeton school of public and international affairs\",\"schar school of policy and government\",\"school of international and public affairs, columbia university\",\"american university school of international service\",\"bush school of government and public service\",\"schar school of policy and government\",\"liechtenstein institute on self-determination\",\"school of international and public affairs, columbia university\",\"daniel kahneman\",\"american university school of international service\",\"bush school of government and public service\",\"schar school of policy and government\",\"school of international and public affairs, columbia university\",\"american university school of international service\",\"bush school of government and public service\",\"supreme court economic review\",\"robert f. wagner graduate school of public service\",\"school of international and public affairs, columbia university\",\"vernon l. smith\",\"american university school of international service\",\"andrea weber\",\"macroeconomic model\",\"richard timberlake\",\"united nations parliamentary assembly\",\"william a. niskanen\",\"divided government in the united states\",\"starve the beast\",\"99ers\",\"neoclassical liberalism\",\"bryan caplan\",\"american recovery and reinvestment act of 2009\",\"franz oppenheimer\",\"private highway\",\"economic nationalism\",\"outline of anarchism\",\"pickens plan\",\"vernon l. smith\",\"universal basic income\",\"free market fairness\",\"resource curse\",\"hedonism\",\"catch-22\",\"norwegian paradox\",\"resource justice\",\"environmental peacebuilding\",\"factor endowment\",\"equality of outcome\",\"history of communism\",\"labour voucher\",\"list of social democratic parties\",\"criticism of capitalism\",\"popular socialism\",\"industrial democracy\",\"religious socialism\",\"blanquism\",\"participism\",\"list of left-wing internationals\",\"left communism\",\"workplace democracy\",\"history of democratic socialism\",\"law of equal liberty\",\"edinburgh university socialist society\",\"equality of outcome\",\"history of communism\",\"labour voucher\",\"list of social democratic parties\",\"industrial democracy\",\"religious socialism\",\"blanquism\",\"frankfurt declaration\",\"participism\",\"list of left-wing internationals\",\"left communism\",\"workplace democracy\",\"edinburgh university socialist society\",\"consensus democracy\",\"michael albert\",\"criticism of capitalism\",\"popular socialism\",\"index of sociology articles\",\"law of equal liberty\",\"history of democratic socialism\",\"social corporatism\",\"list of social democratic parties\",\"michael albert\",\"criticism of capitalism\",\"popular socialism\",\"religious socialism\",\"law of equal liberty\",\"blanquism\",\"participism\",\"list of left-wing internationals\",\"workplace democracy\",\"history of democratic socialism\",\"edinburgh university socialist society\",\"bolivarian revolution\",\"equality of outcome\",\"history of communism\",\"list of social democratic parties\",\"neo-capitalism\",\"religious socialism\",\"blanquism\",\"history of social democracy\",\"gar alperovitz\",\"participism\",\"list of left-wing internationals\",\"left communism\",\"edinburgh university socialist society\",\"criticism of capitalism\",\"popular socialism\",\"theory x and theory y\",\"rat race\",\"neoauthoritarianism (china)\",\"history of democratic socialism\",\"law of equal liberty\",\"index of social and political philosophy articles\",\"list of social democratic parties\",\"religious socialism\",\"participism\",\"list of left-wing internationals\",\"edinburgh university socialist society\",\"criticism of capitalism\",\"popular socialism\",\"neosocialism\",\"history of democratic socialism\",\"law of equal liberty\",\"consumer class\",\"history of communism\",\"list of social democratic parties\",\"economic mobility\",\"religious communism\",\"history of capitalist theory\",\"history of social democracy\",\"john roemer\",\"frankfurt declaration\",\"marxist sociology\",\"participism\",\"list of left-wing internationals\",\"value product\",\"consensus democracy\",\"popular socialism\",\"degrowth\",\"new institutional economics\",\"anglo-saxon model\",\"zombie liberalism\",\"social corporatism\",\"history of democratic socialism\",\"equality of outcome\",\"frente despertar\",\"real-world economics review\",\"privatism\",\"neo-capitalism\",\"religious socialism\",\"revolutions of 1989\",\"left communism\",\"edinburgh university socialist society\",\"visible hand (economics)\",\"criticism of capitalism\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"economic power\",\"eco-capitalism\",\"structural violence\",\"antimilitarism\",\"surplus labour\",\"law of equal liberty\",\"consumer class\",\"list of social democratic parties\",\"civil libertarianism\",\"global justice movement\",\"an anarchist faq\",\"religious socialism\",\"non-interventionism\",\"history of capitalist theory\",\"voluntary society\",\"list of left-wing internationals\",\"left communism\",\"freedom of contract\",\"neoclassical liberalism\",\"edinburgh university socialist society\",\"bryan caplan\",\"consensus democracy\",\"michael albert\",\"outline of anarchism\",\"free migration\",\"antimilitarism\",\"history of democratic socialism\",\"law of equal liberty\",\"index of social and political philosophy articles\",\"history of communism\",\"list of social democratic parties\",\"an anarchist faq\",\"religious socialism\",\"marxist sociology\",\"list of left-wing internationals\",\"legal naturalism\",\"edinburgh university socialist society\",\"michael albert\",\"bibliography of works about communism\",\"outline of anarchism\",\"recuperation (politics)\",\"surplus labour\",\"value product\",\"history of democratic socialism\",\"law of equal liberty\",\"list of social democratic parties\",\"the journal of political philosophy\",\"radical egalitarianism\",\"religious socialism\",\"equality before the law\",\"list of left-wing internationals\",\"universal basic income\",\"history of democratic socialism\",\"edinburgh university socialist society\",\"index of social and political philosophy articles\",\"list of social democratic parties\",\"communism and lgbt rights\",\"crypto-communism\",\"religious socialism\",\"revolutions of 1989\",\"religious communism\",\"communist era\",\"marxist sociology\",\"list of left-wing internationals\",\"crimes against humanity under communist regimes\",\"legal naturalism\",\"edinburgh university socialist society\",\"comunismo a la tica\",\"bibliography of works about communism\",\"national communism\",\"communist correspondence committee\",\"surplus labour\",\"value product\",\"history of democratic socialism\",\"angst und vorurteil\",\"violence peace and peace research\",\"l'empire de la honte\",\"oppression\",\"global apartheid\",\"faye v. harrison\",\"symbolic power\",\"cycle of poverty\",\"verbal self-defense\",\"index of social and political philosophy articles\",\"appeasement\",\"civil libertarianism\",\"global justice movement\",\"peace journalism\",\"give peace a chance\",\"non-interventionism\",\"center on conscience & war\",\"free migration\",\"law of equal liberty\",\"neoclassical liberalism\",\"exequatur\",\"appeasement\",\"peace journalism\",\"note verbale\",\"grey-zone (international relations)\",\"give peace a chance\",\"science diplomacy\",\"charg\\u00e9 de mission\",\"non-interventionism\",\"center on conscience & war\",\"peace through strength\",\"full spectrum diplomacy\",\"idealism in international relations\",\"bryan caplan\",\"civil libertarianism\",\"triangular diplomacy\",\"global justice movement\",\"peace journalism\",\"give peace a chance\",\"non-interventionism\",\"center on conscience & war\",\"swiss neutrality\",\"free migration\",\"authoritarian left\",\"interventionism (politics)\",\"voluntary society\",\"freedom of contract\",\"neoclassical liberalism\",\"center on conscience & war\",\"peace journalism\",\"give peace a chance\",\"advocacy journalism\",\"thomas schelling\",\"economists for peace and security\",\"mesoeconomics\",\"sequential game\",\"thomas schelling\",\"bertrand competition\",\"schelling's segregation model\",\"two-level game theory\",\"paul milgrom\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"internality\",\"hobbesian trap\",\"daniel mcfadden\",\"daniel kahneman\",\"william vickrey\",\"bertrand paradox (economics)\",\"michael spence\",\"vernon l. smith\",\"analytical sociology\",\"trygve haavelmo\",\"john harsanyi\",\"impeachment\",\"worldwide influence of the constitution of the united states\",\"impeachment\",\"concurrent powers\",\"the final days (2000 film)\",\"plenary power\",\"i did not have sexual relations with that woman\",\"implied powers\",\"divided government in the united states\",\"campaign finance\",\"timeline of voting rights in the united states\",\"campaign finance\",\"gevald campaign\",\"voting rights in the united states\",\"daniel kahneman\",\"paul milgrom\",\"william vickrey\",\"sequential game\",\"john harsanyi\",\"daniel kahneman\",\"paul milgrom\",\"william vickrey\",\"bertrand paradox (economics)\",\"bertrand competition\",\"john harsanyi\",\"cognitive bias\",\"blink: the power of thinking without thinking\",\"bertrand competition\",\"schelling's segregation model\",\"clive granger\",\"flashback (psychology)\",\"eugene fama\",\"steven n. s. cheung\",\"swanson, nolan and pelham teacher and parent rating scale\",\"paul romer\",\"harry harlow\",\"quantitative research\",\"cognitivism (psychology)\",\"cumulative prospect theory\",\"accelerator effect\",\"new institutional economics\",\"psychohistory\",\"social cognition and interaction training\",\"daniel mcfadden\",\"daniel kahneman\",\"michael spence\",\"leonid kantorovich\",\"psychoanalytic theory\",\"conditioned emotional response\",\"john harsanyi\",\"economic evaluation of time\",\"list of psychological schools\",\"sunk cost\",\"list of financial economists\",\"quantitative psychological research\",\"nava ashraf\",\"paul milgrom\",\"women-are-wonderful effect\",\"bengt holmstr\\u00f6m\",\"myron scholes\",\"hiding hand principle\",\"list of jewish american economists\",\"william vickrey\",\"georg weizs\\u00e4cker\",\"bertrand paradox (economics)\",\"st. petersburg paradox\",\"repertory grid\",\"vernon l. smith\",\"trygve haavelmo\",\"bertrand competition\",\"wilson doctrine (economics)\",\"paul milgrom\",\"william vickrey\",\"bertrand paradox (economics)\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"vernon l. smith\",\"trygve haavelmo\",\"john harsanyi\",\"list of financial economists\",\"bertrand competition\",\"schelling's segregation model\",\"clive granger\",\"eugene fama\",\"vernon l. smith\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"myron scholes\",\"efficiency wage\",\"erwin plein nemmers prize in economics\",\"daniel mcfadden\",\"william vickrey\",\"michael spence\",\"bertrand paradox (economics)\",\"trygve haavelmo\",\"leonid kantorovich\",\"auction theory\",\"sharon oster\",\"lawrence summers\",\"bertrand competition\",\"schelling's segregation model\",\"clive granger\",\"eugene fama\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"auction theory\",\"jacob hollander\",\"myron scholes\",\"daniel mcfadden\",\"william vickrey\",\"bertrand paradox (economics)\",\"michael spence\",\"leonid kantorovich\",\"vernon l. smith\",\"trygve haavelmo\",\"net worth\",\"interprovincial migration in canada\",\"economic power\",\"list of cognitive biases\",\"social media in the 2020 united states presidential election\",\"social media use by donald trump\",\"consumer class\",\"recuperation (politics)\",\"publicity stunt\",\"religious communism\",\"christian fascism\",\"christian egalitarianism\",\"index of social and political philosophy articles\",\"bibliography of works about communism\",\"national communism\",\"crimes against humanity under communist regimes\",\"harvest hills cooperative community\",\"biblical patriarchy\",\"radical egalitarianism\",\"christian fascism\",\"authoritarian left\",\"titicut follies\",\"obtundation\",\"sopor (sleep)\",\"necropolitics\",\"public opinion and activism in the terri schiavo case\",\"procreative beneficence\",\"coma\",\"list of cycles\",\"awareness\",\"prohibition of dying\",\"out-of-body experience\",\"index of social and political philosophy articles\",\"bryan caplan\",\"free migration\",\"civil libertarianism\",\"global justice movement\",\"voluntary society\",\"law of equal liberty\",\"neoclassical liberalism\",\"index of social and political philosophy articles\",\"organicism\",\"economic nationalism\",\"pathos\",\"index of social and political philosophy articles\",\"ferdinand de saussure\",\"reductionism\",\"sociological naturalism\",\"social organism\",\"conservative corporatism\",\"social corporatism\",\"liberal corporatism\",\"istv\\u00e1n hont\",\"outline of globalization\",\"economic nationalism\",\"acceptance\",\"gratitude\",\"rage (emotion)\",\"resentment\",\"pathos\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"neglect\",\"confusion\",\"emotionality\",\"schadenfreude\",\"wilhelm windelband\",\"catharsis\",\"amusement\",\"moral emotions\",\"corporate communication\",\"hostility\",\"kindness\",\"names for the human species\",\"pride\",\"affect (psychology)\",\"appraisal theory\",\"index of urban sociology articles\",\"pork barrel\",\"distributive tendency\",\"clientelism\",\"survey data collection\",\"data collection system\",\"caucus for a new political science\",\"bibliography of sociology\",\"alan wolfe\",\"econtalk\",\"bryan caplan\",\"vernon l. smith\",\"eugene fama\",\"cognitive bias\",\"asabiyyah\",\"mediumship\",\"hypnosis\",\"inner peace\",\"biorhythm (pseudoscience)\",\"list of cycles\",\"levitation (paranormal)\",\"automatic writing\",\"islam and children\",\"atlanticism\",\"psychohistory\",\"early social changes under islam\",\"lady wonder\",\"gaia philosophy\",\"equality before the law\",\"islamic sexual jurisprudence\",\"cosmos and psyche\",\"islamic toilet etiquette\",\"proto-industrialization\",\"astrology\",\"first world\",\"istv\\u00e1n hont\",\"political studies (journal)\",\"michael thrasher\",\"politics (academic journal)\",\"wyn grant\",\"british journal of politics and international relations\",\"political studies review\",\"against equality of opportunity\",\"school of politics and international relations, university of nottingham\",\"emilia justyna powell\",\"democratic globalization\",\"global citizenship\",\"social dominance orientation\",\"world economy\",\"democratic globalization\",\"global apartheid\",\"united nations parliamentary assembly\",\"ronen palan\",\"global politics\",\"atlanticism\",\"right to development\",\"personhood\",\"proto-industrialization\",\"law of equal liberty\",\"first world\",\"civil libertarianism\",\"global justice movement\",\"voluntary society\",\"bryan caplan\",\"consensus democracy\",\"michael albert\",\"free migration\",\"coma\",\"morphological freedom\",\"right to development\",\"societal attitudes towards abortion\",\"self-awareness\",\"id, ego and super-ego\",\"personhood\",\"gary l. francione\",\"person\",\"international sanctions\",\"least developed countries\",\"pippa norris\",\"glossary of international relations terms\",\"national crime victimization survey\",\"dark figure of crime\",\"national crime victimization survey\",\"ratification\",\"parliamentary procedure\",\"dualism (law)\",\"enemy of the people (albania)\",\"global justice movement\",\"free-market healthcare\",\"voluntary society\",\"neoclassical liberalism\",\"bryan caplan\",\"outline of anarchism\",\"free migration\",\"catch-22\",\"hedonism\",\"echo chamber (media)\",\"cognitive bias\",\"lerner paradox\",\"downs\\u2013thomson paradox\",\"icarus paradox\",\"leontief paradox\",\"edgeworth paradox\",\"philosophy of max stirner\",\"list of futurama characters\",\"reductionism\",\"diamond-water paradox\",\"paradox of value\",\"social reality\",\"anhedonia\",\"scitovsky paradox\",\"hedonism\",\"mandeville's paradox\",\"donor class\",\"paradox of prosperity\",\"bertrand paradox (economics)\",\"st. petersburg paradox\",\"paradox of thrift\",\"abilene paradox\",\"hobbesian trap\",\"diamond-water paradox\",\"the good soldier \\u0161vejk\",\"paradox of value\",\"lerner paradox\",\"nominative determinism\",\"scitovsky paradox\",\"d\\u00e9j\\u00e0 vu\",\"mandeville's paradox\",\"paradox of prosperity\",\"bertrand paradox (economics)\",\"catch-22\",\"downs\\u2013thomson paradox\",\"st. petersburg paradox\",\"icarus paradox\",\"paradox of thrift\",\"leontief paradox\",\"edgeworth paradox\",\"abilene paradox\",\"sequential probability ratio test\",\"guttman scale\",\"reliability (statistics)\",\"psychological statistics\",\"public opinion on climate change\",\"chiara bottici\",\"queer ecology\",\"eco-capitalism\",\"greenwashing\",\"greenwashing\",\"privatism\",\"sustainable business\",\"queer ecology\",\"anti-gender movement\",\"pride\",\"gender essentialism\",\"greenwashing\",\"united nations parliamentary assembly\",\"liberal international order\",\"democratic globalization\",\"democratic globalization\",\"global apartheid\",\"index of social and political philosophy articles\",\"gender essentialism\",\"morphological freedom\",\"anti-gender movement\",\"sexual inversion (sexology)\",\"biology and sexual orientation\",\"sissyphobia: gay men and effeminate behavior\",\"cooper do-nuts riot\",\"person\",\"procreative beneficence\",\"ljiljana radoni\\u0107\",\"identity (philosophy)\",\"reductionism\",\"collective effervescence\",\"self-deception\",\"social reality\",\"social actions\",\"unitarian universalism\",\"abilene paradox\",\"index of social and political philosophy articles\",\"identity (philosophy)\",\"reductionism\",\"collective effervescence\",\"self-deception\",\"index of sociology articles\",\"emotive (sociology)\",\"social actions\",\"unitarian universalism\",\"abilene paradox\",\"psychoanalytic theory\",\"outline of thought\",\"self-deception\",\"peter sloterdijk\",\"awareness\",\"interactionism\",\"cogito, ergo sum\",\"hermann lotze\",\"task force\",\"ernst mally\",\"self-defeating prophecy\",\"mass action (sociology)\",\"l'ann\\u00e9e sociologique\",\"group action (sociology)\",\"instrumental and value-rational action\",\"action theory (sociology)\",\"index of sociology articles\",\"group action (sociology)\",\"social actions\",\"religious literacy\",\"constantin noica\",\"chicago school (sociology)\",\"david chalmers\",\"agency (philosophy)\",\"henri poincar\\u00e9\",\"c. d. broad\",\"task force\",\"possible world\",\"reductionism\",\"wilhelm windelband\",\"index of sociology articles\",\"gaia philosophy\",\"philosophy of life\",\"direct and indirect realism\",\"id, ego and super-ego\",\"logology (science)\",\"sociology of scientific ignorance\",\"philosophical analysis\",\"legalism (chinese philosophy)\",\"emotivism\",\"peace dividend\",\"doncaster pride\",\"numbers (vancouver)\",\"guns versus butter model\",\"private military company\",\"black eagle (montreal)\",\"voluntary society\",\"violent non-state actors at sea\",\"finance & development\",\"guns versus butter model\",\"production\\u2013possibility frontier\",\"songun\",\"exequatur\",\"note verbale\",\"full spectrum diplomacy\",\"science diplomacy\",\"exequatur\",\"note verbale\",\"science diplomacy\",\"economics of science\",\"exequatur\",\"double hermeneutic\",\"scientocracy\",\"mapping controversies\",\"regulation of science\",\"note verbale\",\"science & diplomacy\",\"sociotechnology\",\"sociology of scientific ignorance\",\"technical change\",\"normalization process theory\",\"exequatur\",\"note verbale\",\"jus commune\",\"vacatio legis\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"grace skogstad\",\"james tully (philosopher)\",\"outline of culture\",\"parochial political culture\",\"political culture of germany\",\"the civic culture\",\"political culture of the united states\",\"political culture of germany\",\"political culture of the united states\",\"red wall (us politics)\",\"voluntary society\",\"labor theory of property\",\"bryan caplan\",\"global justice movement\",\"free migration\",\"neoclassical liberalism\",\"consumer class\",\"neo-capitalism\",\"history of capitalist theory\",\"visible hand (economics)\",\"index of sociology articles\",\"new institutional economics\",\"anglo-saxon model\",\"review of international political economy\",\"eric helleiner\",\"attention economy\",\"public opinion on nuclear issues\",\"global environmental politics\",\"sustainable energy\",\"corporatization\",\"in kind\",\"coal phase-out\",\"renewable energy transition\",\"community-supported agriculture\",\"programme for economic advancement and community empowerment\",\"ecocide\",\"drought tolerance\",\"green industrial policy\",\"un-energy\",\"energy research & social science\",\"least developed countries\",\"2000-watt society\",\"territorialisation of carbon governance\",\"green job\",\"environmental policy of the european union\",\"a green new deal\",\"international energy agency\",\"carbon fee and dividend\",\"microgeneration\",\"outline of culture\",\"liesbet hooghe\",\"multi-level governance\",\"european union studies association\",\"bryan caplan\",\"an anarchist faq\",\"eugene fama\",\"william a. niskanen\",\"singleton (global governance)\",\"steven n. s. cheung\",\"david laidler\",\"neoclassical liberalism\",\"myron scholes\",\"bryan caplan\",\"gadsden flag\",\"the independent review\",\"free migration\",\"index of sociopolitical thinkers\",\"fritz w. scharpf\",\"pippa norris\",\"androcentrism\",\"bumiputera (malaysia)\",\"christian privilege\",\"social model of disability\",\"structural discrimination\",\"oppression\",\"discrimination against autistic people\",\"structural discrimination\",\"androcentrism\",\"oppression\",\"bumiputera (malaysia)\",\"discrimination against autistic people\",\"social model of disability\",\"index of social and political philosophy articles\",\"matrix of domination\",\"androcentrism\",\"destabilisation\",\"bumiputera (malaysia)\",\"social model of disability\",\"spatial justice\",\"discrimination against autistic people\",\"fragmentation (sociology)\",\"bibliography of sociology\",\"womyn's land\",\"injustice\",\"neglect\",\"delmos jones\",\"structural discrimination\",\"oppression\",\"androcentrism\",\"medicalization\",\"health geography\",\"bumiputera (malaysia)\",\"index of sociology articles\",\"structural discrimination\",\"discrimination against autistic people\",\"diplomatic protection\",\"person\",\"asu college of public service & community solutions\",\"reflexive modernization\",\"history of social democracy\",\"list of social democratic parties\",\"social corporatism\",\"history of social democracy\",\"list of social democratic parties\",\"violent non-state actor\",\"gustave le bon\",\"ernest jones\",\"list of sociologists\",\"collective mental state\",\"society of anthropology of paris\",\"overview of 21st-century propaganda\",\"political journalism\",\"deployment management\",\"twitter diplomacy\",\"inter-municipal cooperation\",\"corporatization\",\"open economy\",\"unplanned economies\",\"in kind\",\"robinson crusoe economy\",\"anglo-saxon model\",\"world politics\",\"centre for health and international relations\",\"world economy\",\"outline of globalization\",\"democratic globalization\",\"global apartheid\",\"ronen palan\",\"global politics\",\"international sanctions\",\"status quo state\",\"international sanctions\",\"international isolation\",\"cycle of poverty\",\"awza'i\",\"ahl al-hadith\",\"madhhab\",\"thawri\",\"ahl al-hadith\",\"madhhab\",\"thawri\",\"ahl al-hadith\",\"madhhab\",\"madhhab\",\"ghazi (warrior)\",\"madhhab\",\"istihlal\",\"mus\\u00e9e de l'homme\",\"mus\\u00e9e de l'homme\",\"reed's law\",\"beckstrom's law\",\"reed's law\",\"local multiplier effect\",\"history of microeconomics\",\"peak wheat\",\"law of supply\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"preclusive purchasing\",\"extended-hours trading\",\"momentum (finance)\",\"rate of return\",\"growth stock\",\"equity premium puzzle\",\"arbitrage pricing theory\",\"alpha (finance)\",\"market trend\",\"momentum (finance)\",\"rate of return\",\"political risk\",\"equity premium puzzle\",\"growth stock\",\"extended-hours trading\",\"fama\\u2013french three-factor model\",\"concentration risk\",\"roll-geske-whaley\",\"risk factor (finance)\",\"alpha (finance)\",\"market trend\",\"extended-hours trading\",\"momentum (finance)\",\"rate of return\",\"equity premium puzzle\",\"alpha (finance)\",\"market trend\",\"technical indicator\",\"momentum (finance)\",\"breakout (technical analysis)\",\"doji\",\"rate of return\",\"equity premium puzzle\",\"extended-hours trading\",\"donchian channel\",\"carbon bubble\",\"hanging man (candlestick pattern)\",\"alpha (finance)\",\"pride\",\"cognitive bias\",\"sunk cost\",\"nava ashraf\",\"asset specificity\",\"is\\u2013lm model\",\"accelerator effect\",\"macroeconomic model\",\"keynesian cross\",\"ad\\u2013ia model\",\"solow\\u2013swan model\",\"visible hand (economics)\",\"accelerator effect\",\"ak model\",\"macroeconomic model\",\"marginal propensity to consume\",\"99ers\",\"circular flow of income\",\"consumer debt\",\"identity line\",\"ramsey\\u2013cass\\u2013koopmans model\",\"kiyotaki\\u2013moore model\",\"solow\\u2013swan model\",\"indirect inference\",\"visible hand (economics)\",\"accelerator effect\",\"ak model\",\"99ers\",\"consumer debt\",\"time series\",\"ramsey\\u2013cass\\u2013koopmans model\",\"hiding hand principle\",\"new institutional economics\",\"marginal propensity to consume\",\"nava ashraf\",\"steven n. s. cheung\",\"georg weizs\\u00e4cker\",\"gold-collar worker\",\"discouraged worker\",\"99ers\",\"gold-collar worker\",\"99ers\",\"rate of return\",\"seasoned equity offering\",\"returns (economics)\",\"solow\\u2013swan model\",\"risk factor (finance)\",\"rate of return\",\"time value of money\",\"kuznets curve\",\"market for corporate control\",\"economics of science\",\"solow\\u2013swan model\",\"gerald shove\",\"marginal return\",\"convergence (economics)\",\"toothpaste tube theory\",\"history of microeconomics\",\"history of microeconomics\",\"cumulative prospect theory\",\"consumption (sociology)\",\"consumer class\",\"world economy\",\"rebound effect (conservation)\",\"principles of economics (marshall book)\",\"charles henry hull\",\"ecological economics (journal)\",\"new institutional economics\",\"ecomodernism\",\"inframarginal analysis\",\"weak and strong sustainability\",\"neo-ricardianism\",\"paradox of thrift\",\"first world\",\"universal basic income\",\"microgeneration\",\"economics of science\",\"world economy\",\"least developed countries\",\"blue economy\",\"outline of globalization\",\"democratic globalization\",\"ronen palan\",\"primakov readings\",\"sustainable development goal 17\",\"bric\",\"list of countries by inequality-adjusted income\",\"list of countries by share of income of the richest one percent\",\"development geography\",\"list of bordering countries with greatest relative differences in gdp (ppp) per capita\",\"sustainable development goal 11\",\"failed state\",\"sustainable development goal 14\",\"first world\",\"heavily indebted poor countries\",\"double hermeneutic\",\"scientocracy\",\"mapping controversies\",\"regulation of science\",\"sociotechnology\",\"history of science policy\",\"logology (science)\",\"sociology of scientific ignorance\",\"technical change\",\"normalization process theory\",\"community-supported agriculture\",\"blue justice\",\"global justice movement\",\"global apartheid\",\"ronen palan\",\"global apartheid\",\"taxation in uruguay\",\"open economy\",\"unplanned economies\",\"pay it forward\",\"anglo-saxon model\",\"robinson crusoe economy\",\"core self-evaluations\",\"open music model\",\"open-mindedness\",\"fiscal transparency\",\"collaboration\",\"dark triad\",\"openness\",\"binomial options pricing model\",\"option screener\",\"roll-geske-whaley\",\"consumer debt\",\"edgeworth binomial tree\",\"garman-kohlhagen model\",\"forward price\",\"binomial options pricing model\",\"option screener\",\"roll-geske-whaley\",\"consumer debt\",\"edgeworth binomial tree\",\"garman-kohlhagen model\",\"option screener\",\"binomial options pricing model\",\"induced consumption\",\"autonomous consumption\",\"roll-geske-whaley\",\"edgeworth binomial tree\",\"alternative financial service\",\"garman-kohlhagen model\",\"vernon l. smith\",\"index (economics)\",\"economic data\",\"list of financial economists\",\"schelling's segregation model\",\"clive granger\",\"eugene fama\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"myron scholes\",\"supreme court economic review\",\"american recovery and reinvestment act of 2009\",\"econophysics\",\"daniel mcfadden\",\"michael spence\",\"leonid kantorovich\",\"vernon l. smith\",\"trygve haavelmo\",\"heckscher\\u2013ohlin model\",\"population and development review\",\"list of sociology journals\",\"sex and reason\",\"equity premium puzzle\",\"bertrand competition\",\"edgeworth paradox\",\"bertrand competition\",\"impossible trinity\",\"convergence (economics)\",\"communications management\",\"organizational space\",\"a green new deal\",\"pickens plan\",\"peak wheat\",\"kuznets curve\",\"pickens plan\",\"corn exchange\",\"a green new deal\",\"cost of electricity by source\",\"power-to-x\",\"microgeneration\",\"mundell\\u2013tobin effect\",\"paul romer\",\"ramsey\\u2013cass\\u2013koopmans model\",\"price index\",\"balassa\\u2013samuelson effect\",\"heckscher\\u2013ohlin model\",\"leontief paradox\",\"keynes\\u2013ramsey rule\",\"dynamical system\",\"tibor\",\"euronia\",\"greek withdrawal from the eurozone\",\"sofr\",\"sofr\",\"tibor\",\"induced consumption\",\"autonomous consumption\",\"marginal propensity to import\",\"myron scholes\",\"hiding hand principle\",\"new institutional economics\",\"eugene fama\",\"nava ashraf\",\"william a. niskanen\",\"georg weizs\\u00e4cker\",\"david laidler\",\"georg weizs\\u00e4cker\",\"hiding hand principle\",\"new institutional economics\",\"hiding hand principle\",\"new institutional economics\",\"new institutional economics\",\"food sovereignty\",\"destabilisation\",\"social threefolding\",\"myron scholes\",\"on the principles of political economy and taxation\",\"principles of political economy (malthus book)\",\"history of microeconomics\",\"law of rent\",\"myron scholes\",\"list of jewish american economists\",\"list of financial economists\",\"low-volatility anomaly\",\"eugene fama\",\"william a. niskanen\",\"fischer black prize\",\"paul romer\",\"roll-geske-whaley\",\"david laidler\",\"bengt holmstr\\u00f6m\",\"trygve haavelmo\",\"noosphere\",\"noosphere\",\"social organism\",\"econophysics\",\"index (economics)\",\"lag operator\",\"clive granger\",\"secular variation\",\"time warp edit distance\",\"analysis of rhythmic variance\",\"time series\",\"meta learning\",\"financial models with long-tailed distributions and volatility clustering\",\"open energy system databases\",\"unevenly spaced time series\",\"peso problem (finance)\",\"economic puzzle\",\"list of cognitive biases\",\"forward premium anomaly\",\"normalcy bias\",\"law of the instrument\",\"proportionality bias\",\"is the glass half empty or half full?\",\"cognitive bias\",\"outline of thought\",\"trait ascription bias\",\"defence mechanism\",\"probability matching\",\"equity home bias puzzle\",\"forward premium anomaly\",\"peso problem (finance)\",\"peso problem (finance)\",\"price index\",\"b\\u00e9la balassa\",\"sectoral output\",\"cost-weighted activity index\",\"volume index\",\"index (economics)\",\"inertial inflation\",\"deflator\",\"dixit\\u2013stiglitz model\",\"collaboration\",\"managerialism\",\"ministry of infrastructure and water management\",\"debate chamber\",\"control (management)\",\"communications management\",\"collaboration\",\"henri poincar\\u00e9\",\"managerialism\",\"control (management)\",\"communications management\",\"structural inequality\",\"davis\\u2013moore hypothesis\",\"immigrant-host model\",\"consumer class\",\"new institutional economics\",\"economic mobility\",\"society for economic anthropology\",\"colonial origins of comparative development\",\"asset specificity\",\"new institutional economics\",\"consumer class\",\"great gatsby curve\",\"survey on household income and wealth\",\"vertical mobility\",\"feldstein\\u2013horioka puzzle\",\"backus\\u2013kehoe\\u2013kydland puzzle\",\"bowley's law\",\"econophysics\",\"complex adaptive system\",\"value product\",\"surplus labour\",\"production for profit\",\"reproduction (economics)\",\"doji\",\"donchian channel\",\"donchian channel\",\"technical indicator\",\"momentum (finance)\",\"hanging man (candlestick pattern)\",\"technical indicator\",\"momentum (finance)\",\"hanging man (candlestick pattern)\",\"sectoral balances\",\"i-spread\",\"variable rate debt obligation\",\"perpetual bond\",\"black\\u2013derman\\u2013toy model\",\"i-spread\",\"variable rate debt obligation\",\"black\\u2013derman\\u2013toy model\",\"variable rate debt obligation\",\"black\\u2013derman\\u2013toy model\",\"elhanan helpman\",\"paradox of thrift\",\"sectoral balances\",\"economics (textbook)\",\"excess reserves\",\"richard koo\",\"eugene fama\",\"national equities exchange and quotations\",\"macroeconomic regulation and control\",\"globalization and women in china\",\"history of microeconomics\",\"benefit financing model\",\"daniel mcfadden\",\"erwin plein nemmers prize in economics\",\"bengt holmstr\\u00f6m\",\"trygve haavelmo\",\"autonomous consumption\",\"relative income hypothesis\",\"relative income hypothesis\",\"visible hand (economics)\",\"real-time economy\",\"the theory of interstellar trade\",\"rat race\",\"average fixed cost\",\"revealed preference\",\"preference theory\",\"conjoint analysis\",\"sofr\",\"food processing\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"henri poincar\\u00e9\",\"urban metabolism\",\"daniel mcfadden\",\"dynamic discrete choice\",\"conjoint analysis\",\"economists for peace and security\",\"erwin plein nemmers prize in economics\",\"american recovery and reinvestment act of 2009\",\"lawrence summers\",\"schelling's segregation model\",\"michael spence\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"trygve haavelmo\",\"jacob hollander\",\"methodology of econometrics\",\"late trading\",\"benny moldovanu\",\"two-sided matching\",\"political risk\",\"risk factor (finance)\",\"build\\u2013operate\\u2013transfer\",\"risk factor (finance)\",\"first world\",\"labor theory of property\",\"the great transformation (book)\",\"grazing rights\",\"air rights\",\"public property\",\"index of social and political philosophy articles\",\"the great transformation (book)\",\"public property\",\"grazing rights\",\"air rights\",\"demand shaping\",\"snackwell effect\",\"community-supported agriculture\",\"ecolabel\",\"material flow analysis\",\"urban metabolism\",\"greenwashing\",\"list of food labeling regulations\",\"material flow analysis\",\"sustainability standards and certification\",\"urban metabolism\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"organigraph\",\"urban metabolism\",\"list of national legal systems\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"complex adaptive system\",\"gruppi di acquisto solidale\",\"territorialisation of carbon governance\",\"sustainability and environmental management\",\"development-supported agriculture\",\"sustainability standards and certification\",\"sustainable business\",\"carbon fee and dividend\",\"index of social and political philosophy articles\",\"jensen prize\",\"outworker\",\"american system of manufacturing\",\"chaining\",\"acceptance and commitment therapy\",\"autogenic training\",\"conversational model\",\"task analysis\",\"hypnosis\",\"british psychotherapy foundation\",\"history of psychotherapy\",\"catharsis\",\"behaviour therapy\",\"social cognition and interaction training\",\"economic law\",\"clive granger\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"timo ter\\u00e4svirta\",\"quantitative research\",\"trygve haavelmo\",\"time value of money\",\"cost of electricity by source\",\"term (time)\",\"poverty class\",\"cycle of poverty\",\"scottish index of multiple deprivation\",\"social vulnerability\",\"poverty class\",\"scottish index of multiple deprivation\",\"poverty class\",\"cycle of poverty\",\"returns (economics)\",\"deflator\",\"deflator\",\"list of special economic zones\",\"poverty class\",\"environmental racism in the united states\",\"social reproduction\",\"hemline index\",\"paul romer\",\"output elasticity\",\"schelling's segregation model\",\"eugene fama\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"michael spence\",\"leonid kantorovich\",\"trygve haavelmo\",\"american recovery and reinvestment act of 2009\",\"lawrence summers\",\"economic stimulus appropriations act of 1977\",\"american recovery and reinvestment act of 2009\",\"a green new deal\",\"austerity: the history of a dangerous idea\",\"lawrence summers\",\"trygve haavelmo\",\"identity line\",\"the triple revolution\",\"debtocracy\",\"principles of political economy\",\"principles of political economy\",\"principles of political economy (malthus book)\",\"history of democratic socialism\",\"marginal rate of transformation\",\"hobbesian trap\",\"bengt holmstr\\u00f6m\",\"internality\",\"trygve haavelmo\",\"eugene fama\",\"bengt holmstr\\u00f6m\",\"michael spence\",\"leonid kantorovich\",\"trygve haavelmo\",\"eugene fama\",\"bengt holmstr\\u00f6m\",\"michael spence\",\"leonid kantorovich\",\"vertical mobility\",\"great gatsby curve\",\"life chances\",\"sociology of the world religions\",\"iron cage\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"list of sociologists\",\"science as a vocation\",\"ideal type\",\"tripartite classification of authority\",\"roman agrarian history and its significance for public and private law\",\"ernst borinski\",\"ferdinand de saussure\",\"rogers brubaker\",\"donatella della porta\",\"franz oppenheimer\",\"riane eisler\",\"eviatar zerubavel\",\"helmuth plessner\",\"max scheler\",\"chua beng huat\",\"randy david\",\"saskia wieringa\",\"p\\u0131nar selek\",\"life chances\",\"sociology of the world religions\",\"iron cage\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"science as a vocation\",\"ideal type\",\"tripartite classification of authority\",\"roman agrarian history and its significance for public and private law\",\"life chances\",\"iron cage\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"science as a vocation\",\"ideal type\",\"tripartite classification of authority\",\"dyad (sociology)\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"science as a vocation\",\"tripartite classification of authority\",\"index of sociology articles\",\"iron cage\",\"life chances\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"science as a vocation\",\"tripartite classification of authority\",\"law of the instrument\",\"underclass\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"status attainment\",\"science as a vocation\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"authority (sociology)\",\"science as a vocation\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"greek withdrawal from the eurozone\",\"michael spence\",\"microgeneration\",\"hicks-tinbergen award\",\"martin hellwig\",\"fabrizio zilibotti\",\"international energy agency\",\"poverty class\",\"coal phase-out\",\"renewable energy transition\",\"green industrial policy\",\"energy charter treaty\",\"joint organisations data initiative\",\"cost of electricity by source\",\"international energy agency\",\"open energy system databases\",\"power-to-x\",\"cost of electricity by source\",\"microgeneration\",\"bric\",\"3g (countries)\",\"first world\",\"heavily indebted poor countries\",\"real-world economics review\",\"john roemer\",\"marxist sociology\",\"surplus labour\",\"john roemer\",\"reproduction (economics)\",\"superrationality\",\"history of social democracy\",\"neoauthoritarianism (china)\",\"reproduction (economics)\",\"reproduction (economics)\",\"capital (marxism)\",\"reproduction (economics)\",\"sociology in poland\",\"corner solution\",\"ferdinand de saussure\",\"direct and indirect realism\",\"david chalmers\",\"philosophical analysis\",\"computational theory of mind\",\"c. d. broad\",\"task force\",\"role ethics\",\"william frankena\",\"value judgment\",\"david chalmers\",\"philosophical analysis\",\"c. d. broad\",\"state of affairs (sociology)\",\"david chalmers\",\"philosophical analysis\",\"c. d. broad\",\"logical form (linguistics)\",\"interactionism\",\"the emperor's new mind\",\"altered state of consciousness\",\"awareness\",\"direct and indirect realism\",\"global workspace theory\",\"society for philosophy and psychology\",\"computational theory of mind\",\"philosophical analysis\",\"c. d. broad\",\"subconscious\",\"scientocracy\",\"regulation of science\",\"history of science policy\",\"technical change\",\"henri poincar\\u00e9\",\"c. d. broad\",\"double hermeneutic\",\"mapping controversies\",\"wilhelm windelband\",\"sociotechnology\",\"logology (science)\",\"philosophical analysis\",\"normalization process theory\",\"anguish\",\"acceptance\",\"neglect\",\"gratitude\",\"confusion\",\"emotionality\",\"schadenfreude\",\"c. d. broad\",\"amusement\",\"resentment\",\"logology (science)\",\"johann friedrich herbart\",\"hostility\",\"kindness\",\"hermann lotze\",\"pride\",\"philosophical analysis\",\"henri poincar\\u00e9\",\"logology (science)\",\"henri poincar\\u00e9\",\"philosophical analysis\",\"c. d. broad\",\"subconscious\",\"interactionism\",\"c. d. broad\",\"william frankena\",\"logology (science)\",\"causa sui\",\"philosophical analysis\",\"thumos\",\"index of sociopolitical thinkers\",\"ressentiment\",\"psychoanalytic theory\",\"peter sloterdijk\",\"all animals are equal, but some animals are more equal than others\",\"self-awareness\",\"cogito, ergo sum\",\"bicameral mentality\",\"pride\",\"outline of thought\",\"person\",\"altered state of consciousness\",\"awareness\",\"school of diplomacy\",\"legalism (chinese philosophy)\",\"william frankena\",\"control (management)\",\"philosophy of life\",\"theory x and theory y\",\"knowledge of the holocaust in nazi germany and german-occupied europe\",\"responsibility\",\"reflexive modernization\",\"sock puppet account\",\"groupism\",\"value-added theory\",\"global justice movement\",\"list of women anthropologists\",\"marija gimbutas\",\"the state (book)\",\"outline of anarchism\",\"the american journal of economics and sociology\",\"relational sociology\",\"names for the human species\",\"german sociological association\",\"linguistic description\",\"linguistic system\",\"metalanguage\",\"index of sociopolitical thinkers\",\"cogito, ergo sum\",\"max scheler\",\"ressentiment\",\"homo faber\",\"p\\u0131nar selek\",\"analytic frame\",\"list of psychological schools\",\"quantitative psychological research\",\"designing social inquiry\",\"flashback (psychology)\",\"swanson, nolan and pelham teacher and parent rating scale\",\"women-are-wonderful effect\",\"harry harlow\",\"cognitivism (psychology)\",\"index of sociology articles\",\"psychohistory\",\"social cognition and interaction training\",\"british polling council\",\"psychoanalytic theory\",\"repertory grid\",\"conditioned emotional response\",\"agency (sociology)\",\"non-representational theory\",\"secondary deviance\",\"altered state of consciousness\",\"global workspace theory\",\"computational theory of mind\",\"total institution\",\"safety-valve institution\",\"index of sociology articles\",\"resocialization\",\"open-mindedness\",\"black tax\",\"visible minority\",\"official bilingualism in the public service of canada\",\"quiet revolution\",\"national question (quebec)\",\"visible minority\",\"occupational closure\",\"injustice\",\"civility\",\"resentment\",\"acceptance\",\"vulnerable adult\",\"gratitude\",\"destabilisation\",\"rage (emotion)\",\"resentment\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"neglect\",\"confusion\",\"emotionality\",\"schadenfreude\",\"emotional abuse\",\"amusement\",\"moral emotions\",\"adlerian\",\"hostility\",\"kindness\",\"pride\",\"affect (psychology)\",\"appraisal theory\",\"social dominance orientation\",\"emotional abuse\",\"reflexive modernization\",\"classification of advocacy groups\",\"index of social and political philosophy articles\",\"agency (sociology)\",\"instrumental and intrinsic value\",\"instrumental and value rationality\",\"group action (sociology)\",\"bibliography of sociology\",\"ursula apitzsch\",\"ren\\u00e9-k\\u00f6nig-gesellschaft\",\"akademie f\\u00fcr soziologie\",\"kurt heinrich wolff\",\"international council for science\",\"norwegian sociological association\",\"research in social stratification and mobility\",\"european sociological association\",\"sociology in poland\",\"list of sociology journals\",\"l'ann\\u00e9e sociologique\",\"contemporary jewry\",\"the american journal of economics and sociology\",\"sociological insight\",\"journal of sociology\",\"identity crisis\",\"person\",\"greatness\",\"person\",\"topic and comment\",\"hypnosis\",\"sleep and learning\",\"autogenic training\",\"sybil (schreiber book)\",\"altered state of consciousness\",\"mediumship\",\"behaviour therapy\",\"acceptance and commitment therapy\",\"d\\u00e9j\\u00e0 vu\",\"hypnosis\",\"outline of thought\",\"levitation (paranormal)\",\"subconscious\",\"alter ego\",\"hypnodermatology\",\"flow (psychology)\",\"slain in the spirit\",\"catharsis\",\"lady wonder\",\"self-hypnosis\",\"psychonautics\",\"hypnopompic\",\"automatic writing\",\"adaptive capacity\",\"organizational adaptation\",\"computational sociology\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"index of sociology articles\",\"jacqueline rose\",\"the white goddess\",\"acceptance\",\"biology and sexual orientation\",\"gratitude\",\"mad pride\",\"rage (emotion)\",\"resentment\",\"emotional selection\",\"dark triad\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"womyn's land\",\"anguish\",\"scare\",\"sexual inversion (sexology)\",\"cooper do-nuts riot\",\"anti-gender movement\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"garden of allah (cabaret)\",\"moral emotions\",\"hostility\",\"kindness\",\"affect (psychology)\",\"sissyphobia: gay men and effeminate behavior\",\"collective mental state\",\"appraisal theory\",\"sexual inversion (sexology)\",\"sex and gender distinction\",\"anti-gender campaigns in europe\",\"biology and sexual orientation\",\"causes of transsexuality\",\"sissyphobia: gay men and effeminate behavior\",\"cooper do-nuts riot\",\"value judgment\",\"index of social and political philosophy articles\",\"outline of thought\",\"institutional trust (social sciences)\",\"instrumental and value rationality\",\"medical sociologist\",\"radical psychology network\",\"sascha altman dubrul\",\"mad pride\",\"the independent review\",\"american association for the abolition of involuntary mental hospitalization\",\"index of sociology articles\",\"mindfreedom international\",\"psychoanalytic theory\",\"crazy therapies\",\"social phenomenon\",\"secondary deviance\",\"status group\",\"social risk positions\",\"matrilocal residence\",\"microsociology\",\"social balance theory\",\"first world\",\"social reproduction\",\"commodity chain\",\"vertical mobility\",\"non-state actor\",\"social conflict\",\"sociological imagination\",\"social geometry\",\"ferdinand t\\u00f6nnies society\",\"underclass\",\"value-added theory\",\"resocialization\",\"sociological naturalism\",\"kindness\",\"split labor market theory\",\"ethnoscape\",\"list of countries by inequality-adjusted income\",\"list of countries by share of income of the richest one percent\",\"comparing media systems\",\"2000-watt society\",\"list of bordering countries with greatest relative differences in gdp (ppp) per capita\",\"heavily indebted poor countries\",\"acceptance\",\"gratitude\",\"rage (emotion)\",\"resentment\",\"inner peace\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"hostility\",\"kindness\",\"pay it forward\",\"affect (psychology)\",\"collective mental state\",\"appraisal theory\",\"generosity\",\"list of matrilineal or matrilocal societies\",\"patrilocal residence\",\"mesosociology\",\"violent non-state actor\",\"bibliography of sociology\",\"intergroup anxiety\",\"analytic frame\",\"prohibition of dying\",\"sociological imagination\",\"contest mobility\",\"science capital\",\"underclass\",\"social transformation\",\"confucian classes\",\"status attainment\",\"global social mobility index\",\"quiet revolution\",\"official bilingualism in the public service of canada\",\"reflexivity (social theory)\",\"women-are-wonderful effect\",\"performative interval\",\"performative activism\",\"double hermeneutic\",\"scientocracy\",\"mapping controversies\",\"regulation of science\",\"history of science policy\",\"logology (science)\",\"technical change\",\"normalization process theory\",\"scientocracy\",\"mapping controversies\",\"regulation of science\",\"history of science policy\",\"reflexivity (social theory)\",\"logology (science)\",\"technical change\",\"normalization process theory\",\"scientocracy\",\"regulation of science\",\"science in action (book)\",\"history of science policy\",\"logology (science)\",\"technical change\",\"normalization process theory\",\"regulation of science\",\"history of science policy\",\"technocracy movement\",\"logology (science)\",\"technical change\",\"normalization process theory\",\"regulation of science\",\"history of science policy\",\"logology (science)\",\"technical change\",\"history of science policy\",\"logology (science)\",\"regulation of science\",\"history of science policy\",\"logology (science)\",\"humanistic coefficient\",\"analytic induction\",\"sociology in poland\",\"taste (sociology)\",\"psychoanalytic theory\",\"sascha altman dubrul\",\"ernest jones\",\"mad pride\",\"harry harlow\",\"crazy therapies\",\"helene deutsch\",\"radical psychology network\",\"ressentiment\",\"british psychotherapy foundation\",\"shadow (psychology)\",\"defence mechanism\",\"id, ego and super-ego\",\"mindfreedom international\",\"mortido\",\"psychoanalytic theory\",\"object relations theory\",\"preconscious\",\"social transformation\",\"index of social and political philosophy articles\",\"civil discourse\",\"civic virtue\",\"civility\",\"institute for economics and peace\",\"index of social and political philosophy articles\",\"history of democratic socialism\",\"generosity\",\"nudity\",\"nudity\",\"imagery of nude celebrities\",\"moral emotions\",\"ressentiment\",\"index of social and political philosophy articles\",\"the concept of anxiety\",\"cogito, ergo sum\",\"hostility\",\"present age\",\"resentment\",\"acceptance\",\"gratitude\",\"john murray cuddihy\",\"rage (emotion)\",\"resentment\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"hostility\",\"affect (psychology)\",\"collective mental state\",\"appraisal theory\",\"acceptance\",\"gratitude\",\"auditory hallucination\",\"rage (emotion)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"intergroup anxiety\",\"hostility\",\"affect (psychology)\",\"collective mental state\",\"appraisal theory\",\"might makes right\",\"might makes right\",\"index of social and political philosophy articles\",\"food sovereignty\",\"weston a. price foundation\",\"dyad (sociology)\",\"reciprocity (cultural anthropology)\",\"the morals of chess\",\"pay it forward\",\"trobriand islands\",\"robert ekelund\",\"bananas, beaches and bases\",\"analytical sociology\",\"anguish\",\"acceptance\",\"gratitude\",\"confusion\",\"amusement\",\"acceptance\",\"gratitude\",\"rage (emotion)\",\"acceptance and commitment therapy\",\"emotional selection\",\"five stages of grief\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"knowledge of the holocaust in nazi germany and german-occupied europe\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"affect (psychology)\",\"appraisal theory\",\"gratitude\",\"rage (emotion)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"hobby\",\"affect (psychology)\",\"appraisal theory\",\"gratitude\",\"rage (emotion)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"anguish\",\"confusion\",\"emotionality\",\"schadenfreude\",\"moral emotions\",\"the concept of anxiety\",\"affect (psychology)\",\"appraisal theory\",\"present age\",\"blank expression\",\"gratitude\",\"auditory hallucination\",\"rage (emotion)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"confusion\",\"emotionality\",\"schadenfreude\",\"moral emotions\",\"affect (psychology)\",\"appraisal theory\",\"gratitude\",\"rage (emotion)\",\"inner peace\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"emotionality\",\"schadenfreude\",\"moral emotions\",\"affect (psychology)\",\"appraisal theory\",\"sex and gender distinction\",\"androcentrism\",\"index of social and political philosophy articles\",\"joe biden (the onion)\",\"norm entrepreneur\",\"the revolution of everyday life\",\"personal life\",\"relational sociology\",\"ursula apitzsch\",\"christian fuchs (sociologist)\",\"norwegian sociological association\",\"list of national legal systems\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"bolivarian revolution\",\"revolutions of 1989\",\"people's democracy (marxism\\u2013leninism)\",\"communism and lgbt rights\",\"triangular diplomacy\",\"civilian-based defense\",\"bibliography of works about communism\",\"communist front\",\"history of social democracy\",\"sovereignty of puerto rico during the cold war\",\"gar alperovitz\",\"celeb jihad\",\"free migration\",\"border control\",\"global justice movement\",\"free-market healthcare\",\"neoclassical liberalism\",\"argument from authority\",\"ipse dixit\",\"argument from authority\",\"ipse dixit\",\"policy sociology\",\"superiority complex\",\"cognitive bias\",\"trait ascription bias\",\"normalcy bias\",\"proportionality bias\",\"law of the instrument\",\"outline of thought\",\"two-factor theory of emotion\",\"id\\u00e9e fixe (psychology)\",\"emotional reasoning\",\"theories of humor\",\"schadenfreude\",\"ecological imperialism\",\"globalization and women in china\",\"outline of anarchism\",\"consensus democracy\",\"maceration (bone)\",\"mortido\",\"necropolitics\",\"prohibition of dying\",\"out-of-body experience\",\"maceration (bone)\",\"altered state of consciousness\",\"koestler parapsychology unit\",\"prohibition of dying\",\"mediumship\",\"hypnopompic\",\"mortido\",\"richard wiseman\",\"levitation (paranormal)\",\"schizotypy\",\"automatic writing\",\"mortido\",\"maceration (bone)\",\"norwegian journal of sociology\",\"racial threat\",\"day of empire\",\"universal basic income\",\"limitarianism (ethical)\",\"ioana marinescu\",\"work, employment & society\",\"cura annonae\",\"the triple revolution\",\"technoliberalism\",\"universal basic income\",\"levitation (paranormal)\",\"mediumship\",\"koestler parapsychology unit\",\"biorhythm (pseudoscience)\",\"richard wiseman\",\"levitation (paranormal)\",\"automatic writing\",\"mediumship\",\"lady wonder\",\"personal life\",\"hobby\",\"list of scientific occupations\",\"index of social and political philosophy articles\",\"personal life\",\"consumer class\",\"ed miliband bacon sandwich photograph\",\"time-use research\",\"state decoration\",\"feoffment\",\"state order\",\"fount of honour\",\"list of matrilineal or matrilocal societies\",\"the great transformation (book)\",\"1910s in anthropology\",\"trobriand islands\",\"is the glass half empty or half full?\",\"list of women anthropologists\",\"das mutterrecht\",\"laterality\",\"psychohistory\",\"automatic writing\",\"ambidexterity\",\"cephalic index\",\"cephalic index in cats and dogs\",\"sex and gender distinction\",\"list of birds displaying homosexual behavior\",\"causes of transsexuality\",\"list of mammals displaying homosexual behavior\",\"list of animals displaying homosexual behavior\",\"homosexual behavior in animals\",\"joan roughgarden\",\"list of birds displaying homosexual behavior\",\"list of mammals displaying homosexual behavior\",\"list of animals displaying homosexual behavior\",\"homosexual behavior in animals\",\"womyn's land\",\"sexual inversion (sexology)\",\"cooper do-nuts riot\",\"muted group theory\",\"androcentrism\",\"causes of transsexuality\",\"doing gender\",\"suzanne kessler\",\"the hebrew goddess\",\"the witch-cult in western europe\",\"names for the human species\",\"early modern human\",\"homo faber\",\"lingeer\",\"serer maternal clans\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"serer people\",\"serer people\",\"lingeer\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"serer maternal clans\",\"lingeer\",\"serer maternal clans\",\"lingeer\",\"geography of media and communication\",\"affect (psychology)\",\"children's geographies\",\"development geography\",\"mandailing people\",\"angkola people\",\"kluet people\",\"moana (1926 film)\",\"biorhythm (pseudoscience)\",\"list of psychological schools\",\"harry harlow\",\"index of social and political philosophy articles\",\"michael albert\",\"outline of anarchism\",\"androcentrism\",\"honorary male\",\"alter ego\",\"eugen relgis\",\"id, ego and super-ego\",\"hoi polloi\",\"constitutionality\",\"united federal workers of america\",\"list of mammals displaying homosexual behavior\",\"list of animals displaying homosexual behavior\",\"list of animals displaying homosexual behavior\",\"communicative dynamism\",\"homo faber\",\"hermann lotze\",\"ernst mally\",\"state order\",\"state decoration\",\"canadian honours system\",\"vocabulary development\",\"constantin noica\",\"moralia\",\"istihlal\",\"forensic facial reconstruction\",\"forensic facial reconstruction\",\"tropical geography\",\"argentine forensic anthropology team\",\"australian institute of aboriginal and torres strait islander studies\",\"west pride\",\"museum of mankind\",\"anthropological index online\",\"dominic boyer\",\"robert christison\",\"sleep and learning\",\"psychonautics\",\"auditory hallucination\",\"altered state of consciousness\",\"altered states\",\"sleep-learning\",\"preconscious\",\"museum of archaeology and anthropology, university of cambridge\",\"altered states\",\"live free or die\",\"live free or die\",\"cabang atas\",\"cabang atas\",\"unsaid\",\"facial expression\",\"microexpression\",\"blank expression\",\"facial expression\",\"microexpression\",\"blink: the power of thinking without thinking\",\"list of visual anthropology films\",\"emotionality\",\"schadenfreude\",\"rage (emotion)\",\"magical death\",\"list of visual anthropology films\",\"koestler parapsychology unit\",\"levitation (paranormal)\",\"automatic writing\",\"edinburgh university socialist society\",\"poker\",\"poker\",\"blank expression\",\"flow (psychology)\",\"list of rugrats characters\",\"aion: researches into the phenomenology of the self\",\"civilization in transition\",\"alchemical studies\",\"civilization in transition\",\"british psychotherapy foundation\",\"international general medical society for psychotherapy\",\"answer to job\",\"marie-louise von franz\",\"aion: researches into the phenomenology of the self\",\"shadow (psychology)\",\"answer to job\",\"alchemical studies\",\"marie-louise von franz\",\"international general medical society for psychotherapy\",\"consumption (sociology)\",\"commercialism\",\"microgeneration\",\"consumption (sociology)\",\"coal phase-out\",\"renewable energy transition\",\"cost of electricity by source\",\"2000-watt society\",\"a green new deal\",\"faye v. harrison\",\"food bank\",\"joseph rowntree foundation\",\"environmental racism in the united states\",\"lowell l. bennion\",\"womyn's land\",\"journal of lesbian studies\",\"women's week provincetown\",\"women's week provincetown\",\"kriza j\\u00e1nos ethnographic society\",\"toloy\",\"johann friedrich herbart\",\"hermann lotze\",\"ernst mally\",\"imaginary audience\",\"crying\",\"self-assessment\",\"list of psychological schools\",\"quantitative psychological research\",\"flashback (psychology)\",\"swanson, nolan and pelham teacher and parent rating scale\",\"women-are-wonderful effect\",\"harry harlow\",\"cognitivism (psychology)\",\"british psychotherapy foundation\",\"social cognition and interaction training\",\"object relations theory\",\"repertory grid\",\"pit of despair\",\"conditioned emotional response\",\"cognitivism (psychology)\",\"alchemical studies\",\"id, ego and super-ego\",\"adlerian\",\"ernest jones\",\"answer to job\",\"preconscious\",\"marie-louise von franz\",\"gnosis (chaos magic)\",\"autogenic training\",\"acceptance and commitment therapy\",\"autogenic training\",\"harvey jackins\",\"catharsis\",\"sublimation (psychology)\",\"behaviour therapy\",\"sleep-learning\",\"adaptive unconscious\",\"global workspace theory\",\"outline of thought\",\"preconscious\",\"altered state of consciousness\",\"subconscious\",\"richard wiseman\",\"cognitive intervention\",\"autogenic training\",\"conversational model\",\"british psychotherapy foundation\",\"awareness\",\"defence mechanism\",\"behaviour therapy\",\"social cognition and interaction training\",\"eating disorder\",\"history of psychotherapy\",\"wakefulness\",\"autogenic training\",\"conversational model\",\"british psychotherapy foundation\",\"social cognition and interaction training\",\"history of psychotherapy\",\"menninger foundation\",\"conversational model\",\"british psychotherapy foundation\",\"social cognition and interaction training\",\"history of psychotherapy\",\"applied psychological measurement\",\"ernest jones\",\"british psychotherapy foundation\",\"defence mechanism\",\"freud's seduction theory\",\"id, ego and super-ego\",\"on narcissism\",\"adlerian\",\"mortido\",\"outline of thought\",\"object relations theory\",\"mourning and melancholia\",\"helene deutsch\",\"ernest jones\",\"british psychotherapy foundation\",\"defence mechanism\",\"on narcissism\",\"adlerian\",\"mortido\",\"life and how to survive it\",\"object relations theory\",\"mourning and melancholia\",\"helene deutsch\",\"ernest jones\",\"british psychotherapy foundation\",\"defence mechanism\",\"adlerian\",\"mortido\",\"object relations theory\",\"helene deutsch\",\"adlerian\",\"mortido\",\"british psychotherapy foundation\",\"helene deutsch\",\"object relations theory\",\"defence mechanism\",\"freud's seduction theory\",\"entitlement\",\"superiority complex\",\"british psychotherapy foundation\",\"dark triad\",\"egosyntonic and egodystonic\",\"mourning and melancholia\",\"freud's seduction theory\",\"british psychotherapy foundation\",\"journal of the american psychoanalytic association\",\"mortido\",\"british psychotherapy foundation\",\"ego integrity\",\"defence mechanism\",\"alchemical studies\",\"answer to job\",\"marie-louise von franz\",\"inner peace\",\"awareness\",\"contemplation\",\"contemplation\",\"the castle (novel)\",\"apprehension (understanding)\",\"flow (psychology)\",\"coma\",\"altered state of consciousness\",\"awareness\",\"obliviousness\",\"global workspace theory\",\"outline of thought\",\"sustainable development goal 12\",\"wakefulness\",\"bipolar i disorder\",\"auditory hallucination\",\"seasonal affective disorder\",\"anhedonia\",\"motivational salience\",\"schizotypy\",\"dysthymia\",\"eating disorder\",\"bipolar i disorder\",\"auditory hallucination\",\"psychomotor retardation\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"hong kong college of psychiatrists\",\"seasonal affective disorder\",\"disordered eating\",\"eating disorder\",\"psycho-oncology\",\"list of neurological conditions and disorders\",\"hong kong college of psychiatrists\",\"psycho-oncology\",\"coma\",\"psychological evaluation\",\"psycho-oncology\",\"psycho-oncology\",\"outline of thought\",\"obtundation\",\"sopor (sleep)\",\"coma\",\"altered state of consciousness\",\"wakefulness\",\"categorical perception\",\"rage (emotion)\",\"open field (animal test)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"schadenfreude\",\"affect (psychology)\",\"two-factor theory of emotion\",\"appraisal theory\",\"cabin fever\",\"auditory hallucination\",\"psychomotor retardation\",\"the emperor's new mind\",\"flow (psychology)\",\"gnosis (chaos magic)\",\"global workspace theory\",\"wakefulness\",\"wakefulness\",\"the emperor's new mind\",\"black hole bomb\",\"cognitivism (psychology)\",\"dynamicism\",\"post-cognitivist psychology\",\"dynamicism\",\"cosmos and psyche\",\"rage (emotion)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"scare\",\"schadenfreude\",\"affect (psychology)\",\"appraisal theory\",\"scare\",\"why zebras don't get ulcers\",\"fight-or-flight response\",\"scare\",\"conditioned emotional response\",\"neutral stimulus\",\"aversives\",\"psychological resistance\",\"accuracy and precision\",\"feeling good: the new mood therapy\",\"emotional reasoning\",\"alchemical studies\",\"marie-louise von franz\",\"marie-louise von franz\",\"marie-louise von franz\",\"frustration\\u2013aggression hypothesis\",\"emotional abuse\",\"implicit-association test\",\"transliminality\",\"tortured artist\",\"frieda fromm-reichmann\",\"ambidexterity\",\"laterality\",\"mortido\",\"the culture of narcissism\",\"entitlement\",\"dark triad\",\"the culture of narcissism\",\"entitlement\",\"the culture of narcissism\",\"entitlement\",\"cabin fever\",\"intensity of preference\",\"games for change\",\"hereditarianism\",\"james\\u2013lange theory\",\"the concept of anxiety\",\"johann friedrich herbart\",\"present age\",\"cat intelligence\",\"tractatus politicus\",\"tractatus politicus\",\"open field (animal test)\",\"animal testing regulations\",\"pit of despair\",\"open field (animal test)\",\"gary l. francione\",\"siobhan o'sullivan\",\"argument from marginal cases\",\"pit of despair\",\"open field (animal test)\",\"siobhan o'sullivan\",\"gary l. francione\",\"argument from marginal cases\",\"gary l. francione\",\"siobhan o'sullivan\",\"siobhan o'sullivan\",\"gary l. francione\",\"list of psychology awards\",\"mindfreedom international\",\"sascha altman dubrul\",\"mad pride\",\"american association for the abolition of involuntary mental hospitalization\",\"crazy therapies\",\"mad pride\",\"mindfreedom international\",\"sascha altman dubrul\",\"crazy therapies\",\"mindfreedom international\",\"sascha altman dubrul\",\"mad pride\",\"crazy therapies\",\"sascha altman dubrul\",\"crazy therapies\",\"sascha altman dubrul\",\"list of psychology awards\",\"bps barbara wilson lifetime achievement award\",\"kurt koffka medal\",\"spearman medal\",\"reliability (statistics)\",\"accuracy and precision\",\"repeatability\",\"the freudian coverup\",\"comprehension approach\",\"swanson, nolan and pelham teacher and parent rating scale\",\"islamic sexual jurisprudence\",\"islamic toilet etiquette\",\"menstruation in islam\",\"islamic funeral\",\"mahr\",\"islamic funeral\",\"islamic sexual jurisprudence\",\"islamic toilet etiquette\",\"menstruation in islam\",\"mahr\",\"islam and children\",\"international council for science\",\"index of social and political philosophy articles\",\"free-market healthcare\",\"neoclassical liberalism\",\"catherine eschle\",\"rent-setting\",\"rent extraction\",\"maladministration\",\"comparing media systems\",\"authoritarian left\",\"sovereignty of puerto rico during the cold war\",\"harvard institute of politics\",\"triangular diplomacy\",\"autonomous administrative division\",\"autonomous communities administration\",\"d\\u00e9j\\u00e0 vu\",\"kim campbell\",\"parliamentary debate\",\"deliberation\",\"jewish-palestinian living room dialogue group\",\"deliberation\",\"civil discourse\",\"international isolation\",\"communism and lgbt rights\",\"crypto-communism\",\"comunismo a la tica\",\"bibliography of works about communism\",\"communist era\",\"aromanian question\",\"violent non-state actors at sea\",\"violent non-state actor\",\"rent-setting\",\"rent extraction\",\"maladministration\",\"violent non-state actors at sea\",\"grey-zone (international relations)\",\"david laidler\",\"united states farm bill\",\"eugene fama\",\"dualism (law)\",\"molon labe\",\"kaarlo juho st\\u00e5hlberg\",\"index of social and political philosophy articles\",\"res publica christiana\",\"imperium\",\"occupatio\",\"international conference on theory and practice of electronic governance\",\"predictive policing\",\"east turkestan\",\"triangular diplomacy\",\"gadsden flag\",\"political cartoon\",\"peruvian nitrate monopoly\",\"continuismo\",\"cacique\",\"gadsden flag\",\"neoclassical liberalism\",\"passing on the right\",\"foundation for european economic development\",\"eugene fama\",\"list of financial economists\",\"eugene fama\",\"fama\\u2013french three-factor model\",\"notary (catholic canon law)\",\"promulgation (catholic canon law)\",\"custom (catholic canon law)\",\"vacatio legis\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"obreption and subreption (catholic canon law)\",\"notary (catholic canon law)\",\"promulgation (catholic canon law)\",\"custom (catholic canon law)\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"obreption and subreption (catholic canon law)\",\"notary (catholic canon law)\",\"promulgation (catholic canon law)\",\"custom (catholic canon law)\",\"obreption and subreption (catholic canon law)\",\"index of social and political philosophy articles\",\"school of diplomacy\",\"legalism (chinese philosophy)\",\"resource conservation and recovery act\",\"border control\",\"samuel von pufendorf\",\"\\u00bfpor qu\\u00e9 no te callas?\",\"ministry of magic\",\"lesser of two evils principle\",\"in place of strife\",\"scotland's future\",\"logology (science)\",\"danish defence agreement 2013\\u20132017\",\"content marketing\",\"earned media\",\"list of countries by inequality-adjusted income\",\"list of bordering countries with greatest relative differences in gdp (ppp) per capita\",\"list of countries by share of income of the richest one percent\",\"small office/home office\",\"glory to hong kong\",\"squirrel (debate)\",\"parliamentary debate\",\"stephanos bibas\",\"state order\",\"he who does not work, neither shall he eat\",\"comunismo a la tica\",\"crypto-communism\",\"bibliography of works about communism\",\"liberal democratic basic order\",\"independent labour publications\",\"carles boix\",\"index of social and political philosophy articles\",\"international peacekeeping\",\"cacique\",\"maddaddam\",\"national power\",\"special relationship (international relations)\",\"resource conservation and recovery act\",\"timeline of voting rights in the united states\",\"united nations office on drugs and crime\",\"one man, one vote\",\"timeline of voting rights in the united states\",\"the counter-revolution of science\",\"the road to serfdom\",\"ralph borsodi\",\"history of democratic socialism\",\"economic humanitarianism (ra\\u00eblianism)\",\"technocracy movement\",\"chester barnard\",\"human resource management in public administration\",\"jane semeleer\",\"nur f\\u00fcr deutsche\",\"attorney-general v de keyser's royal hotel ltd\",\"proclamation by the crown act 1539\",\"common informer\",\"petitions of right (ireland) act 1873\",\"petition of right\",\"worldwide influence of the constitution of the united states\",\"plenary power\",\"implied powers\",\"exclusive federal powers\",\"worldwide influence of the constitution of the united states\",\"plenary power\",\"worldwide influence of the constitution of the united states\",\"anglo-saxon model\",\"menstruation in islam\",\"sexual jihad\",\"dang guo\",\"party-state capitalism\",\"equalization payments\",\"interprovincial migration in canada\",\"equalization payments\",\"colin rallings\",\"olivier ihl\",\"scientific man versus power politics\",\"idealism in international relations\",\"job cohen\",\"muhammad taqi usmani\",\"syed hayatullah\",\"qazi syed inayatullah\",\"archery\",\"qazi syed inayatullah\",\"(don't) touch me on my studio\",\"air rights\",\"burlesque\",\"energy charter treaty\",\"energy certificate\",\"investment arbitration\",\"ash-shab yurid isqat an-nizam\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"glory to hong kong\",\"walras's law\",\"pierre-andr\\u00e9 chiappori\",\"economic stimulus appropriations act of 1977\",\"criticism of the federal reserve\",\"free market fairness\",\"making peace\",\"adaptive capacity\",\"carbon bubble\",\"coal phase-out\",\"ecocide\",\"index of social and political philosophy articles\",\"foreign agricultural service\",\"commodity credit corporation\",\"risk management agency\",\"jurisprudence of concepts\",\"territorialisation of carbon governance\",\"transformation processes (media systems)\",\"sam potolicchio\",\"wisconsin school (diplomatic history)\",\"decentralized autonomous organization\",\"predictive policing\",\"decentralized autonomous organization\",\"logology (science)\",\"terry karl\",\"arab barometer\",\"elif shafak\",\"robert heilbroner\",\"foundation for european economic development\",\"robert heilbroner\",\"rent-setting\",\"rent extraction\",\"index of social and political philosophy articles\",\"islam and children\",\"the crisis of democracy\",\"ernest barker\",\"a call to action: women, religion, violence, and power\",\"economic stimulus appropriations act of 1977\",\"carbon fee and dividend\",\"enbau\",\"green job\",\"carbon fee and dividend\",\"green industrial policy\",\"green job\",\"index of social and political philosophy articles\",\"ecocide\",\"environment minister\",\"ministry of infrastructure and water management\",\"ecocide\",\"wood industry\",\"list of public works ministries\",\"index of social and political philosophy articles\",\"scotland's future\",\"carl albert center\",\"carl albert center\",\"indian political philosophy\",\"delegated authority\",\"agonism\",\"phillip blond\",\"no war, no peace\",\"quadrilateral security dialogue\",\"nonkilling global political science\",\"list of public works ministries\",\"economists for peace and security\",\"powering past coal alliance\",\"in defense of the national interest\",\"new aspects of politics\",\"sustainable business\",\"greenwashing\",\"archery\",\"classification of advocacy groups\",\"journal of the european economic association\",\"austerity: the history of a dangerous idea\",\"benny moldovanu\",\"hicks-tinbergen award\",\"pierre-andr\\u00e9 chiappori\",\"iza institute of labor economics\",\"fabrizio zilibotti\",\"paola giuliano\",\"slapsoftware\",\"hannah arendt institute for totalitarianism studies\",\"transformation processes (media systems)\",\"coppieters foundation\",\"mariya gabriel\",\"mariya gabriel\",\"western cape department of transport and public works\",\"pakistan public works department\",\"ministry of land, infrastructure, transport and tourism\",\"ministry of housing and works (pakistan)\",\"international workers' day\",\"glory to hong kong\",\"glory to hong kong\",\"xeira\",\"comit\\u00e9s abertos de estudantes\",\"erguer-estudantes da galiza\",\"revolutionary students federation\",\"galician workers union\",\"xeira\",\"comit\\u00e9s abertos de estudantes\",\"revolutionary students federation\",\"galician workers union\",\"comit\\u00e9s abertos de estudantes\",\"revolutionary students federation\",\"galician workers union\",\"neoclassical liberalism\",\"we don't coast\",\"jihad satire\",\"marlon bundo\",\"alva myrdal\",\"alva myrdal\",\"viola klein\",\"wood industry\",\"risk factor (finance)\",\"roll-geske-whaley\",\"black\\u2013derman\\u2013toy model\",\"edgeworth binomial tree\",\"volatility clustering\",\"edgeworth binomial tree\",\"peter jaeckel\",\"farshid jamshidian\",\"gustav stolper prize\",\"leonid kantorovich\",\"vertical farming\",\"black\\u2013derman\\u2013toy model\",\"list of countries by inequality-adjusted income\",\"fabrizio zilibotti\",\"martin hellwig\",\"institute for international economic studies\",\"inside contracting\",\"outworker\",\"freelancer\",\"voluntary sector\",\"nonprofit and voluntary sector quarterly\",\"private highway\",\"risk management agency\",\"united states farm bill\",\"stochastic investment model\",\"mesoeconomics\",\"jacob hollander\",\"family disruption\",\"economics (textbook)\",\"gustav stolper prize\",\"indirect inference\",\"methodology of econometrics\",\"masters in agricultural economics\",\"qem\",\"rethinking economics\",\"murray's hypocycloidal engine\",\"woolrich electrical generator\",\"woolrich electrical generator\",\"giancarlo corsetti\",\"charles henry hull\",\"two-sided matching\",\"conspicuous conservation\",\"greenwashing\",\"cover-up\",\"cooper do-nuts riot\",\"julia's on broadway\",\"julia's on broadway\",\"noel ignatiev\",\"grotesque body\",\"minsky's burlesque\",\"burlesque\",\"suzanne kessler\",\"west pride\",\"argument from authority\",\"civil discourse\",\"archon fung\",\"summerhill (book)\",\"the morals of chess\",\"black eagle (montreal)\",\"obtundation\",\"sopor (sleep)\",\"reliability (statistics)\",\"richard wiseman\",\"johann friedrich herbart\",\"reliability (statistics)\",\"motivational salience\",\"eustress\",\"adaptive unconscious\",\"implicit-association test\",\"rage (emotion)\",\"mentalization\"],\"start\":[\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"biology and political orientation\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"history of political science\",\"history of political science\",\"history of political science\",\"philip converse\",\"philip converse\",\"philip converse\",\"philip converse\",\"philip converse\",\"philip converse\",\"philip converse\",\"philip converse\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"experimental political science\",\"experimental political science\",\"experimental political science\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"structure and agency\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"world values survey\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"non-sampling error\",\"non-sampling error\",\"non-sampling error\",\"non-sampling error\",\"non-sampling error\",\"non-sampling error\",\"coverage error\",\"coverage error\",\"coverage error\",\"coverage error\",\"coverage error\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"statistical inference\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"afrobarometer\",\"afrobarometer\",\"afrobarometer\",\"afrobarometer\",\"afrobarometer\",\"comparative study of electoral systems\",\"comparative study of electoral systems\",\"voter turnout\",\"voter turnout\",\"voter turnout\",\"voter turnout\",\"voter turnout\",\"voter turnout\",\"voter turnout\",\"voter turnout\",\"tactical voting\",\"tactical voting\",\"tactical voting\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"political groups of the european parliament\",\"political groups of the european parliament\",\"political groups of the european parliament\",\"political groups of the european parliament\",\"political groups of the european parliament\",\"political groups of the european parliament\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"civil service\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"eurosphere\",\"eurosphere\",\"eurosphere\",\"eurosphere\",\"eurosphere\",\"eurosphere\",\"eurosphere\",\"eurosphere\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"stein rokkan\",\"stein rokkan\",\"stein rokkan\",\"stein rokkan\",\"stein rokkan\",\"stein rokkan\",\"stein rokkan\",\"stein rokkan\",\"stein rokkan\",\"otto kirchheimer\",\"otto kirchheimer\",\"otto kirchheimer\",\"otto kirchheimer\",\"otto kirchheimer\",\"otto kirchheimer\",\"comparative historical research\",\"comparative historical research\",\"comparative historical research\",\"comparative historical research\",\"comparative historical research\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"democracy-dictatorship index\",\"democracy-dictatorship index\",\"global terrorism index\",\"global terrorism index\",\"behavioralism\",\"behavioralism\",\"behavioralism\",\"behavioralism\",\"behavioralism\",\"behavioralism\",\"behavioralism\",\"behavioralism\",\"behavioralism\",\"international political science association\",\"international political science association\",\"international political science association\",\"international political science association\",\"strict father model\",\"strict father model\",\"strict father model\",\"nurturant parent model\",\"nurturant parent model\",\"nurturant parent model\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"attachment parenting\",\"attachment parenting\",\"attachment parenting\",\"attachment parenting\",\"attachment parenting\",\"attachment parenting\",\"attachment parenting\",\"attachment parenting\",\"attachment parenting\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"systems theory in political science\",\"systems theory in political science\",\"systems theory in political science\",\"systems theory in political science\",\"systems theory in political science\",\"systems theory in political science\",\"systems theory in political science\",\"legitimation crisis\",\"legitimation crisis\",\"legitimation crisis\",\"legitimation crisis\",\"legitimation crisis\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"social integration\",\"public engagement\",\"public engagement\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"digital era governance\",\"digital era governance\",\"digital era governance\",\"digital era governance\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"helen margetts\",\"helen margetts\",\"helen margetts\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"e-government\",\"e-government\",\"e-government\",\"e-government\",\"e-government\",\"e-government\",\"e-government\",\"e-government\",\"e-government\",\"e-government\",\"institutional analysis\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"elinor ostrom\",\"perestroika movement (political science)\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"effective number of parties\",\"party system\",\"party system\",\"party system\",\"party system\",\"party system\",\"party system\",\"party system\",\"party system\",\"party system\",\"party system\",\"party system\",\"political communication\",\"political communication\",\"political communication\",\"political communication\",\"political communication\",\"political communication\",\"political communication\",\"political communication\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"symbol\",\"serfdom in tibet controversy\",\"serfdom in tibet controversy\",\"serfdom in tibet controversy\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"rowman & littlefield award in innovative teaching\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"political research associates\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"social imperialism\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"politics of memory\",\"politics of memory\",\"politics of memory\",\"collective memory\",\"collective memory\",\"collective memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"valence issue\",\"valence issue\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"gun control\",\"gun control\",\"gun control\",\"gun control\",\"gun control\",\"gun control\",\"international centre for black sea studies\",\"international centre for black sea studies\",\"international relations and security network\",\"public comment\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"freedom\",\"open philanthropy (doctrine)\",\"theory of change\",\"theory of change\",\"theory of change\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"ethnosymbolism\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"netnography\",\"netnography\",\"netnography\",\"netnography\",\"netnography\",\"netnography\",\"netnography\",\"netnography\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnic religion\",\"ethnic religion\",\"ethnic religion\",\"ethnic religion\",\"ethnic religion\",\"ethnic religion\",\"ethnic religion\",\"nation-building\",\"nation-building\",\"nation-building\",\"nation-building\",\"nation-building\",\"nation-building\",\"nation-building\",\"moderation theory\",\"moderation theory\",\"median voter theorem\",\"median voter theorem\",\"median voter theorem\",\"median voter theorem\",\"median voter theorem\",\"radicalization\",\"radicalization\",\"tryph\\u00e9\",\"nominate (scaling method)\",\"scale analysis (statistics)\",\"scale analysis (statistics)\",\"multistakeholder governance\",\"bureaucratic drift\",\"peace\\u2013industrial complex\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"the birth of biopolitics\",\"the birth of biopolitics\",\"the birth of biopolitics\",\"the birth of biopolitics\",\"the birth of biopolitics\",\"the birth of biopolitics\",\"the birth of biopolitics\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"security, territory, population\",\"security, territory, population\",\"security, territory, population\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"india quarterly\",\"research papers in economics\",\"research papers in economics\",\"research papers in economics\",\"research papers in economics\",\"research papers in economics\",\"the establishment (pakistan)\",\"the establishment (pakistan)\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"big push model\",\"big push model\",\"big push model\",\"cash crop\",\"cash crop\",\"cash crop\",\"cash crop\",\"cash crop\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"cobweb model\",\"cobweb model\",\"cobweb model\",\"consumer sovereignty\",\"consumer sovereignty\",\"consumer sovereignty\",\"consumer sovereignty\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"differentiated bertrand competition\",\"differentiated bertrand competition\",\"differentiated bertrand competition\",\"dispersed knowledge\",\"dispersed knowledge\",\"dispersed knowledge\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economics terminology that differs from common usage\",\"economics terminology that differs from common usage\",\"economics terminology that differs from common usage\",\"economics terminology that differs from common usage\",\"edgeworth box\",\"edgeworth box\",\"edgeworth box\",\"excess burden of taxation\",\"excess burden of taxation\",\"excess burden of taxation\",\"excess burden of taxation\",\"excess burden of taxation\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"fractional-reserve banking\",\"fractional-reserve banking\",\"fractional-reserve banking\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"gerschenkron effect\",\"gerschenkron effect\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"hotelling's law\",\"import substitution industrialization\",\"import substitution industrialization\",\"import substitution industrialization\",\"import substitution industrialization\",\"import substitution industrialization\",\"import substitution industrialization\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"indifference curve\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal equilibrium\",\"ithaca hours\",\"joint product pricing\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"list of unsolved problems in economics\",\"list of unsolved problems in economics\",\"list of unsolved problems in economics\",\"list of unsolved problems in economics\",\"list of unsolved problems in economics\",\"lorenz curve\",\"lorenz curve\",\"lorenz curve\",\"lorenz curve\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"market anomaly\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"natural capital\",\"network effect\",\"network effect\",\"network effect\",\"network effect\",\"network effect\",\"network effect\",\"network effect\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"ricardian equivalence\",\"ricardian equivalence\",\"ricardian equivalence\",\"ricardian equivalence\",\"risk premium\",\"risk premium\",\"risk premium\",\"risk premium\",\"risk premium\",\"risk premium\",\"risk premium\",\"risk premium\",\"risk premium\",\"robin hood effect\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"subsidy\",\"subsidy\",\"substitution effect\",\"substitution effect\",\"substitution effect\",\"substitution effect\",\"substitution effect\",\"substitution effect\",\"substitution effect\",\"substitution effect\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"list of production functions\",\"list of production functions\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"e. f. schumacher\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"cultural relativism\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"emic and etic\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"linguistic anthropology\",\"linguistic anthropology\",\"linguistic anthropology\",\"linguistic anthropology\",\"linguistic anthropology\",\"linguistic anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"social organization\",\"social organization\",\"social organization\",\"social organization\",\"social organization\",\"social organization\",\"social organization\",\"social organization\",\"social organization\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"peasant economics\",\"peasant economics\",\"peasant economics\",\"peasant economics\",\"peasant economics\",\"peasant economics\",\"shell money\",\"shell money\",\"shell money\",\"shell money\",\"shell money\",\"shell money\",\"shell money\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"heritage commodification\",\"heritage commodification\",\"heritage commodification\",\"heritage commodification\",\"heritage commodification\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"critical medical anthropology\",\"critical medical anthropology\",\"critical medical anthropology\",\"society for medical anthropology\",\"society for medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"age set\",\"age set\",\"age set\",\"age set\",\"age set\",\"leveling mechanism\",\"leveling mechanism\",\"leveling mechanism\",\"leveling mechanism\",\"theatre state\",\"theatre state\",\"theatre state\",\"theatre state\",\"circumscription theory\",\"circumscription theory\",\"f. g. bailey\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"soul dualism\",\"soul dualism\",\"biocultural anthropology\",\"biocultural anthropology\",\"osteology\",\"osteology\",\"osteology\",\"osteology\",\"osteology\",\"osteology\",\"osteology\",\"human behavioral ecology\",\"human behavioral ecology\",\"human ethology\",\"human ethology\",\"human ethology\",\"human ethology\",\"list of anthropologists\",\"list of anthropologists\",\"bibliography of anthropology\",\"bibliography of anthropology\",\"bibliography of anthropology\",\"bibliography of anthropology\",\"bibliography of anthropology\",\"ceremonial pole\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"bioculture\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural liberalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culturgen\",\"culturgen\",\"culturgen\",\"culturgen\",\"culturgen\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"wedding\",\"international security\",\"international security\",\"international security\",\"international security\",\"international security\",\"international security\",\"international security\",\"international security\",\"international security\",\"international security\",\"international security\",\"raptio\",\"paleopathology\",\"paleopathology\",\"paleopathology\",\"paleoanthropology\",\"paleoanthropology\",\"paleoanthropology\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"richard dawkins\",\"cultural group selection\",\"cultural group selection\",\"cultural group selection\",\"cultural group selection\",\"cultural group selection\",\"cultural group selection\",\"race and intelligence\",\"race and intelligence\",\"race and intelligence\",\"race and intelligence\",\"race and intelligence\",\"race and intelligence\",\"race and intelligence\",\"race and intelligence\",\"human genetic variation\",\"human genetic variation\",\"human genetic variation\",\"human genetic variation\",\"intelligence quotient\",\"intelligence quotient\",\"intelligence quotient\",\"intelligence quotient\",\"intelligence quotient\",\"intelligence quotient\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"white wedding\",\"white wedding\",\"white wedding\",\"white wedding\",\"ceremony\",\"ceremony\",\"ceremony\",\"wedding reception\",\"wedding reception\",\"wedding reception\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"honeymoon\",\"honeymoon\",\"honeymoon\",\"consummation\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"female promiscuity\",\"female promiscuity\",\"female promiscuity\",\"female promiscuity\",\"female promiscuity\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"edvard westermarck\",\"edvard westermarck\",\"men who have sex with men\",\"men who have sex with men\",\"men who have sex with men\",\"women who have sex with women\",\"women who have sex with women\",\"women who have sex with women\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"theory of language\",\"theory of language\",\"theory of language\",\"theory of language\",\"theory of language\",\"theory of language\",\"theory of language\",\"theory of language\",\"linguistic relativity\",\"linguistic relativity\",\"linguistic relativity\",\"linguistic relativity\",\"linguistic relativity\",\"linguistic relativity\",\"linguistic relativity\",\"linguistic relativity\",\"performance\",\"performance\",\"performance\",\"performance\",\"performance\",\"performance\",\"performance\",\"performance\",\"performance\",\"identity (social science)\",\"identity (social science)\",\"identity (social science)\",\"identity (social science)\",\"identity (social science)\",\"identity (social science)\",\"identity (social science)\",\"identity (social science)\",\"semiotic anthropology\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health system\",\"health system\",\"health system\",\"population health\",\"population health\",\"population health\",\"headhunting\",\"headhunting\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"shrunken head\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"kshatriya\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"pitt rivers museum\",\"pitt rivers museum\",\"digging stick\",\"digging stick\",\"grave goods\",\"grave goods\",\"grave goods\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"spirituality\",\"susto\",\"susto\",\"susto\",\"susto\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"auspicious wedding dates\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"university of san diego\",\"university of san diego\",\"cognitive archaeology\",\"cognitive archaeology\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"ecological psychology\",\"ecological psychology\",\"ecological psychology\",\"sympathetic magic\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"biophilia hypothesis\",\"biophilia hypothesis\",\"biophilia hypothesis\",\"ethnoichthyology\",\"ethnoichthyology\",\"ethnolichenology\",\"ethnolichenology\",\"ethnoornithology\",\"zooarchaeology\",\"zooarchaeology\",\"poppet\",\"poppet\",\"primitivism\",\"primitivism\",\"primitivism\",\"primitivism\",\"primitivism\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"koteka\",\"koteka\",\"koteka\",\"koteka\",\"koteka\",\"koteka\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"sedentism\",\"reterritorialization\",\"typology (anthropology)\",\"typology (anthropology)\",\"typology (anthropology)\",\"typology (anthropology)\",\"typology (anthropology)\",\"negroid\",\"negroid\",\"negroid\",\"negroid\",\"negroid\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"john beddoe\",\"john beddoe\",\"john beddoe\",\"john beddoe\",\"bertil lundman\",\"bertil lundman\",\"history of anthropometry\",\"history of anthropometry\",\"history of anthropometry\",\"history of anthropometry\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"online ethnography\",\"proto-malay\",\"proto-malay\",\"proto-malay\",\"structural endogamy\",\"structural endogamy\",\"structural endogamy\",\"structural endogamy\",\"assortative mixing\",\"assortative mixing\",\"assortative mixing\",\"social invisibility\",\"social invisibility\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"neurophilosophy\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"anthropological criminology\",\"anthropological criminology\",\"biosocial criminology\",\"biosocial criminology\",\"biosocial criminology\",\"biosocial criminology\",\"biosocial criminology\",\"biosocial criminology\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"fordisc\",\"endocannibalism\",\"general semantics\",\"general semantics\",\"frazer lecture\",\"arthur evans\",\"arthur evans\",\"arthur evans\",\"hill people\",\"hill people\",\"high-altitude adaptation in humans\",\"high-altitude adaptation in humans\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"neo-nationalism\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"fourteen words\",\"fourteen words\",\"fourteen words\",\"kalergi plan\",\"kalergi plan\",\"kalergi plan\",\"basket of deplorables\",\"guanche mummies\",\"guanche mummies\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"skhul and qafzeh hominins\",\"australian aboriginal kinship\",\"joint attention\",\"joint attention\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"asch conformity experiments\",\"prenatal hormones and sexual orientation\",\"prenatal hormones and sexual orientation\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"fallen woman\",\"fallen woman\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"human universals\",\"recent human evolution\",\"postpartum confinement\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"major depressive disorder\",\"paleoradiology\",\"off the verandah\",\"armchair theorizing\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"medical psychology\",\"medical psychology\",\"medical psychology\",\"music psychology\",\"music psychology\",\"music psychology\",\"music psychology\",\"music psychology\",\"occupational health psychology\",\"occupational health psychology\",\"occupational health psychology\",\"occupational health psychology\",\"occupational health psychology\",\"occupational health psychology\",\"occupational health psychology\",\"occupational health psychology\",\"occupational health psychology\",\"occupational health psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychotherapy\",\"list of psychological research methods\",\"list of psychological research methods\",\"list of psychological research methods\",\"list of psychological research methods\",\"list of mnemonics\",\"dsm-iv codes\",\"dsm-iv codes\",\"dsm-iv codes\",\"dsm-iv codes\",\"list of mental disorders\",\"list of mental disorders\",\"list of mental disorders\",\"list of mental disorders\",\"list of mental disorders\",\"list of mental disorders\",\"list of mental disorders\",\"outline of autism\",\"outline of autism\",\"list of psychiatric medications\",\"list of psychiatric medications\",\"list of psychiatric medications\",\"list of psychiatric medications\",\"list of psychiatric medications by condition treated\",\"list of psychiatric medications by condition treated\",\"list of psychiatric medications by condition treated\",\"list of psychiatric medications by condition treated\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of psychology organizations\",\"list of psychology organizations\",\"list of psychology organizations\",\"list of psychology organizations\",\"list of psychology organizations\",\"list of psychology organizations\",\"code of hammurabi\",\"code of hammurabi\",\"code of hammurabi\",\"marriage of the virgin\",\"hierarchical organization\",\"hierarchical organization\",\"hierarchical organization\",\"hierarchical organization\",\"manorialism\",\"manorialism\",\"manorialism\",\"manorialism\",\"manorialism\",\"manorialism\",\"manorialism\",\"manorialism\",\"manorialism\",\"julius stone\",\"feminist legal theory\",\"feminist legal theory\",\"feminist legal theory\",\"feminist legal theory\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"john rawls\",\"constitutional economics\",\"constitutional economics\",\"constitutional economics\",\"constitutional economics\",\"constitutional economics\",\"constitutional economics\",\"constitutional economics\",\"constitutional economics\",\"constitutional economics\",\"political jurisprudence\",\"history of the legal profession\",\"history of the legal profession\",\"history of the legal profession\",\"history of the legal profession\",\"history of the legal profession\",\"history of the legal profession\",\"history of the american legal profession\",\"history of the american legal profession\",\"history of the american legal profession\",\"history of the american legal profession\",\"history of the american legal profession\",\"executive order\",\"executive order\",\"executive order\",\"executive order\",\"executive order\",\"executive order\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"philosophy of sex\",\"philosophy of sex\",\"philosophy of sex\",\"philosophy of sex\",\"philosophy of sex\",\"philosophy of sex\",\"philosophy of sex\",\"philosophy of sex\",\"philosophy of sex\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"balkanization\",\"balkanization\",\"balkanization\",\"balkanization\",\"balkanization\",\"westphalian sovereignty\",\"westphalian sovereignty\",\"westphalian sovereignty\",\"westphalian sovereignty\",\"synarchism\",\"synarchism\",\"synarchism\",\"timocracy\",\"timocracy\",\"timocracy\",\"timocracy\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"enlightened absolutism\",\"enlightened absolutism\",\"enlightened absolutism\",\"enlightened absolutism\",\"enlightened absolutism\",\"enlightened absolutism\",\"enlightened absolutism\",\"enlightened absolutism\",\"soft despotism\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"tyranny of the majority\",\"magnate\",\"magnate\",\"magnate\",\"magnate\",\"the rich get richer and the poor get poorer\",\"the rich get richer and the poor get poorer\",\"the rich get richer and the poor get poorer\",\"history of propaganda\",\"history of propaganda\",\"history of propaganda\",\"history of propaganda\",\"history of propaganda\",\"history of propaganda\",\"history of propaganda\",\"history of propaganda\",\"history of propaganda\",\"history of propaganda\",\"post-truth politics\",\"post-truth politics\",\"post-truth politics\",\"post-truth politics\",\"counterpropaganda\",\"strategy of tension\",\"demonizing the enemy\",\"demonizing the enemy\",\"demonizing the enemy\",\"demonizing the enemy\",\"gish gallop\",\"gish gallop\",\"gish gallop\",\"obscurantism\",\"obscurantism\",\"obscurantism\",\"obscurantism\",\"obscurantism\",\"slogan\",\"slogan\",\"slogan\",\"slogan\",\"slogan\",\"slogan\",\"slogan\",\"slogan\",\"slogan\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"peer pressure\",\"communal reinforcement\",\"communal reinforcement\",\"communal reinforcement\",\"communal reinforcement\",\"communal reinforcement\",\"communal reinforcement\",\"communal reinforcement\",\"communal reinforcement\",\"communal reinforcement\",\"communal reinforcement\",\"shock value\",\"shock value\",\"shock value\",\"f\\u00fchrer\",\"f\\u00fchrer\",\"f\\u00fchrer\",\"political repression\",\"political repression\",\"political repression\",\"political repression\",\"political repression\",\"political repression\",\"political repression\",\"political repression\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"new left review\",\"new left review\",\"new left review\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"social order\",\"social order\",\"social order\",\"social order\",\"social order\",\"social order\",\"social order\",\"social order\",\"social order\",\"social order\",\"social order\",\"ilminism\",\"ilminism\",\"ilminism\",\"rumor\",\"rumor\",\"proverb\",\"proverb\",\"proverb\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"friedrich naumann foundation\",\"responsibility to protect\",\"responsibility to protect\",\"ngo-ization\",\"broken windows theory\",\"broken windows theory\",\"broken windows theory\",\"broken windows theory\",\"broken windows theory\",\"broken windows theory\",\"solitary confinement\",\"solitary confinement\",\"solitary confinement\",\"solitary confinement\",\"community policing\",\"community policing\",\"community policing\",\"community policing\",\"community policing\",\"community policing\",\"community policing\",\"informal social control\",\"proactive policing\",\"problem-oriented policing\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"perpetual war\",\"perpetual war\",\"perpetual war\",\"perpetual war\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"eurasianism\",\"eurasianism\",\"eurasianism\",\"eurasianism\",\"eurasianism\",\"eurasianism\",\"maternalism\",\"maternalism\",\"maternalism\",\"maternalism\",\"maternalism\",\"blue labour\",\"blue labour\",\"blue labour\",\"blue labour\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"christian corporatism\",\"christian corporatism\",\"christian corporatism\",\"christian corporatism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"public policy doctrine\",\"public policy doctrine\",\"public policy doctrine\",\"public policy doctrine\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"archibald crossley\",\"party platform\",\"party platform\",\"american journal of political science\",\"american journal of political science\",\"prediction market\",\"prediction market\",\"prediction market\",\"prediction market\",\"public opinion quarterly\",\"public opinion quarterly\",\"public opinion quarterly\",\"public opinion quarterly\",\"institution\",\"institution\",\"institution\",\"institution\",\"institution\",\"institution\",\"institution\",\"institution\",\"institution\",\"institution\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"sociology of punishment\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"base and superstructure\",\"institutionalist political economy\",\"vaticanology\",\"vaticanology\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"master of public administration\",\"master of public administration\",\"master of public administration\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"sciences po\",\"superpower collapse\",\"superpower collapse\",\"superpower collapse\",\"superpower collapse\",\"superpower collapse\",\"superpower collapse\",\"implementation\",\"implementation\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"democratic capitalism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"capitalist peace\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international society of political psychology\",\"walter f. dodd\",\"walter f. dodd\",\"walter f. dodd\",\"emmette redford\",\"emmette redford\",\"henry e. brady\",\"henry e. brady\",\"opinion leadership\",\"opinion leadership\",\"opinion leadership\",\"opinion leadership\",\"elihu katz\",\"elihu katz\",\"elihu katz\",\"elihu katz\",\"manifest and latent functions and dysfunctions\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"post-behavioralism\",\"post-behavioralism\",\"post-behavioralism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"werturteilsstreit\",\"werturteilsstreit\",\"werturteilsstreit\",\"werturteilsstreit\",\"werturteilsstreit\",\"kyklos\",\"organizational theory\",\"organizational theory\",\"organizational theory\",\"organizational theory\",\"organizational theory\",\"blavatnik school of government\",\"blavatnik school of government\",\"german university of administrative sciences speyer\",\"german university of administrative sciences speyer\",\"german university of administrative sciences speyer\",\"corporative federalism\",\"corporative federalism\",\"corporative federalism\",\"corporative federalism\",\"right to exist\",\"home rule\",\"home rule\",\"home rule\",\"china watcher\",\"kremlinology\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"isaiah berlin\",\"isaiah berlin\",\"isaiah berlin\",\"isaiah berlin\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"liberal conservatism\",\"liberal conservatism\",\"liberal conservatism\",\"liberal conservatism\",\"liberal conservatism\",\"liberal conservatism\",\"liberal conservatism\",\"liberal conservatism\",\"liberal conservatism\",\"china university of political science and law\",\"communication university of china\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"self-criticism\",\"social patriotism\",\"social patriotism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"real socialism\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"social revolution\",\"instituts d'\\u00e9tudes politiques\",\"instituts d'\\u00e9tudes politiques\",\"instituts d'\\u00e9tudes politiques\",\"instituts d'\\u00e9tudes politiques\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"princeton school of public and international affairs\",\"princeton school of public and international affairs\",\"princeton school of public and international affairs\",\"princeton school of public and international affairs\",\"princeton school of public and international affairs\",\"princeton school of public and international affairs\",\"bush school of government and public service\",\"bush school of government and public service\",\"bush school of government and public service\",\"bush school of government and public service\",\"schar school of policy and government\",\"schar school of policy and government\",\"schar school of policy and government\",\"schar school of policy and government\",\"schar school of policy and government\",\"journal of public economics\",\"journal of public economics\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"cato institute\",\"rentier state\",\"resource curse\",\"resource curse\",\"resource curse\",\"resource curse\",\"resource curse\",\"resource curse\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"workplace democracy\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"participism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"equality of outcome\",\"equality of outcome\",\"equality of outcome\",\"equality of outcome\",\"equality of outcome\",\"equality of outcome\",\"equality of outcome\",\"equality of outcome\",\"equality of outcome\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"structural violence\",\"structural violence\",\"structural violence\",\"structural violence\",\"structural violence\",\"structural violence\",\"structural violence\",\"structural violence\",\"conflict resolution research\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"peace journalism\",\"peace journalism\",\"peace journalism\",\"peace journalism\",\"essence of decision\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"security of tenure\",\"impeachment\",\"impeachment\",\"impeachment\",\"impeachment\",\"impeachment\",\"impeachment\",\"impeachment\",\"impeachment\",\"party political broadcast\",\"campaign finance\",\"campaign finance\",\"campaign finance\",\"campaign finance\",\"two-level game theory\",\"two-level game theory\",\"two-level game theory\",\"two-level game theory\",\"two-level game theory\",\"sequential game\",\"sequential game\",\"sequential game\",\"sequential game\",\"sequential game\",\"sequential game\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"divided government in the united states\",\"net worth\",\"net worth\",\"third-person effect\",\"social media in the 2016 united states presidential election\",\"social media in the 2016 united states presidential election\",\"media circus\",\"media circus\",\"media circus\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"christian egalitarianism\",\"christian egalitarianism\",\"christian fascism\",\"conservative liberalism\",\"law and order\",\"persistent vegetative state\",\"persistent vegetative state\",\"persistent vegetative state\",\"persistent vegetative state\",\"persistent vegetative state\",\"persistent vegetative state\",\"persistent vegetative state\",\"persistent vegetative state\",\"persistent vegetative state\",\"persistent vegetative state\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"commodity form theory\",\"corporate statism\",\"corporate statism\",\"corporate statism\",\"organicism\",\"organicism\",\"organicism\",\"organicism\",\"organicism\",\"organicism\",\"organicism\",\"organicism\",\"economic nationalism\",\"economic nationalism\",\"economic nationalism\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"parochialism\",\"parochialism\",\"pork barrel\",\"pork barrel\",\"paid survey\",\"survey data collection\",\"alan wolfe\",\"alan wolfe\",\"alan wolfe\",\"alan wolfe\",\"econtalk\",\"econtalk\",\"econtalk\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies review\",\"political studies review\",\"political studies review\",\"transnational progressivism\",\"transnational progressivism\",\"global citizenship\",\"global citizenship\",\"global citizenship\",\"global citizenship\",\"global citizenship\",\"global citizenship\",\"global citizenship\",\"equality before the law\",\"equality before the law\",\"equality before the law\",\"equality before the law\",\"equality before the law\",\"equality before the law\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"personhood\",\"personhood\",\"personhood\",\"personhood\",\"personhood\",\"personhood\",\"personhood\",\"personhood\",\"personhood\",\"right to development\",\"right to development\",\"karl deutsch award\",\"regionalism (international relations)\",\"victim study\",\"victim study\",\"dark figure of crime\",\"tripartite consultation (international labour standards) convention, 1976\",\"ratification\",\"ratification\",\"no war but the class war\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"fenno's paradox\",\"fenno's paradox\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"catch-22\",\"classical test theory\",\"classical test theory\",\"classical test theory\",\"classical test theory\",\"party identification\",\"domestic analogy\",\"eco-nationalism\",\"eco-nationalism\",\"eco-nationalism\",\"eco-capitalism\",\"eco-capitalism\",\"eco-capitalism\",\"eco-capitalism\",\"queer ecology\",\"queer ecology\",\"queer ecology\",\"queer ecology\",\"cosmopolitan democracy\",\"cosmopolitan democracy\",\"cosmopolitan democracy\",\"united nations parliamentary assembly\",\"united nations parliamentary assembly\",\"societal attitudes towards abortion\",\"antinaturalism (politics)\",\"antinaturalism (politics)\",\"gender essentialism\",\"gender essentialism\",\"gender essentialism\",\"gender essentialism\",\"gender essentialism\",\"morphological freedom\",\"morphological freedom\",\"holocaust trivialization\",\"echo chamber (media)\",\"echo chamber (media)\",\"echo chamber (media)\",\"echo chamber (media)\",\"echo chamber (media)\",\"echo chamber (media)\",\"echo chamber (media)\",\"echo chamber (media)\",\"social reality\",\"social reality\",\"social reality\",\"social reality\",\"social reality\",\"social reality\",\"social reality\",\"social reality\",\"social reality\",\"social reality\",\"self-deception\",\"self-deception\",\"self-deception\",\"self-deception\",\"self-deception\",\"identity (philosophy)\",\"identity (philosophy)\",\"identity (philosophy)\",\"identity (philosophy)\",\"identity (philosophy)\",\"abilene paradox\",\"collective effervescence\",\"collective effervescence\",\"collective effervescence\",\"social actions\",\"social actions\",\"social actions\",\"social actions\",\"social actions\",\"unitarian universalism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"military policy\",\"military policy\",\"military policy\",\"military policy\",\"military policy\",\"military policy\",\"private military company\",\"private military company\",\"peace dividend\",\"peace dividend\",\"guns versus butter model\",\"guns versus butter model\",\"charg\\u00e9 de mission\",\"charg\\u00e9 de mission\",\"charg\\u00e9 de mission\",\"charg\\u00e9 de mission\",\"full spectrum diplomacy\",\"full spectrum diplomacy\",\"full spectrum diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"science diplomacy\",\"exequatur\",\"exequatur\",\"exequatur\",\"exequatur\",\"exequatur\",\"canadian political science association\",\"canadian political science association\",\"civic political culture\",\"civic political culture\",\"civic political culture\",\"civic political culture\",\"civic political culture\",\"parochial political culture\",\"parochial political culture\",\"political culture of the united states\",\"proprietary community\",\"voluntary society\",\"voluntary society\",\"voluntary society\",\"voluntary society\",\"voluntary society\",\"privatism\",\"privatism\",\"privatism\",\"privatism\",\"privatism\",\"privatism\",\"privatism\",\"new political economy (journal)\",\"review of international political economy\",\"public opinion on climate change\",\"public opinion on climate change\",\"public opinion on climate change\",\"public opinion on climate change\",\"attention economy\",\"attention economy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"sustainable energy\",\"culture 21\",\"postfunctionalism\",\"liesbet hooghe\",\"liesbet hooghe\",\"regulatory competition\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"european union studies association\",\"fritz w. scharpf\",\"white power music\",\"white power music\",\"white power music\",\"white power music\",\"white power music\",\"white power music\",\"white power music\",\"christian privilege\",\"christian privilege\",\"christian privilege\",\"christian privilege\",\"christian privilege\",\"christian privilege\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"social model of disability\",\"social model of disability\",\"social model of disability\",\"social model of disability\",\"social model of disability\",\"social model of disability\",\"social model of disability\",\"denationalized citizenship\",\"diplomatic protection\",\"journal of policy history\",\"pippa norris\",\"frankfurt declaration\",\"frankfurt declaration\",\"frankfurt declaration\",\"social corporatism\",\"social corporatism\",\"law without the state\",\"gustave le bon\",\"gustave le bon\",\"gustave le bon\",\"gustave le bon\",\"gustave le bon\",\"xuanchuan\",\"mass media and american politics\",\"deployment management\",\"social media use by donald trump\",\"local service delivery\",\"local service delivery\",\"corporatization\",\"corporatization\",\"corporatization\",\"corporatization\",\"corporatization\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"glossary of international relations terms\",\"glossary of international relations terms\",\"international sanctions\",\"international sanctions\",\"international sanctions\",\"malikism in algeria\",\"malikism in algeria\",\"malikism in algeria\",\"malikism in algeria\",\"awza'i\",\"awza'i\",\"awza'i\",\"thawri\",\"thawri\",\"ahl al-hadith\",\"madhhab\",\"madhhab\",\"madhhab\",\"principle of inalienability of the public domain\",\"mus\\u00e9e de l'homme\",\"metcalfe's law\",\"metcalfe's law\",\"beckstrom's law\",\"social multiplier effect\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"arbitrage pricing theory\",\"growth stock\",\"growth stock\",\"growth stock\",\"growth stock\",\"growth stock\",\"growth stock\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"sunk cost\",\"sunk cost\",\"sunk cost\",\"sunk cost\",\"sunk cost\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"accelerator effect\",\"accelerator effect\",\"accelerator effect\",\"accelerator effect\",\"accelerator effect\",\"accelerator effect\",\"national average salary\",\"national average salary\",\"national average salary\",\"discouraged worker\",\"discouraged worker\",\"weighted average cost of capital\",\"weighted average cost of capital\",\"rate of return\",\"rate of return\",\"rate of return\",\"rate of return\",\"rate of return\",\"rate of return\",\"seasoned equity offering\",\"diminishing returns\",\"diminishing returns\",\"diminishing returns\",\"diminishing returns\",\"diminishing returns\",\"diminishing returns\",\"paradox of value\",\"st. petersburg paradox\",\"st. petersburg paradox\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"degrowth\",\"world economy\",\"world economy\",\"world economy\",\"world economy\",\"world economy\",\"world economy\",\"world economy\",\"world economy\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"least developed countries\",\"economics of science\",\"economics of science\",\"economics of science\",\"economics of science\",\"economics of science\",\"economics of science\",\"economics of science\",\"economics of science\",\"economics of science\",\"economics of science\",\"blue economy\",\"blue economy\",\"democratic globalization\",\"democratic globalization\",\"democratic globalization\",\"ronen palan\",\"ronen palan\",\"in kind\",\"in kind\",\"in kind\",\"in kind\",\"in kind\",\"openness\",\"openness\",\"openness\",\"openness\",\"openness\",\"openness\",\"openness\",\"credit default option\",\"credit default option\",\"credit default option\",\"credit default option\",\"credit default option\",\"credit default option\",\"credit default option\",\"forward price\",\"forward price\",\"forward price\",\"forward price\",\"forward price\",\"forward price\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"economic data\",\"economic data\",\"economic data\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"production\\u2013possibility frontier\",\"world3\",\"population and development review\",\"population and development review\",\"cumulative prospect theory\",\"bertrand paradox (economics)\",\"bertrand paradox (economics)\",\"edgeworth paradox\",\"open economy\",\"open economy\",\"open economy\",\"open economy\",\"hubbert peak theory\",\"hubbert peak theory\",\"hubbert peak theory\",\"hubbert peak theory\",\"peak wheat\",\"peak wheat\",\"pickens plan\",\"pickens plan\",\"pickens plan\",\"pickens plan\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"heckscher\\u2013ohlin model\",\"heckscher\\u2013ohlin model\",\"heckscher\\u2013ohlin model\",\"heckscher\\u2013ohlin model\",\"ramsey\\u2013cass\\u2013koopmans model\",\"ramsey\\u2013cass\\u2013koopmans model\",\"eonia\",\"eonia\",\"eonia\",\"eonia\",\"euronia\",\"euronia\",\"marginal propensity to consume\",\"marginal propensity to consume\",\"marginal propensity to consume\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"nava ashraf\",\"nava ashraf\",\"nava ashraf\",\"georg weizs\\u00e4cker\",\"georg weizs\\u00e4cker\",\"hiding hand principle\",\"economic power\",\"economic power\",\"economic power\",\"list of important publications in economics\",\"list of important publications in economics\",\"on the principles of political economy and taxation\",\"on the principles of political economy and taxation\",\"on the principles of political economy and taxation\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"kenneth boulding's evolutionary perspective\",\"noosphere\",\"noosphere\",\"neo-ricardianism\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"list of cognitive biases\",\"list of cognitive biases\",\"list of cognitive biases\",\"list of cognitive biases\",\"list of cognitive biases\",\"list of cognitive biases\",\"list of cognitive biases\",\"list of cognitive biases\",\"list of cognitive biases\",\"economic puzzle\",\"economic puzzle\",\"economic puzzle\",\"forward premium anomaly\",\"balassa\\u2013samuelson effect\",\"balassa\\u2013samuelson effect\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"land management\",\"land management\",\"land management\",\"collaboration\",\"collaboration\",\"collaboration\",\"collaboration\",\"collaboration\",\"collaboration\",\"managerialism\",\"managerialism\",\"convergence (economics)\",\"structural inequality\",\"structural inequality\",\"history of capitalist theory\",\"history of capitalist theory\",\"history of capitalist theory\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"economic mobility\",\"economic mobility\",\"economic mobility\",\"economic mobility\",\"equity home bias puzzle\",\"equity home bias puzzle\",\"stylized fact\",\"stylized fact\",\"econophysics\",\"net national product\",\"value product\",\"value product\",\"value product\",\"breakout (technical analysis)\",\"breakout (technical analysis)\",\"doji\",\"doji\",\"doji\",\"doji\",\"donchian channel\",\"donchian channel\",\"donchian channel\",\"circular flow of income\",\"nominal yield\",\"nominal yield\",\"nominal yield\",\"nominal yield\",\"perpetual bond\",\"perpetual bond\",\"perpetual bond\",\"i-spread\",\"i-spread\",\"leontief paradox\",\"paradox of thrift\",\"paradox of thrift\",\"paradox of thrift\",\"paradox of thrift\",\"sectoral balances\",\"excess reserves\",\"encouraged industry catalogue\",\"national equities exchange and quotations\",\"national equities exchange and quotations\",\"samuelson condition\",\"simulation modeling\",\"elhanan helpman\",\"elhanan helpman\",\"elhanan helpman\",\"elhanan helpman\",\"induced consumption\",\"induced consumption\",\"autonomous consumption\",\"market mechanism\",\"real economy\",\"rat race\",\"rat race\",\"average variable cost\",\"revealed preference\",\"revealed preference\",\"revealed preference\",\"tibor\",\"conceptual economy\",\"dynamical system\",\"dynamical system\",\"dynamical system\",\"discrete choice\",\"discrete choice\",\"discrete choice\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"dynamic discrete choice\",\"extended-hours trading\",\"auction theory\",\"auction theory\",\"concentration risk\",\"concentration risk\",\"political risk\",\"political risk\",\"political risk\",\"law of rent\",\"law of rent\",\"law of rent\",\"law of rent\",\"law of rent\",\"labor theory of property\",\"labor theory of property\",\"labor theory of property\",\"labor theory of property\",\"labor theory of property\",\"dynamic pricing\",\"rebound effect (conservation)\",\"rebound effect (conservation)\",\"rebound effect (conservation)\",\"rebound effect (conservation)\",\"rebound effect (conservation)\",\"ecolabel\",\"ecolabel\",\"ecolabel\",\"ecolabel\",\"ecolabel\",\"material flow analysis\",\"material flow analysis\",\"material flow analysis\",\"urban metabolism\",\"urban metabolism\",\"urban metabolism\",\"community-supported agriculture\",\"community-supported agriculture\",\"community-supported agriculture\",\"community-supported agriculture\",\"community-supported agriculture\",\"community-supported agriculture\",\"community-supported agriculture\",\"mandeville's paradox\",\"fischer black prize\",\"proto-industrialization\",\"proto-industrialization\",\"volume index\",\"chaining\",\"chaining\",\"chaining\",\"chaining\",\"chaining\",\"chaining\",\"chaining\",\"chaining\",\"chaining\",\"chaining\",\"economic law\",\"gabor\\u2013granger method\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"the theory of interstellar trade\",\"time value of money\",\"time value of money\",\"theories of poverty\",\"theories of poverty\",\"theories of poverty\",\"theories of poverty\",\"social vulnerability\",\"social vulnerability\",\"scottish index of multiple deprivation\",\"scottish index of multiple deprivation\",\"marginal return\",\"base period\",\"deflator\",\"cycle of poverty\",\"cycle of poverty\",\"cycle of poverty\",\"cycle of poverty\",\"men's underwear index\",\"ak model\",\"ak model\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"99ers\",\"99ers\",\"american recovery and reinvestment act of 2009\",\"american recovery and reinvestment act of 2009\",\"american recovery and reinvestment act of 2009\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"identity line\",\"bowley's law\",\"list of economics films\",\"vent for surplus\",\"principles of political economy\",\"principles of political economy\",\"principles of political economy\",\"robinson crusoe economy\",\"schelling's segregation model\",\"schelling's segregation model\",\"schelling's segregation model\",\"schelling's segregation model\",\"trygve haavelmo\",\"trygve haavelmo\",\"trygve haavelmo\",\"trygve haavelmo\",\"trygve haavelmo\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"great gatsby curve\",\"great gatsby curve\",\"least-cost theory\",\"least-cost theory\",\"least-cost theory\",\"least-cost theory\",\"least-cost theory\",\"least-cost theory\",\"least-cost theory\",\"least-cost theory\",\"least-cost theory\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"sociology of the world religions\",\"sociology of the world religions\",\"sociology of the world religions\",\"sociology of the world religions\",\"sociology of the world religions\",\"sociology of the world religions\",\"ideal type\",\"ideal type\",\"ideal type\",\"ideal type\",\"ideal type\",\"ideal type\",\"iron cage\",\"iron cage\",\"iron cage\",\"iron cage\",\"iron cage\",\"life chances\",\"life chances\",\"life chances\",\"life chances\",\"tripartite classification of authority\",\"tripartite classification of authority\",\"tripartite classification of authority\",\"science as a vocation\",\"richard koo\",\"history of microeconomics\",\"capital cost\",\"guido tabellini\",\"guido tabellini\",\"guido tabellini\",\"shale band\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"duck curve\",\"power-to-x\",\"power-to-x\",\"global retirement index\",\"bric\",\"bric\",\"bric\",\"production for profit\",\"production for profit\",\"production for profit\",\"production for profit\",\"surplus labour\",\"surplus labour\",\"john roemer\",\"john roemer\",\"john roemer\",\"john roemer\",\"real-world economics review\",\"marxist sociology\",\"marxist sociology\",\"marxist sociology\",\"inframarginal analysis\",\"task force\",\"task force\",\"task force\",\"task force\",\"task force\",\"task force\",\"task force\",\"emotivism\",\"emotivism\",\"emotivism\",\"emotivism\",\"emotivism\",\"emotivism\",\"possible world\",\"possible world\",\"possible world\",\"possible world\",\"possible world\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"henri poincar\\u00e9\",\"henri poincar\\u00e9\",\"henri poincar\\u00e9\",\"henri poincar\\u00e9\",\"henri poincar\\u00e9\",\"c. d. broad\",\"c. d. broad\",\"c. d. broad\",\"c. d. broad\",\"c. d. broad\",\"c. d. broad\",\"peter sloterdijk\",\"peter sloterdijk\",\"peter sloterdijk\",\"peter sloterdijk\",\"peter sloterdijk\",\"ideocracy\",\"self-awareness\",\"self-awareness\",\"self-awareness\",\"self-awareness\",\"self-awareness\",\"self-awareness\",\"self-awareness\",\"self-awareness\",\"role ethics\",\"role ethics\",\"role ethics\",\"responsibility\",\"responsibility\",\"responsibility\",\"responsibility\",\"responsibility\",\"ecomodernism\",\"passing (sociology)\",\"rogers brubaker\",\"donatella della porta\",\"donatella della porta\",\"riane eisler\",\"riane eisler\",\"franz oppenheimer\",\"franz oppenheimer\",\"franz oppenheimer\",\"helmuth plessner\",\"helmuth plessner\",\"helmuth plessner\",\"ferdinand de saussure\",\"ferdinand de saussure\",\"ferdinand de saussure\",\"ferdinand de saussure\",\"max scheler\",\"max scheler\",\"max scheler\",\"max scheler\",\"p\\u0131nar selek\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"quantitative research\",\"action theory (sociology)\",\"health geography\",\"interactionism\",\"interactionism\",\"interactionism\",\"interactionism\",\"total institution\",\"total institution\",\"total institution\",\"total institution\",\"open-mindedness\",\"person of color\",\"person of color\",\"visible minority\",\"visible minority\",\"visible minority\",\"visible minority\",\"injustice\",\"injustice\",\"injustice\",\"injustice\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"destabilisation\",\"destabilisation\",\"new social movements\",\"new social movements\",\"agency (philosophy)\",\"agency (philosophy)\",\"instrumental and value-rational action\",\"instrumental and value-rational action\",\"instrumental and value-rational action\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"l'ann\\u00e9e sociologique\",\"l'ann\\u00e9e sociologique\",\"list of sociology journals\",\"list of sociology journals\",\"list of sociology journals\",\"list of sociology journals\",\"identity crisis\",\"greatness\",\"greatness\",\"person\",\"person\",\"reality distortion field\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"complex adaptive system\",\"complex adaptive system\",\"complex adaptive system\",\"complex adaptive system\",\"computational sociology\",\"jacqueline rose\",\"jacqueline rose\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"anti-gender movement\",\"anti-gender movement\",\"anti-gender movement\",\"anti-gender movement\",\"anti-gender movement\",\"anti-gender movement\",\"anti-gender movement\",\"value judgment\",\"value judgment\",\"value judgment\",\"value judgment\",\"instrumental and intrinsic value\",\"medicalization\",\"medicalization\",\"medicalization\",\"medicalization\",\"medicalization\",\"medicalization\",\"medicalization\",\"medicalization\",\"medicalization\",\"medicalization\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"commodity chain\",\"first world\",\"first world\",\"first world\",\"first world\",\"first world\",\"first world\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"matrilocal residence\",\"matrilocal residence\",\"microsociology\",\"non-state actor\",\"social conflict\",\"social phenomenon\",\"social phenomenon\",\"social phenomenon\",\"social phenomenon\",\"social reproduction\",\"social reproduction\",\"social reproduction\",\"social reproduction\",\"underclass\",\"vertical mobility\",\"vertical mobility\",\"national question (quebec)\",\"national question (quebec)\",\"performativity\",\"performativity\",\"performativity\",\"performativity\",\"sociotechnology\",\"sociotechnology\",\"sociotechnology\",\"sociotechnology\",\"sociotechnology\",\"sociotechnology\",\"sociotechnology\",\"sociotechnology\",\"double hermeneutic\",\"double hermeneutic\",\"double hermeneutic\",\"double hermeneutic\",\"double hermeneutic\",\"double hermeneutic\",\"double hermeneutic\",\"double hermeneutic\",\"mapping controversies\",\"mapping controversies\",\"mapping controversies\",\"mapping controversies\",\"mapping controversies\",\"mapping controversies\",\"mapping controversies\",\"scientocracy\",\"scientocracy\",\"scientocracy\",\"scientocracy\",\"scientocracy\",\"scientocracy\",\"normalization process theory\",\"normalization process theory\",\"normalization process theory\",\"normalization process theory\",\"technical change\",\"technical change\",\"technical change\",\"regulation of science\",\"regulation of science\",\"humanistic sociology\",\"humanistic sociology\",\"humanistic sociology\",\"taste (sociology)\",\"taste (sociology)\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"status attainment\",\"civic virtue\",\"civic virtue\",\"civic virtue\",\"civic virtue\",\"civility\",\"generosity\",\"generosity\",\"generosity\",\"public morality\",\"nudity\",\"nudity\",\"nudity\",\"tschandala\",\"ressentiment\",\"ressentiment\",\"ressentiment\",\"ressentiment\",\"ressentiment\",\"ressentiment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"law of the jungle\",\"might makes right\",\"procreative beneficence\",\"sociologists without borders\",\"food sovereignty\",\"reflexivity (social theory)\",\"pay it forward\",\"pay it forward\",\"pay it forward\",\"reciprocity (cultural anthropology)\",\"the american journal of economics and sociology\",\"journal of sociology\",\"middle-range theory (sociology)\",\"collective mental state\",\"collective mental state\",\"collective mental state\",\"collective mental state\",\"collective mental state\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"heterosociality\",\"heterosociality\",\"duality of structure\",\"average joe\",\"moral entrepreneur\",\"recuperation (politics)\",\"the revolution of everyday life\",\"german sociological association\",\"european sociological association\",\"european sociological association\",\"european sociological association\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"people power\",\"people power\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"imagery of nude celebrities\",\"social rights (social contract theory)\",\"free migration\",\"free migration\",\"free migration\",\"free migration\",\"island mentality\",\"island mentality\",\"ipse dixit\",\"ipse dixit\",\"bibliography of sociology\",\"cognitive bias\",\"cognitive bias\",\"cognitive bias\",\"cognitive bias\",\"cognitive bias\",\"cognitive bias\",\"cognitive bias\",\"cognitive bias\",\"cognitive bias\",\"cognitive bias\",\"safety-valve institution\",\"theories of humor\",\"outline of globalization\",\"outline of globalization\",\"an anarchist faq\",\"an anarchist faq\",\"necropolitics\",\"necropolitics\",\"necropolitics\",\"necropolitics\",\"necropolitics\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"prohibition of dying\",\"prohibition of dying\",\"norwegian sociological association\",\"group threat theory\",\"market-dominant minority\",\"post-work society\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"gaia philosophy\",\"gaia philosophy\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"hobby\",\"hobby\",\"hobby\",\"personal life\",\"personal life\",\"personal life\",\"personal life\",\"travel behavior\",\"feoffment\",\"feoffment\",\"feoffment\",\"feoffment\",\"trobriand islands\",\"trobriand islands\",\"trobriand islands\",\"trobriand islands\",\"proverbial phrase\",\"marija gimbutas\",\"marija gimbutas\",\"bicameral mentality\",\"bicameral mentality\",\"bicameral mentality\",\"bicameral mentality\",\"cephalic index\",\"cephalic index\",\"biology and sexual orientation\",\"biology and sexual orientation\",\"biology and sexual orientation\",\"biology and sexual orientation\",\"biology and sexual orientation\",\"biology and sexual orientation\",\"homosexual behavior in animals\",\"homosexual behavior in animals\",\"homosexual behavior in animals\",\"homosexual behavior in animals\",\"homosexual behavior in animals\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"the white goddess\",\"the white goddess\",\"early modern human\",\"early modern human\",\"names for the human species\",\"serer-ndut people\",\"serer-ndut people\",\"serer-ndut people\",\"serer-ndut people\",\"serer people\",\"serer people\",\"serer people\",\"serer people\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"serer maternal clans\",\"non-representational theory\",\"non-representational theory\",\"non-representational theory\",\"non-representational theory\",\"minangkabau people\",\"minangkabau people\",\"minangkabau people\",\"moana (1926 film)\",\"psychohistory\",\"psychohistory\",\"psychohistory\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"androcentrism\",\"androcentrism\",\"lila: an inquiry into morals\",\"alter ego\",\"alter ego\",\"hoi polloi\",\"gloss (annotation)\",\"constitutionality\",\"list of birds displaying homosexual behavior\",\"list of birds displaying homosexual behavior\",\"list of mammals displaying homosexual behavior\",\"topic and comment\",\"homo faber\",\"cogito, ergo sum\",\"cogito, ergo sum\",\"fount of honour\",\"fount of honour\",\"fount of honour\",\"general knowledge\",\"constantin noica\",\"moralia\",\"ghazi (warrior)\",\"maceration (bone)\",\"forensic facial reconstruction\",\"development geography\",\"guatemalan forensic anthropology foundation\",\"australian institute of aboriginal and torres strait islander studies\",\"museum of world culture\",\"museum of mankind\",\"museum of mankind\",\"prickly paradigm press\",\"robert christison\",\"hypnopompic\",\"hypnopompic\",\"hypnopompic\",\"psychonautics\",\"psychonautics\",\"sleep and learning\",\"sleep and learning\",\"museum of archaeology and anthropology, university of cambridge\",\"taboo (2002 tv series)\",\"taboo (2002 tv series)\",\"live free or die\",\"confucian classes\",\"cabang atas\",\"unsaid\",\"unsaid\",\"unsaid\",\"facial expression\",\"facial expression\",\"facial expression\",\"microexpression\",\"les ma\\u00eetres fous\",\"moral emotions\",\"moral emotions\",\"moral emotions\",\"list of timothy asch films\",\"magical death\",\"ogilvie professor of human geography\",\"koestler parapsychology unit\",\"koestler parapsychology unit\",\"koestler parapsychology unit\",\"outline of culture\",\"poker\",\"poker\",\"poker\",\"poker\",\"metanoia (psychology)\",\"metanoia (psychology)\",\"aion: researches into the phenomenology of the self\",\"aion: researches into the phenomenology of the self\",\"aion: researches into the phenomenology of the self\",\"aion: researches into the phenomenology of the self\",\"aion: researches into the phenomenology of the self\",\"aion: researches into the phenomenology of the self\",\"aion: researches into the phenomenology of the self\",\"aion: researches into the phenomenology of the self\",\"civilization in transition\",\"civilization in transition\",\"civilization in transition\",\"civilization in transition\",\"consumer class\",\"consumer class\",\"consumer class\",\"microgeneration\",\"microgeneration\",\"microgeneration\",\"microgeneration\",\"microgeneration\",\"microgeneration\",\"list of women anthropologists\",\"poverty class\",\"poverty class\",\"poverty class\",\"food bank\",\"womyn's land\",\"womyn's land\",\"womyn's land\",\"journal of lesbian studies\",\"kriza j\\u00e1nos ethnographic society\",\"toloy\",\"hermann lotze\",\"hermann lotze\",\"hermann lotze\",\"piaget's theory of cognitive development\",\"crying\",\"sociometric status\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"computational theory of mind\",\"shadow (psychology)\",\"shadow (psychology)\",\"shadow (psychology)\",\"shadow (psychology)\",\"shadow (psychology)\",\"shadow (psychology)\",\"shadow (psychology)\",\"self-hypnosis\",\"self-hypnosis\",\"catharsis\",\"catharsis\",\"catharsis\",\"catharsis\",\"catharsis\",\"catharsis\",\"subconscious\",\"subconscious\",\"subconscious\",\"subconscious\",\"subconscious\",\"subconscious\",\"subconscious\",\"automatic writing\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"psychological statistics\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"adlerian\",\"adlerian\",\"adlerian\",\"adlerian\",\"adlerian\",\"adlerian\",\"on narcissism\",\"on narcissism\",\"on narcissism\",\"on narcissism\",\"on narcissism\",\"on narcissism\",\"on narcissism\",\"mourning and melancholia\",\"mourning and melancholia\",\"mourning and melancholia\",\"object relations theory\",\"object relations theory\",\"object relations theory\",\"object relations theory\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"inner peace\",\"inner peace\",\"inner peace\",\"contemplation\",\"contemplation\",\"contemplation\",\"awareness\",\"awareness\",\"awareness\",\"awareness\",\"awareness\",\"awareness\",\"awareness\",\"awareness\",\"awareness\",\"anhedonia\",\"anhedonia\",\"anhedonia\",\"anhedonia\",\"anhedonia\",\"anhedonia\",\"anhedonia\",\"dysthymia\",\"dysthymia\",\"dysthymia\",\"dysthymia\",\"dysthymia\",\"bipolar i disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"list of neurological conditions and disorders\",\"list of neurological conditions and disorders\",\"list of neurological conditions and disorders\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"psycho-oncology\",\"philosophical analysis\",\"coma\",\"coma\",\"coma\",\"coma\",\"coma\",\"pattern recognition (psychology)\",\"emotionality\",\"emotionality\",\"emotionality\",\"emotionality\",\"emotionality\",\"emotionality\",\"emotionality\",\"emotionality\",\"emotionality\",\"emotionality\",\"emotionality\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"altered state of consciousness\",\"altered state of consciousness\",\"altered state of consciousness\",\"altered state of consciousness\",\"altered state of consciousness\",\"wakefulness\",\"global workspace theory\",\"the emperor's new mind\",\"cognitivism (psychology)\",\"cognitivism (psychology)\",\"dynamicism\",\"dynamicism\",\"participatory theory\",\"schadenfreude\",\"schadenfreude\",\"schadenfreude\",\"schadenfreude\",\"schadenfreude\",\"schadenfreude\",\"schadenfreude\",\"schadenfreude\",\"schadenfreude\",\"fight-or-flight response\",\"fight-or-flight response\",\"fight-or-flight response\",\"little albert experiment\",\"little albert experiment\",\"little albert experiment\",\"neutral stimulus\",\"defence mechanism\",\"outline of thought\",\"outline of thought\",\"outline of thought\",\"answer to job\",\"answer to job\",\"alchemical studies\",\"marie-louise von franz\",\"social dominance orientation\",\"social dominance orientation\",\"social dominance orientation\",\"schizotypy\",\"creativity and mental health\",\"creativity and mental health\",\"creativity and mental health\",\"ambidexterity\",\"mortido\",\"superiority complex\",\"superiority complex\",\"superiority complex\",\"dark triad\",\"dark triad\",\"entitlement\",\"entitlement\",\"cabin fever\",\"emotional reasoning\",\"emotional reasoning\",\"hereditarianism\",\"two-factor theory of emotion\",\"the concept of anxiety\",\"the concept of anxiety\",\"the concept of anxiety\",\"law of effect\",\"causa sui\",\"tractatus politicus\",\"behavioural despair test\",\"behavioural despair test\",\"behavioural despair test\",\"animal testing regulations\",\"animal testing regulations\",\"animal testing regulations\",\"animal testing regulations\",\"animal testing regulations\",\"pit of despair\",\"pit of despair\",\"pit of despair\",\"pit of despair\",\"argument from marginal cases\",\"argument from marginal cases\",\"gary l. francione\",\"gary l. francione\",\"european federation of psychologists' associations\",\"radical psychology network\",\"radical psychology network\",\"radical psychology network\",\"radical psychology network\",\"radical psychology network\",\"american association for the abolition of involuntary mental hospitalization\",\"american association for the abolition of involuntary mental hospitalization\",\"american association for the abolition of involuntary mental hospitalization\",\"american association for the abolition of involuntary mental hospitalization\",\"mad pride\",\"mad pride\",\"mad pride\",\"mad pride\",\"mindfreedom international\",\"mindfreedom international\",\"crazy therapies\",\"oskar pfister award\",\"list of psychology awards\",\"list of psychology awards\",\"list of psychology awards\",\"accuracy and precision\",\"accuracy and precision\",\"accuracy and precision\",\"freud's seduction theory\",\"vocabulary development\",\"swanson, nolan and pelham teacher and parent rating scale\",\"bay'ah\",\"bay'ah\",\"bay'ah\",\"bay'ah\",\"bay'ah\",\"mahr\",\"mahr\",\"mahr\",\"mahr\",\"mahr\",\"mahr\",\"international council for science\",\"global justice movement\",\"global justice movement\",\"global justice movement\",\"global justice movement\",\"clientelism\",\"clientelism\",\"clientelism\",\"clientelism\",\"cleavage (politics)\",\"gar alperovitz\",\"gar alperovitz\",\"gar alperovitz\",\"autonomous communities of spain\",\"autonomous communities of spain\",\"d\\u00e9j\\u00e0 vu\",\"kim campbell\",\"parliamentary procedure\",\"parliamentary procedure\",\"deliberation\",\"deliberation\",\"deliberation\",\"burmese way to socialism\",\"national communism\",\"national communism\",\"national communism\",\"national communism\",\"national communism\",\"national communism\",\"failed state\",\"failed state\",\"failed state\",\"failed state\",\"failed state\",\"violent non-state actor\",\"violent non-state actor\",\"william a. niskanen\",\"william a. niskanen\",\"william a. niskanen\",\"list of national legal systems\",\"they shall not pass\",\"kaarlo juho st\\u00e5hlberg\",\"imperium\",\"imperium\",\"imperium\",\"imperium\",\"international conference on theory and practice of electronic governance\",\"inquisitorial system\",\"east turkestan\",\"political cartoon\",\"political cartoon\",\"political cartoon\",\"caudillo\",\"caudillo\",\"caudillo\",\"gadsden flag\",\"gadsden flag\",\"the independent review\",\"david laidler\",\"david laidler\",\"eugene fama\",\"eugene fama\",\"eugene fama\",\"jus commune\",\"jus commune\",\"jus commune\",\"jus commune\",\"jus commune\",\"jus commune\",\"vacatio legis\",\"vacatio legis\",\"vacatio legis\",\"vacatio legis\",\"vacatio legis\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"legalism (chinese philosophy)\",\"legalism (chinese philosophy)\",\"legalism (chinese philosophy)\",\"federal law\",\"border control\",\"samuel von pufendorf\",\"bolivarian revolution\",\"ministry of magic\",\"lesser of two evils principle\",\"white paper\",\"white paper\",\"white paper\",\"white paper\",\"white paper\",\"content marketing\",\"heavily indebted poor countries\",\"heavily indebted poor countries\",\"heavily indebted poor countries\",\"small office/home office\",\"we shall overcome\",\"parliamentary debate\",\"parliamentary debate\",\"parliamentary debate\",\"state decoration\",\"he who does not work, neither shall he eat\",\"crimes against humanity under communist regimes\",\"crimes against humanity under communist regimes\",\"crimes against humanity under communist regimes\",\"liberal international order\",\"socialist campaign group\",\"liechtenstein institute on self-determination\",\"consequentialist justifications of the state\",\"liberalism and conservatism in latin america\",\"cacique\",\"oryx and crake\",\"national power\",\"atlanticism\",\"resource conservation and recovery act\",\"voting rights in the united states\",\"voting rights in the united states\",\"voting rights in the united states\",\"one man, one vote\",\"the road to serfdom\",\"the road to serfdom\",\"ralph borsodi\",\"popular socialism\",\"technocracy movement\",\"technocracy movement\",\"chester barnard\",\"chester barnard\",\"finance & development\",\"nur f\\u00fcr deutsche\",\"petition of right\",\"petition of right\",\"petition of right\",\"petition of right\",\"petition of right\",\"concurrent powers\",\"concurrent powers\",\"concurrent powers\",\"concurrent powers\",\"implied powers\",\"implied powers\",\"plenary power\",\"german model\",\"islamic sexual jurisprudence\",\"islamic sexual jurisprudence\",\"proposed national unification promotion law\",\"dang guo\",\"fiscal imbalance\",\"equalization payments\",\"equalization payments\",\"michael thrasher\",\"grenoble institute of political studies\",\"the twenty years' crisis\",\"the twenty years' crisis\",\"job cohen\",\"muhammad taqi usmani\",\"muhammad taqi usmani\",\"muhammad taqi usmani\",\"syed hayatullah\",\"syed hayatullah\",\"international isolation\",\"unearned income\",\"air rights\",\"energy community\",\"energy community\",\"energy charter treaty\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"fiscal policy of the united states\",\"fiscal policy of the united states\",\"the journal of politics\",\"the journal of politics\",\"renewable energy transition\",\"renewable energy transition\",\"cost of electricity by source\",\"cost of electricity by source\",\"critique: journal of socialist theory\",\"foreign service officer\",\"foreign agricultural service\",\"foreign agricultural service\",\"legal naturalism\",\"multi-level governance\",\"advocacy journalism\",\"mccourt school of public policy\",\"robert m. la follette school of public affairs\",\"decentralized computing\",\"decentralized autonomous organization\",\"decentralized autonomous organization\",\"history of science policy\",\"journal of democracy\",\"journal of democracy\",\"elif shafak\",\"the triple revolution\",\"robert heilbroner\",\"robert heilbroner\",\"maladministration\",\"rent-setting\",\"the machiavellian moment\",\"early social changes under islam\",\"the soldier and the state\",\"ernest barker\",\"commentary on palestine: peace not apartheid\",\"a call to action: women, religion, violence, and power\",\"2000-watt society\",\"2000-watt society\",\"2000-watt society\",\"green job\",\"green job\",\"green job\",\"catonism\",\"list of environmental ministries\",\"list of environmental ministries\",\"list of environmental ministries\",\"ecocide\",\"ecocide\",\"environment minister\",\"james tully (philosopher)\",\"choosing scotland's future\",\"political man\",\"carl albert center\",\"index of social and political philosophy articles\",\"index of social and political philosophy articles\",\"index of social and political philosophy articles\",\"phillip blond\",\"grey-zone (international relations)\",\"note verbale\",\"nonkilling global political science\",\"development bureau\",\"institute for economics and peace\",\"coal phase-out\",\"scientific man versus power politics\",\"scientific man versus power politics\",\"green institute foundation\",\"sustainable business\",\"archery\",\"wyn grant\",\"expansionary fiscal contraction\",\"expansionary fiscal contraction\",\"journal of the european economic association\",\"journal of the european economic association\",\"journal of the european economic association\",\"journal of the european economic association\",\"journal of the european economic association\",\"journal of the european economic association\",\"electronic process of law\",\"hannah arendt institute for totalitarianism studies\",\"comparing media systems\",\"martens centre\",\"martens centre\",\"mariya gabriel\",\"list of public works ministries\",\"list of public works ministries\",\"list of public works ministries\",\"pakistan public works department\",\"international workers' day\",\"glory to ukraine\",\"glory to hong kong\",\"galician student league\",\"galician student league\",\"galician student league\",\"galician student league\",\"galician student league\",\"erguer-estudantes da galiza\",\"erguer-estudantes da galiza\",\"erguer-estudantes da galiza\",\"erguer-estudantes da galiza\",\"xeira\",\"xeira\",\"xeira\",\"free market fairness\",\"keep indy indie\",\"celeb jihad\",\"marlon bundo\",\"history of social democracy\",\"alva myrdal\",\"alva myrdal\",\"industry (economics)\",\"fama\\u2013french three-factor model\",\"binomial options pricing model\",\"binomial options pricing model\",\"binomial options pricing model\",\"financial models with long-tailed distributions and volatility clustering\",\"skew\",\"list of financial economists\",\"list of financial economists\",\"erwin plein nemmers prize in economics\",\"leonid kantorovich\",\"development-supported agriculture\",\"edgeworth binomial tree\",\"list of countries by share of income of the richest one percent\",\"charlie bean (economist)\",\"fabrizio zilibotti\",\"fabrizio zilibotti\",\"american system of manufacturing\",\"inside contracting\",\"freelancer\",\"quaternary sector of the economy\",\"voluntary sector\",\"private highway\",\"commodity credit corporation\",\"commodity credit corporation\",\"black\\u2013derman\\u2013toy model\",\"mesoeconomics\",\"jacob hollander\",\"iza institute of labor economics\",\"economics (textbook)\",\"martin hellwig\",\"structural estimation\",\"structural estimation\",\"masters in agricultural economics\",\"masters in agricultural economics\",\"economics handbooks\",\"murray's hypocycloidal engine\",\"murray's hypocycloidal engine\",\"woolrich electrical generator\",\"giancarlo corsetti\",\"charles henry hull\",\"benny moldovanu\",\"greenwashing\",\"greenwashing\",\"cover-up\",\"garden of allah (cabaret)\",\"garden of allah (cabaret)\",\"julia's on broadway\",\"noel ignatiev\",\"burlesque\",\"burlesque\",\"burlesque\",\"doing gender\",\"west pride\",\"argument from authority\",\"civil discourse\",\"civil discourse\",\"social service review\",\"the morals of chess\",\"numbers (vancouver)\",\"obtundation\",\"obtundation\",\"repeatability\",\"richard wiseman\",\"johann friedrich herbart\",\"reliability (statistics)\",\"psychological resistance\",\"eustress\",\"blink: the power of thinking without thinking\",\"blink: the power of thinking without thinking\",\"rage (emotion)\",\"meta learning\"]},\"selected\":{\"id\":\"1120\"},\"selection_policy\":{\"id\":\"1119\"}},\"id\":\"1069\",\"type\":\"ColumnDataSource\"},{\"attributes\":{\"text\":\"Undirected network of the weakly connected component\",\"text_font_size\":\"16pt\"},\"id\":\"1062\",\"type\":\"Title\"},{\"attributes\":{},\"id\":\"1054\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"1041\",\"type\":\"LinearScale\"},{\"attributes\":{},\"id\":\"1039\",\"type\":\"LinearScale\"},{\"attributes\":{\"data_source\":{\"id\":\"1065\"},\"glyph\":{\"id\":\"1089\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1067\"}},\"id\":\"1066\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"edge_renderer\":{\"id\":\"1070\"},\"inspection_policy\":{\"id\":\"1116\"},\"layout_provider\":{\"id\":\"1076\"},\"node_renderer\":{\"id\":\"1066\"},\"selection_policy\":{\"id\":\"1107\"}},\"id\":\"1063\",\"type\":\"GraphRenderer\"},{\"attributes\":{\"fill_alpha\":{\"field\":\"alpha\"},\"fill_color\":{\"field\":\"node_colour\"},\"size\":{\"field\":\"node_sizes\"}},\"id\":\"1089\",\"type\":\"Circle\"},{\"attributes\":{\"source\":{\"id\":\"1065\"}},\"id\":\"1067\",\"type\":\"CDSView\"},{\"attributes\":{\"source\":{\"id\":\"1069\"}},\"id\":\"1071\",\"type\":\"CDSView\"}],\"root_ids\":[\"1036\"]},\"title\":\"Bokeh Application\",\"version\":\"2.3.2\"}};\n",
       "  var render_items = [{\"docid\":\"ed309431-8520-45ae-8831-6397d519dd8b\",\"root_ids\":[\"1036\"],\"roots\":{\"1036\":\"f2455d81-0c7a-4c77-8999-2d24fd3786f4\"}}];\n",
       "  root.Bokeh.embed.embed_items_notebook(docs_json, render_items);\n",
       "\n",
       "  }\n",
       "  if (root.Bokeh !== undefined) {\n",
       "    embed_document(root);\n",
       "  } else {\n",
       "    var attempts = 0;\n",
       "    var timer = setInterval(function(root) {\n",
       "      if (root.Bokeh !== undefined) {\n",
       "        clearInterval(timer);\n",
       "        embed_document(root);\n",
       "      } else {\n",
       "        attempts++;\n",
       "        if (attempts > 100) {\n",
       "          clearInterval(timer);\n",
       "          console.log(\"Bokeh: ERROR: Unable to run BokehJS code because BokehJS library is missing\");\n",
       "        }\n",
       "      }\n",
       "    }, 10, root)\n",
       "  }\n",
       "})(window);"
      ],
      "application/vnd.bokehjs_exec.v0+json": ""
     },
     "metadata": {
      "application/vnd.bokehjs_exec.v0+json": {
       "id": "1036"
      }
     },
     "output_type": "display_data"
    }
   ],
   "source": [
    "# Set toolbar and title for pot\n",
    "HOVER_TOOLTIPS = [(\"Page\", \"@index\"),\n",
    "                  (\"Discipline\", \"@parent\")]\n",
    "\n",
    "#Create a plot\n",
    "plot = figure(tooltips = HOVER_TOOLTIPS,\n",
    "              tools=\"pan,wheel_zoom,save,reset\", active_scroll='wheel_zoom',\n",
    "              x_range=Range1d(-1000, 1000),\n",
    "              y_range=Range1d(-1000, 1000))\n",
    "\n",
    "# Add title\n",
    "plot.add_layout(Title(text='Undirected network of the weakly connected component', text_font_size=\"16pt\"), 'above')\n",
    "\n",
    "# Hide axis and gridlines\n",
    "plot.axis.visible = False\n",
    "plot.grid.grid_line_color = None\n",
    "\n",
    "#Set positions, node size and color\n",
    "G_interactive = from_networkx(G, positions, scale=1, center=(0, 0))\n",
    "G_interactive.node_renderer.data_source.data['node_sizes'] = [G.degree(node) * 0.25 for node in G.nodes()]\n",
    "G_interactive.node_renderer.data_source.data['node_colour'] = get_color_list_from_palette(G)\n",
    "G_interactive.node_renderer.data_source.data['alpha'] = [0.75 for node in G.nodes()]\n",
    "G_interactive.node_renderer.glyph = Circle(\n",
    "    size=\"node_sizes\",\n",
    "    fill_color=\"node_colour\",\n",
    "    fill_alpha = \"alpha\")\n",
    "\n",
    "#Set edge opacity and width\n",
    "G_interactive.edge_renderer.glyph = MultiLine(line_alpha=0.8, line_width=0.1)\n",
    "\n",
    "plot.renderers.append(G_interactive)\n",
    "show(plot)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 25,
   "id": "68620d12",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T22:02:18.266178Z",
     "start_time": "2021-12-08T22:02:18.129826Z"
    }
   },
   "outputs": [],
   "source": [
    "%%capture\n",
    "# Saving plot\n",
    "output_file(filename=\"full_network.html\", title=\"full_network\")\n",
    "save(plot)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "148c2fa2",
   "metadata": {},
   "source": [
    "Although a bit messy, the visual inspection still reveals some properties of our network. As we already knew from the analysis of the degree distributions, metapages such as political science or anthropology are central in our network. The new information we get from this network is how clearly the different disciplines tend to bundle together. It seems, however, to be some interdisciplinary variance. To gain more knowledge about our network we plot five subgraphs - one for each discipline."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "id": "2cd01f3b",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:52:06.455924Z",
     "start_time": "2021-12-08T20:50:59.445467Z"
    }
   },
   "outputs": [],
   "source": [
    "%%capture\n",
    "\n",
    "# Get set of discipline nodes and based on this create 5 supgraphs\n",
    "# We use sorted to keep the order of the list when transformed to a set\n",
    "disciplines = [G.nodes[node][\"parent\"] for node in G.nodes()]\n",
    "disciplines = sorted(set(disciplines), key=disciplines.index)\n",
    "\n",
    "disciplines_graphs = {}\n",
    "for d in disciplines:\n",
    "    discipline_nodes = set([x for x, y in G.nodes(data=True) if y['parent']==d])\n",
    "    disciplines_graphs[d] = G.subgraph(discipline_nodes)\n",
    "        \n",
    "# Create and store a graph object for each discipline\n",
    "graphs = {}\n",
    "for i, k in enumerate(disciplines_graphs.keys()):\n",
    "    G = disciplines_graphs[k]\n",
    "    title = f'Network for discipline: {\" \".join(k.split(\"_\"))}'\n",
    "    HOVER_TOOLTIPS = [(\"Page\", \"@index\")]\n",
    "    \n",
    "    #Create a plot\n",
    "    graphs[k] = figure(tooltips = HOVER_TOOLTIPS,\n",
    "                  width=500, plot_height=500,\n",
    "                  tools=\"pan,wheel_zoom,save,reset\", active_scroll='wheel_zoom', \n",
    "                  x_range=Range1d(-400, 400),\n",
    "                  y_range=Range1d(-400, 400))\n",
    "    \n",
    "    # Add title\n",
    "    graphs[k].add_layout(Title(text=f'Network for discipline: {\" \".join(k.split(\"_\"))}', text_font_size=\"12pt\"), 'above')\n",
    "\n",
    "    # Hide axis and gridlines\n",
    "    graphs[k].axis.visible = False\n",
    "    graphs[k].grid.grid_line_color = None    \n",
    "    \n",
    "    #Set positions, node size and color\n",
    "    positions = forceatlas2.forceatlas2_networkx_layout(G, pos=None, iterations=2000)\n",
    "    G_interactive = from_networkx(G, positions, scale=1, center=(0, 0))\n",
    "    G_interactive.node_renderer.data_source.data['node_sizes'] = [G.degree(node) * 0.25 for node in tqdm(G.nodes())]\n",
    "    G_interactive.node_renderer.data_source.data['node_colour'] = get_color_list_from_palette(G)\n",
    "    G_interactive.node_renderer.data_source.data['alpha'] = [0.75 for node in G.nodes()]\n",
    "    G_interactive.node_renderer.glyph = Circle(\n",
    "        size=\"node_sizes\",\n",
    "        fill_color=\"node_colour\",\n",
    "        fill_alpha = \"alpha\")\n",
    "\n",
    "    #Set edge opacity and width\n",
    "    G_interactive.edge_renderer.glyph = MultiLine(line_alpha=0.8, line_width=0.1)\n",
    "    graphs[k].renderers.append(G_interactive)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "2d24784a",
   "metadata": {},
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "id": "44e24009",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-08T20:52:10.674894Z",
     "start_time": "2021-12-08T20:52:06.460219Z"
    },
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "  <div class=\"bk-root\" id=\"dd15032a-b86e-49c7-8b19-68f63c6045d7\" data-root-id=\"1779\"></div>\n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "(function(root) {\n",
       "  function embed_document(root) {\n",
       "    \n",
       "  var docs_json = {\"a3883246-cf47-49c3-a497-56c42b9f4bd2\":{\"defs\":[],\"roots\":{\"references\":[{\"attributes\":{\"children\":[{\"id\":\"1716\"},{\"id\":\"1651\"}]},\"id\":\"1779\",\"type\":\"Row\"},{\"attributes\":{},\"id\":\"1734\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"1842\",\"type\":\"UnionRenderers\"},{\"attributes\":{\"active_multi\":null,\"active_scroll\":{\"id\":\"1732\"},\"tools\":[{\"id\":\"1731\"},{\"id\":\"1732\"},{\"id\":\"1733\"},{\"id\":\"1734\"},{\"id\":\"1735\"}]},\"id\":\"1736\",\"type\":\"Toolbar\"},{\"attributes\":{},\"id\":\"1841\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"1839\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"1840\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"1844\",\"type\":\"UnionRenderers\"},{\"attributes\":{\"data\":{\"alpha\":[0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75],\"depth\":[1,2,2,1,2,2,1,2,2,2,2,1,1,1,1,1,2,2,2,1,1,2,1,2,2,2,2,2,2,1,1,2,2,2,2,1,1,2,1,2,2,2,1,2,1,1,1,1,2,1,2,1,1,2,2,2,2,1,2,2,2,2,1,1,2,1,1,1,1,2,1,2,1,1,2,2,1,2,2,1,2,1,2,2,2,1,2,2,2,2,2,2,1,2,2,1,1,1,2,1,2,2,1,2,2,2,2,1,1,2,2,1,2,2,2,2,2,1,1,1,2,2,1,1,1,2,2,1,2,1,2,1,1,1,2,2,1,1,1,2,1,1,1,2,2,2,1,1,2,1,2,1,2,2,1,1,1,2,2,1,1,1,1,2,1,2,2,1,2,1,1,2,1,1,2,2,1,1,1,1,1,1,2,2,1,2,2,2,1,2,2,1,1,1,2,2,1,2,2,1,1,1,1,2,2,2,1,2,1,1,1,2,1,2,1,2,2,2,2,1,2,2,2,2,2,2,1,1,1,1,1,2,2,1,1,1,2,1,1,1,2,2,2,1,2,2,1,1,1,1,2,1,1,1,2,2,1,2,1,2,2,1,2,2,1,2,2,2,2,2,1,2,2,1,2,2,1,2,1,1,1,1,2,2,1,2,1,2,1,2,1,2,2,2,1,1,1,2,2,1,2,1,1,2,2,2,2,2,2,2,1,2,2,2,1,1,2,2,2,1,2,2,2,1,2,2,2,2,1,2,2,1,1,2,2,2,1,2,2,1,2,2,2,2,1,2,1,1,2,1,1,1,2,2,2,2,1,1,1,1,2,1,2,2,2,2,1,1,2,1,2,2,2,2,1,2,2,2,2,1,2,2,1,2,2,1,2,2,2,2,1,2,2,1,0,1,2,2,1,1,2,1,1,2,1,2,1,1,2,1,2,2,2,2,2,2,2,1,2,2,2,1,2,2,2,2,2,2,1,2,1,1,2,1,1,2,1,1,2,1,2,2,1,1,2,2,2,1,2,2,2,1,1,2,1,1,2,2,1,1,2,1,2,1,1,2,2,1,2,1,2,1,1,2,1,1,2,1,1,1,1,2,1,2,2,2,1,2,1,1,1,1,1,2,2,1,1,1,1,1,1,1,1,1,2,2,2],\"index\":[\"arrow's impossibility theorem\",\"forward price\",\"joseph schumpeter\",\"relative income hypothesis\",\"journal of public economics\",\"andrea weber\",\"hotelling's law\",\"criticism of the federal reserve\",\"tax-allocation district\",\"autonomous consumption\",\"market trend\",\"guns versus butter model\",\"electronic funds transfer\",\"economic model\",\"i-spread\",\"split labor market theory\",\"foundation for european economic development\",\"economics of science\",\"cumulative process\",\"unplanned economies\",\"gabor\\u2013granger method\",\"efficiency wage\",\"identity line\",\"el centro integrado de technologia appropriada\",\"thomas schelling\",\"elhanan helpman\",\"corner solution\",\"sharon oster\",\"wallace neutrality\",\"marginal return\",\"in kind\",\"murray's hypocycloidal engine\",\"risk factor (finance)\",\"political risk\",\"clive granger\",\"rebound effect (conservation)\",\"backus\\u2013kehoe\\u2013kydland puzzle\",\"neo-capitalism\",\"market for corporate control\",\"robert ekelund\",\"fractional-reserve banking\",\"the reformation in economics\",\"hubbert peak theory\",\"simulation modeling\",\"option screener\",\"dynamic discrete choice\",\"commercialism\",\"weighted average cost of capital\",\"econophysics\",\"liquidity premium\",\"eco-capitalism\",\"forward premium anomaly\",\"factor endowment\",\"factors of production\",\"bertrand russell\",\"state price density\",\"pauline barrieu\",\"macroeconomic model\",\"outworker\",\"george hilton (historian)\",\"erwin plein nemmers prize in economics\",\"new institutional economics\",\"feldstein\\u2013horioka puzzle\",\"euronia\",\"3g (countries)\",\"open economy\",\"auction theory\",\"donchian channel\",\"rat race\",\"community-supported agriculture\",\"market rate\",\"technocracy movement\",\"is\\u2013lm model\",\"induced consumption\",\"journal of behavioral and experimental economics\",\"list of financial economists\",\"technical change\",\"joint organisations data initiative\",\"consumer debt\",\"least-cost theory\",\"risk management agency\",\"st. petersburg paradox\",\"daniel mcfadden\",\"pork cycle\",\"venture capital in spaceflight\",\"starve the beast\",\"ecodynamics\",\"inside contracting\",\"cura annonae\",\"weak and strong sustainability\",\"songun\",\"price index\",\"volatility clustering\",\"ap microeconomics\",\"beatrice cherrier\",\"survey on household income and wealth\",\"equity premium puzzle\",\"demand shaping\",\"binomial options pricing model\",\"identity economics\",\"foreign agricultural service\",\"debtocracy\",\"cobweb model\",\"b\\u00e9la balassa\",\"pierre-andr\\u00e9 chiappori\",\"jhai foundation\",\"purchasing power parity\",\"vent for surplus\",\"mainstream economics\",\"structural estimation\",\"richard timberlake\",\"history of microeconomics\",\"iza institute of labor economics\",\"anarcho-capitalism\",\"journal of the european economic association\",\"bipu\",\"francesco caselli\",\"implicit cost\",\"joint product pricing\",\"cost-weighted activity index\",\"centre for appropriate technology (australia)\",\"information economics\",\"term (time)\",\"learning economy\",\"reed's law\",\"superrationality\",\"market microstructure\",\"mandeville's paradox\",\"cash crop\",\"price support\",\"experimental economics\",\"mundell\\u2013tobin effect\",\"breakout (technical analysis)\",\"keynes\\u2013ramsey rule\",\"georgism\",\"industry (economics)\",\"demand curve\",\"paradox of value\",\"capital cost\",\"blue economy\",\"assume a can opener\",\"inertial inflation\",\"open music model\",\"social cost\",\"jacob hollander\",\"corn exchange\",\"stylized fact\",\"list of economics films\",\"garman-kohlhagen model\",\"average variable cost\",\"international economics\",\"peso problem (finance)\",\"evolutionary game theory\",\"paul milgrom\",\"kuznets curve\",\"keynesian cross\",\"bertrand competition\",\"black\\u2013derman\\u2013toy model\",\"vernon l. smith\",\"sectoral balances\",\"harris\\u2013todaro model\",\"heckscher\\u2013ohlin model\",\"edgeworth box\",\"steven n. s. cheung\",\"discrete choice\",\"low-volatility anomaly\",\"weston a. price foundation\",\"walras's law\",\"discouraged worker\",\"national average salary\",\"solow\\u2013swan model\",\"obshchina\",\"maturity transformation\",\"primary market\",\"michael spence\",\"lawrence summers\",\"deflator\",\"the elephant curve\",\"phillips curve\",\"differentiated bertrand competition\",\"net national product\",\"shale band\",\"dynamical system\",\"human development index\",\"average fixed cost\",\"skew\",\"environment minister\",\"commodity credit corporation\",\"precautionary demand\",\"consumption distribution\",\"nayakrishi\",\"rethinking economics\",\"dixit\\u2013stiglitz model\",\"late trading\",\"infant industry argument\",\"institute for international economic studies\",\"knowledge economy\",\"economic indicator\",\"fama\\u2013french three-factor model\",\"network effect\",\"the rich get richer and the poor get poorer\",\"law of rent\",\"sectoral output\",\"excess reserves\",\"homo economicus\",\"momentum (finance)\",\"fischer black prize\",\"yakama manty jones\",\"samuelson condition\",\"market mechanism\",\"economic transformation\",\"l'empire de la honte\",\"neo-ricardianism\",\"bengt holmstr\\u00f6m\",\"lerner paradox\",\"party-state capitalism\",\"surplus value\",\"bric\",\"w. kip viscusi\",\"inventory bounce\",\"edgeworth binomial tree\",\"john roemer\",\"public economics\",\"public property\",\"growth stock\",\"knowledge assessment methodology\",\"universe (economics)\",\"nominal yield\",\"cournot competition\",\"seasoned equity offering\",\"housing affordability index\",\"economics handbooks\",\"georg weizs\\u00e4cker\",\"merger simulation\",\"encouraged industry catalogue\",\"forward exchange market\",\"cycle of poverty\",\"gerschenkron effect\",\"norwegian paradox\",\"preclusive purchasing\",\"financial economics\",\"gustav stolper prize\",\"ioana marinescu\",\"volume index\",\"the road to serfdom\",\"equalization payments\",\"long-run cost curve\",\"economic base analysis\",\"world economy\",\"diamond-water paradox\",\"cost of electricity by source\",\"time-use research\",\"market allocation scheme\",\"world3\",\"myron scholes\",\"armchair theorizing\",\"hiding hand principle\",\"research papers in economics\",\"extended-hours trading\",\"intertemporal choice\",\"paul romer\",\"credit default option\",\"robert heilbroner\",\"eugene fama\",\"toothpaste tube theory\",\"paul de grauwe\",\"contingent claim analysis\",\"methodology of econometrics\",\"time warp edit distance\",\"gold-collar worker\",\"schelling's segregation model\",\"hicks-tinbergen award\",\"economic nationalism\",\"lorenz curve\",\"lag operator\",\"least developed countries\",\"tibor\",\"excess burden of taxation\",\"giffen good\",\"economic satiation\",\"productive capacity\",\"economic graph\",\"giancarlo corsetti\",\"michael albert\",\"triangle model\",\"abnormal profit\",\"land management\",\"civilizing the economy\",\"metcalfe's law\",\"leonid kantorovich\",\"visible hand (economics)\",\"martin hellwig\",\"list of jewish american economists\",\"time series\",\"kenneth boulding's evolutionary perspective\",\"per capita personal income in the united states\",\"balassa\\u2013samuelson effect\",\"richard koo\",\"intensity of preference\",\"base period\",\"economists for peace and security\",\"dispersed knowledge\",\"resource curse\",\"internality\",\"financial models with long-tailed distributions and volatility clustering\",\"interprovincial migration in canada\",\"marginal rate of transformation\",\"indirect inference\",\"qem\",\"lump-sum tax\",\"beckstrom's law\",\"real-world economics review\",\"service economy\",\"import substitution industrialization\",\"men's underwear index\",\"economic power\",\"reproduction (economics)\",\"economics (textbook)\",\"sex and reason\",\"proto-industrialization\",\"paola giuliano\",\"austerity: the history of a dangerous idea\",\"two-sided matching\",\"global retirement index\",\"time value of money\",\"financial innovation\",\"utility\",\"samuel von pufendorf\",\"beveridge curve\",\"returns (economics)\",\"sequential game\",\"market-based valuation\",\"j curve\",\"pricing kernel\",\"econtalk\",\"risk premium\",\"convergence (economics)\",\"national agricultural policy center\",\"marginal propensity to consume\",\"list of important publications in economics\",\"rate of return\",\"analysis of rhythmic variance\",\"sofr\",\"american system of manufacturing\",\"icarus paradox\",\"doji\",\"economics terminology that differs from common usage\",\"sailing ship effect\",\"kenneth arrow\",\"scottish index of multiple deprivation\",\"lipstick index\",\"jensen prize\",\"cumulative prospect theory\",\"arif ahmed (philosopher)\",\"united states farm bill\",\"index (economics)\",\"economic evaluation of time\",\"robinson crusoe economy\",\"conceptual economy\",\"duck curve\",\"taxation in uruguay\",\"list of production functions\",\"principles of economics (marshall book)\",\"peak wheat\",\"wilson doctrine (economics)\",\"roll-geske-whaley\",\"global social mobility index\",\"jel classification codes\",\"national equities exchange and quotations\",\"dynamic pricing\",\"drought tolerance\",\"ricardian equivalence\",\"john hicks\",\"alpha (finance)\",\"output elasticity\",\"investment arbitration\",\"asset specificity\",\"marginal factor cost\",\"foreclosure rescue\",\"supply and demand\",\"marginal rate of substitution\",\"adam smith\",\"downs\\u2013thomson paradox\",\"istv\\u00e1n hont\",\"hemline index\",\"fei\\u2013ranis model of economic growth\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"ecological economics (journal)\",\"trygve haavelmo\",\"supreme court economic review\",\"ak model\",\"heavily indebted poor countries\",\"charles henry hull\",\"kiyotaki\\u2013moore model\",\"index of economics articles\",\"leontief paradox\",\"fabrizio zilibotti\",\"freelancer\",\"law of increasing costs\",\"big push model\",\"surplus labour\",\"net worth\",\"variable rate debt obligation\",\"friedrich hayek\",\"intertemporal equilibrium\",\"william vickrey\",\"glossary of economics\",\"inframarginal analysis\",\"tore ellingsen\",\"ithaca hours\",\"finance & development\",\"guido tabellini\",\"timo ter\\u00e4svirta\",\"voluntary sector\",\"first world\",\"nava ashraf\",\"benny moldovanu\",\"marginalism\",\"wood industry\",\"food processing\",\"the counter-revolution of science\",\"hicks-neutral technical change\",\"privatism\",\"green job\",\"mesoeconomics\",\"alternative financial service\",\"john harsanyi\",\"economic humanitarianism (ra\\u00eblianism)\",\"ad\\u2013ia model\",\"benjamin moll\",\"concentration risk\",\"99ers\",\"arbitrage pricing theory\",\"real economy\",\"paradox of prosperity\",\"k\\u00e4the leichter\",\"commodity chain\",\"ceteris paribus\",\"carbon bubble\",\"edgeworth paradox\",\"woolrich electrical generator\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"production for profit\",\"local multiplier effect\",\"farshid jamshidian\",\"jane semeleer\",\"unevenly spaced time series\",\"ramsey\\u2013cass\\u2013koopmans model\",\"democratic capitalism\",\"black hole bomb\",\"private highway\",\"opportunity cost\",\"convex preferences\",\"masters in agricultural economics\",\"economic puzzle\",\"hanging man (candlestick pattern)\",\"eric french (professor)\",\"quaternary sector of the economy\",\"dollar voting\",\"impossible trinity\",\"vertical farming\",\"history of capitalist theory\",\"technical indicator\",\"peasant economics\",\"macroeconomic regulation and control\",\"benefit financing model\",\"daniel kahneman\",\"bowley's law\",\"charlie bean (economist)\",\"accelerator effect\",\"stochastic investment model\",\"paradox of thrift\",\"diminishing returns\",\"gerald shove\",\"economic law\",\"indifference curve\",\"secular variation\",\"the theory of interstellar trade\",\"bertrand paradox (economics)\",\"list of unsolved problems in economics\",\"leontief production function\",\"marginal propensity to import\",\"loopco\",\"peter jaeckel\",\"value product\",\"google finance\",\"eonia\",\"market anomaly\",\"law of supply\",\"economic data\",\"circular flow of income\",\"theories of poverty\",\"equity home bias puzzle\",\"perpetual bond\",\"john rawls\",\"great gatsby curve\",\"substitution effect\",\"colonial origins of comparative development\",\"scitovsky paradox\",\"real-time economy\",\"backward bending supply curve of labour\",\"production\\u2013possibility frontier\",\"list of special economic zones\",\"problems with economic models\",\"david laidler\",\"bishop\\u2013cannings theorem\",\"elinor ostrom\"],\"node_colour\":[\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\",\"#3B518A\"],\"node_sizes\":[4.25,1.75,14.75,0.5,0.75,0.25,0.5,0.0,0.0,1.5,3.75,0.75,0.25,7.75,1.0,0.0,0.5,1.0,0.25,0.25,0.25,0.75,0.75,0.0,6.25,1.75,0.5,0.25,0.25,0.5,1.75,0.75,1.75,1.25,3.0,0.5,0.5,1.75,0.25,0.0,1.0,0.0,0.5,0.5,0.75,0.5,0.0,1.0,3.5,0.25,2.0,1.0,0.25,6.0,1.25,1.0,0.0,6.75,0.5,0.0,1.0,6.75,0.5,0.75,0.25,1.0,1.0,1.5,0.75,0.5,0.25,0.75,5.25,1.25,0.25,2.0,0.25,0.0,4.5,0.25,0.5,1.75,4.75,0.5,0.0,0.0,0.0,0.5,0.0,0.0,0.25,3.25,0.5,0.25,0.25,0.0,3.0,0.25,1.75,0.25,0.5,0.25,1.25,0.25,0.5,0.0,5.5,0.25,10.75,0.5,0.25,5.5,0.25,2.0,1.5,0.0,0.0,3.0,0.5,0.25,0.0,4.5,0.25,0.25,1.0,0.75,0.25,0.5,1.25,0.25,14.25,0.25,0.75,0.5,14.0,0.25,3.0,1.0,0.25,2.5,7.25,0.25,0.0,4.0,1.25,0.25,0.5,0.25,0.75,0.5,13.5,0.75,4.0,7.75,0.5,6.25,3.25,1.5,7.0,0.75,0.25,2.75,1.0,2.75,0.5,0.75,0.0,0.25,1.0,1.0,5.25,0.0,0.25,2.25,3.5,3.0,1.25,0.25,7.25,1.0,0.5,0.0,0.25,2.75,0.5,0.5,0.0,0.75,0.25,0.25,0.0,0.25,0.25,0.25,0.25,0.25,5.75,5.5,1.0,2.0,0.0,1.0,0.25,1.0,5.0,1.75,0.75,0.0,0.75,0.5,2.75,0.0,1.0,5.75,0.25,0.0,5.5,1.75,0.25,0.25,1.5,1.5,13.25,1.0,2.25,0.25,0.25,1.0,4.0,0.5,0.0,0.5,2.0,0.75,0.25,0.25,0.75,0.75,0.5,0.25,12.25,0.5,0.0,0.25,1.5,0.75,0.5,0.25,1.5,0.75,0.25,0.0,0.25,0.0,5.0,0.0,1.75,0.75,1.5,2.75,6.0,1.75,1.5,4.75,0.25,0.25,0.25,0.75,0.25,0.75,3.0,0.75,1.25,1.5,0.25,1.5,0.75,1.0,5.0,0.25,0.25,0.5,0.75,0.5,0.25,0.25,0.0,0.25,0.75,2.5,3.25,0.75,0.5,2.75,0.0,0.0,1.5,0.25,0.5,0.75,0.75,1.25,0.75,0.5,0.75,0.5,1.0,0.5,0.25,0.25,0.75,0.75,4.25,2.0,0.25,0.75,1.25,1.0,0.25,0.5,0.25,0.25,0.5,0.25,1.25,0.25,10.0,0.75,0.25,0.75,3.0,0.25,0.0,1.0,0.75,2.75,2.5,0.25,2.0,4.25,3.25,0.25,0.75,0.5,0.25,1.5,1.25,0.25,14.75,0.75,0.25,0.5,0.75,0.0,0.25,3.75,0.25,1.0,0.5,0.0,0.0,1.0,1.0,1.0,0.25,1.5,0.0,8.25,0.5,0.75,0.0,1.25,16.5,1.25,0.25,0.0,0.25,0.25,0.0,12.75,3.75,21.75,0.25,0.5,0.5,3.0,3.0,0.0,6.0,0.25,2.5,1.0,1.25,0.5,16.5,1.25,1.25,0.5,2.25,3.0,1.5,0.75,0.75,16.5,0.5,8.75,13.25,2.75,0.0,0.25,0.5,1.0,0.25,0.25,1.25,1.75,0.75,14.25,0.25,0.25,1.0,0.5,3.25,0.5,1.25,0.25,5.25,0.5,0.25,0.25,1.0,4.25,4.0,0.75,0.25,0.0,0.0,3.0,0.25,1.0,0.75,0.25,1.25,0.0,0.25,0.25,0.25,4.75,2.5,0.0,0.5,7.75,0.75,0.75,1.25,0.75,0.25,0.25,0.25,0.75,0.0,2.25,0.75,0.0,0.25,0.25,10.25,0.5,0.25,5.75,0.25,2.5,6.25,0.25,0.5,3.5,0.25,0.5,3.75,1.75,0.5,0.25,0.25,0.25,1.5,0.0,0.75,3.0,2.75,1.5,1.5,1.0,1.25,1.0,1.25,0.5,4.0,0.25,0.25,0.25,0.5,1.25,0.25,0.5,1.0,0.25,14.75],\"parent\":[\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\",\"economics\"]},\"selected\":{\"id\":\"1839\"},\"selection_policy\":{\"id\":\"1838\"}},\"id\":\"1745\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"1845\",\"type\":\"Selection\"},{\"attributes\":{\"line_alpha\":{\"value\":0.8},\"line_width\":{\"value\":0.1}},\"id\":\"1774\",\"type\":\"MultiLine\"},{\"attributes\":{},\"id\":\"1654\",\"type\":\"LinearScale\"},{\"attributes\":{\"data_source\":{\"id\":\"1745\"},\"glyph\":{\"id\":\"1769\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1747\"}},\"id\":\"1746\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"1663\",\"type\":\"BasicTicker\"},{\"attributes\":{\"fill_alpha\":{\"field\":\"alpha\"},\"fill_color\":{\"field\":\"node_colour\"},\"size\":{\"field\":\"node_sizes\"}},\"id\":\"1769\",\"type\":\"Circle\"},{\"attributes\":{},\"id\":\"1838\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"1843\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"1822\",\"type\":\"AllLabels\"},{\"attributes\":{},\"id\":\"1659\",\"type\":\"BasicTicker\"},{\"attributes\":{\"data\":{\"end\":[\"religion\",\"slavery\",\"serfdom\",\"manorialism\",\"peasant\",\"cultural movement\",\"magnate\",\"kshatriya\",\"underclass\",\"warrior\",\"business magnate\",\"typology (anthropology)\",\"negroid\",\"sinodonty and sundadonty\",\"history of anthropometry\",\"john beddoe\",\"martial race\",\"bertil lundman\",\"cephalic index\",\"anthropology\",\"religion\",\"cultural relativism\",\"emic and etic\",\"alliance theory\",\"culture theory\",\"performance studies\",\"cultural anthropology\",\"race and intelligence\",\"human genetic clustering\",\"early modern human\",\"recent human evolution\",\"androcentrism\",\"human ecology\",\"ethnoarchaeology\",\"ethnobiology\",\"ethnozoology\",\"ethnomedicine\",\"ecological anthropology\",\"ethnoichthyology\",\"zooarchaeology\",\"ethnoornithology\",\"hunter-gatherer\",\"anthropology\",\"linguistics\",\"polygyny\",\"promiscuity\",\"biology and sexual orientation\",\"homosexual behavior in animals\",\"list of mammals displaying homosexual behavior\",\"list of animals displaying homosexual behavior\",\"cultural memory\",\"cultural relativism\",\"culture theory\",\"cultural anthropology\",\"cultural mapping\",\"transcultural nursing\",\"high culture\",\"cultural radicalism\",\"cultural movement\",\"outline of culture\",\"welfare culture\",\"culture hero\",\"cultural nationalism\",\"ceremony\",\"anthropology\",\"religion\",\"ethnomedicine\",\"cultural relativism\",\"emic and etic\",\"alliance theory\",\"culture theory\",\"performance studies\",\"cultural anthropology\",\"biological anthropology\",\"nutritional anthropology\",\"critical medical anthropology\",\"society for medical anthropology\",\"medical anthropology\",\"wedding\",\"white wedding\",\"ceremony\",\"wedding reception\",\"honeymoon\",\"consummation\",\"religion\",\"language\",\"people\",\"culture theory\",\"ecological anthropology\",\"non-representational theory\",\"archaeology\",\"human ecology\",\"osteology\",\"online ethnography\",\"zooarchaeology\",\"ethnobiology\",\"netnography\",\"ethnozoology\",\"arthur evans\",\"ecological anthropology\",\"ethnoichthyology\",\"direct historical approach\",\"ethnic religion\",\"ethnomuseology\",\"ethnomedicine\",\"ethnoornithology\",\"paleopathology\",\"warrior\",\"anthropology\",\"cultural anthropology\",\"development anthropology\",\"sedentism\",\"heritage commodification\",\"nutritional anthropology\",\"shell money\",\"reciprocity (cultural anthropology)\",\"history of anthropometry\",\"cephalic index\",\"linguistics\",\"cultural anthropology\",\"proverb\",\"religion\",\"cultural memory\",\"cultural relativism\",\"culture theory\",\"cultural anthropology\",\"cultural mapping\",\"high culture\",\"cultural nationalism\",\"cultural radicalism\",\"cultural movement\",\"outline of culture\",\"welfare culture\",\"koteka\",\"proto-malay\",\"mandailing people\",\"angkola people\",\"kluet people\",\"archaeology\",\"biological anthropology\",\"osteology\",\"zooarchaeology\",\"paleoradiology\",\"arthur evans\",\"sympathetic magic\",\"poppet\",\"anthropology\",\"linguistics\",\"human ecology\",\"ethnobiology\",\"online ethnography\",\"zooarchaeology\",\"netnography\",\"ethnic religion\",\"ethnomuseology\",\"cultural anthropology\",\"ecological anthropology\",\"ethnomedicine\",\"ethnoichthyology\",\"ethnoornithology\",\"people\",\"cultural anthropology\",\"development anthropology\",\"shell money\",\"nutritional anthropology\",\"heritage commodification\",\"sedentism\",\"medical anthropology\",\"population health\",\"anthropology\",\"bibliography of anthropology\",\"promiscuity\",\"people\",\"economic mobility\",\"personal life\",\"anthropology\",\"cultural anthropology\",\"theatre state\",\"darwinian anthropology\",\"emic and etic\",\"paleoanthropology\",\"slavery\",\"theory of language\",\"alliance theory\",\"feminist anthropology\",\"woman, culture, and society\",\"linguistic description\",\"language\",\"laura boulton\",\"heritage commodification\",\"linguistic anthropology\",\"human terrain system\",\"diane bell (anthropologist)\",\"outline of culture\",\"bibliography of anthropology\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"classificatory kinship\",\"solano people\",\"les ma\\u00eetres fous\",\"digging stick\",\"lila: an inquiry into morals\",\"rudolf virchow award\",\"usc center for visual anthropology\",\"development anthropology\",\"urban revolution\",\"linguistic relativity\",\"podom\",\"matrilocal residence\",\"moving anthropology student network\",\"polygyny\",\"anthropology of institutions\",\"online ethnography\",\"museum of mankind\",\"nutritional anthropology\",\"human universals\",\"ethnobiology\",\"archaeology\",\"circumscription theory\",\"performance studies\",\"netnography\",\"das mutterrecht\",\"cultural group selection\",\"kriza j\\u00e1nos ethnographic society\",\"anthropology\",\"human ethology\",\"ethnoichthyology\",\"naturalistic disease theories\",\"critical medical anthropology\",\"postmodernist anthropology\",\"anthropological criminology\",\"nanook of the north\",\"mus\\u00e9e de l'homme\",\"1910s in anthropology\",\"1990s in anthropology\",\"museo nacional de antropolog\\u00eda (madrid)\",\"human ecology\",\"exocannibalism\",\"cultural movement\",\"forensic facial reconstruction\",\"history of anthropometry\",\"person\",\"ethnomedicine\",\"gotai\",\"anthropological index online\",\"vanua\",\"neuroanthropology\",\"age set\",\"human behavioral ecology\",\"society for medical anthropology\",\"educational anthropology\",\"grave goods\",\"constantin noica\",\"anthrobotics\",\"applied anthropology research methods\",\"utinahica\",\"americanoid\",\"list of anthropologists\",\"toloy\",\"typology (anthropology)\",\"semiotic anthropology\",\"apuli\",\"the hebrew goddess\",\"biological anthropology\",\"orthograde posture\",\"anthropology of art\",\"transcultural nursing\",\"ethnic religion\",\"ethnomuseology\",\"village head\",\"soul dualism\",\"1890s in anthropology\",\"maloca\",\"list of years in anthropology\",\"faye v. harrison\",\"ethnoscape\",\"viking fund medal\",\"osteology\",\"religion\",\"linguistics\",\"prickly paradigm press\",\"f. g. bailey\",\"zooarchaeology\",\"shell money\",\"georg pfeffer\",\"deep history\",\"hau (anthropology)\",\"encyclopedia of anthropology\",\"list of matrilineal or matrilocal societies\",\"mus\\u00e9e des confluences\",\"gaonburha\",\"2000s in anthropology\",\"ecological anthropology\",\"culture theory\",\"biocultural anthropology\",\"lambda alpha\",\"disability anthropology\",\"area studies\",\"ethnopediatrics\",\"sodality (social anthropology)\",\"cultural mapping\",\"contrast set\",\"heel\\u2013ball index\",\"leveling mechanism\",\"cultural relativism\",\"medical anthropology\",\"cornell-peru project\",\"cultural anthropology\",\"pitt rivers museum\",\"society of anthropology of paris\",\"cultural anthropology\",\"anthropology of art\",\"laura boulton\",\"museo de antropolog\\u00eda de xalapa\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"museum of archaeology and anthropology, university of cambridge\",\"the hunters (1957 film)\",\"nanook of the north\",\"moana (1926 film)\",\"list of visual anthropology films\",\"cultural anthropology\",\"anthropology of art\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"endocannibalism\",\"language\",\"religion\",\"peasant\",\"people\",\"high culture\",\"warrior\",\"kshatriya\",\"business magnate\",\"guanche mummies\",\"donor class\",\"magnate\",\"archaeology\",\"religion\",\"cultural relativism\",\"emic and etic\",\"alliance theory\",\"culture theory\",\"performance studies\",\"human ecology\",\"ethnobiology\",\"netnography\",\"online ethnography\",\"nutritional anthropology\",\"zooarchaeology\",\"society for medical anthropology\",\"ecological anthropology\",\"ethnoichthyology\",\"critical medical anthropology\",\"ethnic religion\",\"medical anthropology\",\"ethnomuseology\",\"cultural anthropology\",\"ethnoornithology\",\"warrior\",\"slavery\",\"people\",\"person\",\"topic and comment\",\"religion\",\"language\",\"high-altitude adaptation in humans\",\"skhul and qafzeh hominins\",\"recent human evolution\",\"names for the human species\",\"early modern human\",\"typology (anthropology)\",\"negroid\",\"history of anthropometry\",\"martial race\",\"bertil lundman\",\"cultural memory\",\"cultural relativism\",\"culture theory\",\"cultural anthropology\",\"cultural mapping\",\"transcultural nursing\",\"high culture\",\"cultural nationalism\",\"cultural radicalism\",\"cultural movement\",\"outline of culture\",\"guanche mummies\",\"religion\",\"cultural relativism\",\"emic and etic\",\"alliance theory\",\"culture theory\",\"performance studies\",\"cultural anthropology\",\"nutritional anthropology\",\"shell money\",\"reciprocity (cultural anthropology)\",\"development anthropology\",\"heritage commodification\",\"religion\",\"cultural relativism\",\"emic and etic\",\"alliance theory\",\"culture theory\",\"performance studies\",\"cultural anthropology\",\"shell money\",\"critical medical anthropology\",\"reciprocity (cultural anthropology)\",\"society for medical anthropology\",\"medical anthropology\",\"heritage commodification\",\"hunter-gatherer\",\"peasant\",\"hunter-gatherer\",\"argentine forensic anthropology team\",\"peter sloterdijk\",\"cultural anthropology\",\"anthropology of art\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"religion\",\"ethnobiology\",\"netnography\",\"online ethnography\",\"emic and etic\",\"alliance theory\",\"cultural relativism\",\"performance studies\",\"ethnic religion\",\"culture theory\",\"anthropology of institutions\",\"ethnoichthyology\",\"linguistics\",\"language\",\"religion\",\"serer-ndut people\",\"serer people\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"serer maternal clans\",\"linguistics\",\"language\",\"linguistic relativity\",\"nudity\",\"cultural anthropology\",\"anthropology of art\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"les ma\\u00eetres fous\",\"magical death\",\"slavery\",\"language\",\"androcentrism\",\"archaeology\",\"linguistics\",\"cultural anthropology\",\"age set\",\"leveling mechanism\",\"theatre state\",\"circumscription theory\",\"religion\",\"cultural relativism\",\"emic and etic\",\"online ethnography\",\"paleoanthropology\",\"museum of mankind\",\"neuroanthropology\",\"chinese kinship\",\"feminist anthropology\",\"performance studies\",\"linguistic description\",\"list of matrilineal or matrilocal societies\",\"mosuo women\",\"linguistic anthropology\",\"diane bell (anthropologist)\",\"bibliography of anthropology\",\"ecological anthropology\",\"classificatory kinship\",\"culture theory\",\"semiotic anthropology\",\"patrilocal residence\",\"reciprocity (cultural anthropology)\",\"biological anthropology\",\"anthropology of art\",\"medical anthropology\",\"australian aboriginal kinship\",\"anthropology of institutions\",\"matrilocal residence\",\"cultural anthropology\",\"list of years in anthropology\",\"polygyny\",\"status group\",\"outline of culture\",\"hong kong honours system\",\"womyn's land\",\"donor class\",\"cultural group selection\",\"anthropological criminology\",\"business magnate\",\"evolutionary studies institute\",\"biological anthropology\",\"cultural radicalism\",\"ethnoornithology\",\"people\",\"official cantonese translations of english names for british officials\",\"magnate\",\"max scheler\",\"names for the human species\",\"homo faber\",\"cultural anthropology\",\"shell money\",\"travel behavior\",\"reciprocity (cultural anthropology)\",\"honeymoon\",\"ethnobiology\",\"biocultural anthropology\",\"religion\",\"language\",\"paleoanthropology\",\"hunter-gatherer\",\"digging stick\",\"grave goods\",\"linguistics\",\"language\",\"polygyny\",\"hunter-gatherer\",\"promiscuity\",\"female promiscuity\",\"homosexual behavior in animals\",\"men who have sex with men\",\"list of mammals displaying homosexual behavior\",\"women who have sex with women\",\"religion\",\"business magnate\",\"donor class\",\"magnate\",\"medical anthropology\",\"susto\",\"neo-nationalism\",\"language\",\"cultural anthropology\",\"human universals\",\"religion\",\"language\",\"archaeology\",\"slavery\",\"peasant\",\"poverty class\",\"confucian classes\",\"status group\",\"kshatriya\",\"underclass\",\"business magnate\",\"cultural memory\",\"cultural relativism\",\"culture theory\",\"cultural anthropology\",\"cultural mapping\",\"transcultural nursing\",\"cultural radicalism\",\"outline of culture\",\"middlebrow\",\"high culture\",\"hoi polloi\",\"cultural movement\",\"cultural nationalism\",\"cultural anthropology\",\"biological anthropology\",\"archaeology\",\"osteology\",\"zooarchaeology\",\"frazer lecture\",\"arthur evans\",\"human ecology\",\"cultural anthropology\",\"moana (1926 film)\",\"hunter-gatherer\",\"cultural anthropology\",\"society for medical anthropology\",\"medical anthropology\",\"female promiscuity\",\"biology and sexual orientation\",\"homosexual behavior in animals\",\"marriage of the virgin\",\"polygyny\",\"biology and sexual orientation\",\"homosexual behavior in animals\",\"list of animals displaying homosexual behavior\",\"personal life\",\"hobby\",\"history of anthropometry\",\"negroid\",\"bertil lundman\",\"archaeology\",\"religion\",\"cultural anthropology\",\"cultural anthropology\",\"bibliography of anthropology\",\"1990s in anthropology\",\"linguistics\",\"theory of language\",\"possible world\",\"list of women anthropologists\",\"marija gimbutas\",\"homosexual behavior in animals\",\"cultural anthropology\",\"polygyny\",\"men who have sex with men\",\"women who have sex with women\",\"fallen woman\",\"language\",\"religion\",\"slavery\",\"peasant\",\"kshatriya\",\"poverty class\",\"confucian classes\",\"status group\",\"underclass\",\"business magnate\",\"biblical patriarchy\",\"language\",\"list of women anthropologists\",\"prickly paradigm press\",\"archaeology\",\"linguistics\",\"area studies\",\"human ecology\",\"religion\",\"cultural relativism\",\"emic and etic\",\"culture theory\",\"performance studies\",\"cultural anthropology\",\"museum of archaeology and anthropology, university of cambridge\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"archaeology\",\"cultural anthropology\",\"polygyny\",\"feminist anthropology\",\"australian aboriginal kinship\",\"list of matrilineal or matrilocal societies\",\"patrilocal residence\",\"linguistics\",\"religion\",\"language\",\"cultural relativism\",\"emic and etic\",\"culture theory\",\"performance studies\",\"theory of language\",\"linguistic relativity\",\"paleoradiology\",\"neuroanthropology\",\"archaeology\",\"cultural anthropology\",\"polygyny\",\"feminist anthropology\",\"trobriand islands\",\"human ecology\",\"biological anthropology\",\"polygyny\",\"darwinian anthropology\",\"susto\",\"archaeology\",\"linguistics\",\"area studies\",\"human ecology\",\"religion\",\"cultural relativism\",\"emic and etic\",\"culture theory\",\"performance studies\",\"religion\",\"language\",\"biological anthropology\",\"hill people\",\"recent human evolution\",\"linguistics\",\"literacy\",\"kriza j\\u00e1nos ethnographic society\",\"language\",\"religion\",\"honeymoon\",\"wedding\",\"white wedding\",\"consummation\",\"honeymoon\",\"kshatriya\",\"negroid\",\"bertil lundman\",\"history of anthropometry\",\"religion\",\"wedding\",\"white wedding\",\"honeymoon\",\"religion\",\"cultural memory\",\"language\",\"cultural relativism\",\"emic and etic\",\"paleoanthropology\",\"feminist anthropology\",\"non-representational theory\",\"development geography\",\"outline of culture\",\"linguistic anthropology\",\"bibliography of anthropology\",\"semiotic anthropology\",\"biological anthropology\",\"transcultural nursing\",\"list of years in anthropology\",\"cultural nationalism\",\"cultural radicalism\",\"anthropology of institutions\",\"online ethnography\",\"museum of mankind\",\"health geography\",\"performance studies\",\"ecological anthropology\",\"geography of media and communication\",\"cultural mapping\",\"medical anthropology\",\"cultural movement\",\"cultural anthropology\",\"archaeology\",\"linguistics\",\"area studies\",\"biological anthropology\",\"ethnoornithology\",\"zooarchaeology\",\"ethnobiology\",\"personal life\",\"ecological anthropology\",\"ethnoichthyology\",\"human ecology\",\"cultural anthropology\",\"archaeology\",\"linguistics\",\"area studies\",\"religion\",\"cultural memory\",\"ethnobiology\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"theatre state\",\"paleoanthropology\",\"nomads of the longbow\",\"feminist anthropology\",\"human terrain system\",\"outline of culture\",\"diane bell (anthropologist)\",\"mosuo women\",\"bibliography of anthropology\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"classificatory kinship\",\"cultural nationalism\",\"polygyny\",\"circumscription theory\",\"muted group theory\",\"museum of archaeology and anthropology, university of cambridge\",\"reciprocity (cultural anthropology)\",\"cultural movement\",\"history of anthropometry\",\"anthropological index online\",\"ceremonial pole\",\"age set\",\"chinese kinship\",\"society for medical anthropology\",\"patrilocal residence\",\"transcultural nursing\",\"australian aboriginal kinship\",\"cultural radicalism\",\"anthropological survey of india\",\"shell money\",\"ecological anthropology\",\"disability anthropology\",\"cultural resource management\",\"cultural mapping\",\"leveling mechanism\",\"medical anthropology\",\"cultural anthropology\",\"cultural memory\",\"cultural relativism\",\"cultural mapping\",\"cultural movement\",\"outline of culture\",\"cultural nationalism\",\"cultural radicalism\",\"names for the human species\",\"ethnobiology\",\"ecological anthropology\",\"ethnoichthyology\",\"zooarchaeology\",\"archaeology\",\"ethnobiology\",\"biological anthropology\",\"osteology\",\"maceration (bone)\",\"zooarchaeology\",\"forensic facial reconstruction\",\"religion\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"linguistic anthropology\",\"linguistics\",\"communicative dynamism\",\"language\",\"men who have sex with men\",\"biology and sexual orientation\",\"archaeology\",\"religion\",\"cultural memory\",\"cultural relativism\",\"cultural mapping\",\"cultural nationalism\",\"cultural movement\",\"outline of culture\",\"language\",\"cultural memory\",\"language\",\"cultural relativism\",\"cultural mapping\",\"outline of culture\",\"neo-nationalism\",\"cultural movement\",\"shrunken head\",\"forensic facial reconstruction\",\"archaeology\",\"hunter-gatherer\",\"digging stick\",\"serer people\",\"archaeology\",\"linguistics\",\"outline of culture\",\"area studies\",\"biological anthropology\",\"cultural memory\",\"cultural relativism\",\"outline of culture\",\"cultural movement\",\"archaeology\",\"hunter-gatherer\",\"slavery\",\"poverty class\",\"confucian classes\",\"status group\",\"literacy\",\"peasant\",\"mosuo women\",\"kshatriya\",\"underclass\",\"museum of archaeology and anthropology, university of cambridge\",\"shell money\",\"reciprocity (cultural anthropology)\",\"age set\",\"leveling mechanism\",\"circumscription theory\",\"linguistics\",\"paleoanthropology\",\"age set\",\"circumscription theory\",\"linguistics\",\"archaeology\",\"archaeology\",\"slavery\",\"language\",\"zooarchaeology\",\"urban revolution\",\"religion\",\"language\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"biological anthropology\",\"history of anthropometry\",\"marija gimbutas\",\"religion\",\"slavery\",\"bumiputera (malaysia)\",\"language\",\"race and intelligence\",\"biological anthropology\",\"kshatriya\",\"underclass\",\"cultural movement\",\"cultural relativism\",\"cultural movement\",\"outline of culture\",\"medical anthropology\",\"religion\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"museum of mankind\",\"anthropological index online\",\"nations and iq\",\"archaeology\",\"koteka\",\"proto-malay\",\"linguistics\",\"theory of language\",\"status group\",\"development geography\",\"language\",\"linguistic anthropology\",\"neo-nationalism\",\"linguistic relativity\",\"health geography\",\"literacy\",\"geography of media and communication\",\"gaia philosophy\",\"bumiputera (malaysia)\",\"constantin noica\",\"non-representational theory\",\"friction of distance\",\"apuli\",\"biological anthropology\",\"philosophy of life\",\"cognitive archaeology\",\"australian institute of aboriginal and torres strait islander studies\",\"list of women anthropologists\",\"koteka\",\"bumiputera (malaysia)\",\"religion\",\"kshatriya\",\"the white goddess\",\"linguistics\",\"religion\",\"list of women anthropologists\",\"prickly paradigm press\",\"moralia\",\"religion\",\"ethnobiology\",\"netnography\",\"ethnic religion\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"polygyny\",\"feminist anthropology\",\"max scheler\",\"chinese kinship\",\"feminist anthropology\",\"homosexual behavior in animals\",\"raptio\",\"mosuo women\",\"classificatory kinship\",\"patrilocal residence\",\"australian aboriginal kinship\",\"wedding\",\"polygyny\",\"feminist anthropology\",\"feminist anthropology\",\"linguistics\",\"linguistic relativity\",\"religion\",\"non-representational theory\",\"archaeology\",\"linguistics\",\"journal of ethnobiology\",\"zooarchaeology\",\"ethnobiology\",\"netnography\",\"ecological anthropology\",\"ethnoichthyology\",\"hawaiian ethnobiology\",\"ethnic religion\",\"ethnic religion\",\"ethnoichthyology\",\"linguistics\",\"theory of language\",\"cognitive archaeology\",\"development geography\",\"nations and iq\",\"literacy\",\"religion\",\"kshatriya\",\"list of timothy asch films\",\"religion\",\"wedding\",\"biology and sexual orientation\",\"list of animals displaying homosexual behavior\",\"homosexual behavior in animals\",\"trobriand islands\",\"biological anthropology\",\"wedding\",\"honeymoon\",\"archaeology\",\"religion\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"negroid\",\"history of anthropometry\",\"linguistics\",\"religion\",\"serer maternal clans\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"serer people\",\"kshatriya\",\"linguistics\",\"trobriand islands\",\"ceremonial pole\",\"religion\",\"cultural relativism\",\"outline of culture\",\"cultural relativism\",\"religion\",\"religion\",\"serer people\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"religion\",\"toloy\",\"wedding\",\"ceremony\",\"religion\",\"serer people\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"canadian honours system\",\"pitt rivers museum\",\"religion\",\"hill people\",\"hoi polloi\",\"development geography\",\"archaeology\",\"cultural relativism\",\"archaeology\",\"linguistics\",\"religion\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"zooarchaeology\",\"bibliography of anthropology\",\"heel\\u2013ball index\",\"medical anthropology\",\"forensic facial reconstruction\",\"cha\\u00eene op\\u00e9ratoire\",\"history of anthropometry\",\"fordisc\",\"archaeology\",\"religion\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"patrilocal residence\",\"chinese kinship\",\"michelle rosaldo book prize\",\"woman, culture, and society\",\"classificatory kinship\",\"archaeology\",\"emic and etic\",\"development geography\",\"linguistic anthropology\",\"bibliography of anthropology\",\"health geography\",\"ethnic religion\",\"religion\",\"cultural relativism\",\"donor class\",\"anthropology of institutions\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"bumiputera (malaysia)\",\"constantin noica\",\"non-representational theory\",\"apuli\",\"ecological anthropology\",\"medical anthropology\",\"archaeology\",\"theory of language\",\"linguistic anthropology\",\"theta criterion\",\"unsaid\",\"gloss (annotation)\",\"linguistic relativity\",\"tonograph\",\"communicative dynamism\",\"neolinguistics\",\"heel\\u2013ball index\",\"forensic facial reconstruction\",\"anthropological index online\",\"medical anthropology\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"non-representational theory\",\"kshatriya\",\"underclass\",\"cabang atas\",\"womyn's land\",\"raptio\",\"wedding\",\"honeymoon\",\"bibliography of anthropology\",\"archaeology\",\"raptio\",\"koteka\",\"history of anthropometry\",\"archaeology\",\"koteka\",\"circumscription theory\",\"linguistic anthropology\",\"theta criterion\",\"communicative dynamism\",\"cultural relativism\",\"emic and etic\",\"performance studies\",\"society for medical anthropology\",\"rudolf virchow award\",\"ecological anthropology\",\"unsaid\",\"list of animals displaying homosexual behavior\",\"ceremonial pole\",\"the white goddess\",\"archaeology\",\"university of tennessee anthropological research facility\",\"constantin noica\",\"applied anthropology research methods\",\"bibliography of anthropology\",\"apuli\",\"cha\\u00eene op\\u00e9ratoire\",\"cognitive archaeology\",\"zooarchaeology\",\"archaeology\",\"cultural resource management\",\"forensic facial reconstruction\",\"pitt rivers museum\",\"anthropological index online\",\"cultural relativism\",\"emic and etic\",\"linguistic anthropology\",\"bibliography of anthropology\",\"ecological anthropology\",\"kshatriya\",\"underclass\",\"ethnoichthyology\",\"ecological anthropology\",\"trobriand islands\",\"history of anthropometry\",\"history of anthropometry\",\"cultural relativism\",\"emic and etic\",\"zooarchaeology\",\"australian institute of aboriginal and torres strait islander studies\",\"trobriand islands\",\"society for medical anthropology\",\"forensic facial reconstruction\",\"cultural relativism\",\"emic and etic\",\"linguistic anthropology\",\"personal life\",\"non-representational theory\",\"children's geographies\",\"cultural relativism\",\"koteka\",\"cultural relativism\",\"linguistic anthropology\",\"cabang atas\",\"pitt rivers museum\",\"cultural relativism\",\"linguistic relativity\",\"linguistic relativity\",\"mus\\u00e9e de l'homme\",\"museum of archaeology and anthropology, university of cambridge\"],\"start\":[\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"serfdom\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"sinodonty and sundadonty\",\"cephalic index in cats and dogs\",\"standard cross-cultural sample\",\"standard cross-cultural sample\",\"standard cross-cultural sample\",\"standard cross-cultural sample\",\"standard cross-cultural sample\",\"standard cross-cultural sample\",\"standard cross-cultural sample\",\"standard cross-cultural sample\",\"human genetic variation\",\"human genetic variation\",\"human genetic variation\",\"human genetic variation\",\"honorary male\",\"ethnolichenology\",\"ethnolichenology\",\"ethnolichenology\",\"ethnolichenology\",\"ethnolichenology\",\"ethnolichenology\",\"ethnolichenology\",\"ethnolichenology\",\"ethnolichenology\",\"list of stateless societies\",\"waga sculpture\",\"linguistic linked open data\",\"list of birds displaying homosexual behavior\",\"list of birds displaying homosexual behavior\",\"list of birds displaying homosexual behavior\",\"list of birds displaying homosexual behavior\",\"list of birds displaying homosexual behavior\",\"list of birds displaying homosexual behavior\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"cultural practice\",\"releasing the spirits: a balinese ceremony\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"cognitive anthropology\",\"wedding vow renewal ceremony\",\"wedding vow renewal ceremony\",\"wedding vow renewal ceremony\",\"wedding vow renewal ceremony\",\"wedding vow renewal ceremony\",\"wedding vow renewal ceremony\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"psychogeography\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"ethnoarchaeology\",\"warrior (character class)\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"nomadic pastoralism\",\"cephalic index\",\"cephalic index\",\"proverbial phrase\",\"proverbial phrase\",\"proverbial phrase\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"culture hero\",\"minangkabau people\",\"minangkabau people\",\"minangkabau people\",\"minangkabau people\",\"minangkabau people\",\"paleopathology\",\"paleopathology\",\"paleopathology\",\"paleopathology\",\"paleopathology\",\"paleopathology\",\"poppet\",\"poppet\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"ethnozoology\",\"sedentism\",\"sedentism\",\"sedentism\",\"sedentism\",\"sedentism\",\"sedentism\",\"sedentism\",\"population health policies and interventions\",\"population health policies and interventions\",\"edvard westermarck\",\"edvard westermarck\",\"edvard westermarck\",\"consumer class\",\"consumer class\",\"consumer class\",\"historical behaviour studies\",\"historical behaviour studies\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"nanook of the north\",\"the hunters (1957 film)\",\"the hunters (1957 film)\",\"the hunters (1957 film)\",\"exocannibalism\",\"richard gaskin\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"upper class\",\"postmodernist anthropology\",\"postmodernist anthropology\",\"postmodernist anthropology\",\"postmodernist anthropology\",\"postmodernist anthropology\",\"postmodernist anthropology\",\"postmodernist anthropology\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"ethnomedicine\",\"hoplology\",\"person\",\"person\",\"person\",\"person\",\"early modern human\",\"early modern human\",\"early modern human\",\"early modern human\",\"early modern human\",\"early modern human\",\"early modern human\",\"john beddoe\",\"john beddoe\",\"john beddoe\",\"john beddoe\",\"john beddoe\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"welfare culture\",\"mummy of san andr\\u00e9s\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"development anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"nutritional anthropology\",\"kalahari debate\",\"manorialism\",\"manorialism\",\"guatemalan forensic anthropology foundation\",\"peter sloterdijk\",\"museo de antropolog\\u00eda de xalapa\",\"museo de antropolog\\u00eda de xalapa\",\"museo de antropolog\\u00eda de xalapa\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"ethnomuseology\",\"media linguistics\",\"media linguistics\",\"lingeer\",\"lingeer\",\"lingeer\",\"lingeer\",\"lingeer\",\"metalanguage\",\"metalanguage\",\"metalanguage\",\"nudity\",\"list of visual anthropology films\",\"list of visual anthropology films\",\"list of visual anthropology films\",\"list of visual anthropology films\",\"list of visual anthropology films\",\"androcentrism\",\"androcentrism\",\"androcentrism\",\"deep history\",\"deep history\",\"f. g. bailey\",\"f. g. bailey\",\"f. g. bailey\",\"f. g. bailey\",\"f. g. bailey\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"alliance theory\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"people\",\"homo faber\",\"homo faber\",\"homo faber\",\"heritage commodification\",\"heritage commodification\",\"heritage commodification\",\"heritage commodification\",\"heritage commodification\",\"biocultural diversity\",\"biocultural diversity\",\"hunting hypothesis\",\"hunting hypothesis\",\"hunting hypothesis\",\"hunting hypothesis\",\"hunting hypothesis\",\"hunting hypothesis\",\"displacement (linguistics)\",\"displacement (linguistics)\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"promiscuity\",\"magnate\",\"magnate\",\"magnate\",\"magnate\",\"naturalistic disease theories\",\"naturalistic disease theories\",\"trash doves\",\"human ethology\",\"human ethology\",\"human ethology\",\"hong kong honours system\",\"gallowglass\",\"argentine forensic anthropology team\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"warrior\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"high culture\",\"biocultural anthropology\",\"biocultural anthropology\",\"arthur evans\",\"arthur evans\",\"arthur evans\",\"arthur evans\",\"arthur evans\",\"aparna rao\",\"aparna rao\",\"moana (1926 film)\",\"sympathetic magic\",\"critical medical anthropology\",\"critical medical anthropology\",\"critical medical anthropology\",\"prenatal hormones and sexual orientation\",\"prenatal hormones and sexual orientation\",\"prenatal hormones and sexual orientation\",\"marriage of the virgin\",\"list of mammals displaying homosexual behavior\",\"list of mammals displaying homosexual behavior\",\"list of mammals displaying homosexual behavior\",\"list of mammals displaying homosexual behavior\",\"hobby\",\"hobby\",\"typology (anthropology)\",\"typology (anthropology)\",\"typology (anthropology)\",\"rossville points\",\"rossville points\",\"multimodal anthropology\",\"human universals\",\"human universals\",\"human universals\",\"logical form (linguistics)\",\"logical form (linguistics)\",\"logical form (linguistics)\",\"riane eisler\",\"riane eisler\",\"joan roughgarden\",\"museo nacional de antropolog\\u00eda (madrid)\",\"female promiscuity\",\"female promiscuity\",\"female promiscuity\",\"female promiscuity\",\"logophonetic\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"business magnate\",\"fallen woman\",\"cultural survival\",\"list of anthropologists\",\"list of anthropologists\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"anthropology of art\",\"matrilocal residence\",\"matrilocal residence\",\"matrilocal residence\",\"matrilocal residence\",\"matrilocal residence\",\"matrilocal residence\",\"matrilocal residence\",\"linguistic description\",\"linguistic description\",\"linguistic description\",\"linguistic description\",\"linguistic description\",\"linguistic description\",\"linguistic description\",\"linguistic description\",\"linguistic description\",\"paleoradiology\",\"cognized environment\",\"list of matrilineal or matrilocal societies\",\"list of matrilineal or matrilocal societies\",\"list of matrilineal or matrilocal societies\",\"list of matrilineal or matrilocal societies\",\"list of matrilineal or matrilocal societies\",\"human behavioral ecology\",\"human behavioral ecology\",\"human behavioral ecology\",\"human behavioral ecology\",\"auspicious wedding dates\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"neuroanthropology\",\"cultural group selection\",\"cultural group selection\",\"cultural group selection\",\"high-altitude adaptation in humans\",\"high-altitude adaptation in humans\",\"kriza j\\u00e1nos ethnographic society\",\"kriza j\\u00e1nos ethnographic society\",\"kriza j\\u00e1nos ethnographic society\",\"educational anthropology\",\"official cantonese translations of english names for british officials\",\"travel behavior\",\"wedding reception\",\"wedding reception\",\"wedding reception\",\"wedding reception\",\"martial race\",\"martial race\",\"martial race\",\"martial race\",\"consummation\",\"consummation\",\"consummation\",\"consummation\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"culture theory\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"human ecology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"cultural anthropology\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"transcultural nursing\",\"helmuth plessner\",\"ethnoornithology\",\"ethnoornithology\",\"ethnoornithology\",\"ethnoornithology\",\"osteology\",\"osteology\",\"osteology\",\"osteology\",\"osteology\",\"osteology\",\"osteology\",\"semiotic anthropology\",\"semiotic anthropology\",\"semiotic anthropology\",\"semiotic anthropology\",\"semiotic anthropology\",\"topic and comment\",\"topic and comment\",\"names for the human species\",\"women who have sex with women\",\"women who have sex with women\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"cultural radicalism\",\"skhul and qafzeh hominins\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"cultural nationalism\",\"headhunting\",\"maceration (bone)\",\"grave goods\",\"grave goods\",\"grave goods\",\"grave goods\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"area studies\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"cultural mapping\",\"digging stick\",\"digging stick\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"peasant\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"shell money\",\"shell money\",\"theatre state\",\"theatre state\",\"theatre state\",\"possible world\",\"endocast\",\"leveling mechanism\",\"leveling mechanism\",\"human terrain system\",\"viking fund medal\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"hunter-gatherer\",\"paleoanthropology\",\"paleoanthropology\",\"paleoanthropology\",\"paleoanthropology\",\"paleoanthropology\",\"paleoanthropology\",\"paleoanthropology\",\"das mutterrecht\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"slavery\",\"cultural memory\",\"cultural memory\",\"cultural memory\",\"population health\",\"museum of mankind\",\"museum of mankind\",\"museum of mankind\",\"museum of mankind\",\"museum of mankind\",\"museum of mankind\",\"race and intelligence\",\"museu da lourinh\\u00e3\",\"mandailing people\",\"mandailing people\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"language\",\"faye v. harrison\",\"proto-malay\",\"proto-malay\",\"poverty class\",\"poverty class\",\"the witch-cult in western europe\",\"marija gimbutas\",\"marija gimbutas\",\"marija gimbutas\",\"dominic boyer\",\"moralia\",\"online ethnography\",\"online ethnography\",\"online ethnography\",\"online ethnography\",\"online ethnography\",\"online ethnography\",\"online ethnography\",\"diane bell (anthropologist)\",\"diane bell (anthropologist)\",\"max scheler\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"polygyny\",\"australian aboriginal kinship\",\"mosuo women\",\"linguistics in science fiction\",\"linguistics in science fiction\",\"geography of media and communication\",\"geography of media and communication\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"ethnobiology\",\"netnography\",\"netnography\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"literacy\",\"status group\",\"status group\",\"magical death\",\"gaia philosophy\",\"gate crashing\",\"homosexual behavior in animals\",\"homosexual behavior in animals\",\"homosexual behavior in animals\",\"1910s in anthropology\",\"craig stanford\",\"white wedding\",\"white wedding\",\"list of years in anthropology\",\"list of years in anthropology\",\"list of years in anthropology\",\"list of years in anthropology\",\"list of years in anthropology\",\"bertil lundman\",\"bertil lundman\",\"squib (writing)\",\"serer-ndut people\",\"serer-ndut people\",\"serer-ndut people\",\"serer-ndut people\",\"census of india prior to independence\",\"proverb\",\"proverb\",\"soul dualism\",\"cultural movement\",\"cultural movement\",\"cultural movement\",\"oikofobie. de angst voor het eigene\",\"philosophy of life\",\"serer maternal clans\",\"serer maternal clans\",\"serer maternal clans\",\"toloy\",\"toloy\",\"ceremony\",\"ceremony\",\"serer people\",\"serer people\",\"serer people\",\"fount of honour\",\"shrunken head\",\"andean civilizations\",\"andean civilizations\",\"hoi polloi\",\"tropical geography\",\"outline of culture\",\"outline of culture\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"biological anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"feminist anthropology\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"religion\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"linguistics\",\"disability anthropology\",\"anthropology of institutions\",\"anthropology of institutions\",\"anthropology of institutions\",\"health geography\",\"confucian classes\",\"confucian classes\",\"confucian classes\",\"womyn's land\",\"wedding\",\"wedding\",\"wedding\",\"deep play: notes on the balinese cockfight\",\"maya research program\",\"patrilocal residence\",\"angkola people\",\"anthropological criminology\",\"direct historical approach\",\"kluet people\",\"age set\",\"theory of language\",\"theory of language\",\"theory of language\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"medical anthropology\",\"unsaid\",\"biology and sexual orientation\",\"the hebrew goddess\",\"the hebrew goddess\",\"urban revolution\",\"fordisc\",\"constantin noica\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"archaeology\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"performance studies\",\"kshatriya\",\"kshatriya\",\"ethnic religion\",\"ethnoichthyology\",\"reciprocity (cultural anthropology)\",\"anthropometric history\",\"negroid\",\"ecological anthropology\",\"ecological anthropology\",\"ecological anthropology\",\"australian institute of aboriginal and torres strait islander studies\",\"trobriand islands\",\"rudolf virchow award\",\"forensic facial reconstruction\",\"bibliography of anthropology\",\"bibliography of anthropology\",\"bibliography of anthropology\",\"personal life\",\"development geography\",\"non-representational theory\",\"applied anthropology research methods\",\"koteka\",\"emic and etic\",\"emic and etic\",\"cabang atas\",\"pitt rivers museum\",\"linguistic anthropology\",\"linguistic anthropology\",\"cultural relativism\",\"mus\\u00e9e de l'homme\",\"museum of archaeology and anthropology, university of cambridge\"]},\"selected\":{\"id\":\"1845\"},\"selection_policy\":{\"id\":\"1844\"}},\"id\":\"1684\",\"type\":\"ColumnDataSource\"},{\"attributes\":{\"source\":{\"id\":\"1745\"}},\"id\":\"1747\",\"type\":\"CDSView\"},{\"attributes\":{\"data_source\":{\"id\":\"1684\"},\"glyph\":{\"id\":\"1709\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1686\"}},\"id\":\"1685\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"axis\":{\"id\":\"1723\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"1726\",\"type\":\"Grid\"},{\"attributes\":{\"callback\":null,\"tooltips\":[[\"Page\",\"@index\"]]},\"id\":\"1670\",\"type\":\"HoverTool\"},{\"attributes\":{},\"id\":\"1824\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"1668\",\"type\":\"SaveTool\"},{\"attributes\":{},\"id\":\"1721\",\"type\":\"LinearScale\"},{\"attributes\":{\"edge_renderer\":{\"id\":\"1685\"},\"inspection_policy\":{\"id\":\"1837\"},\"layout_provider\":{\"id\":\"1691\"},\"node_renderer\":{\"id\":\"1681\"},\"selection_policy\":{\"id\":\"1828\"}},\"id\":\"1678\",\"type\":\"GraphRenderer\"},{\"attributes\":{},\"id\":\"1728\",\"type\":\"BasicTicker\"},{\"attributes\":{\"axis\":{\"id\":\"1727\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"1730\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"1809\",\"type\":\"AllLabels\"},{\"attributes\":{},\"id\":\"1837\",\"type\":\"NodesOnly\"},{\"attributes\":{\"data\":{\"end\":[\"homo economicus\",\"index of economics articles\",\"evolutionary game theory\",\"intensity of preference\",\"sequential game\",\"thomas schelling\",\"bertrand competition\",\"john rawls\",\"daniel kahneman\",\"paul milgrom\",\"william vickrey\",\"glossary of economics\",\"kenneth arrow\",\"bertrand paradox (economics)\",\"cournot competition\",\"giffen good\",\"john harsanyi\",\"credit default option\",\"binomial options pricing model\",\"option screener\",\"roll-geske-whaley\",\"consumer debt\",\"edgeworth binomial tree\",\"garman-kohlhagen model\",\"john hicks\",\"democratic capitalism\",\"thomas schelling\",\"economic model\",\"schelling's segregation model\",\"utility\",\"macroeconomic model\",\"keynesian cross\",\"history of capitalist theory\",\"paul romer\",\"economic indicator\",\"robert heilbroner\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"norwegian paradox\",\"elhanan helpman\",\"index of economics articles\",\"international economics\",\"accelerator effect\",\"new institutional economics\",\"daniel mcfadden\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"surplus value\",\"mainstream economics\",\"cournot competition\",\"marginalism\",\"joseph schumpeter\",\"economic transformation\",\"privatism\",\"neo-capitalism\",\"financial economics\",\"supply and demand\",\"service economy\",\"is\\u2013lm model\",\"list of important publications in economics\",\"pork cycle\",\"history of microeconomics\",\"bengt holmstr\\u00f6m\",\"ramsey\\u2013cass\\u2013koopmans model\",\"experimental economics\",\"99ers\",\"jacob hollander\",\"friedrich hayek\",\"social cost\",\"visible hand (economics)\",\"purchasing power parity\",\"adam smith\",\"econophysics\",\"william vickrey\",\"eco-capitalism\",\"kenneth arrow\",\"phillips curve\",\"implicit cost\",\"anarcho-capitalism\",\"trygve haavelmo\",\"induced consumption\",\"autonomous consumption\",\"public economics\",\"andrea weber\",\"macroeconomic model\",\"index of economics articles\",\"bertrand paradox (economics)\",\"homo economicus\",\"glossary of economics\",\"consumer debt\",\"marginal propensity to consume\",\"induced consumption\",\"market anomaly\",\"primary market\",\"arbitrage pricing theory\",\"growth stock\",\"technical indicator\",\"momentum (finance)\",\"breakout (technical analysis)\",\"doji\",\"rate of return\",\"equity premium puzzle\",\"extended-hours trading\",\"donchian channel\",\"carbon bubble\",\"hanging man (candlestick pattern)\",\"alpha (finance)\",\"opportunity cost\",\"production\\u2013possibility frontier\",\"songun\",\"fractional-reserve banking\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"mainstream economics\",\"international economics\",\"jel classification codes\",\"experimental economics\",\"public economics\",\"john hicks\",\"assume a can opener\",\"cobweb model\",\"kiyotaki\\u2013moore model\",\"solow\\u2013swan model\",\"georgism\",\"financial economics\",\"michael albert\",\"is\\u2013lm model\",\"economic model\",\"macroeconomic model\",\"glossary of economics\",\"heckscher\\u2013ohlin model\",\"kenneth arrow\",\"phillips curve\",\"problems with economic models\",\"loopco\",\"marginalism\",\"ramsey\\u2013cass\\u2013koopmans model\",\"nominal yield\",\"perpetual bond\",\"variable rate debt obligation\",\"black\\u2013derman\\u2013toy model\",\"david laidler\",\"robert heilbroner\",\"public economics\",\"diminishing returns\",\"world economy\",\"technical change\",\"supply and demand\",\"in kind\",\"clive granger\",\"homo economicus\",\"opportunity cost\",\"paul milgrom\",\"keynesian cross\",\"identity line\",\"elinor ostrom\",\"homo economicus\",\"cournot competition\",\"evolutionary game theory\",\"economists for peace and security\",\"mesoeconomics\",\"sequential game\",\"thomas schelling\",\"bertrand competition\",\"schelling's segregation model\",\"paul milgrom\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"internality\",\"daniel mcfadden\",\"daniel kahneman\",\"william vickrey\",\"bertrand paradox (economics)\",\"michael spence\",\"vernon l. smith\",\"trygve haavelmo\",\"john harsanyi\",\"kenneth arrow\",\"leontief paradox\",\"daniel mcfadden\",\"erwin plein nemmers prize in economics\",\"bengt holmstr\\u00f6m\",\"trygve haavelmo\",\"indifference curve\",\"inframarginal analysis\",\"paul milgrom\",\"ricardian equivalence\",\"diminishing returns\",\"returns (economics)\",\"georgism\",\"knowledge economy\",\"service economy\",\"democratic capitalism\",\"open economy\",\"robinson crusoe economy\",\"murray's hypocycloidal engine\",\"woolrich electrical generator\",\"financial economics\",\"market anomaly\",\"arbitrage pricing theory\",\"rate of return\",\"concentration risk\",\"political risk\",\"fama\\u2013french three-factor model\",\"financial economics\",\"arbitrage pricing theory\",\"concentration risk\",\"first world\",\"elinor ostrom\",\"financial economics\",\"daniel kahneman\",\"paul milgrom\",\"william vickrey\",\"vernon l. smith\",\"time series\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"timo ter\\u00e4svirta\",\"trygve haavelmo\",\"substitution effect\",\"community-supported agriculture\",\"list of unsolved problems in economics\",\"equity home bias puzzle\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"marginalism\",\"surplus value\",\"privatism\",\"seasoned equity offering\",\"index of economics articles\",\"maturity transformation\",\"excess reserves\",\"peak wheat\",\"kuznets curve\",\"jel classification codes\",\"benefit financing model\",\"credit default option\",\"consumer debt\",\"discrete choice\",\"methodology of econometrics\",\"opportunity cost\",\"risk premium\",\"rate of return\",\"seasoned equity offering\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"experimental economics\",\"public economics\",\"john hicks\",\"georgism\",\"marginalism\",\"utility\",\"kenneth arrow\",\"vernon l. smith\",\"neo-ricardianism\",\"stylized fact\",\"risk premium\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"georgism\",\"marginalism\",\"surplus value\",\"privatism\",\"financial economics\",\"equity premium puzzle\",\"economic puzzle\",\"peso problem (finance)\",\"resource curse\",\"adam smith\",\"index of economics articles\",\"mainstream economics\",\"economics terminology that differs from common usage\",\"leontief production function\",\"production\\u2013possibility frontier\",\"net national product\",\"solow\\u2013swan model\",\"list of production functions\",\"history of microeconomics\",\"factors of production\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"heckscher\\u2013ohlin model\",\"circular flow of income\",\"marginal rate of transformation\",\"surplus value\",\"value product\",\"long-run cost curve\",\"surplus labour\",\"marginal factor cost\",\"fei\\u2013ranis model of economic growth\",\"georgism\",\"john rawls\",\"sex and reason\",\"michael albert\",\"paradox of thrift\",\"financial economics\",\"marginal rate of substitution\",\"risk premium\",\"utility\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"mainstream economics\",\"international economics\",\"experimental economics\",\"public economics\",\"john hicks\",\"georgism\",\"marginalism\",\"phillips curve\",\"kenneth arrow\",\"is\\u2013lm model\",\"keynesian cross\",\"kiyotaki\\u2013moore model\",\"solow\\u2013swan model\",\"indirect inference\",\"visible hand (economics)\",\"accelerator effect\",\"ak model\",\"99ers\",\"consumer debt\",\"time series\",\"ramsey\\u2013cass\\u2013koopmans model\",\"proto-industrialization\",\"inside contracting\",\"paul milgrom\",\"daniel mcfadden\",\"gustav stolper prize\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"mainstream economics\",\"international economics\",\"jel classification codes\",\"experimental economics\",\"public economics\",\"john hicks\",\"assume a can opener\",\"georgism\",\"marginalism\",\"surplus value\",\"daniel kahneman\",\"privatism\",\"accelerator effect\",\"steven n. s. cheung\",\"nava ashraf\",\"georg weizs\\u00e4cker\",\"hiding hand principle\",\"history of capitalist theory\",\"colonial origins of comparative development\",\"asset specificity\",\"new institutional economics\",\"list of unsolved problems in economics\",\"equity home bias puzzle\",\"eonia\",\"sofr\",\"tibor\",\"bric\",\"big push model\",\"impossible trinity\",\"convergence (economics)\",\"paul milgrom\",\"william vickrey\",\"benny moldovanu\",\"two-sided matching\",\"breakout (technical analysis)\",\"doji\",\"technical indicator\",\"momentum (finance)\",\"hanging man (candlestick pattern)\",\"the theory of interstellar trade\",\"rat race\",\"blue economy\",\"supply and demand\",\"economic humanitarianism (ra\\u00eblianism)\",\"technocracy movement\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"international economics\",\"experimental economics\",\"public economics\",\"john hicks\",\"georgism\",\"marginalism\",\"opportunity cost\",\"phillips curve\",\"glossary of economics\",\"kenneth arrow\",\"is\\u2013lm model\",\"accelerator effect\",\"keynesian cross\",\"ad\\u2013ia model\",\"homo economicus\",\"consumer debt\",\"marginal propensity to consume\",\"experimental economics\",\"financial economics\",\"daniel kahneman\",\"paul milgrom\",\"vernon l. smith\",\"myron scholes\",\"eugene fama\",\"peter jaeckel\",\"farshid jamshidian\",\"adam smith\",\"friedrich hayek\",\"homo economicus\",\"international economics\",\"john hicks\",\"phillips curve\",\"keynesian cross\",\"credit default option\",\"binomial options pricing model\",\"roll-geske-whaley\",\"edgeworth binomial tree\",\"alternative financial service\",\"garman-kohlhagen model\",\"zur geschichte der handelsgesellschaften im mittelalter\",\"foreign agricultural service\",\"commodity credit corporation\",\"financial economics\",\"giffen good\",\"marginalism\",\"utility\",\"daniel kahneman\",\"history of microeconomics\",\"cumulative prospect theory\",\"elinor ostrom\",\"kenneth arrow\",\"daniel kahneman\",\"paul milgrom\",\"william vickrey\",\"vernon l. smith\",\"discrete choice\",\"economists for peace and security\",\"lawrence summers\",\"schelling's segregation model\",\"michael spence\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"trygve haavelmo\",\"jacob hollander\",\"cobweb model\",\"american system of manufacturing\",\"ceteris paribus\",\"economic indicator\",\"purchasing power parity\",\"glossary of economics\",\"heckscher\\u2013ohlin model\",\"balassa\\u2013samuelson effect\",\"sectoral output\",\"cost-weighted activity index\",\"volume index\",\"index (economics)\",\"inertial inflation\",\"deflator\",\"dixit\\u2013stiglitz model\",\"financial economics\",\"financial models with long-tailed distributions and volatility clustering\",\"glossary of economics\",\"public economics\",\"financial economics\",\"list of unsolved problems in economics\",\"market anomaly\",\"risk premium\",\"primary market\",\"arbitrage pricing theory\",\"growth stock\",\"cumulative prospect theory\",\"peso problem (finance)\",\"economic puzzle\",\"dynamic pricing\",\"financial economics\",\"credit default option\",\"roll-geske-whaley\",\"black\\u2013derman\\u2013toy model\",\"edgeworth binomial tree\",\"index of economics articles\",\"commodity credit corporation\",\"list of economics films\",\"supply and demand\",\"index of economics articles\",\"history of microeconomics\",\"balassa\\u2013samuelson effect\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"journal of the european economic association\",\"human development index\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"experimental economics\",\"public economics\",\"john hicks\",\"georgism\",\"gerschenkron effect\",\"marginalism\",\"world economy\",\"real economy\",\"balassa\\u2013samuelson effect\",\"bric\",\"index (economics)\",\"economic power\",\"glossary of economics\",\"kenneth arrow\",\"heckscher\\u2013ohlin model\",\"adam smith\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"blue economy\",\"john hicks\",\"law of increasing costs\",\"financial economics\",\"principles of economics (marshall book)\",\"jel classification codes\",\"law of supply\",\"service economy\",\"list of important publications in economics\",\"keynesian cross\",\"information economics\",\"public economics\",\"economics (textbook)\",\"experimental economics\",\"economic indicator\",\"assume a can opener\",\"georgism\",\"big push model\",\"international economics\",\"charles henry hull\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"inframarginal analysis\",\"opportunity cost\",\"knowledge economy\",\"glossary of economics\",\"kenneth arrow\",\"phillips curve\",\"diminishing returns\",\"convergence (economics)\",\"marginalism\",\"neo-ricardianism\",\"paradox of thrift\",\"fei\\u2013ranis model of economic growth\",\"indirect inference\",\"methodology of econometrics\",\"friedrich hayek\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"experimental economics\",\"public economics\",\"john hicks\",\"georgism\",\"giffen good\",\"indifference curve\",\"intertemporal choice\",\"marginalism\",\"substitution effect\",\"utility\",\"kenneth arrow\",\"demand curve\",\"paradox of value\",\"samuelson condition\",\"michael spence\",\"journal of the european economic association\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"georgism\",\"marginalism\",\"surplus value\",\"privatism\",\"benny moldovanu\",\"hicks-tinbergen award\",\"fabrizio zilibotti\",\"paola giuliano\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"experimental economics\",\"public economics\",\"john hicks\",\"georgism\",\"marginalism\",\"opportunity cost\",\"glossary of economics\",\"kenneth arrow\",\"index of economics articles\",\"glossary of economics\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"international economics\",\"jel classification codes\",\"experimental economics\",\"public economics\",\"john hicks\",\"assume a can opener\",\"indifference curve\",\"utility\",\"intertemporal choice\",\"glossary of economics\",\"michael spence\",\"vernon l. smith\",\"network effect\",\"substitution effect\",\"time value of money\",\"knowledge economy\",\"network effect\",\"utility\",\"metcalfe's law\",\"beckstrom's law\",\"homo economicus\",\"utility\",\"john roemer\",\"financial economics\",\"adam smith\",\"giffen good\",\"supply and demand\",\"index of economics articles\",\"least developed countries\",\"cash crop\",\"supply and demand\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"international economics\",\"jel classification codes\",\"john hicks\",\"utility\",\"keynesian cross\",\"economic indicator\",\"assume a can opener\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"accelerator effect\",\"inframarginal analysis\",\"daniel kahneman\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"cournot competition\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"blue economy\",\"economic transformation\",\"law of increasing costs\",\"financial economics\",\"law of supply\",\"service economy\",\"list of important publications in economics\",\"public economics\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"evolutionary game theory\",\"social cost\",\"big push model\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"opportunity cost\",\"kenneth arrow\",\"phillips curve\",\"economic data\",\"convergence (economics)\",\"georg weizs\\u00e4cker\",\"vernon l. smith\",\"solow\\u2013swan model\",\"doji\",\"intertemporal choice\",\"ramsey\\u2013cass\\u2013koopmans model\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"international economics\",\"jel classification codes\",\"public economics\",\"john hicks\",\"assume a can opener\",\"economic indicator\",\"excess burden of taxation\",\"financial economics\",\"democratic capitalism\",\"utility\",\"keynesian cross\",\"solow\\u2013swan model\",\"index (economics)\",\"georgism\",\"charles henry hull\",\"accelerator effect\",\"economic humanitarianism (ra\\u00eblianism)\",\"inframarginal analysis\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"theories of poverty\",\"marginalism\",\"neo-ricardianism\",\"law of rent\",\"economic transformation\",\"principles of economics (marshall book)\",\"service economy\",\"list of important publications in economics\",\"public property\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"social cost\",\"william vickrey\",\"phillips curve\",\"wood industry\",\"supply and demand\",\"economics terminology that differs from common usage\",\"indifference curve\",\"intertemporal choice\",\"substitution effect\",\"utility\",\"glossary of economics\",\"peak wheat\",\"law of supply\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"preclusive purchasing\",\"adam smith\",\"giffen good\",\"marginalism\",\"glossary of economics\",\"adam smith\",\"international economics\",\"jel classification codes\",\"public economics\",\"john hicks\",\"assume a can opener\",\"world economy\",\"supply and demand\",\"adam smith\",\"index of economics articles\",\"international economics\",\"jel classification codes\",\"public economics\",\"law of increasing costs\",\"financial economics\",\"law of supply\",\"service economy\",\"list of important publications in economics\",\"economic indicator\",\"big push model\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"inframarginal analysis\",\"opportunity cost\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"convergence (economics)\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"public economics\",\"john hicks\",\"marginalism\",\"opportunity cost\",\"social cost\",\"kenneth arrow\",\"fei\\u2013ranis model of economic growth\",\"william vickrey\",\"jacob hollander\",\"peak wheat\",\"bowley's law\",\"credit default option\",\"glossary of economics\",\"average fixed cost\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"john hicks\",\"balassa\\u2013samuelson effect\",\"ak model\",\"keynesian cross\",\"import substitution industrialization\",\"leontief paradox\",\"economic indicator\",\"solow\\u2013swan model\",\"international economics\",\"accelerator effect\",\"inframarginal analysis\",\"knowledge economy\",\"glossary of economics\",\"diminishing returns\",\"impossible trinity\",\"marginalism\",\"giancarlo corsetti\",\"fei\\u2013ranis model of economic growth\",\"law of increasing costs\",\"financial economics\",\"jel classification codes\",\"law of supply\",\"service economy\",\"list of important publications in economics\",\"public economics\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"big push model\",\"visible hand (economics)\",\"list of unsolved problems in economics\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"paul de grauwe\",\"opportunity cost\",\"kenneth arrow\",\"phillips curve\",\"convergence (economics)\",\"economic puzzle\",\"homo economicus\",\"cournot competition\",\"kenneth arrow\",\"bishop\\u2013cannings theorem\",\"evolutionary game theory\",\"sequential game\",\"bertrand competition\",\"daniel kahneman\",\"paul milgrom\",\"william vickrey\",\"bertrand paradox (economics)\",\"john harsanyi\",\"elinor ostrom\",\"friedrich hayek\",\"homo economicus\",\"john hicks\",\"cournot competition\",\"kenneth arrow\",\"sequential game\",\"daniel kahneman\",\"john harsanyi\",\"bertrand competition\",\"schelling's segregation model\",\"eugene fama\",\"vernon l. smith\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"myron scholes\",\"william vickrey\",\"michael spence\",\"bertrand paradox (economics)\",\"trygve haavelmo\",\"leonid kantorovich\",\"rate of return\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"public economics\",\"john hicks\",\"marginalism\",\"phillips curve\",\"kenneth arrow\",\"solow\\u2013swan model\",\"visible hand (economics)\",\"accelerator effect\",\"ak model\",\"marginal propensity to consume\",\"99ers\",\"circular flow of income\",\"ramsey\\u2013cass\\u2013koopmans model\",\"cournot competition\",\"differentiated bertrand competition\",\"kenneth arrow\",\"sequential game\",\"daniel kahneman\",\"john harsanyi\",\"william vickrey\",\"bertrand paradox (economics)\",\"edgeworth paradox\",\"nominal yield\",\"perpetual bond\",\"edgeworth binomial tree\",\"stochastic investment model\",\"elinor ostrom\",\"friedrich hayek\",\"john hicks\",\"kenneth arrow\",\"daniel kahneman\",\"john harsanyi\",\"william vickrey\",\"econtalk\",\"economic data\",\"schelling's segregation model\",\"eugene fama\",\"paul romer\",\"bengt holmstr\\u00f6m\",\"myron scholes\",\"supreme court economic review\",\"michael spence\",\"leonid kantorovich\",\"vernon l. smith\",\"trygve haavelmo\",\"circular flow of income\",\"paradox of thrift\",\"richard koo\",\"index of economics articles\",\"import substitution industrialization\",\"network effect\",\"production\\u2013possibility frontier\",\"balassa\\u2013samuelson effect\",\"heckscher\\u2013ohlin model\",\"leontief paradox\",\"index of economics articles\",\"robinson crusoe economy\",\"kenneth arrow\",\"edgeworth paradox\",\"elinor ostrom\",\"adam smith\",\"daniel kahneman\",\"accelerator effect\",\"myron scholes\",\"hiding hand principle\",\"eugene fama\",\"nava ashraf\",\"georg weizs\\u00e4cker\",\"david laidler\",\"financial economics\",\"market anomaly\",\"myron scholes\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"phillips curve\",\"national average salary\",\"gold-collar worker\",\"99ers\",\"phillips curve\",\"gold-collar worker\",\"99ers\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"public economics\",\"john hicks\",\"marginalism\",\"phillips curve\",\"kenneth arrow\",\"rate of return\",\"diminishing returns\",\"paul romer\",\"ramsey\\u2013cass\\u2013koopmans model\",\"market anomaly\",\"extended-hours trading\",\"momentum (finance)\",\"rate of return\",\"growth stock\",\"arbitrage pricing theory\",\"alpha (finance)\",\"elinor ostrom\",\"research papers in economics\",\"kenneth arrow\",\"daniel kahneman\",\"william vickrey\",\"paul romer\",\"trygve haavelmo\",\"bengt holmstr\\u00f6m\",\"friedrich hayek\",\"john hicks\",\"financial economics\",\"ricardian equivalence\",\"kenneth arrow\",\"william vickrey\",\"99ers\",\"austerity: the history of a dangerous idea\",\"lawrence summers\",\"trygve haavelmo\",\"glossary of economics\",\"base period\",\"deflator\",\"lorenz curve\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"public economics\",\"john hicks\",\"marginalism\",\"beveridge curve\",\"gold-collar worker\",\"ak model\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"visible hand (economics)\",\"triangle model\",\"accelerator effect\",\"kenneth arrow\",\"index of economics articles\",\"bertrand paradox (economics)\",\"merger simulation\",\"value product\",\"ramsey\\u2013cass\\u2013koopmans model\",\"bric\",\"index of economics articles\",\"human development index\",\"least developed countries\",\"diminishing returns\",\"theories of poverty\",\"first world\",\"heavily indebted poor countries\",\"scottish index of multiple deprivation\",\"glossary of economics\",\"financial economics\",\"edgeworth binomial tree\",\"united states farm bill\",\"opportunity cost\",\"lorenz curve\",\"economics handbooks\",\"extended-hours trading\",\"import substitution industrialization\",\"fabrizio zilibotti\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"jel classification codes\",\"public economics\",\"john hicks\",\"knowledge assessment methodology\",\"service economy\",\"conceptual economy\",\"knowledge economy\",\"kenneth arrow\",\"marginalism\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"jel classification codes\",\"public economics\",\"john hicks\",\"index (economics)\",\"lipstick index\",\"hemline index\",\"base period\",\"glossary of economics\",\"kenneth arrow\",\"economic data\",\"marginalism\",\"financial economics\",\"arbitrage pricing theory\",\"eugene fama\",\"index of economics articles\",\"metcalfe's law\",\"sailing ship effect\",\"utility\",\"beckstrom's law\",\"elinor ostrom\",\"adam smith\",\"public property\",\"opportunity cost\",\"paradox of thrift\",\"eugene fama\",\"adam smith\",\"index of economics articles\",\"financial economics\",\"sequential game\",\"homo economicus\",\"list of unsolved problems in economics\",\"daniel kahneman\",\"william vickrey\",\"kenneth arrow\",\"john harsanyi\",\"market anomaly\",\"arbitrage pricing theory\",\"growth stock\",\"doji\",\"financial economics\",\"myron scholes\",\"jensen prize\",\"marginal rate of substitution\",\"utility\",\"supply and demand\",\"visible hand (economics)\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"public economics\",\"john hicks\",\"gerschenkron effect\",\"marginalism\",\"kenneth arrow\",\"marginalism\",\"elinor ostrom\",\"friedrich hayek\",\"john hicks\",\"kenneth arrow\",\"daniel kahneman\",\"john harsanyi\",\"william vickrey\",\"myron scholes\",\"paul romer\",\"schelling's segregation model\",\"trygve haavelmo\",\"eugene fama\",\"bengt holmstr\\u00f6m\",\"leonid kantorovich\",\"giffen good\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"marginalism\",\"democratic capitalism\",\"history of capitalist theory\",\"john roemer\",\"production for profit\",\"reproduction (economics)\",\"real-world economics review\",\"privatism\",\"circular flow of income\",\"visible hand (economics)\",\"surplus labour\",\"value product\",\"least developed countries\",\"global retirement index\",\"first world\",\"heavily indebted poor countries\",\"kenneth arrow\",\"glossary of economics\",\"credit default option\",\"john rawls\",\"production for profit\",\"surplus labour\",\"reproduction (economics)\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"jel classification codes\",\"john hicks\",\"utility\",\"eric french (professor)\",\"index (economics)\",\"accelerator effect\",\"inframarginal analysis\",\"glossary of economics\",\"diminishing returns\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"law of increasing costs\",\"financial economics\",\"law of supply\",\"service economy\",\"list of important publications in economics\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"big push model\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"opportunity cost\",\"william vickrey\",\"convergence (economics)\",\"elinor ostrom\",\"adam smith\",\"market anomaly\",\"arbitrage pricing theory\",\"extended-hours trading\",\"rate of return\",\"alpha (finance)\",\"index of economics articles\",\"variable rate debt obligation\",\"perpetual bond\",\"supply and demand\",\"index of economics articles\",\"daniel kahneman\",\"william vickrey\",\"kenneth arrow\",\"bertrand paradox (economics)\",\"merger simulation\",\"sequential game\",\"john harsanyi\",\"jel classification codes\",\"elinor ostrom\",\"daniel kahneman\",\"accelerator effect\",\"nava ashraf\",\"hiding hand principle\",\"index of economics articles\",\"national equities exchange and quotations\",\"supply and demand\",\"theories of poverty\",\"scottish index of multiple deprivation\",\"list of special economic zones\",\"index of economics articles\",\"resource curse\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"jel classification codes\",\"john hicks\",\"financial economics\",\"utility\",\"marginal rate of substitution\",\"eugene fama\",\"pricing kernel\",\"arbitrage pricing theory\",\"contingent claim analysis\",\"jensen prize\",\"myron scholes\",\"real economy\",\"glossary of economics\",\"equity home bias puzzle\",\"risk premium\",\"kenneth arrow\",\"concentration risk\",\"marginalism\",\"financial models with long-tailed distributions and volatility clustering\",\"martin hellwig\",\"adam smith\",\"friedrich hayek\",\"dispersed knowledge\",\"the counter-revolution of science\",\"the road to serfdom\",\"interprovincial migration in canada\",\"equalization payments\",\"ceteris paribus\",\"index of economics articles\",\"world economy\",\"least developed countries\",\"adam smith\",\"giffen good\",\"marginalism\",\"time value of money\",\"adam smith\",\"elinor ostrom\",\"daniel kahneman\",\"william vickrey\",\"list of important publications in economics\",\"myron scholes\",\"list of jewish american economists\",\"eugene fama\",\"paul romer\",\"roll-geske-whaley\",\"david laidler\",\"trygve haavelmo\",\"elinor ostrom\",\"daniel kahneman\",\"accelerator effect\",\"nava ashraf\",\"jel classification codes\",\"eugene fama\",\"market anomaly\",\"arbitrage pricing theory\",\"supply and demand\",\"index of economics articles\",\"opportunity cost\",\"glossary of economics\",\"utility\",\"marginal rate of substitution\",\"marginal propensity to consume\",\"elinor ostrom\",\"friedrich hayek\",\"john hicks\",\"kenneth arrow\",\"daniel kahneman\",\"john harsanyi\",\"william vickrey\",\"ak model\",\"schelling's segregation model\",\"eugene fama\",\"paul romer\",\"leonid kantorovich\",\"trygve haavelmo\",\"roll-geske-whaley\",\"adam smith\",\"friedrich hayek\",\"robert heilbroner\",\"elinor ostrom\",\"daniel kahneman\",\"william vickrey\",\"econtalk\",\"trygve haavelmo\",\"david laidler\",\"eugene fama\",\"diminishing returns\",\"supply and demand\",\"time series\",\"elinor ostrom\",\"daniel kahneman\",\"william vickrey\",\"internality\",\"trygve haavelmo\",\"john hicks\",\"guido tabellini\",\"adam smith\",\"import substitution industrialization\",\"istv\\u00e1n hont\",\"economic nationalism\",\"index of economics articles\",\"net worth\",\"lorenz curve\",\"time series\",\"first world\",\"heavily indebted poor countries\",\"eonia\",\"sofr\",\"adam smith\",\"index of economics articles\",\"lump-sum tax\",\"supply and demand\",\"index of economics articles\",\"scitovsky paradox\",\"resource curse\",\"paradox of prosperity\",\"bertrand paradox (economics)\",\"indifference curve\",\"downs\\u2013thomson paradox\",\"icarus paradox\",\"paradox of thrift\",\"leontief paradox\",\"edgeworth paradox\",\"substitution effect\",\"utility\",\"glossary of economics\",\"supply and demand\",\"index of economics articles\",\"giancarlo corsetti\",\"opportunity cost\",\"adam smith\",\"beckstrom's law\",\"elinor ostrom\",\"daniel kahneman\",\"william vickrey\",\"trygve haavelmo\",\"leonid kantorovich\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"john hicks\",\"marginalism\",\"privatism\",\"guido tabellini\",\"fabrizio zilibotti\",\"daniel kahneman\",\"index (economics)\",\"secular variation\",\"analysis of rhythmic variance\",\"time series\",\"financial models with long-tailed distributions and volatility clustering\",\"unevenly spaced time series\",\"import substitution industrialization\",\"kenneth arrow\",\"glossary of economics\",\"kenneth arrow\",\"friedrich hayek\",\"index of economics articles\",\"the counter-revolution of science\",\"dollar voting\",\"net worth\",\"marginal rate of substitution\",\"opportunity cost\",\"robinson crusoe economy\",\"masters in agricultural economics\",\"production for profit\",\"reproduction (economics)\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"jel classification codes\",\"john hicks\",\"marginalism\",\"glossary of economics\",\"kenneth arrow\",\"adam smith\",\"index of economics articles\",\"leontief paradox\",\"hemline index\",\"supply and demand\",\"net worth\",\"value product\",\"surplus labour\",\"paradox of thrift\",\"economics (textbook)\",\"american system of manufacturing\",\"benny moldovanu\",\"glossary of economics\",\"rate of return\",\"the theory of interstellar trade\",\"adam smith\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"john hicks\",\"ceteris paribus\",\"indifference curve\",\"intertemporal equilibrium\",\"marginal rate of substitution\",\"marginalism\",\"opportunity cost\",\"substitution effect\",\"list of important publications in economics\",\"pricing kernel\",\"ramsey\\u2013cass\\u2013koopmans model\",\"dynamic pricing\",\"backward bending supply curve of labour\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"daniel kahneman\",\"glossary of economics\",\"kenneth arrow\",\"problems with economic models\",\"adam smith\",\"samuel von pufendorf\",\"adam smith\",\"rate of return\",\"kenneth arrow\",\"daniel kahneman\",\"william vickrey\",\"bertrand paradox (economics)\",\"john harsanyi\",\"risk premium\",\"marginal rate of substitution\",\"risk premium\",\"adam smith\",\"index of economics articles\",\"impossible trinity\",\"economic puzzle\",\"arbitrage pricing theory\",\"adam smith\",\"jel classification codes\",\"john hicks\",\"diminishing returns\",\"supply and demand\",\"economics terminology that differs from common usage\",\"glossary of economics\",\"accelerator effect\",\"marginal propensity to import\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"jel classification codes\",\"john hicks\",\"marginalism\",\"substitution effect\",\"kenneth arrow\",\"market anomaly\",\"arbitrage pricing theory\",\"rate of return\",\"eonia\",\"technical indicator\",\"hanging man (candlestick pattern)\",\"index of economics articles\",\"opportunity cost\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"john hicks\",\"glossary of economics\",\"ak model\",\"index (economics)\",\"accelerator effect\",\"daniel kahneman\",\"diminishing returns\",\"john harsanyi\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"william vickrey\",\"kenneth arrow\",\"bertrand paradox (economics)\",\"trygve haavelmo\",\"theories of poverty\",\"daniel kahneman\",\"elinor ostrom\",\"adam smith\",\"friedrich hayek\",\"john hicks\",\"marginalism\",\"economic data\",\"daniel kahneman\",\"marginal rate of substitution\",\"food processing\",\"index of economics articles\",\"leontief production function\",\"hicks-neutral technical change\",\"supply and demand\",\"marginalism\",\"supply and demand\",\"john harsanyi\",\"arbitrage pricing theory\",\"supply and demand\",\"adam smith\",\"index of economics articles\",\"john hicks\",\"law of increasing costs\",\"law of supply\",\"big push model\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"inframarginal analysis\",\"opportunity cost\",\"glossary of economics\",\"diminishing returns\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"macroeconomic regulation and control\",\"supply and demand\",\"index of economics articles\",\"benjamin moll\",\"mesoeconomics\",\"elinor ostrom\",\"supply and demand\",\"adam smith\",\"friedrich hayek\",\"index of economics articles\",\"john hicks\",\"bowley's law\",\"ak model\",\"accelerator effect\",\"inframarginal analysis\",\"daniel kahneman\",\"glossary of economics\",\"diminishing returns\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"law of increasing costs\",\"hicks-neutral technical change\",\"law of supply\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"big push model\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"opportunity cost\",\"william vickrey\",\"trygve haavelmo\",\"substitution effect\",\"market anomaly\",\"arbitrage pricing theory\",\"ak model\",\"ceteris paribus\",\"democratic capitalism\",\"history of capitalist theory\",\"indifference curve\",\"index of economics articles\",\"glossary of economics\",\"marginalism\",\"privatism\",\"mesoeconomics\",\"law of supply\",\"friedrich hayek\",\"adam smith\",\"opportunity cost\",\"william vickrey\",\"substitution effect\",\"index of economics articles\",\"indifference curve\",\"convex preferences\",\"production\\u2013possibility frontier\",\"marginalism\",\"fei\\u2013ranis model of economic growth\",\"substitution effect\",\"elinor ostrom\",\"democratic capitalism\",\"paradox of thrift\",\"index of economics articles\",\"inframarginal analysis\",\"marginalism\",\"john harsanyi\",\"privatism\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"friedrich hayek\",\"big push model\",\"sonnenschein\\u2013mantel\\u2013debreu theorem\",\"istv\\u00e1n hont\",\"ak model\",\"history of capitalist theory\",\"accelerator effect\",\"the counter-revolution of science\",\"glossary of economics\",\"diminishing returns\",\"fei\\u2013ranis model of economic growth\",\"law of increasing costs\",\"law of supply\",\"circular flow of income\",\"adam smith\",\"opportunity cost\",\"big push model\",\"elinor ostrom\",\"friedrich hayek\",\"daniel kahneman\",\"john harsanyi\",\"william vickrey\",\"trygve haavelmo\",\"friedrich hayek\",\"first world\",\"marginalism\",\"charles henry hull\",\"elinor ostrom\",\"friedrich hayek\",\"ceteris paribus\",\"market anomaly\",\"indifference curve\",\"glossary of economics\",\"marginalism\",\"ithaca hours\",\"intertemporal equilibrium\",\"big push model\",\"list of unsolved problems in economics\",\"opportunity cost\",\"substitution effect\",\"guido tabellini\",\"charlie bean (economist)\",\"freelancer\",\"glossary of economics\",\"glossary of economics\",\"value product\",\"production for profit\",\"perpetual bond\",\"elinor ostrom\",\"democratic capitalism\",\"paradox of thrift\",\"daniel kahneman\",\"marginalism\",\"privatism\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"friedrich hayek\",\"history of capitalist theory\",\"accelerator effect\",\"the counter-revolution of science\",\"glossary of economics\",\"diminishing returns\",\"william vickrey\",\"finance & development\",\"elinor ostrom\",\"daniel kahneman\",\"john harsanyi\",\"william vickrey\",\"bertrand paradox (economics)\",\"elinor ostrom\",\"ceteris paribus\",\"indifference curve\",\"marginalism\",\"opportunity cost\",\"substitution effect\",\"convex preferences\",\"law of supply\",\"guido tabellini\",\"circular flow of income\",\"diminishing returns\",\"marginalism\",\"jane semeleer\",\"quaternary sector of the economy\",\"elinor ostrom\",\"daniel kahneman\",\"accelerator effect\",\"ceteris paribus\",\"indifference curve\",\"democratic capitalism\",\"history of capitalist theory\",\"accelerator effect\",\"diminishing returns\",\"privatism\",\"ramsey\\u2013cass\\u2013koopmans model\",\"99ers\",\"opportunity cost\",\"democratic capitalism\",\"history of capitalist theory\",\"green job\",\"mesoeconomics\",\"elinor ostrom\",\"daniel kahneman\",\"bertrand paradox (economics)\",\"john harsanyi\",\"arbitrage pricing theory\",\"elinor ostrom\",\"market anomaly\",\"real-time economy\",\"ceteris paribus\",\"diminishing returns\",\"accelerator effect\",\"substitution effect\",\"bertrand paradox (economics)\",\"woolrich electrical generator\",\"value product\",\"elinor ostrom\",\"history of capitalist theory\",\"private highway\",\"indifference curve\",\"production\\u2013possibility frontier\",\"opportunity cost\",\"diminishing returns\",\"substitution effect\",\"indifference curve\",\"masters in agricultural economics\",\"equity home bias puzzle\",\"elinor ostrom\",\"accelerator effect\",\"daniel kahneman\",\"bertrand paradox (economics)\",\"elinor ostrom\",\"paradox of thrift\",\"elinor ostrom\",\"gerald shove\",\"economic law\",\"substitution effect\",\"equity home bias puzzle\",\"economic data\",\"john rawls\",\"great gatsby curve\",\"backward bending supply curve of labour\",\"elinor ostrom\"],\"start\":[\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"arrow's impossibility theorem\",\"forward price\",\"forward price\",\"forward price\",\"forward price\",\"forward price\",\"forward price\",\"forward price\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"joseph schumpeter\",\"relative income hypothesis\",\"relative income hypothesis\",\"journal of public economics\",\"journal of public economics\",\"journal of public economics\",\"hotelling's law\",\"hotelling's law\",\"autonomous consumption\",\"autonomous consumption\",\"autonomous consumption\",\"autonomous consumption\",\"autonomous consumption\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"market trend\",\"guns versus butter model\",\"guns versus butter model\",\"guns versus butter model\",\"electronic funds transfer\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"economic model\",\"i-spread\",\"i-spread\",\"i-spread\",\"i-spread\",\"foundation for european economic development\",\"foundation for european economic development\",\"economics of science\",\"economics of science\",\"economics of science\",\"economics of science\",\"cumulative process\",\"unplanned economies\",\"gabor\\u2013granger method\",\"efficiency wage\",\"efficiency wage\",\"efficiency wage\",\"identity line\",\"identity line\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"thomas schelling\",\"elhanan helpman\",\"elhanan helpman\",\"elhanan helpman\",\"elhanan helpman\",\"elhanan helpman\",\"elhanan helpman\",\"corner solution\",\"corner solution\",\"sharon oster\",\"wallace neutrality\",\"marginal return\",\"marginal return\",\"in kind\",\"in kind\",\"in kind\",\"in kind\",\"in kind\",\"in kind\",\"murray's hypocycloidal engine\",\"murray's hypocycloidal engine\",\"risk factor (finance)\",\"risk factor (finance)\",\"risk factor (finance)\",\"risk factor (finance)\",\"risk factor (finance)\",\"risk factor (finance)\",\"risk factor (finance)\",\"political risk\",\"political risk\",\"political risk\",\"political risk\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"clive granger\",\"rebound effect (conservation)\",\"rebound effect (conservation)\",\"backus\\u2013kehoe\\u2013kydland puzzle\",\"backus\\u2013kehoe\\u2013kydland puzzle\",\"neo-capitalism\",\"neo-capitalism\",\"neo-capitalism\",\"neo-capitalism\",\"neo-capitalism\",\"neo-capitalism\",\"market for corporate control\",\"fractional-reserve banking\",\"fractional-reserve banking\",\"fractional-reserve banking\",\"hubbert peak theory\",\"hubbert peak theory\",\"simulation modeling\",\"simulation modeling\",\"option screener\",\"option screener\",\"dynamic discrete choice\",\"dynamic discrete choice\",\"weighted average cost of capital\",\"weighted average cost of capital\",\"weighted average cost of capital\",\"weighted average cost of capital\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"econophysics\",\"liquidity premium\",\"eco-capitalism\",\"eco-capitalism\",\"eco-capitalism\",\"eco-capitalism\",\"eco-capitalism\",\"eco-capitalism\",\"eco-capitalism\",\"forward premium anomaly\",\"forward premium anomaly\",\"forward premium anomaly\",\"forward premium anomaly\",\"factor endowment\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"factors of production\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"bertrand russell\",\"state price density\",\"state price density\",\"state price density\",\"state price density\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"macroeconomic model\",\"outworker\",\"outworker\",\"erwin plein nemmers prize in economics\",\"erwin plein nemmers prize in economics\",\"erwin plein nemmers prize in economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"new institutional economics\",\"feldstein\\u2013horioka puzzle\",\"feldstein\\u2013horioka puzzle\",\"euronia\",\"euronia\",\"euronia\",\"3g (countries)\",\"open economy\",\"open economy\",\"open economy\",\"auction theory\",\"auction theory\",\"auction theory\",\"auction theory\",\"donchian channel\",\"donchian channel\",\"donchian channel\",\"donchian channel\",\"donchian channel\",\"rat race\",\"rat race\",\"community-supported agriculture\",\"market rate\",\"technocracy movement\",\"technocracy movement\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"is\\u2013lm model\",\"induced consumption\",\"induced consumption\",\"induced consumption\",\"journal of behavioral and experimental economics\",\"list of financial economists\",\"list of financial economists\",\"list of financial economists\",\"list of financial economists\",\"list of financial economists\",\"list of financial economists\",\"list of financial economists\",\"list of financial economists\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"consumer debt\",\"least-cost theory\",\"risk management agency\",\"risk management agency\",\"st. petersburg paradox\",\"st. petersburg paradox\",\"st. petersburg paradox\",\"st. petersburg paradox\",\"st. petersburg paradox\",\"st. petersburg paradox\",\"st. petersburg paradox\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"daniel mcfadden\",\"pork cycle\",\"inside contracting\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"price index\",\"volatility clustering\",\"volatility clustering\",\"ap microeconomics\",\"beatrice cherrier\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"equity premium puzzle\",\"demand shaping\",\"binomial options pricing model\",\"binomial options pricing model\",\"binomial options pricing model\",\"binomial options pricing model\",\"binomial options pricing model\",\"identity economics\",\"foreign agricultural service\",\"debtocracy\",\"cobweb model\",\"cobweb model\",\"cobweb model\",\"b\\u00e9la balassa\",\"pierre-andr\\u00e9 chiappori\",\"pierre-andr\\u00e9 chiappori\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"purchasing power parity\",\"vent for surplus\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"mainstream economics\",\"structural estimation\",\"structural estimation\",\"richard timberlake\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"history of microeconomics\",\"iza institute of labor economics\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"anarcho-capitalism\",\"journal of the european economic association\",\"journal of the european economic association\",\"journal of the european economic association\",\"journal of the european economic association\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"implicit cost\",\"joint product pricing\",\"joint product pricing\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"information economics\",\"term (time)\",\"learning economy\",\"reed's law\",\"reed's law\",\"reed's law\",\"reed's law\",\"superrationality\",\"superrationality\",\"superrationality\",\"market microstructure\",\"mandeville's paradox\",\"mandeville's paradox\",\"cash crop\",\"cash crop\",\"cash crop\",\"cash crop\",\"price support\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"experimental economics\",\"mundell\\u2013tobin effect\",\"breakout (technical analysis)\",\"keynes\\u2013ramsey rule\",\"keynes\\u2013ramsey rule\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"georgism\",\"industry (economics)\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"demand curve\",\"paradox of value\",\"paradox of value\",\"paradox of value\",\"capital cost\",\"blue economy\",\"blue economy\",\"blue economy\",\"blue economy\",\"blue economy\",\"blue economy\",\"blue economy\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"assume a can opener\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"social cost\",\"jacob hollander\",\"jacob hollander\",\"corn exchange\",\"stylized fact\",\"garman-kohlhagen model\",\"average variable cost\",\"average variable cost\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"international economics\",\"peso problem (finance)\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"evolutionary game theory\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"paul milgrom\",\"kuznets curve\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"keynesian cross\",\"bertrand competition\",\"bertrand competition\",\"bertrand competition\",\"bertrand competition\",\"bertrand competition\",\"bertrand competition\",\"bertrand competition\",\"bertrand competition\",\"bertrand competition\",\"black\\u2013derman\\u2013toy model\",\"black\\u2013derman\\u2013toy model\",\"black\\u2013derman\\u2013toy model\",\"black\\u2013derman\\u2013toy model\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"vernon l. smith\",\"sectoral balances\",\"sectoral balances\",\"sectoral balances\",\"harris\\u2013todaro model\",\"heckscher\\u2013ohlin model\",\"heckscher\\u2013ohlin model\",\"heckscher\\u2013ohlin model\",\"heckscher\\u2013ohlin model\",\"heckscher\\u2013ohlin model\",\"heckscher\\u2013ohlin model\",\"edgeworth box\",\"edgeworth box\",\"edgeworth box\",\"edgeworth box\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"steven n. s. cheung\",\"low-volatility anomaly\",\"low-volatility anomaly\",\"low-volatility anomaly\",\"walras's law\",\"discouraged worker\",\"discouraged worker\",\"discouraged worker\",\"discouraged worker\",\"national average salary\",\"national average salary\",\"national average salary\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"solow\\u2013swan model\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"primary market\",\"michael spence\",\"michael spence\",\"michael spence\",\"michael spence\",\"michael spence\",\"michael spence\",\"michael spence\",\"michael spence\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"lawrence summers\",\"deflator\",\"deflator\",\"deflator\",\"the elephant curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"phillips curve\",\"differentiated bertrand competition\",\"differentiated bertrand competition\",\"differentiated bertrand competition\",\"net national product\",\"dynamical system\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"human development index\",\"average fixed cost\",\"skew\",\"skew\",\"commodity credit corporation\",\"precautionary demand\",\"consumption distribution\",\"rethinking economics\",\"late trading\",\"infant industry argument\",\"institute for international economic studies\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"knowledge economy\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"economic indicator\",\"fama\\u2013french three-factor model\",\"fama\\u2013french three-factor model\",\"fama\\u2013french three-factor model\",\"network effect\",\"network effect\",\"network effect\",\"network effect\",\"network effect\",\"law of rent\",\"law of rent\",\"law of rent\",\"excess reserves\",\"excess reserves\",\"excess reserves\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"homo economicus\",\"momentum (finance)\",\"momentum (finance)\",\"momentum (finance)\",\"momentum (finance)\",\"fischer black prize\",\"fischer black prize\",\"fischer black prize\",\"samuelson condition\",\"samuelson condition\",\"market mechanism\",\"market mechanism\",\"economic transformation\",\"economic transformation\",\"economic transformation\",\"economic transformation\",\"economic transformation\",\"economic transformation\",\"economic transformation\",\"economic transformation\",\"neo-ricardianism\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"bengt holmstr\\u00f6m\",\"lerner paradox\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"surplus value\",\"bric\",\"bric\",\"bric\",\"bric\",\"w. kip viscusi\",\"inventory bounce\",\"edgeworth binomial tree\",\"john roemer\",\"john roemer\",\"john roemer\",\"john roemer\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public economics\",\"public property\",\"public property\",\"growth stock\",\"growth stock\",\"growth stock\",\"growth stock\",\"growth stock\",\"universe (economics)\",\"nominal yield\",\"nominal yield\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"cournot competition\",\"economics handbooks\",\"georg weizs\\u00e4cker\",\"georg weizs\\u00e4cker\",\"georg weizs\\u00e4cker\",\"georg weizs\\u00e4cker\",\"georg weizs\\u00e4cker\",\"merger simulation\",\"encouraged industry catalogue\",\"forward exchange market\",\"cycle of poverty\",\"cycle of poverty\",\"cycle of poverty\",\"gerschenkron effect\",\"norwegian paradox\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"financial economics\",\"gustav stolper prize\",\"the road to serfdom\",\"the road to serfdom\",\"the road to serfdom\",\"the road to serfdom\",\"the road to serfdom\",\"equalization payments\",\"equalization payments\",\"long-run cost curve\",\"economic base analysis\",\"world economy\",\"world economy\",\"diamond-water paradox\",\"diamond-water paradox\",\"diamond-water paradox\",\"cost of electricity by source\",\"market allocation scheme\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"myron scholes\",\"hiding hand principle\",\"hiding hand principle\",\"hiding hand principle\",\"hiding hand principle\",\"research papers in economics\",\"research papers in economics\",\"extended-hours trading\",\"extended-hours trading\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"intertemporal choice\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"paul romer\",\"credit default option\",\"robert heilbroner\",\"robert heilbroner\",\"robert heilbroner\",\"eugene fama\",\"eugene fama\",\"eugene fama\",\"eugene fama\",\"eugene fama\",\"eugene fama\",\"eugene fama\",\"toothpaste tube theory\",\"methodology of econometrics\",\"time warp edit distance\",\"schelling's segregation model\",\"schelling's segregation model\",\"schelling's segregation model\",\"schelling's segregation model\",\"schelling's segregation model\",\"hicks-tinbergen award\",\"hicks-tinbergen award\",\"economic nationalism\",\"economic nationalism\",\"economic nationalism\",\"economic nationalism\",\"lorenz curve\",\"lorenz curve\",\"lorenz curve\",\"lag operator\",\"least developed countries\",\"least developed countries\",\"tibor\",\"tibor\",\"excess burden of taxation\",\"excess burden of taxation\",\"excess burden of taxation\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"giffen good\",\"economic satiation\",\"productive capacity\",\"economic graph\",\"economic graph\",\"giancarlo corsetti\",\"abnormal profit\",\"civilizing the economy\",\"metcalfe's law\",\"leonid kantorovich\",\"leonid kantorovich\",\"leonid kantorovich\",\"leonid kantorovich\",\"leonid kantorovich\",\"visible hand (economics)\",\"visible hand (economics)\",\"visible hand (economics)\",\"visible hand (economics)\",\"visible hand (economics)\",\"visible hand (economics)\",\"martin hellwig\",\"martin hellwig\",\"list of jewish american economists\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"time series\",\"balassa\\u2013samuelson effect\",\"intensity of preference\",\"base period\",\"economists for peace and security\",\"dispersed knowledge\",\"dispersed knowledge\",\"dispersed knowledge\",\"dispersed knowledge\",\"interprovincial migration in canada\",\"marginal rate of transformation\",\"marginal rate of transformation\",\"marginal rate of transformation\",\"qem\",\"real-world economics review\",\"real-world economics review\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"service economy\",\"import substitution industrialization\",\"import substitution industrialization\",\"import substitution industrialization\",\"men's underwear index\",\"economic power\",\"economic power\",\"reproduction (economics)\",\"reproduction (economics)\",\"economics (textbook)\",\"economics (textbook)\",\"proto-industrialization\",\"two-sided matching\",\"time value of money\",\"time value of money\",\"time value of money\",\"financial innovation\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"utility\",\"samuel von pufendorf\",\"samuel von pufendorf\",\"returns (economics)\",\"returns (economics)\",\"sequential game\",\"sequential game\",\"sequential game\",\"sequential game\",\"sequential game\",\"market-based valuation\",\"pricing kernel\",\"pricing kernel\",\"econtalk\",\"risk premium\",\"risk premium\",\"risk premium\",\"risk premium\",\"convergence (economics)\",\"convergence (economics)\",\"convergence (economics)\",\"convergence (economics)\",\"national agricultural policy center\",\"marginal propensity to consume\",\"marginal propensity to consume\",\"marginal propensity to consume\",\"marginal propensity to consume\",\"list of important publications in economics\",\"list of important publications in economics\",\"list of important publications in economics\",\"list of important publications in economics\",\"list of important publications in economics\",\"list of important publications in economics\",\"list of important publications in economics\",\"list of important publications in economics\",\"rate of return\",\"rate of return\",\"rate of return\",\"sofr\",\"doji\",\"doji\",\"economics terminology that differs from common usage\",\"economics terminology that differs from common usage\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"kenneth arrow\",\"scottish index of multiple deprivation\",\"cumulative prospect theory\",\"index (economics)\",\"index (economics)\",\"index (economics)\",\"index (economics)\",\"index (economics)\",\"index (economics)\",\"economic evaluation of time\",\"robinson crusoe economy\",\"conceptual economy\",\"list of production functions\",\"list of production functions\",\"list of production functions\",\"principles of economics (marshall book)\",\"principles of economics (marshall book)\",\"peak wheat\",\"wilson doctrine (economics)\",\"roll-geske-whaley\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"jel classification codes\",\"national equities exchange and quotations\",\"dynamic pricing\",\"ricardian equivalence\",\"ricardian equivalence\",\"ricardian equivalence\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"john hicks\",\"alpha (finance)\",\"alpha (finance)\",\"output elasticity\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"supply and demand\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"marginal rate of substitution\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"adam smith\",\"fei\\u2013ranis model of economic growth\",\"trygve haavelmo\",\"trygve haavelmo\",\"trygve haavelmo\",\"trygve haavelmo\",\"trygve haavelmo\",\"trygve haavelmo\",\"ak model\",\"heavily indebted poor countries\",\"charles henry hull\",\"charles henry hull\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"index of economics articles\",\"fabrizio zilibotti\",\"fabrizio zilibotti\",\"freelancer\",\"law of increasing costs\",\"big push model\",\"surplus labour\",\"surplus labour\",\"variable rate debt obligation\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"friedrich hayek\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"william vickrey\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"glossary of economics\",\"inframarginal analysis\",\"finance & development\",\"voluntary sector\",\"nava ashraf\",\"nava ashraf\",\"nava ashraf\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"marginalism\",\"privatism\",\"privatism\",\"green job\",\"mesoeconomics\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"john harsanyi\",\"concentration risk\",\"99ers\",\"arbitrage pricing theory\",\"real economy\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"ceteris paribus\",\"edgeworth paradox\",\"woolrich electrical generator\",\"production for profit\",\"ramsey\\u2013cass\\u2013koopmans model\",\"democratic capitalism\",\"private highway\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"opportunity cost\",\"convex preferences\",\"masters in agricultural economics\",\"economic puzzle\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"daniel kahneman\",\"accelerator effect\",\"paradox of thrift\",\"diminishing returns\",\"diminishing returns\",\"economic law\",\"indifference curve\",\"list of unsolved problems in economics\",\"economic data\",\"john rawls\",\"great gatsby curve\",\"substitution effect\",\"elinor ostrom\"]},\"selected\":{\"id\":\"1841\"},\"selection_policy\":{\"id\":\"1840\"}},\"id\":\"1749\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"1719\",\"type\":\"LinearScale\"},{\"attributes\":{},\"id\":\"1821\",\"type\":\"NodesOnly\"},{\"attributes\":{\"formatter\":{\"id\":\"1827\"},\"major_label_policy\":{\"id\":\"1825\"},\"ticker\":{\"id\":\"1659\"},\"visible\":false},\"id\":\"1658\",\"type\":\"LinearAxis\"},{\"attributes\":{\"formatter\":{\"id\":\"1824\"},\"major_label_policy\":{\"id\":\"1822\"},\"ticker\":{\"id\":\"1663\"},\"visible\":false},\"id\":\"1662\",\"type\":\"LinearAxis\"},{\"attributes\":{\"data\":{\"alpha\":[0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75],\"depth\":[1,1,1,0,1,1,1,0,0,1,1,0,1,1,0,1,1,1,1,1,1,1,1,1,1,1,0,1,1,0,1,1,1,0,0,1,1,1,1,0,1,1,0,1,0,1,1,1,1,1,1,0,1,0,1,1,0,1,1,1,1,1,0,1,0,1,1,1,1,1,0,1,0,1,1,1,1,0,0,0,1,1,0,1,1,1,1,1,1,1,1,0,1,0,1,1,1,0,0,1,1,1,1,1,1,0,0,1,1,1,1,1,1,0,1,1,0,1,1,1,0,1,1,0,0,1,1,0,1,0,0,0,1,1,1,1,0,0,1,1,1,1,1,1,0,0,0,1,1,0,1,0,1,1,1,1,1,1,0,1,0,1,0,1,1,0,1,1,1,1,0,1,1,1,1,1,1,0,1,1,1,1,1,0,1,1,1,1,1,1,0,0,1,1,1,1,1,0,1,1,0,0,1,1,1,1,0,1,1,1,1,0,1,1,1,1,1,1,1,0,1,0,1,0,1,1,1,1,1,0,1,1,1,1,1,1,1,0,1,0,1,1,0,1,1,1,0,1,0,0,1,1,1,1,0,1,1,1,1,1,1,1,0,1,1,1,1,1,0,1,0,0,0,1,0,1,1,1,1,0,1,1,0,1,1,1,1,1,1,1,1,1,1,0,0,1,0,1,0,1,1,1,0,1,1,1,1,0,1,1,1,0,1,0,1,1,1,1,0,1,0,1,1,0,0,1,1,1,1,1,0,1,0,1,0,0,0,0,0,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,1,1,0,1,1,1,1,1,1,0,1,0],\"index\":[\"serfdom\",\"sinodonty and sundadonty\",\"cephalic index in cats and dogs\",\"standard cross-cultural sample\",\"human genetic variation\",\"honorary male\",\"ethnolichenology\",\"list of stateless societies\",\"waga sculpture\",\"linguistic linked open data\",\"list of birds displaying homosexual behavior\",\"cultural practice\",\"releasing the spirits: a balinese ceremony\",\"mars needs moms\",\"cognitive anthropology\",\"wedding vow renewal ceremony\",\"psychogeography\",\"ghazi (warrior)\",\"ethnoarchaeology\",\"warrior (character class)\",\"nomadic pastoralism\",\"cephalic index\",\"proverbial phrase\",\"culture hero\",\"minangkabau people\",\"paleopathology\",\"poppet\",\"museum of world culture\",\"ethnozoology\",\"sedentism\",\"population health policies and interventions\",\"edvard westermarck\",\"consumer class\",\"historical behaviour studies\",\"anthropology\",\"1890s in anthropology\",\"taboo (2002 tv series)\",\"nanook of the north\",\"the hunters (1957 film)\",\"exocannibalism\",\"richard gaskin\",\"upper class\",\"postmodernist anthropology\",\"ethnomedicine\",\"hoplology\",\"person\",\"early modern human\",\"john beddoe\",\"welfare culture\",\"mummy of san andr\\u00e9s\",\"vanua\",\"development anthropology\",\"nutritional anthropology\",\"anthrobotics\",\"heide g\\u00f6ttner-abendroth\",\"heterotopia (space)\",\"kalahari debate\",\"manorialism\",\"guatemalan forensic anthropology foundation\",\"village head\",\"peter sloterdijk\",\"museo de antropolog\\u00eda de xalapa\",\"ethnomuseology\",\"media linguistics\",\"reterritorialization\",\"lingeer\",\"metalanguage\",\"nudity\",\"list of visual anthropology films\",\"androcentrism\",\"deep history\",\"f. g. bailey\",\"alliance theory\",\"people\",\"society for economic anthropology\",\"homo faber\",\"heritage commodification\",\"structural endogamy\",\"biocultural diversity\",\"hunting hypothesis\",\"displacement (linguistics)\",\"usc center for visual anthropology\",\"promiscuity\",\"magnate\",\"naturalistic disease theories\",\"trash doves\",\"orthograde posture\",\"human ethology\",\"hong kong honours system\",\"gallowglass\",\"argentine forensic anthropology team\",\"warrior\",\"high culture\",\"biocultural anthropology\",\"arthur evans\",\"aparna rao\",\"moana (1926 film)\",\"sympathetic magic\",\"critical medical anthropology\",\"prenatal hormones and sexual orientation\",\"marriage of the virgin\",\"martti olavi siirala\",\"list of mammals displaying homosexual behavior\",\"podom\",\"hobby\",\"typology (anthropology)\",\"rossville points\",\"multimodal anthropology\",\"human universals\",\"logical form (linguistics)\",\"riane eisler\",\"joan roughgarden\",\"museo nacional de antropolog\\u00eda (madrid)\",\"female promiscuity\",\"logophonetic\",\"business magnate\",\"frazer lecture\",\"fallen woman\",\"cultural survival\",\"list of anthropologists\",\"anthropology of art\",\"matrilocal residence\",\"linguistic description\",\"paleoradiology\",\"cognized environment\",\"gotai\",\"list of matrilineal or matrilocal societies\",\"human behavioral ecology\",\"auspicious wedding dates\",\"neuroanthropology\",\"cultural group selection\",\"high-altitude adaptation in humans\",\"kriza j\\u00e1nos ethnographic society\",\"laura boulton\",\"utinahica\",\"gay, straight, and the reason why\",\"educational anthropology\",\"official cantonese translations of english names for british officials\",\"travel behavior\",\"wedding reception\",\"martial race\",\"consummation\",\"culture theory\",\"human ecology\",\"cultural anthropology\",\"transcultural nursing\",\"postpartum confinement\",\"helmuth plessner\",\"maloca\",\"ethnoornithology\",\"osteology\",\"semiotic anthropology\",\"topic and comment\",\"human genetic clustering\",\"names for the human species\",\"women who have sex with women\",\"cultural radicalism\",\"2000s in anthropology\",\"skhul and qafzeh hominins\",\"cultural nationalism\",\"headhunting\",\"maceration (bone)\",\"grave goods\",\"area studies\",\"cultural mapping\",\"digging stick\",\"peasant\",\"hypnopompic\",\"n\\u01c3ai, the story of a \\u01c3kung woman\",\"shell money\",\"theatre state\",\"possible world\",\"endocast\",\"leveling mechanism\",\"human terrain system\",\"viking fund medal\",\"hunter-gatherer\",\"paleoanthropology\",\"das mutterrecht\",\"slavery\",\"cultural memory\",\"population health\",\"museum of mankind\",\"race and intelligence\",\"museu da lourinh\\u00e3\",\"mandailing people\",\"language\",\"muted group theory\",\"faye v. harrison\",\"recent human evolution\",\"proto-malay\",\"hau (anthropology)\",\"poverty class\",\"the witch-cult in western europe\",\"marija gimbutas\",\"dominic boyer\",\"moralia\",\"online ethnography\",\"diane bell (anthropologist)\",\"max scheler\",\"polygyny\",\"australian aboriginal kinship\",\"mosuo women\",\"linguistics in science fiction\",\"linguistic system\",\"geography of media and communication\",\"ethnobiology\",\"netnography\",\"literacy\",\"status group\",\"magical death\",\"endocannibalism\",\"gaia philosophy\",\"gate crashing\",\"homosexual behavior in animals\",\"1910s in anthropology\",\"biblical patriarchy\",\"craig stanford\",\"middlebrow\",\"guanche mummies\",\"geography of antisemitism\",\"off the verandah\",\"white wedding\",\"list of years in anthropology\",\"bertil lundman\",\"squib (writing)\",\"serer-ndut people\",\"jerzy adam kowalski\",\"census of india prior to independence\",\"sodality (social anthropology)\",\"proverb\",\"soul dualism\",\"men who have sex with men\",\"cultural movement\",\"oikofobie. de angst voor het eigene\",\"philosophy of life\",\"serer maternal clans\",\"americanoid\",\"toloy\",\"ceremony\",\"serer people\",\"fount of honour\",\"shrunken head\",\"andean civilizations\",\"hoi polloi\",\"tropical geography\",\"cornell-peru project\",\"outline of culture\",\"biological anthropology\",\"feminist anthropology\",\"religion\",\"linguistics\",\"disability anthropology\",\"tonograph\",\"anthropology of institutions\",\"gloss (annotation)\",\"health geography\",\"confucian classes\",\"georg pfeffer\",\"evolutionary studies institute\",\"womyn's land\",\"list of timothy asch films\",\"wedding\",\"deep play: notes on the balinese cockfight\",\"maya research program\",\"woman, culture, and society\",\"patrilocal residence\",\"angkola people\",\"anthropological criminology\",\"lila: an inquiry into morals\",\"direct historical approach\",\"friction of distance\",\"classificatory kinship\",\"kluet people\",\"chinese kinship\",\"society of anthropology of paris\",\"solano people\",\"age set\",\"theory of language\",\"neo-nationalism\",\"list of women anthropologists\",\"moving anthropology student network\",\"medical anthropology\",\"honeymoon\",\"unsaid\",\"biology and sexual orientation\",\"the hebrew goddess\",\"les ma\\u00eetres fous\",\"1990s in anthropology\",\"ogilvie professor of human geography\",\"michelle rosaldo book prize\",\"journal of ethnobiology\",\"canadian honours system\",\"urban revolution\",\"fordisc\",\"lingeer ngon\\u00e9 di\\u00e8ye\",\"anthropological survey of india\",\"constantin noica\",\"archaeology\",\"cultural resource management\",\"raptio\",\"prickly paradigm press\",\"performance studies\",\"sexual inversion (sexology)\",\"kshatriya\",\"ethnic religion\",\"ethnoichthyology\",\"cha\\u00eene op\\u00e9ratoire\",\"hawaiian ethnobiology\",\"reciprocity (cultural anthropology)\",\"anthropometric history\",\"negroid\",\"ceremonial pole\",\"ecological anthropology\",\"history of anthropometry\",\"mus\\u00e9e des confluences\",\"australian institute of aboriginal and torres strait islander studies\",\"trobriand islands\",\"contrast set\",\"communicative dynamism\",\"cognitive archaeology\",\"rudolf virchow award\",\"forensic facial reconstruction\",\"bibliography of anthropology\",\"lambda alpha\",\"personal life\",\"bumiputera (malaysia)\",\"development geography\",\"nomads of the longbow\",\"non-representational theory\",\"applied anthropology research methods\",\"children's geographies\",\"koteka\",\"apuli\",\"darwinian anthropology\",\"nations and iq\",\"circumscription theory\",\"hill people\",\"emic and etic\",\"donor class\",\"economic mobility\",\"ethnoscape\",\"cabang atas\",\"pitt rivers museum\",\"zooarchaeology\",\"heel\\u2013ball index\",\"linguistic anthropology\",\"neolinguistics\",\"gaonburha\",\"cultural relativism\",\"mus\\u00e9e de l'homme\",\"underclass\",\"encyclopedia of anthropology\",\"male state\",\"museum of archaeology and anthropology, university of cambridge\",\"the white goddess\",\"ethnopediatrics\",\"theta criterion\",\"university of tennessee anthropological research facility\",\"list of animals displaying homosexual behavior\",\"linguistic relativity\",\"anthropological index online\",\"society for medical anthropology\",\"primitivism\",\"metanoia (psychology)\",\"susto\"],\"node_colour\":[\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\",\"#FDE724\"],\"node_sizes\":[3.0,2.0,0.25,2.0,1.0,0.25,2.25,0.25,0.25,0.25,1.5,3.25,0.25,0.0,3.5,1.5,1.5,0.0,4.5,0.25,2.0,1.0,0.75,3.25,1.25,1.75,0.75,0.0,4.0,2.25,0.5,0.75,0.75,0.5,35.0,0.25,0.0,3.0,1.0,0.5,0.25,2.5,2.0,5.0,0.25,1.5,2.25,1.5,3.25,0.25,0.25,4.0,4.75,0.25,0.0,0.0,0.25,0.75,0.25,0.25,0.5,1.0,4.0,0.5,0.0,1.25,0.75,0.5,1.5,1.25,0.75,1.5,9.5,5.25,0.0,1.0,2.5,0.0,0.5,1.5,0.5,0.25,2.75,2.0,0.75,0.25,0.25,1.0,0.5,0.25,0.5,3.0,4.5,1.0,2.0,0.5,0.75,0.5,1.75,0.75,0.5,0.0,1.5,0.25,0.75,1.5,0.5,0.25,1.25,0.75,0.5,0.25,0.5,1.5,0.25,3.75,0.25,0.5,0.25,0.75,4.5,2.25,2.75,0.75,0.25,0.25,2.0,1.25,0.25,3.0,1.25,0.75,1.25,0.5,0.25,0.0,0.5,0.5,0.5,1.25,1.5,1.5,11.25,5.5,20.25,3.25,0.0,0.25,0.25,2.5,3.0,2.0,0.75,0.25,1.0,1.0,4.0,0.25,0.5,3.75,0.25,0.5,1.5,2.75,3.5,1.25,3.75,0.0,2.0,2.5,1.5,0.5,0.25,1.5,0.75,0.5,3.25,3.25,0.5,4.5,3.25,0.5,2.5,0.75,0.25,0.75,11.25,0.25,0.5,0.75,1.0,0.25,1.25,0.25,1.25,0.25,0.5,3.5,1.25,0.75,5.5,1.25,1.25,0.5,0.0,1.0,5.75,2.25,2.5,1.75,0.5,0.25,0.5,0.25,2.5,0.5,0.25,0.25,0.25,0.5,0.0,0.0,1.25,2.0,1.5,0.25,1.25,0.0,0.25,0.25,0.75,0.5,0.75,4.25,0.25,0.5,1.25,0.25,1.0,1.25,2.0,0.25,0.5,0.5,0.75,0.25,0.25,4.25,7.5,5.0,16.75,10.0,0.75,0.25,2.0,0.25,1.0,1.5,0.25,0.25,0.75,0.25,2.75,0.25,0.25,0.5,1.5,0.5,0.75,0.25,0.5,0.25,1.25,0.5,1.0,0.25,0.25,1.5,2.25,0.75,1.0,0.25,5.0,1.75,0.75,1.5,0.75,0.5,0.5,0.0,0.25,0.25,0.25,0.75,0.5,1.25,0.25,1.25,11.0,0.5,0.75,0.75,6.75,0.0,3.5,2.5,3.0,0.5,0.25,2.0,0.25,1.5,0.75,4.75,3.25,0.25,0.75,1.5,0.25,0.75,0.75,0.75,2.0,3.5,0.25,1.25,1.0,1.5,0.25,2.0,0.75,0.25,1.75,1.0,0.5,0.5,1.5,0.5,7.0,1.0,0.25,0.25,0.75,1.25,3.75,0.75,3.25,0.25,0.25,10.5,0.75,1.75,0.25,0.0,1.5,0.5,0.25,0.5,0.25,1.0,2.0,1.25,2.0,0.0,0.0,0.5],\"parent\":[\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\",\"anthropology\"]},\"selected\":{\"id\":\"1843\"},\"selection_policy\":{\"id\":\"1842\"}},\"id\":\"1680\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"1724\",\"type\":\"BasicTicker\"},{\"attributes\":{},\"id\":\"1667\",\"type\":\"WheelZoomTool\"},{\"attributes\":{},\"id\":\"1802\",\"type\":\"Title\"},{\"attributes\":{},\"id\":\"1812\",\"type\":\"NodesOnly\"},{\"attributes\":{},\"id\":\"1666\",\"type\":\"PanTool\"},{\"attributes\":{\"source\":{\"id\":\"1749\"}},\"id\":\"1751\",\"type\":\"CDSView\"},{\"attributes\":{},\"id\":\"1825\",\"type\":\"AllLabels\"},{\"attributes\":{\"axis\":{\"id\":\"1662\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"1665\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"1669\",\"type\":\"ResetTool\"},{\"attributes\":{\"source\":{\"id\":\"1684\"}},\"id\":\"1686\",\"type\":\"CDSView\"},{\"attributes\":{\"text\":\"Network for discipline: anthropology\",\"text_font_size\":\"12pt\"},\"id\":\"1677\",\"type\":\"Title\"},{\"attributes\":{\"above\":[{\"id\":\"1677\"}],\"below\":[{\"id\":\"1658\"}],\"center\":[{\"id\":\"1661\"},{\"id\":\"1665\"}],\"height\":500,\"left\":[{\"id\":\"1662\"}],\"renderers\":[{\"id\":\"1678\"}],\"title\":{\"id\":\"1804\"},\"toolbar\":{\"id\":\"1671\"},\"width\":500,\"x_range\":{\"id\":\"1649\"},\"x_scale\":{\"id\":\"1654\"},\"y_range\":{\"id\":\"1650\"},\"y_scale\":{\"id\":\"1656\"}},\"id\":\"1651\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{},\"id\":\"1732\",\"type\":\"WheelZoomTool\"},{\"attributes\":{},\"id\":\"1827\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"above\":[{\"id\":\"1742\"}],\"below\":[{\"id\":\"1723\"}],\"center\":[{\"id\":\"1726\"},{\"id\":\"1730\"}],\"height\":500,\"left\":[{\"id\":\"1727\"}],\"renderers\":[{\"id\":\"1743\"}],\"title\":{\"id\":\"1802\"},\"toolbar\":{\"id\":\"1736\"},\"width\":500,\"x_range\":{\"id\":\"1714\"},\"x_scale\":{\"id\":\"1719\"},\"y_range\":{\"id\":\"1715\"},\"y_scale\":{\"id\":\"1721\"}},\"id\":\"1716\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{\"axis\":{\"id\":\"1658\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"1661\",\"type\":\"Grid\"},{\"attributes\":{\"text\":\"Network for discipline: economics\",\"text_font_size\":\"12pt\"},\"id\":\"1742\",\"type\":\"Title\"},{\"attributes\":{},\"id\":\"1808\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"graph_layout\":{\"3g (countries)\":[-311.18354831515006,39.01166315910959],\"99ers\":[75.04082613430239,-81.47447801191012],\"abnormal profit\":[-143.15232715372065,39.96520258732154],\"accelerator effect\":[77.93431467903353,-54.775894237346996],\"adam smith\":[19.490581748053426,-3.0552359458661207],\"ad\\u2013ia model\":[87.08771178543131,-57.10634849254432],\"ak model\":[84.35401046944608,-102.03990116490631],\"alpha (finance)\":[-224.97776773333203,-333.9358194302896],\"alternative financial service\":[65.688559803228,-259.17322782642026],\"american system of manufacturing\":[-57.60492461890382,1327.9712047923788],\"analysis of rhythmic variance\":[151.98792046391665,-270.6562942764755],\"anarcho-capitalism\":[54.65480029265583,63.72852157625811],\"andrea weber\":[-9.422132715286972,-200.30944938040153],\"ap microeconomics\":[-139.64080114918508,-11.585061980525213],\"arbitrage pricing theory\":[-176.18787456006567,-290.39611559280326],\"arif ahmed (philosopher)\":[-740.3747118066631,772.2527271397869],\"armchair theorizing\":[-860.0677710289971,-672.3302410560137],\"arrow's impossibility theorem\":[179.86762322083874,36.97032592458986],\"asset specificity\":[123.98650348340577,66.52708804617984],\"assume a can opener\":[-42.09809361601858,-17.66433012933174],\"auction theory\":[276.09481223553684,-168.06933367590509],\"austerity: the history of a dangerous idea\":[184.29191608719637,-140.29824375636605],\"autonomous consumption\":[22.035661054697144,-163.86213026631114],\"average fixed cost\":[-160.8893344176335,-9.887077914633943],\"average variable cost\":[-161.57615527665658,-4.689655247245645],\"backus\\u2013kehoe\\u2013kydland puzzle\":[-106.16588010316285,-225.62496057855344],\"backward bending supply curve of labour\":[-99.88284889391758,68.08130904691146],\"balassa\\u2013samuelson effect\":[-124.2098974390299,79.6395086863106],\"base period\":[-113.7098595836272,49.964680980444584],\"beatrice cherrier\":[-68.74307439875736,-89.3720319812983],\"beckstrom's law\":[-192.09574654446476,174.28613813636528],\"benefit financing model\":[-211.27431386425613,-99.02325720697038],\"bengt holmstr\\u00f6m\":[204.6757785228289,-88.8790264398886],\"benjamin moll\":[247.84308694938778,8.294581977865318],\"benny moldovanu\":[276.8209672612747,-267.052528839866],\"bertrand competition\":[227.0184968641399,27.25667914509842],\"bertrand paradox (economics)\":[208.5397998413217,39.60299514126222],\"bertrand russell\":[81.06609561639598,165.38369774408477],\"beveridge curve\":[75.15834031161096,-148.96423226494684],\"big push model\":[-61.87961511071133,-29.607524193282106],\"binomial options pricing model\":[78.03832439441636,-339.1984215578614],\"bipu\":[41.648054343048486,1515.5532804603617],\"bishop\\u2013cannings theorem\":[282.664211507563,27.68243762491311],\"black hole bomb\":[444.07681175517223,1028.8300995120476],\"black\\u2013derman\\u2013toy model\":[177.096357815304,-497.0722428593418],\"blue economy\":[-77.80757289395723,-49.78228715115159],\"bowley's law\":[119.19171808906323,30.942160823324638],\"breakout (technical analysis)\":[-291.98191766583034,-400.11526493552606],\"bric\":[-269.69920108470257,27.336516176764214],\"b\\u00e9la balassa\":[-172.5860048647594,109.65251242792671],\"capital cost\":[-134.86660183452693,-18.120482064368158],\"carbon bubble\":[-276.46320529247055,-375.3073930914545],\"cash crop\":[-139.63586482655225,72.97973706573322],\"centre for appropriate technology (australia)\":[-779.0125765390434,799.4113623475537],\"ceteris paribus\":[-64.40520728482971,66.5458679080892],\"charles henry hull\":[-10.816523472692495,50.10448664043288],\"charlie bean (economist)\":[194.9560053429382,-382.7172758562943],\"circular flow of income\":[-14.789491499795858,100.65176303610659],\"civilizing the economy\":[0.47988184732202543,-58.02976820404529],\"clive granger\":[197.0508993354379,-133.50095859655391],\"cobweb model\":[13.498092446316047,93.18388573533191],\"colonial origins of comparative development\":[119.13167299297223,70.21834433049133],\"commercialism\":[70.61974881841071,-1304.575880198086],\"commodity chain\":[596.6446966394515,-951.7180465526761],\"commodity credit corporation\":[-839.7294968557856,1023.6845362659991],\"community-supported agriculture\":[-163.7171035501721,-20.771157953553466],\"concentration risk\":[-142.9287898903569,-238.2061249735491],\"conceptual economy\":[54.8734299827328,189.73513337275378],\"consumer debt\":[58.44929739433989,-215.80433443982008],\"consumption distribution\":[-15.09994514661318,364.1594677966252],\"contingent claim analysis\":[-38.60245521050248,-199.4170968621948],\"convergence (economics)\":[-60.43172394709709,-60.041303269908774],\"convex preferences\":[-130.9772827117535,44.69521145957221],\"corn exchange\":[-233.05272741019667,5.07101587217504],\"corner solution\":[-95.06373350721381,36.72068369113846],\"cost of electricity by source\":[-330.13347937361715,-198.1390441374528],\"cost-weighted activity index\":[-165.71410674670759,135.54488726833787],\"cournot competition\":[173.1256882227684,21.753726696633304],\"credit default option\":[68.84067379335309,-331.2886091949555],\"criticism of the federal reserve\":[-685.9027950791623,-872.5342712788956],\"cumulative process\":[-11.319741413517711,135.70864705259783],\"cumulative prospect theory\":[24.421112067029664,-146.25230921424932],\"cura annonae\":[879.7918289950995,-640.8561684295634],\"cycle of poverty\":[-316.10385734957583,108.21882365318416],\"daniel kahneman\":[182.50809815894843,-52.59880576913005],\"daniel mcfadden\":[240.6080917380733,-72.29028497972949],\"david laidler\":[176.49994582812585,-146.65213909658476],\"debtocracy\":[1259.6587150117211,82.27010351424057],\"deflator\":[-154.70033218088324,66.41301396422924],\"demand curve\":[-111.99971711918751,23.28013841550263],\"demand shaping\":[-91.51744032146985,188.65239131224405],\"democratic capitalism\":[45.144075753376896,80.20613414492105],\"diamond-water paradox\":[41.28895164895202,97.32576831196772],\"differentiated bertrand competition\":[159.16608610844796,77.69286522033482],\"diminishing returns\":[-74.97685331181755,-33.70348730639872],\"discouraged worker\":[90.9280278344284,-160.56500390660895],\"discrete choice\":[281.73420019736744,-123.67202135827675],\"dispersed knowledge\":[3.1025129411924994,-106.51726671436977],\"dixit\\u2013stiglitz model\":[-163.1779968061255,143.29445341522904],\"doji\":[-286.9870810332855,-393.8370979053407],\"dollar voting\":[-4.637044574512303,-164.42869751881605],\"donchian channel\":[-281.2256591748031,-400.9552098379109],\"downs\\u2013thomson paradox\":[94.93064208823509,193.1265645749517],\"drought tolerance\":[970.674607304096,-567.0214686876645],\"duck curve\":[-877.058608354464,678.8969076804732],\"dynamic discrete choice\":[246.23887050799948,-142.47961284102342],\"dynamic pricing\":[-64.03357561362027,138.5142387983462],\"dynamical system\":[15.584038129888532,-128.72830370454534],\"eco-capitalism\":[64.96320859649623,63.00197036499715],\"ecodynamics\":[-265.0028543249569,1065.6115542012292],\"ecological economics (journal)\":[-978.7201385921762,478.7167370700109],\"economic base analysis\":[-58.953220470886336,104.26508620445402],\"economic data\":[110.9066893762203,1.9661808371384535],\"economic evaluation of time\":[263.04447776645,-54.627165618596074],\"economic graph\":[-28.721492985694223,114.54006238873437],\"economic humanitarianism (ra\\u00eblianism)\":[110.2396463413365,161.81129767505317],\"economic indicator\":[14.88533113533703,28.744253685262933],\"economic law\":[-1180.8545974975157,-787.2064011008915],\"economic model\":[-5.851542119517751,-29.825582434631116],\"economic nationalism\":[-64.97998580653109,100.61095980008727],\"economic power\":[-29.14794508639726,201.88975192701986],\"economic puzzle\":[-144.61391289888286,-264.98809312647586],\"economic satiation\":[-102.65281390388202,58.90476867306234],\"economic transformation\":[56.5124311641914,2.8016929407198523],\"economics (textbook)\":[0.6318339062524873,124.08474994333835],\"economics handbooks\":[-176.66162101866837,-76.07910580794805],\"economics of science\":[-166.57444032786245,-44.713118592552256],\"economics terminology that differs from common usage\":[-100.2250313074828,39.70011385822757],\"economists for peace and security\":[248.3864816229896,-36.61491018066889],\"econophysics\":[72.35712508569397,3.100442514087198],\"econtalk\":[132.5192756851212,-95.20558199026064],\"edgeworth binomial tree\":[86.7961922990129,-366.28526561368653],\"edgeworth box\":[60.670790402540774,104.07407867085274],\"edgeworth paradox\":[168.68976994070724,104.39057574943942],\"efficiency wage\":[122.70708120015588,-42.271611301834405],\"el centro integrado de technologia appropriada\":[1027.4544567725418,-486.44078004541575],\"electronic funds transfer\":[-72.96574519668964,262.40311479685835],\"elhanan helpman\":[185.6179714785933,-22.482107773602703],\"elinor ostrom\":[103.11738418042084,-49.34414839614795],\"encouraged industry catalogue\":[-476.5442616292437,-1223.3057723956229],\"environment minister\":[-255.51113304017966,1108.2316353414003],\"eonia\":[1317.4388591065554,-792.2402622231197],\"equalization payments\":[44.04953536490029,583.6495784427203],\"equity home bias puzzle\":[-100.06182652099302,-232.6795771972342],\"equity premium puzzle\":[-155.49551876711422,-269.55911183075614],\"eric french (professor)\":[-62.981682145197645,-93.51284793740025],\"erwin plein nemmers prize in economics\":[260.19228951574746,-112.61642059308203],\"eugene fama\":[153.5996370740759,-115.32449142515337],\"euronia\":[1314.3748129059327,-786.0412492744657],\"evolutionary game theory\":[216.34508945274095,5.72693239834845],\"excess burden of taxation\":[-4.438297263871064,104.36458624107387],\"excess reserves\":[11.918013223109421,102.56139776292902],\"experimental economics\":[19.633268353222835,-29.63382879209805],\"extended-hours trading\":[-238.85745357139834,-337.8493185818694],\"fabrizio zilibotti\":[183.36267236289498,-349.48658958990364],\"factor endowment\":[174.47405779564926,239.43927916081392],\"factors of production\":[-54.96642161817043,120.60409128469566],\"fama\\u2013french three-factor model\":[-59.82760938007529,-228.0033468342624],\"farshid jamshidian\":[218.99303331006797,-192.22993150494509],\"fei\\u2013ranis model of economic growth\":[-49.44802869619269,-2.67324317777171],\"feldstein\\u2013horioka puzzle\":[-98.37785373414214,-225.77813938866967],\"finance & development\":[130.84047751408582,-157.30542698113854],\"financial economics\":[-23.198604308192042,-151.18962933191563],\"financial innovation\":[4.249504402909249,-28.860399247093937],\"financial models with long-tailed distributions and volatility clustering\":[31.87904570922133,-249.5299307173517],\"first world\":[-267.04031559153475,-23.590592129672398],\"fischer black prize\":[40.597168252832155,-201.63925988315233],\"food processing\":[70.08206939484818,244.52953782770098],\"foreclosure rescue\":[-1059.978553177729,390.56537781130874],\"foreign agricultural service\":[-845.8663479389346,1026.7682296567507],\"forward exchange market\":[-1.4575250719798867,143.14464790377727],\"forward premium anomaly\":[-125.29305191879678,-266.10931933514064],\"forward price\":[67.2527457121744,-339.2223247012771],\"foundation for european economic development\":[168.36683631986975,-142.38103674817987],\"fractional-reserve banking\":[-51.80455769746861,201.06310168239457],\"francesco caselli\":[82.14742571860464,-1169.4647846257203],\"freelancer\":[1106.0175908045144,885.5697886450912],\"friedrich hayek\":[75.1198029172213,-30.513212231302248],\"gabor\\u2013granger method\":[236.49795580477834,-168.31838307664745],\"garman-kohlhagen model\":[64.31215610374241,-317.17888659614107],\"georg weizs\\u00e4cker\":[140.45043442363382,-40.624895738132516],\"george hilton (historian)\":[671.050901089651,883.8191729237849],\"georgism\":[35.325438746114,27.341010581394908],\"gerald shove\":[-131.7339281826922,-53.14650687287464],\"gerschenkron effect\":[-32.3238324741671,71.91500231641488],\"giancarlo corsetti\":[-82.69894793618617,-134.66907467101433],\"giffen good\":[79.14839327353138,137.55249115217708],\"global retirement index\":[-310.3118126241718,33.074800251969315],\"global social mobility index\":[1219.6076948225534,230.38575411377386],\"glossary of economics\":[-75.4865487239225,-6.944124569146162],\"gold-collar worker\":[88.92753472036338,-176.98342841235691],\"google finance\":[-826.9893497588788,-713.9654012949578],\"great gatsby curve\":[1106.362979936839,-924.6706512398787],\"green job\":[-874.8662453756123,1132.036404681916],\"growth stock\":[-220.7469799298828,-323.1987573956208],\"guido tabellini\":[112.46721275461837,-253.18439289197175],\"guns versus butter model\":[-181.72489989283073,96.86694331751447],\"gustav stolper prize\":[251.22769429152547,-230.88190030549356],\"hanging man (candlestick pattern)\":[-287.4047318731196,-405.8252851452135],\"harris\\u2013todaro model\":[-52.27444483154273,104.227151841131],\"heavily indebted poor countries\":[-282.33937967015004,16.796947730429334],\"heckscher\\u2013ohlin model\":[-103.78235272126632,109.27554929682572],\"hemline index\":[21.11682878027255,163.49158069665452],\"hicks-neutral technical change\":[-33.964894628111615,99.28427458887302],\"hicks-tinbergen award\":[119.43163544518646,-239.40130596873414],\"hiding hand principle\":[154.18814155616536,-40.22703035758532],\"history of capitalist theory\":[66.22174039535058,77.41205377644785],\"history of microeconomics\":[11.124521769103355,48.05161941432546],\"homo economicus\":[131.3783546736404,-66.93876249655298],\"hotelling's law\":[116.54384683387221,84.9085723547936],\"housing affordability index\":[-849.1923661040793,723.5312928569381],\"hubbert peak theory\":[-255.0189551065542,-94.23565873007873],\"human development index\":[-223.1188596855848,35.31182434764365],\"i-spread\":[219.8296024858828,-564.1398315751061],\"icarus paradox\":[104.35783662710591,186.34555883653908],\"identity economics\":[-72.61015236034729,106.2162237909718],\"identity line\":[54.65057597060338,-158.74287566756232],\"implicit cost\":[34.929926537570566,-15.104884570707176],\"import substitution industrialization\":[-78.48156269434472,93.07751179330639],\"impossible trinity\":[-126.24038480912925,-115.55293609578575],\"in kind\":[-33.31261180297186,88.00553505164596],\"index (economics)\":[49.90757088170775,-18.933052686166285],\"index of economics articles\":[-30.953074928262364,55.00395187924471],\"indifference curve\":[-78.86947633622614,67.25316892899504],\"indirect inference\":[112.17058519190134,-178.7405901893597],\"induced consumption\":[41.026748799084466,-183.86525908585946],\"industry (economics)\":[-1257.6049150793594,161.00116143941048],\"inertial inflation\":[-169.6684873398172,140.43717752888995],\"infant industry argument\":[-112.55179994964718,143.43948710282186],\"information economics\":[-33.20131314271355,4.89161760033463],\"inframarginal analysis\":[-31.977394657698387,-29.364868394576874],\"inside contracting\":[-58.43045180395178,1320.6116702395225],\"institute for international economic studies\":[190.13017436873918,-386.28118394830295],\"intensity of preference\":[188.32371245382345,28.19612576218612],\"internality\":[283.18342953176517,-36.32862197706049],\"international economics\":[-23.254178380230307,-71.25212388357966],\"interprovincial migration in canada\":[24.86282307310964,526.1412536610328],\"intertemporal choice\":[-95.42939735468428,12.0559706945796],\"intertemporal equilibrium\":[-65.26516174532979,80.83534340140356],\"inventory bounce\":[-133.80632309712283,-11.487507820666346],\"investment arbitration\":[-1369.3736118186016,-224.52665285529207],\"ioana marinescu\":[115.92204630600288,1436.879146996483],\"istv\\u00e1n hont\":[-46.855868279690014,91.11878528072747],\"is\\u2013lm model\":[51.4191688085504,-43.179521000271485],\"ithaca hours\":[-67.67639553779011,112.72723833609193],\"iza institute of labor economics\":[198.47748814733842,-351.5116035353636],\"j curve\":[1115.243917908894,331.9256582159994],\"jacob hollander\":[240.56461112184653,-32.8129837289703],\"jane semeleer\":[158.65261499365332,-206.03406203861545],\"jel classification codes\":[-51.33074048733154,-41.27806758494961],\"jensen prize\":[3.1562711031554116,-213.9616482566345],\"jhai foundation\":[1332.6677828896989,93.45745291127865],\"john harsanyi\":[211.00179000689724,-14.702894873957582],\"john hicks\":[34.62059149701906,-52.54464913192623],\"john rawls\":[131.93310032072847,179.44623806926657],\"john roemer\":[63.38224201540259,215.26718840016653],\"joint organisations data initiative\":[-311.14422381753144,-1248.3529218356002],\"joint product pricing\":[-96.03924710218429,49.43427010720391],\"joseph schumpeter\":[92.42796043093054,5.837112120751617],\"journal of behavioral and experimental economics\":[45.94239526496908,-66.76843261881731],\"journal of public economics\":[1.2803023187608453,-150.59570323721007],\"journal of the european economic association\":[185.15999528357588,-319.83272855575063],\"kenneth arrow\":[119.51982048478925,-20.389545371183253],\"kenneth boulding's evolutionary perspective\":[-960.1915102581477,-562.2170735782986],\"keynesian cross\":[45.969084252219474,-76.97685044727415],\"keynes\\u2013ramsey rule\":[-89.3943372088441,-56.196511803617916],\"kiyotaki\\u2013moore model\":[9.873963047831538,-113.75430814245134],\"knowledge assessment methodology\":[27.03568571875711,115.12791099602126],\"knowledge economy\":[25.482864677705695,55.906786432805504],\"kuznets curve\":[-262.492255340102,-178.53256984262958],\"k\\u00e4the leichter\":[367.4106459415114,-1279.8900948604246],\"l'empire de la honte\":[724.0001357214586,838.3877486480529],\"lag operator\":[147.13016354586054,-267.7996354206783],\"land management\":[-673.6960531759329,-834.9120794780262],\"late trading\":[-266.83679968233906,-366.4555525102869],\"law of increasing costs\":[-37.79786894482164,-53.39380364120241],\"law of rent\":[96.43536290917311,29.4251753339489],\"law of supply\":[-57.35728475939765,-17.70680890435495],\"lawrence summers\":[147.42876021160734,-88.22808018682277],\"learning economy\":[37.91999038765498,113.60797559675875],\"least developed countries\":[-251.9333931705405,22.29123554307169],\"least-cost theory\":[-1179.9891086049402,453.1541619795267],\"leonid kantorovich\":[225.75880642167832,-92.70474498044855],\"leontief paradox\":[19.145256572958758,84.96145147360018],\"leontief production function\":[-76.91500239968096,176.7897810421973],\"lerner paradox\":[98.36920031645113,184.27903521342964],\"lipstick index\":[21.76623304928881,98.05635287421562],\"liquidity premium\":[-189.76932466591893,-192.58903871285608],\"list of economics films\":[1263.6350853958652,81.9334624378039],\"list of financial economists\":[185.52540261140004,-155.92195203700072],\"list of important publications in economics\":[12.11154865518396,-48.45725132442368],\"list of jewish american economists\":[206.70002222236883,-131.2805556934585],\"list of production functions\":[-65.20301421287802,152.61051980807989],\"list of special economic zones\":[-361.1134437487232,129.02221118386834],\"list of unsolved problems in economics\":[-72.0433326456709,-172.22754731579866],\"local multiplier effect\":[-548.3292726835205,-953.0634524540171],\"long-run cost curve\":[-88.969372312236,138.35222044348785],\"loopco\":[-59.27338281662761,-79.21607565945004],\"lorenz curve\":[-19.337496324353836,322.7107459096108],\"low-volatility anomaly\":[-32.93476528973908,-223.33985660313553],\"lump-sum tax\":[-12.907748131740677,163.7684272913898],\"macroeconomic model\":[44.19497422675644,-99.65502925505331],\"macroeconomic regulation and control\":[-468.07532707453856,-1226.8695741548229],\"mainstream economics\":[-18.099497306454428,-2.759943623330896],\"mandeville's paradox\":[71.42951191864185,113.5504248720318],\"marginal factor cost\":[-83.28088208815986,170.67491670833886],\"marginal propensity to consume\":[-40.18319130707968,-103.94987834452746],\"marginal propensity to import\":[-75.37836358847025,-146.390431021499],\"marginal rate of substitution\":[-115.00110219222228,33.609745736857434],\"marginal rate of transformation\":[-109.09352701003964,97.45663183702322],\"marginal return\":[-143.50451140427396,-102.21843063858404],\"marginalism\":[0.5151928888914304,21.976494248803863],\"market allocation scheme\":[0.9818464179376699,-39.570511041622154],\"market anomaly\":[-195.95788713119572,-282.4758817221032],\"market for corporate control\":[-344.7426840478538,-194.4200389377505],\"market mechanism\":[46.49922850429972,98.02655744052106],\"market microstructure\":[-44.492708156646046,-196.93452058243972],\"market rate\":[-13.4950823204741,141.08174453557174],\"market trend\":[-255.3540171101869,-355.3254652159955],\"market-based valuation\":[-186.56433185876043,-197.72557264309637],\"martin hellwig\":[196.4162902156885,-299.4926681256654],\"masters in agricultural economics\":[-1310.0757940254066,318.01273484519],\"maturity transformation\":[-68.49365309779641,251.3297948113371],\"men's underwear index\":[25.620143728710453,210.81754053903384],\"merger simulation\":[128.78708279061186,83.11832248542338],\"mesoeconomics\":[173.8574054074363,58.106262766416386],\"metcalfe's law\":[-196.63614310356758,177.75078787482076],\"methodology of econometrics\":[142.9121034480933,-114.22371956364545],\"michael albert\":[52.83262178351172,113.9981067003586],\"michael spence\":[165.91003444837926,-56.23937004199516],\"momentum (finance)\":[-242.0007067924752,-354.4116305470062],\"mundell\\u2013tobin effect\":[2.499542348061447,-130.74755559748758],\"murray's hypocycloidal engine\":[-174.45272277415003,1473.6421892869998],\"myron scholes\":[146.7059562167514,-142.97483689580903],\"national agricultural policy center\":[-4.552385184938631,136.06102730221295],\"national average salary\":[84.67198131912619,-162.7612307706233],\"national equities exchange and quotations\":[-473.94753629349964,-1228.9856770826436],\"nava ashraf\":[155.44875238067442,-30.2988045989034],\"nayakrishi\":[1090.466724934639,-363.0501742876026],\"neo-capitalism\":[55.327298897555046,74.55789919698044],\"neo-ricardianism\":[43.76148423595326,53.56778998647736],\"net national product\":[-36.983263465120075,213.89553708491476],\"net worth\":[-7.668932183316453,395.46974846402463],\"network effect\":[-142.41022423757528,132.6969087928041],\"new institutional economics\":[80.46123126643958,24.474707922141963],\"nominal yield\":[225.53478552364436,-558.2088324276924],\"norwegian paradox\":[148.5179814788759,135.3688300627932],\"obshchina\":[678.634360778407,-860.6337816646284],\"open economy\":[-116.0926129215345,-42.655431816267225],\"open music model\":[1055.4820446388553,-468.725517395108],\"opportunity cost\":[-80.92610590050565,21.99613828281839],\"option screener\":[72.2596677367445,-316.12108588849867],\"output elasticity\":[107.48283468833428,-149.56186154654588],\"outworker\":[-64.93822769964923,1321.352096060551],\"paola giuliano\":[200.89648737288985,-356.31520952999523],\"paradox of prosperity\":[92.21410327235992,187.57264280821906],\"paradox of thrift\":[32.826104818208364,124.39511966972945],\"paradox of value\":[34.71155160225314,91.78593000739305],\"party-state capitalism\":[351.23699910012164,1105.831848461156],\"paul de grauwe\":[-64.36437106868672,-118.32357308453409],\"paul milgrom\":[222.65810409042103,-64.28924927256953],\"paul romer\":[183.50995033643068,-93.22930441769775],\"pauline barrieu\":[816.879927608519,760.706329486916],\"peak wheat\":[-184.670930208767,5.2859071398982005],\"peasant economics\":[-591.952649399409,-960.1605933563701],\"per capita personal income in the united states\":[738.2169371428714,-809.939072090002],\"perpetual bond\":[217.85553425977514,-557.0183006281424],\"peso problem (finance)\":[-149.50163770743492,-292.11916701748],\"peter jaeckel\":[224.21070319123876,-188.90726111123013],\"phillips curve\":[61.47172671418147,-98.48149624146069],\"pierre-andr\\u00e9 chiappori\":[74.72255544972434,-236.00581180347564],\"political risk\":[-170.60809042863636,-206.20565144461662],\"pork cycle\":[84.09220491709512,93.93096715095473],\"precautionary demand\":[-144.48197268375287,33.44314763064936],\"preclusive purchasing\":[-168.62373093079552,37.4096038764972],\"price index\":[-129.68611056823212,101.1504263920228],\"price support\":[-7.761951687203459,141.24018565177263],\"pricing kernel\":[-114.07730647505264,-86.4576619187598],\"primary market\":[-230.05076574612224,-319.00676278376204],\"principles of economics (marshall book)\":[-10.305263992342294,61.704582943649804],\"private highway\":[1097.2489014046707,-848.8806389164314],\"privatism\":[77.62931155035223,75.96333348590807],\"problems with economic models\":[-92.00841211387254,-19.116625318809426],\"production for profit\":[34.94043188661339,242.77753370578725],\"production\\u2013possibility frontier\":[-141.2484697788824,94.73931193046882],\"productive capacity\":[-137.28894503461316,-4.247343464487236],\"proto-industrialization\":[-64.11236625342288,1328.706476168377],\"public economics\":[-18.92178555218681,-44.413120804707894],\"public property\":[92.58068043988267,35.23731253297966],\"purchasing power parity\":[-62.71900543571353,31.724694475192965],\"qem\":[-1304.142558870168,316.50911073724325],\"quaternary sector of the economy\":[-315.5932216212504,1190.1256278072162],\"ramsey\\u2013cass\\u2013koopmans model\":[19.66919162206312,-71.00785381141147],\"rat race\":[-512.1181739635728,-273.95022228070934],\"rate of return\":[-214.73668420182491,-244.03321622157853],\"real economy\":[-110.10600271232327,-105.23560209346623],\"real-time economy\":[-154.17604229440454,-129.43990477514723],\"real-world economics review\":[47.17512695618965,239.5151769667361],\"rebound effect (conservation)\":[-164.11713429412765,22.2152441244011],\"reed's law\":[-169.16287117480329,152.82215629568682],\"relative income hypothesis\":[25.97443129499995,-211.7436422962814],\"reproduction (economics)\":[37.6477492802298,235.3984446968174],\"research papers in economics\":[109.97942226395936,-104.86008532811265],\"resource curse\":[151.5803539457675,199.28641195155072],\"rethinking economics\":[-224.2984402024397,-88.52861572504361],\"returns (economics)\":[-139.41995870358156,-135.465581696523],\"ricardian equivalence\":[184.44356573057385,16.27128094262483],\"richard koo\":[-10.896800880767652,247.1219931614996],\"richard timberlake\":[101.6459316159544,-73.02664258691814],\"risk factor (finance)\":[-154.35029174093853,-247.7037535551017],\"risk management agency\":[-841.4114074324272,1030.3729120191229],\"risk premium\":[-153.57342226375474,-173.69866593204162],\"robert ekelund\":[588.6199016007569,943.5765439871703],\"robert heilbroner\":[114.28053404326894,-71.20670088044885],\"robinson crusoe economy\":[-76.1912625279105,116.12586623629379],\"roll-geske-whaley\":[40.591781504472785,-300.3492731798745],\"sailing ship effect\":[-182.0642069860386,171.48080362710883],\"samuel von pufendorf\":[-30.15274149825977,-100.05541524118111],\"samuelson condition\":[-90.37377994071059,61.50161641327082],\"schelling's segregation model\":[236.5634723458848,-54.604757233978425],\"scitovsky paradox\":[100.77460015665966,191.42987087895028],\"scottish index of multiple deprivation\":[-283.3148800272248,84.83980892326619],\"seasoned equity offering\":[-311.379192462086,-185.58149457885577],\"sectoral balances\":[-1.501059542968183,192.4564866444397],\"sectoral output\":[-172.5795368847307,130.52990552714587],\"secular variation\":[146.9183821939583,-275.19737241032925],\"sequential game\":[230.14014675354696,2.3591216327408233],\"service economy\":[1.1962789682396395,-5.271293157525238],\"sex and reason\":[99.52312415476841,217.91363116701376],\"shale band\":[214.89028130906613,-1335.8430220260632],\"sharon oster\":[294.6167970736132,-72.31148365968565],\"simulation modeling\":[-167.03334124454236,-84.40025404746294],\"skew\":[29.79071778141147,-287.43191689724495],\"social cost\":[43.59248760960726,9.87248471327865],\"sofr\":[1311.2645204558517,-795.3754152895602],\"solow\\u2013swan model\":[10.994961242229188,-80.48152116403791],\"songun\":[-224.73106428719345,122.72106081932577],\"sonnenschein\\u2013mantel\\u2013debreu theorem\":[-48.153622359938616,-75.83166066735959],\"split labor market theory\":[-567.0741157598011,-1037.9781792733856],\"st. petersburg paradox\":[49.18399836440142,-6.733277845781764],\"starve the beast\":[-349.77781684817813,1006.6251839354585],\"state price density\":[-118.25196471135793,-80.2310611067562],\"steven n. s. cheung\":[147.72258457407662,-72.83636452118745],\"stochastic investment model\":[197.03371660556138,-515.8919275707042],\"structural estimation\":[147.03792050525996,-181.95975665148563],\"stylized fact\":[127.9345540494428,50.04294412793542],\"substitution effect\":[-73.6509031337744,52.11894591946569],\"superrationality\":[72.68445306341013,98.88112109134352],\"supply and demand\":[1.472020734720793,74.68350218599079],\"supreme court economic review\":[227.26564527954866,-116.85855972413938],\"surplus labour\":[20.212882293286814,225.47078295316442],\"surplus value\":[41.63515981351357,136.27719709684487],\"survey on household income and wealth\":[-1540.2008769473102,-93.8336079356503],\"tax-allocation district\":[8.88270051542702,1423.9020834572239],\"taxation in uruguay\":[-601.5941286286969,901.8792992796884],\"technical change\":[-250.70803724250777,-56.98215047426521],\"technical indicator\":[-296.8652487180964,-395.9014369821467],\"technocracy movement\":[144.22633682047285,226.35942387907332],\"term (time)\":[-328.3469414683365,-203.848645173885],\"the counter-revolution of science\":[19.844520137461537,-101.26137407636797],\"the elephant curve\":[-16.27568868584748,358.9235585145196],\"the reformation in economics\":[-1140.7609748719212,-470.71067846368123],\"the rich get richer and the poor get poorer\":[1086.496813788877,-392.49606711673516],\"the road to serfdom\":[21.360051065048985,-110.81750769522586],\"the theory of interstellar trade\":[-443.43617074242036,-246.49779682773698],\"theories of poverty\":[-225.71142601808654,76.30057497039247],\"thomas schelling\":[234.21991090212788,-22.762562305338513],\"tibor\":[1308.1774476187284,-789.163460062503],\"time series\":[133.17586873206162,-231.70439908768253],\"time value of money\":[-297.1710411657468,-188.15926146523776],\"time warp edit distance\":[156.3099777585465,-266.50648480280495],\"time-use research\":[1000.3762753714637,-514.577514176419],\"timo ter\\u00e4svirta\":[241.50771070732523,-164.71875325798146],\"toothpaste tube theory\":[-133.6476433039789,-46.708021683467834],\"tore ellingsen\":[1060.8808063939875,404.73212750532576],\"triangle model\":[70.22717812141674,-153.1110992502458],\"trygve haavelmo\":[201.64904633077305,-73.70920325059382],\"two-sided matching\":[300.0566458415435,-237.00063398948026],\"unevenly spaced time series\":[156.39739224568558,-273.9957630731139],\"united states farm bill\":[-834.2477361765144,1017.062136746081],\"universe (economics)\":[-64.40566910571162,108.592768784495],\"unplanned economies\":[-50.608952086129094,147.6135750469609],\"utility\":[-43.55043847041389,25.839648014487075],\"value product\":[2.84617167155296,225.91723415204726],\"variable rate debt obligation\":[233.60573607115793,-575.1527354396505],\"vent for surplus\":[3.3077026325210017,-22.05050786961904],\"venture capital in spaceflight\":[406.5722575647218,1016.6599032498247],\"vernon l. smith\":[171.2027886885925,-79.70916544633319],\"vertical farming\":[181.11626236884322,1354.8119316037912],\"visible hand (economics)\":[56.30800408841299,21.927054123597127],\"volatility clustering\":[-7.177536457886842,-267.46288344916417],\"volume index\":[-174.146154454294,135.92348452839187],\"voluntary sector\":[-317.1906224762698,1193.7827725813852],\"w. kip viscusi\":[164.6315089324076,3.7743104824939526],\"wallace neutrality\":[247.7658776292635,13.918571702248023],\"walras's law\":[-90.07450432481936,-113.55599463796962],\"weak and strong sustainability\":[130.91016331546155,-1301.680201490449],\"weighted average cost of capital\":[-224.85780679096285,-161.27964802488816],\"weston a. price foundation\":[-798.3562334691493,-760.7805208504469],\"william vickrey\":[196.1025347796062,-35.44178428834688],\"wilson doctrine (economics)\":[276.0135671531714,3.465149794552658],\"wood industry\":[-1261.5186159625382,161.78617960073885],\"woolrich electrical generator\":[-179.13592266539513,1469.8797981787088],\"world economy\":[-182.2228230352051,-13.980114354455143],\"world3\":[-53.54694409296868,-1517.1139919933728],\"yakama manty jones\":[96.33022086819429,-1180.5238973720088],\"zur geschichte der handelsgesellschaften im mittelalter\":[-1180.0010685481489,457.1590490256916]}},\"id\":\"1756\",\"type\":\"StaticLayoutProvider\"},{\"attributes\":{\"callback\":null,\"tooltips\":[[\"Page\",\"@index\"]]},\"id\":\"1735\",\"type\":\"HoverTool\"},{\"attributes\":{\"data_source\":{\"id\":\"1749\"},\"glyph\":{\"id\":\"1774\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1751\"}},\"id\":\"1750\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1649\",\"type\":\"Range1d\"},{\"attributes\":{\"active_multi\":null,\"active_scroll\":{\"id\":\"1667\"},\"tools\":[{\"id\":\"1666\"},{\"id\":\"1667\"},{\"id\":\"1668\"},{\"id\":\"1669\"},{\"id\":\"1670\"}]},\"id\":\"1671\",\"type\":\"Toolbar\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1650\",\"type\":\"Range1d\"},{\"attributes\":{},\"id\":\"1828\",\"type\":\"NodesOnly\"},{\"attributes\":{},\"id\":\"1733\",\"type\":\"SaveTool\"},{\"attributes\":{\"line_alpha\":{\"value\":0.8},\"line_width\":{\"value\":0.1}},\"id\":\"1709\",\"type\":\"MultiLine\"},{\"attributes\":{\"formatter\":{\"id\":\"1808\"},\"major_label_policy\":{\"id\":\"1806\"},\"ticker\":{\"id\":\"1728\"},\"visible\":false},\"id\":\"1727\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"1811\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"graph_layout\":{\"1890s in anthropology\":[-39.094111522771264,-60.4443110192013],\"1910s in anthropology\":[104.76301400278875,-36.281079140037306],\"1990s in anthropology\":[-24.99321171851279,-26.385462653813207],\"2000s in anthropology\":[-28.55964211675572,-81.52818523956351],\"age set\":[85.60793412033257,-104.94670088739035],\"alliance theory\":[68.8461085033594,-4.2741219874715854],\"americanoid\":[-49.49613547247694,-42.91693860533816],\"andean civilizations\":[-119.47939240460123,163.45643273368796],\"androcentrism\":[-146.89162362277193,173.25254023018812],\"angkola people\":[-509.25399335192526,276.13638529085614],\"anthrobotics\":[-46.96513726365946,-76.89354010985278],\"anthropological criminology\":[-140.7727803516061,-28.345259372738305],\"anthropological index online\":[9.60178083389052,-13.504673880419077],\"anthropological survey of india\":[104.33758749561929,-67.13272882620356],\"anthropology\":[-13.29820651337106,-49.68424114942786],\"anthropology of art\":[42.32068828570443,-69.09476846162885],\"anthropology of institutions\":[14.479712544864887,-4.686308794970912],\"anthropometric history\":[-221.4889675957641,-64.13606294133494],\"aparna rao\":[28.90249546912594,-107.05853214774264],\"applied anthropology research methods\":[-28.57777807142361,-18.22544730573868],\"apuli\":[-75.02580094199409,18.479890755821376],\"archaeology\":[-65.48943168423988,-47.61961671401772],\"area studies\":[-11.817893270640706,-22.478913608372057],\"argentine forensic anthropology team\":[-131.4584109226088,-129.45033481097266],\"arthur evans\":[-100.32182043445427,-156.97156724024427],\"auspicious wedding dates\":[213.33394277745182,-281.0314825368102],\"australian aboriginal kinship\":[132.8550415080391,-12.961763902808599],\"australian institute of aboriginal and torres strait islander studies\":[-96.29042839589034,180.86122981565944],\"bertil lundman\":[-268.348774084757,-61.0672032149102],\"biblical patriarchy\":[397.38400931544913,73.12149228381044],\"bibliography of anthropology\":[26.00659297845464,3.201287409408455],\"biocultural anthropology\":[-17.26215673462498,-82.72657981278141],\"biocultural diversity\":[-38.38834905017675,-151.59166572786916],\"biological anthropology\":[-62.00429772743381,-15.358402830722197],\"biology and sexual orientation\":[333.92235046404437,35.47450199711164],\"bumiputera (malaysia)\":[-194.96471339366093,151.06870061900543],\"business magnate\":[-198.81082174727902,121.07981031449457],\"cabang atas\":[-279.9426640496217,185.18370300256726],\"canadian honours system\":[-621.7961500502773,783.0116085500136],\"census of india prior to independence\":[-266.8950356463117,134.27068162371896],\"cephalic index\":[-288.6455531267601,-99.09852627858436],\"cephalic index in cats and dogs\":[-323.74388086612953,-115.37463342963116],\"ceremonial pole\":[-41.083251973999886,-133.140735801273],\"ceremony\":[367.4208754393965,-97.34997166091549],\"cha\\u00eene op\\u00e9ratoire\":[-95.15021322528663,-45.82971637749131],\"children's geographies\":[-97.47498830071477,137.13047894197985],\"chinese kinship\":[132.4156317454222,-1.849814533472918],\"circumscription theory\":[93.03655392394401,-106.3031078554714],\"classificatory kinship\":[109.17764689989686,-9.779819252955198],\"cognitive anthropology\":[29.661087022386628,-45.635995730336134],\"cognitive archaeology\":[-86.24734676807378,88.33106697529806],\"cognized environment\":[31.502544389805013,15.033581767449279],\"communicative dynamism\":[30.648218028885953,140.28997455547338],\"confucian classes\":[-239.8248074305385,157.81687397393208],\"constantin noica\":[-76.01933629328572,63.86145225426219],\"consumer class\":[-193.61550448901178,-79.52096235106845],\"consummation\":[267.5141149417595,-69.2336970912818],\"contrast set\":[-45.458524008146135,-49.25631760966909],\"cornell-peru project\":[-34.01073582943451,-79.47320154645416],\"craig stanford\":[-100.04693891250734,-28.83506483722051],\"critical medical anthropology\":[52.1772988319573,-96.37010708300745],\"cultural anthropology\":[67.75761224720848,-39.008767171090604],\"cultural group selection\":[-89.80519678538916,32.8092393191787],\"cultural mapping\":[36.91119495255045,84.75412546142813],\"cultural memory\":[49.00006666520795,97.29063602652987],\"cultural movement\":[-14.752008060825236,95.06354431445648],\"cultural nationalism\":[13.951148683841826,106.24898298612193],\"cultural practice\":[40.29664010916733,108.54006737783983],\"cultural radicalism\":[-0.30368538386062716,83.7756840218637],\"cultural relativism\":[37.82786001402367,31.167312533929394],\"cultural resource management\":[16.522069991260356,-69.25130255310748],\"cultural survival\":[-98.17177230280231,161.79506640415264],\"culture hero\":[19.44798403871004,96.27568562294097],\"culture theory\":[1.5599593918452204,33.09040532366605],\"darwinian anthropology\":[16.670746938802047,-82.002062054999],\"das mutterrecht\":[-28.68534887149313,57.077246149013426],\"deep history\":[-24.562213101447846,-5.2982476832083165],\"deep play: notes on the balinese cockfight\":[69.26322535465155,27.223805948171798],\"development anthropology\":[85.87350705965893,-30.713690806349252],\"development geography\":[-58.18046235795906,127.30711628023967],\"diane bell (anthropologist)\":[112.55618140835325,-16.983449254933458],\"digging stick\":[-108.18072021418405,-23.367164342494274],\"direct historical approach\":[-78.56845780106654,-134.2462546210861],\"disability anthropology\":[40.71372171356571,-86.40095702071766],\"displacement (linguistics)\":[-27.167917559887766,122.81719747565987],\"dominic boyer\":[-55.54933959393622,97.32867444204415],\"donor class\":[-152.50564655949964,78.70940915155279],\"early modern human\":[-131.6354177000527,227.88492693765437],\"ecological anthropology\":[-12.318516318890612,-93.89009498176047],\"economic mobility\":[-221.09450758625132,-99.43190590446649],\"educational anthropology\":[-61.54484122665792,63.90214310580173],\"edvard westermarck\":[122.86249333522247,10.919557286015767],\"emic and etic\":[23.072743464135282,-24.950665685010858],\"encyclopedia of anthropology\":[-36.26568851943568,-83.00582651453219],\"endocannibalism\":[137.40557526668994,48.28462599090439],\"endocast\":[-77.87091324763016,10.344902518785764],\"ethnic religion\":[-21.14367516821019,-129.85411336780984],\"ethnoarchaeology\":[-51.99427799904988,-154.21194443320417],\"ethnobiology\":[-26.538407371567377,-142.8747590187204],\"ethnoichthyology\":[-18.56778568485555,-161.71878905497942],\"ethnolichenology\":[-34.676498273076305,-166.7077344970623],\"ethnomedicine\":[10.339785412146822,-133.5066710283727],\"ethnomuseology\":[9.62705358998083,-96.26504736116404],\"ethnoornithology\":[-49.868588520123964,-138.92520551199843],\"ethnopediatrics\":[-54.49672353820371,-77.35902133929615],\"ethnoscape\":[-39.562077212496526,-47.62525793102589],\"ethnozoology\":[-9.634640805049955,-126.45122843131786],\"evolutionary studies institute\":[-158.07826806552504,55.11545656574751],\"exocannibalism\":[95.17723024087078,23.621557839270853],\"f. g. bailey\":[98.22640267904559,-100.96081476497952],\"fallen woman\":[370.7973124290169,65.82308086974082],\"faye v. harrison\":[-32.56182810400974,70.75419563033208],\"female promiscuity\":[304.62689164470237,47.190096038275044],\"feminist anthropology\":[97.67669238043798,8.491041700474664],\"fordisc\":[-144.18708519584544,-63.03057524598773],\"forensic facial reconstruction\":[-83.08133100039898,-63.421210051329396],\"fount of honour\":[-618.1519935913402,784.6799597706192],\"frazer lecture\":[-111.075828034774,-199.2195006216106],\"friction of distance\":[-99.3868543074781,156.01682788075206],\"gaia philosophy\":[-95.40942237994209,100.6477796138644],\"gallowglass\":[-93.96875266060628,164.29668505529636],\"gaonburha\":[-44.7098279292351,-81.43651296701998],\"gate crashing\":[345.89558932039705,-77.28803181729604],\"gay, straight, and the reason why\":[-693.807207709498,489.1039113779781],\"geography of antisemitism\":[673.0885830837487,509.8854049612896],\"geography of media and communication\":[-67.19500306977741,88.18622156140131],\"georg pfeffer\":[-43.619040290881046,-88.63317222417292],\"ghazi (warrior)\":[-855.6739457564884,-170.84930889541386],\"gloss (annotation)\":[77.09209848137739,96.90778554905698],\"gotai\":[-41.65513517426342,-53.29461388766742],\"grave goods\":[-121.74550168395359,-16.605455644431302],\"guanche mummies\":[-276.75378066884343,159.07875278355345],\"guatemalan forensic anthropology foundation\":[-150.31233190763143,-163.18458373864934],\"hau (anthropology)\":[-51.059601849474284,-81.9700793155783],\"hawaiian ethnobiology\":[-28.10361099368988,-193.61196440521647],\"headhunting\":[-188.23848027103227,-204.31504770530535],\"health geography\":[-62.12798317579369,93.5304519834752],\"heel\\u2013ball index\":[-22.976501175473235,5.9557056775228805],\"heide g\\u00f6ttner-abendroth\":[601.295464522731,579.4164525885327],\"helmuth plessner\":[-142.2994985446767,299.539998056411],\"heritage commodification\":[146.96417413891749,-71.51545237160454],\"heterotopia (space)\":[-327.9497769730356,-828.614221451544],\"high culture\":[12.508682833081044,120.79296304593707],\"high-altitude adaptation in humans\":[-155.28899472699217,263.99943532775796],\"hill people\":[-149.85633245440442,236.0244283637372],\"historical behaviour studies\":[45.387439161757925,-56.93713580120906],\"history of anthropometry\":[-194.07077773572922,-50.63642614839506],\"hobby\":[-204.26677380415552,-176.82885177010047],\"hoi polloi\":[28.16529374217682,189.62374606725388],\"homo faber\":[-166.37980935839963,350.8670360505552],\"homosexual behavior in animals\":[313.1772342218569,24.18623616757529],\"honeymoon\":[289.8591309357217,-88.89446750600008],\"hong kong honours system\":[-121.3359301239862,55.225459026528796],\"honorary male\":[-166.29669499181804,201.18636057093062],\"hoplology\":[-243.7085655459619,178.84176648509538],\"human behavioral ecology\":[23.493880289383853,-69.38408081641244],\"human ecology\":[-29.500108356990673,-106.65321685315203],\"human ethology\":[-16.25097816984047,14.862209982830223],\"human genetic clustering\":[-185.66874525494146,299.3170470118721],\"human genetic variation\":[-170.20648612968284,272.7697315474774],\"human terrain system\":[53.153323953947954,4.06801995248812],\"human universals\":[7.261852049239593,-23.60688737523236],\"hunter-gatherer\":[-119.15115521012098,6.449044083044567],\"hunting hypothesis\":[-108.85570173288502,25.53032565959611],\"hypnopompic\":[-221.49228417756697,-1148.0890008321078],\"jerzy adam kowalski\":[-677.6748695451623,-471.01280260647997],\"joan roughgarden\":[348.6190253404047,23.292930280781412],\"john beddoe\":[-272.56574949063435,-49.659525832407645],\"journal of ethnobiology\":[-27.298901945794285,-199.1390467101727],\"kalahari debate\":[-153.98690981194113,1.316712037834643],\"kluet people\":[-507.62873030378904,282.83861891785244],\"koteka\":[-492.1542937334377,278.2765638180721],\"kriza j\\u00e1nos ethnographic society\":[-22.99571961278856,81.22725724102413],\"kshatriya\":[-228.9680384019021,123.85673732614026],\"lambda alpha\":[-63.08774999639862,-66.75912684748396],\"language\":[-79.02448407499675,123.0444652054227],\"laura boulton\":[50.232276324625985,-140.1981696195029],\"les ma\\u00eetres fous\":[43.682621402979635,-160.41937624901246],\"leveling mechanism\":[88.3679050325675,-97.45888613328673],\"lila: an inquiry into morals\":[-50.58320484056367,-88.19188444536272],\"lingeer\":[-167.84471907862684,46.23229905663026],\"lingeer ngon\\u00e9 di\\u00e8ye\":[-166.51061732362817,38.06134800297225],\"linguistic anthropology\":[17.89056753448938,44.82864670804264],\"linguistic description\":[7.244707923038619,53.42044252625346],\"linguistic linked open data\":[82.53735542026386,102.47071102996767],\"linguistic relativity\":[17.354441480043544,74.05615654751054],\"linguistic system\":[1164.5743671635887,-159.02056910654392],\"linguistics\":[40.86507464157514,65.36895215897145],\"linguistics in science fiction\":[67.5429592836203,101.81073570797132],\"list of animals displaying homosexual behavior\":[329.03229799237357,24.031109395220703],\"list of anthropologists\":[-43.10553007618592,72.39764897064731],\"list of birds displaying homosexual behavior\":[292.8891370455853,25.684905651330624],\"list of mammals displaying homosexual behavior\":[295.37705910408135,17.88362051023665],\"list of matrilineal or matrilocal societies\":[98.3245416378651,-17.010628714301507],\"list of stateless societies\":[-157.00679661859456,-3.550236127571908],\"list of timothy asch films\":[32.15437113980294,-334.2456233690924],\"list of visual anthropology films\":[70.99028583646025,-173.69128305327573],\"list of women anthropologists\":[-32.71269650353121,143.22612143642405],\"list of years in anthropology\":[0.8835428504556805,1.8152278121569623],\"literacy\":[-63.85182371380171,149.84219357173652],\"logical form (linguistics)\":[67.86698693454316,136.80928992807677],\"logophonetic\":[-87.87286257972895,163.3982012963282],\"maceration (bone)\":[-108.14527960179464,-111.44781647264934],\"magical death\":[48.705024230946314,-286.80162052773073],\"magnate\":[-168.34188903898337,93.37735324825974],\"male state\":[157.11452951058186,1099.397152579156],\"maloca\":[-43.318322790922515,-62.342726465094685],\"mandailing people\":[-476.38525379554284,268.51235391344744],\"manorialism\":[-180.51774699846493,90.9727041437706],\"marija gimbutas\":[-25.358471977504788,126.53887651199055],\"marriage of the virgin\":[-792.3485238895285,760.6139386622835],\"mars needs moms\":[-14.721856179956553,1162.3756904981208],\"martial race\":[-275.2769201901609,-24.234787957949962],\"martti olavi siirala\":[-1065.0276299511506,136.31329862051678],\"matrilocal residence\":[111.45154230698168,-25.470996584373125],\"max scheler\":[-180.8150255005381,384.33093206694764],\"maya research program\":[-95.88325842995596,-78.75814284334506],\"media linguistics\":[-18.096287136773093,127.01746738567223],\"medical anthropology\":[51.19891603025086,-80.88986542522301],\"men who have sex with men\":[298.893370198303,57.12106808975436],\"metalanguage\":[-7.978717456904243,116.94142016208316],\"metanoia (psychology)\":[-430.9573049694766,-696.5124868773187],\"michelle rosaldo book prize\":[149.88130663124537,29.367721504355888],\"middlebrow\":[23.118800478605344,173.1985847104391],\"minangkabau people\":[-490.18766659525136,270.33719670086566],\"moana (1926 film)\":[120.72521928364556,-247.45070451168814],\"moralia\":[-1042.1353272629788,281.56214373247633],\"mosuo women\":[72.65526320895442,38.942419498830716],\"moving anthropology student network\":[-31.960962375812187,-87.67258475748677],\"multimodal anthropology\":[116.48965532210576,-46.6294933880334],\"mummy of san andr\\u00e9s\":[-325.08052030136156,184.2364493177925],\"museo de antropolog\\u00eda de xalapa\":[81.2765103654142,-122.8023675155304],\"museo nacional de antropolog\\u00eda (madrid)\":[37.24980745183848,-59.636636870729404],\"museu da lourinh\\u00e3\":[-100.47874418484614,-74.40115380334659],\"museum of archaeology and anthropology, university of cambridge\":[94.29545014619282,-130.81889506937793],\"museum of mankind\":[13.852866338667095,7.73818137139657],\"museum of world culture\":[716.3850563495306,430.67185884282645],\"mus\\u00e9e de l'homme\":[-68.85313160048685,-94.01150769471927],\"mus\\u00e9e des confluences\":[-41.09971469043832,-75.56601255323183],\"muted group theory\":[113.15611241156004,-52.62797435563347],\"names for the human species\":[-133.83589323227582,269.2187254819787],\"nanook of the north\":[82.11451163190878,-151.36558804396307],\"nations and iq\":[-118.46849528828324,210.49502890625658],\"naturalistic disease theories\":[100.02240819254959,-164.63844003092856],\"negroid\":[-264.56456180552414,-52.71402531395077],\"neo-nationalism\":[-37.317948923355445,182.08233266792794],\"neolinguistics\":[81.84988814503237,93.55477112343814],\"netnography\":[-6.225187051296461,-155.10471766323948],\"neuroanthropology\":[-2.9834883268347387,-7.076650874649381],\"nomadic pastoralism\":[115.49333425092367,-62.09740651918502],\"nomads of the longbow\":[108.40116472416017,-58.80081726984613],\"non-representational theory\":[-74.81885391468887,102.55904573435743],\"nudity\":[830.9923949885921,-1185.2398623187155],\"nutritional anthropology\":[71.81571073877176,-65.95512979583843],\"n\\u01c3ai, the story of a \\u01c3kung woman\":[74.31561475928758,-132.10251868419962],\"off the verandah\":[-323.3587034300022,858.0332437570285],\"official cantonese translations of english names for british officials\":[-116.20428352174434,51.40975182080232],\"ogilvie professor of human geography\":[-880.7417312782637,-219.01503902256246],\"oikofobie. de angst voor het eigene\":[80.09747896200706,64.74479143755426],\"online ethnography\":[1.9891272201154993,-82.56662187758913],\"orthograde posture\":[-48.6408890342504,-74.77972615618312],\"osteology\":[-89.9376282029743,-115.22612141388306],\"outline of culture\":[1.3899886811131281,67.7501855006045],\"paleoanthropology\":[-41.13066532415776,10.044942878538707],\"paleopathology\":[-99.48041929386497,-135.17806259056326],\"paleoradiology\":[-128.08526764269178,-189.47337340938262],\"patrilocal residence\":[156.65133240091708,-19.738440491011698],\"peasant\":[-175.95691210633143,142.53006312130913],\"people\":[-129.68799969030576,42.42605561722165],\"performance studies\":[33.79682991718701,-15.110419423645967],\"person\":[-100.63997793104963,72.16911004741816],\"personal life\":[-168.94146318158232,-141.43186264512477],\"peter sloterdijk\":[-1078.1680911726642,-215.7275019693301],\"philosophy of life\":[-88.98335219768894,100.18912066032684],\"pitt rivers museum\":[-114.53622272871384,-112.32424799158258],\"podom\":[-39.95151962356675,-67.06043860939798],\"polygyny\":[183.12580634707757,-6.791772942378834],\"poppet\":[-271.9304468585917,6.5951031715969775],\"population health\":[107.45988479608751,-133.556894974712],\"population health policies and interventions\":[112.36165280936864,-131.93065997901073],\"possible world\":[79.22257038458989,130.69914615005507],\"postmodernist anthropology\":[-8.813987699780428,2.25530065449618],\"postpartum confinement\":[-889.9432787730461,313.1835487727004],\"poverty class\":[-197.76393402359093,133.10206337262778],\"prenatal hormones and sexual orientation\":[341.5332299728254,43.78888140154267],\"prickly paradigm press\":[-48.20840724603839,58.27922365362725],\"primitivism\":[162.15615186912873,-1106.48680671148],\"promiscuity\":[239.32541243239763,31.337518269993573],\"proto-malay\":[-423.6523790424764,247.06584483117675],\"proverb\":[127.37814877313598,47.09106062694996],\"proverbial phrase\":[108.34962974676698,42.759763186864106],\"psychogeography\":[-81.51560900265386,56.61469630580526],\"race and intelligence\":[-156.70788013209565,218.93489771034965],\"raptio\":[244.48601824988722,-35.00932483347371],\"recent human evolution\":[-160.41950994923118,275.6952242103678],\"reciprocity (cultural anthropology)\":[136.9567535056161,-51.76849668433008],\"releasing the spirits: a balinese ceremony\":[392.51413388037366,-108.50006024161176],\"religion\":[-61.98874284369695,40.95480943590756],\"reterritorialization\":[34.53408062312545,-1189.0583580345537],\"riane eisler\":[-25.524149559446297,173.25562182947345],\"richard gaskin\":[-91.72217661880099,157.08408623984755],\"rossville points\":[-92.33287522295818,-4.806074352832539],\"rudolf virchow award\":[38.76885620565901,-109.41277967933357],\"sedentism\":[93.64925506453179,-55.42403341647505],\"semiotic anthropology\":[20.440627606565254,19.262066572125097],\"serer maternal clans\":[-175.36016285134136,43.734897910695466],\"serer people\":[-168.99276641811826,24.673700559816076],\"serer-ndut people\":[-175.56979189594773,36.13768547287255],\"serfdom\":[-173.58847937706042,126.34301044373163],\"sexual inversion (sexology)\":[-472.4266502705037,-661.1004361117276],\"shell money\":[115.40779269878422,-72.24449198231187],\"shrunken head\":[-168.46867157823786,-178.10700788440724],\"sinodonty and sundadonty\":[-279.044505687302,-57.84361557263732],\"skhul and qafzeh hominins\":[-114.0352818222452,199.98787639368308],\"slavery\":[-147.93822176179117,115.75043424891857],\"society for economic anthropology\":[-529.3220033295964,637.0262762127254],\"society for medical anthropology\":[49.23164817939498,-105.6773918296165],\"society of anthropology of paris\":[-38.686328034130135,-77.19269434451878],\"sodality (social anthropology)\":[-46.80451169489891,-59.365406719438745],\"solano people\":[-38.72520396831017,-88.88628884249049],\"soul dualism\":[-48.69158636087867,-110.23349824330295],\"squib (writing)\":[88.03147358508525,94.70830637573651],\"standard cross-cultural sample\":[38.01603177278949,3.8168313094899196],\"status group\":[-167.09907124655126,114.65639220730492],\"structural endogamy\":[-566.2877414699009,-597.5618381873943],\"susto\":[183.06769796849915,-252.70334709910628],\"sympathetic magic\":[-221.9894177154735,4.615690862408298],\"taboo (2002 tv series)\":[-379.5561467195666,-759.5867675178366],\"the hebrew goddess\":[-86.34794853228165,-184.52531368412704],\"the hunters (1957 film)\":[88.7564863987032,-122.26105600281694],\"the white goddess\":[-157.55736457170372,-288.35197788285603],\"the witch-cult in western europe\":[-185.14552615094564,-323.6865902257913],\"theatre state\":[96.8133972194468,-94.87810558360412],\"theory of language\":[20.35567916869388,127.44112164835192],\"theta criterion\":[53.31718115291976,130.1778047009343],\"toloy\":[-72.85961128024398,1.2746617531108377],\"tonograph\":[77.11640210286144,104.92620652670121],\"topic and comment\":[-10.474572229430446,126.33558490205253],\"transcultural nursing\":[24.369496227951675,80.64384267374511],\"trash doves\":[-38.7066333994115,227.27831542118528],\"travel behavior\":[239.27892712811135,-89.83076768362737],\"trobriand islands\":[151.24606095466842,-9.364296195800208],\"tropical geography\":[-64.29084800593587,174.77383456916576],\"typology (anthropology)\":[-232.8456512428847,-60.08631576443553],\"underclass\":[-216.04826649644312,144.72482963792535],\"university of tennessee anthropological research facility\":[-174.3969580165491,-83.79958047840192],\"unsaid\":[99.43065305049205,117.53208432300997],\"upper class\":[-179.6098780937423,111.7246111255092],\"urban revolution\":[-92.43243353385841,-37.275111555232066],\"usc center for visual anthropology\":[-50.72057964238484,-70.2762567539522],\"utinahica\":[-56.55360599123147,-73.05090992145247],\"vanua\":[-37.14926553886283,-71.82440520521752],\"viking fund medal\":[-66.92478222184289,-72.46564092100478],\"village head\":[-41.09301951890887,-82.40564009492964],\"waga sculpture\":[-57.174577835931274,-67.45831113987919],\"warrior\":[-218.5451508757467,155.11920297641262],\"warrior (character class)\":[-248.04122650595605,174.10367705415297],\"wedding\":[312.56198889717734,-71.96220324148354],\"wedding reception\":[320.24780030604853,-85.38513421399577],\"wedding vow renewal ceremony\":[332.5394017291096,-90.79982167012952],\"welfare culture\":[34.6375151051605,98.99904791182126],\"white wedding\":[318.9294410126186,-93.40703616442804],\"woman, culture, and society\":[69.0969333723482,8.585790713338112],\"women who have sex with women\":[313.60567321368046,53.844120920514605],\"womyn's land\":[-192.1175600878514,57.04452062535171],\"zooarchaeology\":[-65.21646421505406,-122.76461944146516]}},\"id\":\"1691\",\"type\":\"StaticLayoutProvider\"},{\"attributes\":{\"edge_renderer\":{\"id\":\"1750\"},\"inspection_policy\":{\"id\":\"1821\"},\"layout_provider\":{\"id\":\"1756\"},\"node_renderer\":{\"id\":\"1746\"},\"selection_policy\":{\"id\":\"1812\"}},\"id\":\"1743\",\"type\":\"GraphRenderer\"},{\"attributes\":{},\"id\":\"1731\",\"type\":\"PanTool\"},{\"attributes\":{},\"id\":\"1806\",\"type\":\"AllLabels\"},{\"attributes\":{\"formatter\":{\"id\":\"1811\"},\"major_label_policy\":{\"id\":\"1809\"},\"ticker\":{\"id\":\"1724\"},\"visible\":false},\"id\":\"1723\",\"type\":\"LinearAxis\"},{\"attributes\":{\"data_source\":{\"id\":\"1680\"},\"glyph\":{\"id\":\"1704\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1682\"}},\"id\":\"1681\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"1656\",\"type\":\"LinearScale\"},{\"attributes\":{\"fill_alpha\":{\"field\":\"alpha\"},\"fill_color\":{\"field\":\"node_colour\"},\"size\":{\"field\":\"node_sizes\"}},\"id\":\"1704\",\"type\":\"Circle\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1715\",\"type\":\"Range1d\"},{\"attributes\":{},\"id\":\"1804\",\"type\":\"Title\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1714\",\"type\":\"Range1d\"},{\"attributes\":{\"source\":{\"id\":\"1680\"}},\"id\":\"1682\",\"type\":\"CDSView\"}],\"root_ids\":[\"1779\"]},\"title\":\"Bokeh Application\",\"version\":\"2.3.2\"}};\n",
       "  var render_items = [{\"docid\":\"a3883246-cf47-49c3-a497-56c42b9f4bd2\",\"root_ids\":[\"1779\"],\"roots\":{\"1779\":\"dd15032a-b86e-49c7-8b19-68f63c6045d7\"}}];\n",
       "  root.Bokeh.embed.embed_items_notebook(docs_json, render_items);\n",
       "\n",
       "  }\n",
       "  if (root.Bokeh !== undefined) {\n",
       "    embed_document(root);\n",
       "  } else {\n",
       "    var attempts = 0;\n",
       "    var timer = setInterval(function(root) {\n",
       "      if (root.Bokeh !== undefined) {\n",
       "        clearInterval(timer);\n",
       "        embed_document(root);\n",
       "      } else {\n",
       "        attempts++;\n",
       "        if (attempts > 100) {\n",
       "          clearInterval(timer);\n",
       "          console.log(\"Bokeh: ERROR: Unable to run BokehJS code because BokehJS library is missing\");\n",
       "        }\n",
       "      }\n",
       "    }, 10, root)\n",
       "  }\n",
       "})(window);"
      ],
      "application/vnd.bokehjs_exec.v0+json": ""
     },
     "metadata": {
      "application/vnd.bokehjs_exec.v0+json": {
       "id": "1779"
      }
     },
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "  <div class=\"bk-root\" id=\"1a2ecd43-a87d-4925-af88-bb27ed642fc4\" data-root-id=\"2599\"></div>\n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "(function(root) {\n",
       "  function embed_document(root) {\n",
       "    \n",
       "  var docs_json = {\"c6a9d662-5601-4411-994d-bbd296e617fa\":{\"defs\":[],\"roots\":{\"references\":[{\"attributes\":{\"children\":[{\"id\":\"1456\"},{\"id\":\"1586\"}]},\"id\":\"2599\",\"type\":\"Row\"},{\"attributes\":{\"axis\":{\"id\":\"1597\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"1600\",\"type\":\"Grid\"},{\"attributes\":{\"source\":{\"id\":\"1615\"}},\"id\":\"1617\",\"type\":\"CDSView\"},{\"attributes\":{},\"id\":\"1601\",\"type\":\"PanTool\"},{\"attributes\":{\"data\":{\"alpha\":[0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75],\"depth\":[2,1,2,2,1,2,1,1,1,1,1,2,2,2,1,2,1,2,2,1,1,1,1,1,1,2,2,1,1,2,1,2,2,2,2,1,1,2,1,1,2,2,1,1,2,2,1,1,1,1,2,2,2,2,1,1,2,2,2,1,1,1,2,2,2,2,2,1,1,1,1,1,1,2,2,1,1,0,1,1,1,1,1,2,2,2,2,1,2,1,1,1,1,2,2,2,2,1,1,1,2,2,2,1,2,2,2,1,2,1,2,1,2,1,1,1,2,1,2,1,1,2,2,2,2,2,1,2,1,2,2,1,1,2,1,2,2,1,2,1,2,1,2,1,2,2,2,1,1,1,1,1,2,1,1,2,2,1,2,1,1,2,2,2,1,2,1,1,2,1,2,1,1,2,2,2,2,2,1,2,1,2,2,2,2,2,2,2,1,1,2,1,1,2,2,2,2,1,1,2,2,1,1,2,1,1,2,2,1,2,1,1,2,1,1,2,1,2,1,2,2,1,2,2,1,1,1,1,1,2,2,2,2,1,2,1,1,1,2,2,2,1,2,1,2,1,2,1,2,2,2,2,2,1,2,2,2,1,1,2,2,1,2,1,1,1,2,2,1,1,1,2,1,1,1,1,1,2,2,1,1,2,1,2,2,2,1,1,1,2,1,1,1,1,1,1,1,2,2,2,1,2,1,1,1,1,1,2,2,2,2,1,2,2,1,2,2,2,1,2,1,1,1,2,1,0,2,1,2,1,1,1,2,2,1,1,1,1,1,2,2,2,1,2,2,1,1,1,1,1,2,2],\"index\":[\"sleep and learning\",\"character computing\",\"coma\",\"self-deception\",\"brainwashing\",\"resentment\",\"open-mindedness\",\"evolutionary psychology\",\"law of effect\",\"child behavior checklist\",\"verbal behavior\",\"classical test theory\",\"obtundation\",\"detection theory\",\"reasoned action approach\",\"altered states\",\"medical psychology\",\"seasonal affective disorder\",\"hong kong college of psychiatrists\",\"timeline of psychology\",\"psychological nativism\",\"barbara rogoff\",\"list of psychiatric medications\",\"causa sui\",\"helene deutsch\",\"crazy therapies\",\"mindfreedom international\",\"jenkins activity survey\",\"hypnosis\",\"sascha altman dubrul\",\"transpersonal psychology\",\"sopor (sleep)\",\"behaviour therapy\",\"psycho-oncology\",\"sleep-learning\",\"spearman medal\",\"sublimation (psychology)\",\"why zebras don't get ulcers\",\"general knowledge\",\"gestaltzerfall\",\"hedonism\",\"out-of-body experience\",\"biosocial criminology\",\"five stages of grief\",\"preconscious\",\"journal of the american psychoanalytic association\",\"society for philosophy and psychology\",\"women-are-wonderful effect\",\"freud's seduction theory\",\"list of schools of psychoanalysis\",\"creativity\",\"nobody nowhere\",\"transliminality\",\"titicut follies\",\"histrionic personality disorder\",\"dsm-iv codes\",\"levitation (paranormal)\",\"cat intelligence\",\"the concept of anxiety\",\"intelligence\",\"abnormal psychology\",\"two-factor theory of emotion\",\"unitarian universalism\",\"laterality\",\"flashback (psychology)\",\"nominative determinism\",\"autogenic training\",\"little albert experiment\",\"british psychotherapy foundation\",\"internal family systems model\",\"psychoinformatics\",\"inner peace\",\"history of dyslexia research\",\"anguish\",\"self-assessment\",\"is the glass half empty or half full?\",\"id, ego and super-ego\",\"outline of psychology\",\"information metabolism\",\"identity (philosophy)\",\"behavioral neuroscience\",\"shock value\",\"adlerian\",\"accuracy and precision\",\"grotesque body\",\"la borde clinic\",\"self-criticism\",\"oskar pfister award\",\"international association of art critics\",\"developmental psychology\",\"european federation of psychologists' associations\",\"object relations theory\",\"emotional reasoning\",\"slain in the spirit\",\"repeatability\",\"how are we to live?\",\"mediumship\",\"psychological evaluation\",\"global workspace theory\",\"wakefulness\",\"biorhythm (pseudoscience)\",\"intelligence quotient\",\"sock puppet account\",\"radical psychology network\",\"answer to job\",\"task analysis\",\"solitary confinement\",\"james\\u2013lange theory\",\"influence: science and practice\",\"applied psychological measurement\",\"ernest jones\",\"blank expression\",\"sequential probability ratio test\",\"psychoanalysis\",\"on narcissism\",\"conspicuous conservation\",\"william frankena\",\"life and how to survive it\",\"motivational salience\",\"superiority complex\",\"catharsis\",\"flow (psychology)\",\"behavior\",\"biophilia hypothesis\",\"pride\",\"direct and indirect realism\",\"microexpression\",\"comprehension approach\",\"music psychology\",\"gratitude\",\"ego integrity\",\"hereditarianism\",\"naturalistic observation\",\"conjoint analysis\",\"cognitive intervention\",\"subconscious\",\"trait ascription bias\",\"cognitivism (psychology)\",\"just-noticeable difference\",\"timeline of psychotherapy\",\"poker\",\"neutral stimulus\",\"persistent vegetative state\",\"list of mnemonics\",\"piaget's theory of cognitive development\",\"ferdinand de saussure\",\"burlesque\",\"behavioral pharmacology\",\"sid parnes\",\"feeling good: the new mood therapy\",\"list of neurological conditions and disorders\",\"list of credentials in psychology\",\"alter ego\",\"list of psychology awards\",\"cosmos and psyche\",\"eating disorder\",\"computational theory of mind\",\"proportionality bias\",\"disordered eating\",\"appraisal theory\",\"behavioural despair test\",\"civilization in transition\",\"psychological resistance\",\"mania\",\"list of psychiatric medications by condition treated\",\"dysthymia\",\"neglect\",\"bicameral mentality\",\"ernst mally\",\"gnosis (chaos magic)\",\"rationalism\",\"sybil (schreiber book)\",\"theories of humor\",\"normalcy bias\",\"self-hypnosis\",\"defence mechanism\",\"richard wiseman\",\"lady wonder\",\"sarnoff a. mednick\",\"harry harlow\",\"history of psychotherapy\",\"eustress\",\"imaginary audience\",\"henri poincar\\u00e9\",\"sunk cost\",\"law of the instrument\",\"abilene paradox\",\"implicit-association test\",\"dark triad\",\"frieda fromm-reichmann\",\"sensory threshold\",\"international general medical society for psychotherapy\",\"stimulation\",\"ambidexterity\",\"adaptive unconscious\",\"minsky's burlesque\",\"harvey jackins\",\"bps barbara wilson lifetime achievement award\",\"obliviousness\",\"chaining\",\"list of cycles\",\"gustave le bon\",\"cabin fever\",\"menninger foundation\",\"emotions in virtual communication\",\"core self-evaluations\",\"guttman scale\",\"task force\",\"fight-or-flight response\",\"blink: the power of thinking without thinking\",\"emotional selection\",\"repertory grid\",\"automatic writing\",\"social cognition and interaction training\",\"international society of political psychology\",\"meta learning\",\"psychoanalytic theory\",\"kindness\",\"thumos\",\"mad pride\",\"astrology\",\"contemplation\",\"david marks (psychologist)\",\"egosyntonic and egodystonic\",\"psychological statistics\",\"philosophical analysis\",\"field theory (psychology)\",\"boris maciejovsky\",\"destabilisation\",\"vocabulary development\",\"waking the tiger\",\"alchemical studies\",\"cover-up\",\"the freudian coverup\",\"statistical inference\",\"mourning and melancholia\",\"pathos\",\"psychometrics\",\"hypnodermatology\",\"general semantics\",\"reliability (statistics)\",\"confusion\",\"bipolar i disorder\",\"facial expression\",\"tortured artist\",\"emotivism\",\"quantitative psychological research\",\"mentalization\",\"aversives\",\"david chalmers\",\"rage (emotion)\",\"pattern recognition (psychology)\",\"acceptance and commitment therapy\",\"apprehension (understanding)\",\"pseudodysphagia\",\"d\\u00e9j\\u00e0 vu\",\"richard dawkins\",\"post-cognitivist psychology\",\"index of psychometrics articles\",\"anhedonia\",\"hostility\",\"cyranoid\",\"learning\",\"koestler parapsychology unit\",\"crying\",\"modular cognition framework\",\"marie-louise von franz\",\"acceptance\",\"gestalt psychology\",\"cogito, ergo sum\",\"altered state of consciousness\",\"awareness\",\"outline of autism\",\"noosphere\",\"conversational model\",\"list of psychological research methods\",\"outline of thought\",\"psychological trauma\",\"self-defeating prophecy\",\"list of mental disorders\",\"relational developmental systems\",\"attachment parenting\",\"id\\u00e9e fixe (psychology)\",\"mortido\",\"who moved my cheese?\",\"affect (psychology)\",\"occupational health psychology\",\"emotional abuse\",\"paradoxical intention\",\"the emperor's new mind\",\"gestalt theoretical psychotherapy\",\"list of cognitive biases\",\"soul\",\"unipolar mania\",\"amusement\",\"conditioned emotional response\",\"creativity and mental health\",\"anti-psychiatry\",\"models of abnormality\",\"hermann lotze\",\"social degeneration\",\"categorical perception\",\"schizotypy\",\"joint attention\",\"shadow (psychology)\",\"technobiophilia\",\"list of psychology organizations\",\"social dominance orientation\",\"theory x and theory y\",\"philosophy of sex\",\"spirituality\",\"asch conformity experiments\",\"performance\",\"aion: researches into the phenomenology of the self\",\"list of psychological schools\",\"major depressive disorder\",\"american association for the abolition of involuntary mental hospitalization\",\"psychohistory\",\"moral emotions\",\"paul ferdinand schilder\",\"open field (animal test)\",\"sociometric status\",\"pit of despair\",\"national association of school psychologists\",\"pathognomy\",\"interpersonal neurobiology\",\"neural adaptation\",\"multidimensional aptitude battery ii\",\"cognitive bias\",\"specialist in psychology\",\"neurophilosophy\",\"self-awareness\",\"auditory hallucination\",\"wilhelm windelband\",\"frustration\\u2013aggression hypothesis\",\"kurt koffka medal\",\"identity crisis\",\"transfer (propaganda)\",\"jacqueline rose\",\"dynamicism\",\"johann friedrich herbart\",\"mental environment\",\"emotionality\",\"schadenfreude\",\"psychomotor retardation\",\"snackwell effect\",\"ecological psychology\",\"psychonautics\",\"swanson, nolan and pelham teacher and parent rating scale\",\"causes of transsexuality\",\"probability matching\",\"participatory theory\"],\"node_colour\":[\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\",\"#208F8C\"],\"node_sizes\":[1.0,0.25,2.25,1.5,3.0,6.25,0.5,6.25,0.5,0.25,0.5,1.25,1.25,2.25,0.25,0.25,1.25,2.5,2.5,5.25,0.5,0.25,1.75,0.25,1.75,1.75,1.75,0.25,6.75,1.75,3.5,0.75,2.5,2.25,0.5,0.25,0.25,0.25,0.5,0.25,1.5,2.5,1.0,0.25,4.75,0.5,0.25,1.0,1.25,3.5,5.5,0.25,0.5,0.0,2.0,2.25,2.0,0.75,1.25,18.0,3.5,1.0,0.75,0.5,1.0,0.0,3.0,0.75,5.25,0.25,0.25,2.25,0.0,6.5,0.25,0.25,4.0,6.75,0.25,1.5,7.75,0.25,3.5,1.5,0.25,0.0,0.75,0.25,0.0,6.5,0.5,3.5,4.5,0.25,0.5,0.0,3.25,0.75,1.5,1.5,0.75,2.0,0.0,1.75,1.75,0.5,1.0,0.25,0.0,0.25,4.0,0.75,0.25,13.0,2.25,0.0,0.25,0.25,0.5,0.75,2.75,1.25,4.75,0.5,7.0,0.75,0.5,0.25,2.75,7.0,0.75,0.75,0.25,0.0,0.25,3.0,0.75,2.25,0.25,1.5,1.0,0.5,1.5,0.5,1.25,0.75,1.0,0.0,0.25,0.5,1.75,0.25,0.5,1.5,0.75,5.5,1.5,0.5,0.25,3.75,0.75,1.75,0.75,4.25,2.25,2.5,7.0,1.5,1.25,0.5,3.5,0.25,0.25,0.5,0.75,2.75,1.5,1.0,0.25,8.0,1.75,0.75,0.25,2.0,1.0,0.75,0.5,1.0,1.0,0.25,0.25,0.5,3.75,1.0,0.5,0.25,0.5,0.25,0.25,2.75,0.5,1.0,0.75,0.5,3.75,0.0,0.25,2.5,1.0,0.75,3.75,1.0,2.0,2.25,0.25,0.25,6.75,7.0,0.0,2.5,4.25,1.5,0.25,0.75,0.75,2.0,0.25,0.0,1.25,0.75,0.25,1.75,0.5,0.25,0.75,1.75,6.5,12.5,0.25,0.0,1.5,7.25,1.75,1.25,0.25,0.75,1.25,0.25,0.5,3.5,4.5,0.75,4.0,0.25,0.25,0.75,2.0,0.25,0.5,3.0,6.75,0.0,4.75,1.0,1.0,0.0,2.25,6.75,3.75,1.75,4.75,4.5,0.5,0.5,1.25,1.75,4.75,2.25,0.25,3.25,0.25,2.25,0.5,2.75,0.0,3.75,1.75,1.25,0.25,0.75,0.25,2.25,7.25,0.25,6.5,1.25,1.5,5.75,0.75,2.5,0.0,0.5,1.0,0.5,3.5,0.25,2.0,2.0,0.0,0.25,4.0,2.0,0.25,2.75,3.0,4.5,1.5,2.5,4.25,0.25,0.75,0.5,0.75,0.25,6.0,1.25,0.0,0.25,4.5,0.25,2.5,2.75,2.0,5.5,0.5,1.0,0.75,0.0,0.75,1.0,1.25,0.25,6.5,6.5,1.0,0.0,1.5,0.75,1.5,0.0,0.25,0.5],\"parent\":[\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\",\"psychology\"]},\"selected\":{\"id\":\"2707\"},\"selection_policy\":{\"id\":\"2706\"}},\"id\":\"1615\",\"type\":\"ColumnDataSource\"},{\"attributes\":{\"data_source\":{\"id\":\"1619\"},\"glyph\":{\"id\":\"1644\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1621\"}},\"id\":\"1620\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"1589\",\"type\":\"LinearScale\"},{\"attributes\":{},\"id\":\"1604\",\"type\":\"ResetTool\"},{\"attributes\":{\"source\":{\"id\":\"1619\"}},\"id\":\"1621\",\"type\":\"CDSView\"},{\"attributes\":{},\"id\":\"1594\",\"type\":\"BasicTicker\"},{\"attributes\":{\"formatter\":{\"id\":\"2691\"},\"major_label_policy\":{\"id\":\"2689\"},\"ticker\":{\"id\":\"1594\"},\"visible\":false},\"id\":\"1593\",\"type\":\"LinearAxis\"},{\"attributes\":{\"axis\":{\"id\":\"1593\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"1596\",\"type\":\"Grid\"},{\"attributes\":{\"text\":\"Network for discipline: psychology\",\"text_font_size\":\"12pt\"},\"id\":\"1612\",\"type\":\"Title\"},{\"attributes\":{},\"id\":\"1602\",\"type\":\"WheelZoomTool\"},{\"attributes\":{\"above\":[{\"id\":\"1612\"}],\"below\":[{\"id\":\"1593\"}],\"center\":[{\"id\":\"1596\"},{\"id\":\"1600\"}],\"height\":500,\"left\":[{\"id\":\"1597\"}],\"renderers\":[{\"id\":\"1613\"}],\"title\":{\"id\":\"2668\"},\"toolbar\":{\"id\":\"1606\"},\"width\":500,\"x_range\":{\"id\":\"1584\"},\"x_scale\":{\"id\":\"1589\"},\"y_range\":{\"id\":\"1585\"},\"y_scale\":{\"id\":\"1591\"}},\"id\":\"1586\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{\"data\":{\"end\":[\"learning\",\"hypnosis\",\"sleep-learning\",\"preconscious\",\"behavior\",\"persistent vegetative state\",\"awareness\",\"list of neurological conditions and disorders\",\"obtundation\",\"sopor (sleep)\",\"coma\",\"altered state of consciousness\",\"wakefulness\",\"histrionic personality disorder\",\"psychoanalytic theory\",\"outline of thought\",\"self-deception\",\"awareness\",\"asch conformity experiments\",\"destabilisation\",\"emotional abuse\",\"brainwashing\",\"mediumship\",\"lady wonder\",\"hypnosis\",\"solitary confinement\",\"levitation (paranormal)\",\"astrology\",\"automatic writing\",\"intelligence\",\"pathognomy\",\"pathos\",\"wilhelm windelband\",\"neglect\",\"pride\",\"kindness\",\"acceptance\",\"gratitude\",\"rage (emotion)\",\"resentment\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"anguish\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"hostility\",\"affect (psychology)\",\"appraisal theory\",\"open-mindedness\",\"developmental psychology\",\"cognitive bias\",\"piaget's theory of cognitive development\",\"harry harlow\",\"psychometrics\",\"unitarian universalism\",\"spirituality\",\"behavioral neuroscience\",\"richard dawkins\",\"psychological nativism\",\"intelligence\",\"list of psychological schools\",\"social dominance orientation\",\"outline of psychology\",\"timeline of psychology\",\"computational theory of mind\",\"biophilia hypothesis\",\"soul\",\"evolutionary psychology\",\"ecological psychology\",\"shadow (psychology)\",\"fight-or-flight response\",\"mental environment\",\"biosocial criminology\",\"timeline of psychology\",\"cat intelligence\",\"developmental psychology\",\"psychometrics\",\"timeline of psychology\",\"psychometrics\",\"sequential probability ratio test\",\"guttman scale\",\"reliability (statistics)\",\"psychological statistics\",\"persistent vegetative state\",\"obtundation\",\"sopor (sleep)\",\"psychometrics\",\"intelligence\",\"behavioral neuroscience\",\"neurophilosophy\",\"just-noticeable difference\",\"interpersonal neurobiology\",\"eating disorder\",\"harry harlow\",\"sensory threshold\",\"behavior\",\"psychonautics\",\"psychometrics\",\"intelligence\",\"behavioral neuroscience\",\"outline of psychology\",\"harry harlow\",\"mania\",\"major depressive disorder\",\"abnormal psychology\",\"anhedonia\",\"dysthymia\",\"bipolar i disorder\",\"eating disorder\",\"cabin fever\",\"auditory hallucination\",\"psychomotor retardation\",\"anti-psychiatry\",\"psychoanalysis\",\"dsm-iv codes\",\"list of mental disorders\",\"list of psychiatric medications\",\"list of psychiatric medications by condition treated\",\"eating disorder\",\"list of neurological conditions and disorders\",\"psychological evaluation\",\"psycho-oncology\",\"psychometrics\",\"anti-psychiatry\",\"intelligence\",\"transpersonal psychology\",\"psychoanalysis\",\"asch conformity experiments\",\"mania\",\"outline of psychology\",\"gestalt psychology\",\"gustave le bon\",\"little albert experiment\",\"identity crisis\",\"the concept of anxiety\",\"hermann lotze\",\"harry harlow\",\"object relations theory\",\"two-factor theory of emotion\",\"timeline of psychotherapy\",\"rationalism\",\"developmental psychology\",\"anti-psychiatry\",\"psychoanalysis\",\"outline of psychology\",\"list of psychiatric medications by condition treated\",\"eating disorder\",\"psycho-oncology\",\"rationalism\",\"psychoanalysis\",\"list of schools of psychoanalysis\",\"psychoanalytic theory\",\"preconscious\",\"id, ego and super-ego\",\"ernest jones\",\"adlerian\",\"anti-psychiatry\",\"psychoanalytic theory\",\"radical psychology network\",\"american association for the abolition of involuntary mental hospitalization\",\"mad pride\",\"mindfreedom international\",\"sascha altman dubrul\",\"anti-psychiatry\",\"psychoanalytic theory\",\"radical psychology network\",\"american association for the abolition of involuntary mental hospitalization\",\"mad pride\",\"sascha altman dubrul\",\"psychometrics\",\"psychoanalysis\",\"abnormal psychology\",\"astrology\",\"chaining\",\"autogenic training\",\"sybil (schreiber book)\",\"altered state of consciousness\",\"mediumship\",\"behaviour therapy\",\"acceptance and commitment therapy\",\"d\\u00e9j\\u00e0 vu\",\"hypnosis\",\"outline of thought\",\"levitation (paranormal)\",\"subconscious\",\"alter ego\",\"hypnodermatology\",\"flow (psychology)\",\"slain in the spirit\",\"catharsis\",\"lady wonder\",\"self-hypnosis\",\"psychonautics\",\"automatic writing\",\"anti-psychiatry\",\"psychoanalytic theory\",\"radical psychology network\",\"american association for the abolition of involuntary mental hospitalization\",\"mad pride\",\"psychometrics\",\"creativity\",\"intelligence\",\"participatory theory\",\"behavioral neuroscience\",\"list of psychological schools\",\"altered state of consciousness\",\"psychoanalysis\",\"outline of psychology\",\"harry harlow\",\"history of psychotherapy\",\"levitation (paranormal)\",\"spirituality\",\"persistent vegetative state\",\"psychoanalysis\",\"chaining\",\"catharsis\",\"acceptance and commitment therapy\",\"autogenic training\",\"conversational model\",\"british psychotherapy foundation\",\"social cognition and interaction training\",\"history of psychotherapy\",\"dsm-iv codes\",\"list of mental disorders\",\"list of psychiatric medications by condition treated\",\"eating disorder\",\"list of neurological conditions and disorders\",\"psycho-oncology\",\"subconscious\",\"list of psychology awards\",\"catharsis\",\"fight-or-flight response\",\"intelligence\",\"vocabulary development\",\"gestalt psychology\",\"rationalism\",\"cognitive bias\",\"anhedonia\",\"hedonism\",\"abilene paradox\",\"soul\",\"persistent vegetative state\",\"altered state of consciousness\",\"koestler parapsychology unit\",\"mediumship\",\"mortido\",\"richard wiseman\",\"levitation (paranormal)\",\"schizotypy\",\"automatic writing\",\"intelligence\",\"richard dawkins\",\"solitary confinement\",\"acceptance\",\"creativity\",\"psychoanalysis\",\"list of schools of psychoanalysis\",\"psychoanalytic theory\",\"shadow (psychology)\",\"subconscious\",\"ernest jones\",\"british psychotherapy foundation\",\"defence mechanism\",\"freud's seduction theory\",\"id, ego and super-ego\",\"on narcissism\",\"adlerian\",\"mortido\",\"outline of thought\",\"object relations theory\",\"mourning and melancholia\",\"psychoanalysis\",\"mourning and melancholia\",\"david chalmers\",\"psychometrics\",\"intelligence\",\"behavioral neuroscience\",\"harry harlow\",\"psychoanalysis\",\"on narcissism\",\"mourning and melancholia\",\"the freudian coverup\",\"psychoanalysis\",\"outline of psychology\",\"menninger foundation\",\"ernest jones\",\"british psychotherapy foundation\",\"shadow (psychology)\",\"defence mechanism\",\"id, ego and super-ego\",\"adlerian\",\"mortido\",\"psychoanalytic theory\",\"object relations theory\",\"psychometrics\",\"intelligence quotient\",\"sid parnes\",\"piaget's theory of cognitive development\",\"creativity\",\"outline of thought\",\"mania\",\"transliminality\",\"henri poincar\\u00e9\",\"sarnoff a. mednick\",\"major depressive disorder\",\"ambidexterity\",\"music psychology\",\"creativity and mental health\",\"shadow (psychology)\",\"learning\",\"psychoanalytic theory\",\"intelligence\",\"schizotypy\",\"outline of autism\",\"schizotypy\",\"eating disorder\",\"list of mental disorders\",\"emotionality\",\"pride\",\"psychoanalytic theory\",\"dsm-iv codes\",\"psychological evaluation\",\"anti-psychiatry\",\"psychoanalysis\",\"major depressive disorder\",\"outline of psychology\",\"eating disorder\",\"bipolar i disorder\",\"spirituality\",\"astrology\",\"mediumship\",\"koestler parapsychology unit\",\"intelligence\",\"behavior\",\"anguish\",\"the concept of anxiety\",\"johann friedrich herbart\",\"psychometrics\",\"developmental psychology\",\"attachment parenting\",\"intelligence quotient\",\"acceptance\",\"gratitude\",\"rage (emotion)\",\"pattern recognition (psychology)\",\"flashback (psychology)\",\"piaget's theory of cognitive development\",\"hereditarianism\",\"cogito, ergo sum\",\"hermann lotze\",\"pathos\",\"swanson, nolan and pelham teacher and parent rating scale\",\"david marks (psychologist)\",\"harry harlow\",\"outline of thought\",\"cognitivism (psychology)\",\"stimulation\",\"ernst mally\",\"behavioral neuroscience\",\"identity (philosophy)\",\"occupational health psychology\",\"confusion\",\"psychohistory\",\"richard dawkins\",\"social cognition and interaction training\",\"psychoanalytic theory\",\"affect (psychology)\",\"intelligence\",\"conditioned emotional response\",\"pathognomy\",\"list of psychological schools\",\"quantitative psychological research\",\"outline of psychology\",\"self-awareness\",\"gestalt psychology\",\"emotional selection\",\"david chalmers\",\"computational theory of mind\",\"emotions in virtual communication\",\"task force\",\"emotional reasoning\",\"abnormal psychology\",\"anguish\",\"emotionality\",\"list of psychological research methods\",\"music psychology\",\"schadenfreude\",\"wilhelm windelband\",\"amusement\",\"moral emotions\",\"hostility\",\"kindness\",\"pride\",\"learning\",\"list of psychology organizations\",\"appraisal theory\",\"repertory grid\",\"psychometrics\",\"behavior\",\"behavioral neuroscience\",\"mania\",\"outline of psychology\",\"pseudodysphagia\",\"models of abnormality\",\"harry harlow\",\"psychoanalytic theory\",\"history of psychotherapy\",\"egosyntonic and egodystonic\",\"cognitive bias\",\"emotionality\",\"james\\u2013lange theory\",\"soul\",\"spirituality\",\"bicameral mentality\",\"ambidexterity\",\"psychometrics\",\"behavioral neuroscience\",\"harry harlow\",\"psychoanalysis\",\"chaining\",\"self-hypnosis\",\"catharsis\",\"acceptance and commitment therapy\",\"menninger foundation\",\"conversational model\",\"british psychotherapy foundation\",\"social cognition and interaction training\",\"history of psychotherapy\",\"conditioned emotional response\",\"neutral stimulus\",\"attachment parenting\",\"soul\",\"psychoanalysis\",\"chaining\",\"psychoanalytic theory\",\"aion: researches into the phenomenology of the self\",\"harry harlow\",\"acceptance and commitment therapy\",\"id, ego and super-ego\",\"ernest jones\",\"adlerian\",\"on narcissism\",\"mourning and melancholia\",\"object relations theory\",\"alchemical studies\",\"answer to job\",\"marie-louise von franz\",\"psychological trauma\",\"psychometrics\",\"soul\",\"spirituality\",\"astrology\",\"kindness\",\"gratitude\",\"inner peace\",\"awareness\",\"contemplation\",\"pathognomy\",\"pathos\",\"wilhelm windelband\",\"neglect\",\"pride\",\"kindness\",\"hostility\",\"acceptance\",\"amusement\",\"gratitude\",\"rage (emotion)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotional reasoning\",\"anguish\",\"confusion\",\"emotionality\",\"schadenfreude\",\"moral emotions\",\"affect (psychology)\",\"appraisal theory\",\"sociometric status\",\"list of cognitive biases\",\"psychoanalysis\",\"psychoanalytic theory\",\"alter ego\",\"shadow (psychology)\",\"ernest jones\",\"defence mechanism\",\"on narcissism\",\"adlerian\",\"mortido\",\"life and how to survive it\",\"object relations theory\",\"mourning and melancholia\",\"psychometrics\",\"developmental psychology\",\"behavior\",\"psychoanalysis\",\"ecological psychology\",\"behavioral neuroscience\",\"occupational health psychology\",\"music psychology\",\"list of psychological research methods\",\"outline of autism\",\"list of credentials in psychology\",\"list of mnemonics\",\"gestalt psychology\",\"list of mental disorders\",\"list of psychiatric medications by condition treated\",\"list of psychology organizations\",\"outline of thought\",\"timeline of psychotherapy\",\"psychoanalysis\",\"soul\",\"cogito, ergo sum\",\"hermann lotze\",\"task force\",\"ernst mally\",\"psychometrics\",\"developmental psychology\",\"learning\",\"list of psychological schools\",\"quantitative psychological research\",\"neurophilosophy\",\"interpersonal neurobiology\",\"gestalt psychology\",\"eating disorder\",\"swanson, nolan and pelham teacher and parent rating scale\",\"harry harlow\",\"cognitivism (psychology)\",\"occupational health psychology\",\"list of psychological research methods\",\"music psychology\",\"models of abnormality\",\"psychohistory\",\"social cognition and interaction training\",\"psychoanalytic theory\",\"list of psychology organizations\",\"repertory grid\",\"conditioned emotional response\",\"asch conformity experiments\",\"psychoanalysis\",\"neglect\",\"shadow (psychology)\",\"ernest jones\",\"adlerian\",\"mortido\",\"object relations theory\",\"defence mechanism\",\"psychometrics\",\"outline of thought\",\"reliability (statistics)\",\"accuracy and precision\",\"repeatability\",\"burlesque\",\"major depressive disorder\",\"self-criticism\",\"list of psychology awards\",\"psychometrics\",\"naturalistic observation\",\"developmental psychology\",\"sociometric status\",\"ego integrity\",\"list of psychological schools\",\"piaget's theory of cognitive development\",\"interpersonal neurobiology\",\"kurt koffka medal\",\"harry harlow\",\"specialist in psychology\",\"ecological psychology\",\"relational developmental systems\",\"moral emotions\",\"list of psychology awards\",\"learning\",\"attachment parenting\",\"crying\",\"implicit-association test\",\"list of psychology organizations\",\"list of psychology awards\",\"attachment parenting\",\"psychoanalysis\",\"psychoanalytic theory\",\"harry harlow\",\"ernest jones\",\"mortido\",\"ego integrity\",\"defence mechanism\",\"psychometrics\",\"pathognomy\",\"pathos\",\"neglect\",\"pride\",\"kindness\",\"hostility\",\"acceptance\",\"amusement\",\"confusion\",\"gratitude\",\"cognitive bias\",\"emotionality\",\"schadenfreude\",\"outline of thought\",\"reliability (statistics)\",\"spirituality\",\"astrology\",\"koestler parapsychology unit\",\"biorhythm (pseudoscience)\",\"richard wiseman\",\"automatic writing\",\"mediumship\",\"lady wonder\",\"psychoanalysis\",\"soul\",\"david chalmers\",\"subconscious\",\"awareness\",\"altered state of consciousness\",\"the emperor's new mind\",\"acceptance and commitment therapy\",\"awareness\",\"altered state of consciousness\",\"wakefulness\",\"astrology\",\"psychohistory\",\"psychometrics\",\"intelligence quotient\",\"index of psychometrics articles\",\"multidimensional aptitude battery ii\",\"learning\",\"anti-psychiatry\",\"psychoanalytic theory\",\"mad pride\",\"american association for the abolition of involuntary mental hospitalization\",\"soul\",\"aion: researches into the phenomenology of the self\",\"civilization in transition\",\"shadow (psychology)\",\"alchemical studies\",\"marie-louise von franz\",\"ecological psychology\",\"chaining\",\"solitary confinement\",\"psychological statistics\",\"psychoanalysis\",\"timeline of psychotherapy\",\"gustave le bon\",\"psychoanalytic theory\",\"shadow (psychology)\",\"ernest jones\",\"defence mechanism\",\"mortido\",\"confusion\",\"facial expression\",\"poker\",\"attachment parenting\",\"anti-psychiatry\",\"psychological trauma\",\"civilization in transition\",\"acceptance and commitment therapy\",\"feeling good: the new mood therapy\",\"list of psychiatric medications by condition treated\",\"list of neurological conditions and disorders\",\"major depressive disorder\",\"psychohistory\",\"chaining\",\"social cognition and interaction training\",\"mortido\",\"list of mental disorders\",\"psychological resistance\",\"psychoanalytic theory\",\"egosyntonic and egodystonic\",\"ferdinand de saussure\",\"conversational model\",\"list of psychological schools\",\"jacqueline rose\",\"psychoanalysis\",\"on narcissism\",\"eating disorder\",\"aion: researches into the phenomenology of the self\",\"catharsis\",\"shadow (psychology)\",\"defence mechanism\",\"history of psychotherapy\",\"mourning and melancholia\",\"superiority complex\",\"dark triad\",\"egosyntonic and egodystonic\",\"mourning and melancholia\",\"emotivism\",\"anhedonia\",\"psychological resistance\",\"cognitive bias\",\"dark triad\",\"pathos\",\"chaining\",\"acceptance and commitment therapy\",\"harvey jackins\",\"catharsis\",\"spirituality\",\"poker\",\"awareness\",\"altered state of consciousness\",\"auditory hallucination\",\"aversives\",\"cognitive bias\",\"altered state of consciousness\",\"eating disorder\",\"outline of thought\",\"subconscious\",\"confusion\",\"soul\",\"ecological psychology\",\"amusement\",\"hostility\",\"behavior\",\"technobiophilia\",\"pathognomy\",\"pathos\",\"sunk cost\",\"wilhelm windelband\",\"self-awareness\",\"neglect\",\"acceptance\",\"gratitude\",\"mad pride\",\"rage (emotion)\",\"emotional selection\",\"dark triad\",\"emotions in virtual communication\",\"stimulation\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"hostility\",\"kindness\",\"affect (psychology)\",\"appraisal theory\",\"rationalism\",\"task force\",\"david chalmers\",\"facial expression\",\"blink: the power of thinking without thinking\",\"vocabulary development\",\"psychometrics\",\"learning\",\"performance\",\"gestalt psychology\",\"music psychology\",\"harry harlow\",\"soul\",\"spirituality\",\"pathognomy\",\"pathos\",\"wilhelm windelband\",\"neglect\",\"kindness\",\"hostility\",\"acceptance\",\"amusement\",\"confusion\",\"gratitude\",\"rage (emotion)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"emotionality\",\"schadenfreude\",\"moral emotions\",\"affect (psychology)\",\"appraisal theory\",\"psychometrics\",\"hereditarianism\",\"acceptance and commitment therapy\",\"david chalmers\",\"henri poincar\\u00e9\",\"adaptive unconscious\",\"outline of thought\",\"altered state of consciousness\",\"subconscious\",\"psychometrics\",\"list of cognitive biases\",\"cognitive bias\",\"psychometrics\",\"learning\",\"harry harlow\",\"computational theory of mind\",\"cognitivism (psychology)\",\"dynamicism\",\"anti-psychiatry\",\"spirituality\",\"mania\",\"poker\",\"aversives\",\"list of cycles\",\"awareness\",\"outline of thought\",\"imaginary audience\",\"richard dawkins\",\"task force\",\"minsky's burlesque\",\"burlesque\",\"outline of thought\",\"anti-psychiatry\",\"list of mental disorders\",\"eating disorder\",\"bps barbara wilson lifetime achievement award\",\"kurt koffka medal\",\"richard dawkins\",\"astrology\",\"participatory theory\",\"anti-psychiatry\",\"neurophilosophy\",\"mania\",\"major depressive disorder\",\"list of mental disorders\",\"list of psychiatric medications by condition treated\",\"acceptance and commitment therapy\",\"dysthymia\",\"disordered eating\",\"eating disorder\",\"neurophilosophy\",\"task force\",\"david chalmers\",\"list of cognitive biases\",\"cognitive bias\",\"pathognomy\",\"pathos\",\"neglect\",\"kindness\",\"hostility\",\"acceptance\",\"amusement\",\"confusion\",\"emotionality\",\"schadenfreude\",\"learning\",\"open field (animal test)\",\"pit of despair\",\"soul\",\"aion: researches into the phenomenology of the self\",\"alchemical studies\",\"marie-louise von franz\",\"international general medical society for psychotherapy\",\"defence mechanism\",\"bipolar i disorder\",\"auditory hallucination\",\"unipolar mania\",\"psychomotor retardation\",\"altered state of consciousness\",\"anhedonia\",\"list of mental disorders\",\"mania\",\"major depressive disorder\",\"dysthymia\",\"anti-psychiatry\",\"major depressive disorder\",\"dysthymia\",\"major depressive disorder\",\"list of mental disorders\",\"anhedonia\",\"bipolar i disorder\",\"auditory hallucination\",\"psychomotor retardation\",\"psychological trauma\",\"pathognomy\",\"pathos\",\"wilhelm windelband\",\"acceptance\",\"destabilisation\",\"rage (emotion)\",\"emotional selection\",\"emotions in virtual communication\",\"stimulation\",\"neglect\",\"confusion\",\"emotionality\",\"schadenfreude\",\"emotional abuse\",\"amusement\",\"moral emotions\",\"hostility\",\"kindness\",\"affect (psychology)\",\"richard dawkins\",\"self-awareness\",\"psychohistory\",\"automatic writing\",\"ambidexterity\",\"soul\",\"cogito, ergo sum\",\"hermann lotze\",\"self-hypnosis\",\"altered state of consciousness\",\"neurophilosophy\",\"philosophy of sex\",\"cogito, ergo sum\",\"henri poincar\\u00e9\",\"task force\",\"rationalism\",\"wilhelm windelband\",\"philosophical analysis\",\"astrology\",\"schadenfreude\",\"list of cognitive biases\",\"cognitive bias\",\"list of cognitive biases\",\"psychoanalytic theory\",\"acceptance and commitment therapy\",\"richard dawkins\",\"automatic writing\",\"richard wiseman\",\"astrology\",\"psychometrics\",\"attachment parenting\",\"occupational health psychology\",\"gestalt psychology\",\"list of psychological research methods\",\"list of psychology organizations\",\"psychoanalytic theory\",\"psychohistory\",\"list of psychological schools\",\"quantitative psychological research\",\"swanson, nolan and pelham teacher and parent rating scale\",\"harry harlow\",\"social cognition and interaction training\",\"repertory grid\",\"pit of despair\",\"conditioned emotional response\",\"chaining\",\"acceptance and commitment therapy\",\"attachment parenting\",\"eustress\",\"neurophilosophy\",\"wilhelm windelband\",\"henri poincar\\u00e9\",\"philosophical analysis\",\"cognitive bias\",\"sunk cost\",\"anti-psychiatry\",\"list of cognitive biases\",\"cognitive bias\",\"self-defeating prophecy\",\"asch conformity experiments\",\"social dominance orientation\",\"blink: the power of thinking without thinking\",\"spirituality\",\"creativity and mental health\",\"aion: researches into the phenomenology of the self\",\"pathognomy\",\"pathos\",\"kindness\",\"hostility\",\"acceptance\",\"amusement\",\"confusion\",\"emotionality\",\"schadenfreude\",\"creativity and mental health\",\"blink: the power of thinking without thinking\",\"anti-psychiatry\",\"awareness\",\"acceptance and commitment therapy\",\"conversational model\",\"social cognition and interaction training\",\"astrology\",\"gustave le bon\",\"cabin fever\",\"pathognomy\",\"pathos\",\"kindness\",\"hostility\",\"acceptance\",\"amusement\",\"confusion\",\"emotionality\",\"schadenfreude\",\"david chalmers\",\"philosophical analysis\",\"task force\",\"fight-or-flight response\",\"pathognomy\",\"pathos\",\"kindness\",\"hostility\",\"acceptance\",\"amusement\",\"confusion\",\"emotionality\",\"schadenfreude\",\"psychometrics\",\"astrology\",\"koestler parapsychology unit\",\"psychometrics\",\"acceptance and commitment therapy\",\"list of psychology organizations\",\"mentalization\",\"psychometrics\",\"anti-psychiatry\",\"mad pride\",\"shadow (psychology)\",\"mortido\",\"psychoanalytic theory\",\"soul\",\"spirituality\",\"pathognomy\",\"pathos\",\"wilhelm windelband\",\"acceptance\",\"rage (emotion)\",\"confusion\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"hostility\",\"kindness\",\"affect (psychology)\",\"anti-psychiatry\",\"american association for the abolition of involuntary mental hospitalization\",\"mad pride\",\"soul\",\"spirituality\",\"cognitive bias\",\"psychohistory\",\"astrology\",\"soul\",\"spirituality\",\"contemplation\",\"apprehension (understanding)\",\"psychometrics\",\"neurophilosophy\",\"emotivism\",\"david chalmers\",\"wilhelm windelband\",\"outline of thought\",\"gestalt psychology\",\"psychological trauma\",\"social dominance orientation\",\"emotional abuse\",\"joint attention\",\"psychological trauma\",\"soul\",\"aion: researches into the phenomenology of the self\",\"shadow (psychology)\",\"marie-louise von franz\",\"cover-up\",\"psychometrics\",\"statistical inference\",\"pathognomy\",\"acceptance\",\"rage (emotion)\",\"pathos\",\"confusion\",\"emotionality\",\"schadenfreude\",\"wilhelm windelband\",\"amusement\",\"moral emotions\",\"hostility\",\"affect (psychology)\",\"cognitive bias\",\"interpersonal neurobiology\",\"reliability (statistics)\",\"swanson, nolan and pelham teacher and parent rating scale\",\"psychometrics\",\"occupational health psychology\",\"models of abnormality\",\"psychohistory\",\"index of psychometrics articles\",\"conditioned emotional response\",\"paradoxical intention\",\"list of psychological schools\",\"quantitative psychological research\",\"social dominance orientation\",\"gestalt psychology\",\"list of psychological research methods\",\"learning\",\"list of psychology organizations\",\"id\\u00e9e fixe (psychology)\",\"reliability (statistics)\",\"psychological trauma\",\"pathognomy\",\"wilhelm windelband\",\"hostility\",\"acceptance\",\"amusement\",\"auditory hallucination\",\"rage (emotion)\",\"confusion\",\"emotionality\",\"schadenfreude\",\"moral emotions\",\"affect (psychology)\",\"major depressive disorder\",\"list of mental disorders\",\"anhedonia\",\"pathognomy\",\"facial expression\",\"creativity and mental health\",\"david chalmers\",\"list of psychological research methods\",\"soul\",\"neurophilosophy\",\"the emperor's new mind\",\"altered state of consciousness\",\"awareness\",\"pathognomy\",\"hostility\",\"acceptance\",\"amusement\",\"moral emotions\",\"emotionality\",\"schadenfreude\",\"rage (emotion)\",\"gestalt psychology\",\"categorical perception\",\"acceptance\",\"conversational model\",\"awareness\",\"d\\u00e9j\\u00e0 vu\",\"learning\",\"dynamicism\",\"major depressive disorder\",\"list of mental disorders\",\"auditory hallucination\",\"anhedonia\",\"schizotypy\",\"pathognomy\",\"wilhelm windelband\",\"acceptance\",\"auditory hallucination\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"hostility\",\"affect (psychology)\",\"anti-psychiatry\",\"altered state of consciousness\",\"awareness\",\"kurt koffka medal\",\"outline of thought\",\"categorical perception\",\"learning\",\"attachment parenting\",\"crying\",\"soul\",\"aion: researches into the phenomenology of the self\",\"shadow (psychology)\",\"marie-louise von franz\",\"pathognomy\",\"wilhelm windelband\",\"acceptance\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"affect (psychology)\",\"gestalt theoretical psychotherapy\",\"list of psychological schools\",\"paul ferdinand schilder\",\"kurt koffka medal\",\"outline of thought\",\"soul\",\"self-awareness\",\"hermann lotze\",\"soul\",\"major depressive disorder\",\"self-awareness\",\"psychonautics\",\"awareness\",\"the emperor's new mind\",\"soul\",\"spirituality\",\"self-awareness\",\"awareness\",\"outline of thought\",\"noosphere\",\"occupational health psychology\",\"list of cognitive biases\",\"self-awareness\",\"cognitive bias\",\"emotional abuse\",\"creativity and mental health\",\"social dominance orientation\",\"anti-psychiatry\",\"major depressive disorder\",\"psychohistory\",\"cognitive bias\",\"mortido\",\"pathognomy\",\"amusement\",\"emotionality\",\"schadenfreude\",\"major depressive disorder\",\"social dominance orientation\",\"cognitive bias\",\"probability matching\",\"self-awareness\",\"hermann lotze\",\"aion: researches into the phenomenology of the self\",\"spirituality\",\"major depressive disorder\",\"soul\",\"shadow (psychology)\",\"pathognomy\",\"wilhelm windelband\",\"emotionality\",\"schadenfreude\",\"amusement\",\"moral emotions\",\"major depressive disorder\",\"list of psychological schools\",\"american association for the abolition of involuntary mental hospitalization\",\"anti-psychiatry\",\"wilhelm windelband\",\"johann friedrich herbart\",\"hermann lotze\",\"self-awareness\",\"aion: researches into the phenomenology of the self\",\"national association of school psychologists\",\"asch conformity experiments\",\"frustration\\u2013aggression hypothesis\",\"wilhelm windelband\",\"frustration\\u2013aggression hypothesis\",\"asch conformity experiments\",\"aion: researches into the phenomenology of the self\",\"ecological psychology\",\"psychohistory\",\"auditory hallucination\",\"psychomotor retardation\",\"pathognomy\",\"emotionality\",\"schadenfreude\",\"emotionality\",\"pit of despair\",\"emotionality\",\"schadenfreude\",\"wilhelm windelband\",\"neurophilosophy\",\"cognitive bias\",\"wilhelm windelband\",\"self-awareness\",\"emotionality\",\"schadenfreude\",\"johann friedrich herbart\",\"identity crisis\",\"jacqueline rose\",\"dynamicism\",\"johann friedrich herbart\",\"schadenfreude\",\"schadenfreude\",\"swanson, nolan and pelham teacher and parent rating scale\"],\"start\":[\"sleep and learning\",\"sleep and learning\",\"sleep and learning\",\"sleep and learning\",\"character computing\",\"coma\",\"coma\",\"coma\",\"coma\",\"coma\",\"coma\",\"coma\",\"coma\",\"self-deception\",\"self-deception\",\"self-deception\",\"self-deception\",\"self-deception\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"brainwashing\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"resentment\",\"open-mindedness\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"evolutionary psychology\",\"law of effect\",\"law of effect\",\"child behavior checklist\",\"verbal behavior\",\"verbal behavior\",\"classical test theory\",\"classical test theory\",\"classical test theory\",\"classical test theory\",\"classical test theory\",\"obtundation\",\"obtundation\",\"obtundation\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"detection theory\",\"reasoned action approach\",\"altered states\",\"medical psychology\",\"medical psychology\",\"medical psychology\",\"medical psychology\",\"medical psychology\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"seasonal affective disorder\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"hong kong college of psychiatrists\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"timeline of psychology\",\"psychological nativism\",\"barbara rogoff\",\"list of psychiatric medications\",\"list of psychiatric medications\",\"list of psychiatric medications\",\"list of psychiatric medications\",\"list of psychiatric medications\",\"list of psychiatric medications\",\"causa sui\",\"helene deutsch\",\"helene deutsch\",\"helene deutsch\",\"helene deutsch\",\"helene deutsch\",\"helene deutsch\",\"helene deutsch\",\"crazy therapies\",\"crazy therapies\",\"crazy therapies\",\"crazy therapies\",\"crazy therapies\",\"crazy therapies\",\"crazy therapies\",\"mindfreedom international\",\"mindfreedom international\",\"mindfreedom international\",\"mindfreedom international\",\"mindfreedom international\",\"mindfreedom international\",\"jenkins activity survey\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"hypnosis\",\"sascha altman dubrul\",\"sascha altman dubrul\",\"sascha altman dubrul\",\"sascha altman dubrul\",\"sascha altman dubrul\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"transpersonal psychology\",\"sopor (sleep)\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"behaviour therapy\",\"psycho-oncology\",\"psycho-oncology\",\"psycho-oncology\",\"psycho-oncology\",\"psycho-oncology\",\"psycho-oncology\",\"sleep-learning\",\"spearman medal\",\"sublimation (psychology)\",\"why zebras don't get ulcers\",\"general knowledge\",\"general knowledge\",\"gestaltzerfall\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"hedonism\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"out-of-body experience\",\"biosocial criminology\",\"biosocial criminology\",\"biosocial criminology\",\"five stages of grief\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"preconscious\",\"journal of the american psychoanalytic association\",\"journal of the american psychoanalytic association\",\"society for philosophy and psychology\",\"women-are-wonderful effect\",\"women-are-wonderful effect\",\"women-are-wonderful effect\",\"women-are-wonderful effect\",\"freud's seduction theory\",\"freud's seduction theory\",\"freud's seduction theory\",\"freud's seduction theory\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"list of schools of psychoanalysis\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"creativity\",\"nobody nowhere\",\"transliminality\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"histrionic personality disorder\",\"dsm-iv codes\",\"dsm-iv codes\",\"dsm-iv codes\",\"dsm-iv codes\",\"dsm-iv codes\",\"dsm-iv codes\",\"levitation (paranormal)\",\"levitation (paranormal)\",\"levitation (paranormal)\",\"levitation (paranormal)\",\"cat intelligence\",\"cat intelligence\",\"the concept of anxiety\",\"the concept of anxiety\",\"the concept of anxiety\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"intelligence\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"abnormal psychology\",\"two-factor theory of emotion\",\"two-factor theory of emotion\",\"two-factor theory of emotion\",\"unitarian universalism\",\"unitarian universalism\",\"laterality\",\"laterality\",\"flashback (psychology)\",\"flashback (psychology)\",\"flashback (psychology)\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"autogenic training\",\"little albert experiment\",\"little albert experiment\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"british psychotherapy foundation\",\"internal family systems model\",\"psychoinformatics\",\"inner peace\",\"inner peace\",\"inner peace\",\"inner peace\",\"inner peace\",\"inner peace\",\"inner peace\",\"inner peace\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"anguish\",\"self-assessment\",\"is the glass half empty or half full?\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"id, ego and super-ego\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"outline of psychology\",\"information metabolism\",\"identity (philosophy)\",\"identity (philosophy)\",\"identity (philosophy)\",\"identity (philosophy)\",\"identity (philosophy)\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"behavioral neuroscience\",\"shock value\",\"adlerian\",\"adlerian\",\"adlerian\",\"adlerian\",\"adlerian\",\"adlerian\",\"adlerian\",\"adlerian\",\"accuracy and precision\",\"accuracy and precision\",\"accuracy and precision\",\"accuracy and precision\",\"accuracy and precision\",\"grotesque body\",\"self-criticism\",\"self-criticism\",\"oskar pfister award\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"developmental psychology\",\"european federation of psychologists' associations\",\"european federation of psychologists' associations\",\"object relations theory\",\"object relations theory\",\"object relations theory\",\"object relations theory\",\"object relations theory\",\"object relations theory\",\"object relations theory\",\"object relations theory\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"emotional reasoning\",\"repeatability\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"mediumship\",\"psychological evaluation\",\"global workspace theory\",\"global workspace theory\",\"global workspace theory\",\"global workspace theory\",\"global workspace theory\",\"global workspace theory\",\"wakefulness\",\"wakefulness\",\"wakefulness\",\"wakefulness\",\"biorhythm (pseudoscience)\",\"biorhythm (pseudoscience)\",\"intelligence quotient\",\"intelligence quotient\",\"intelligence quotient\",\"intelligence quotient\",\"intelligence quotient\",\"radical psychology network\",\"radical psychology network\",\"radical psychology network\",\"radical psychology network\",\"answer to job\",\"answer to job\",\"answer to job\",\"answer to job\",\"answer to job\",\"answer to job\",\"task analysis\",\"task analysis\",\"solitary confinement\",\"applied psychological measurement\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"ernest jones\",\"blank expression\",\"blank expression\",\"blank expression\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"psychoanalysis\",\"on narcissism\",\"on narcissism\",\"on narcissism\",\"on narcissism\",\"william frankena\",\"motivational salience\",\"motivational salience\",\"superiority complex\",\"superiority complex\",\"catharsis\",\"catharsis\",\"catharsis\",\"catharsis\",\"catharsis\",\"flow (psychology)\",\"flow (psychology)\",\"flow (psychology)\",\"flow (psychology)\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"behavior\",\"biophilia hypothesis\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"pride\",\"direct and indirect realism\",\"direct and indirect realism\",\"direct and indirect realism\",\"microexpression\",\"microexpression\",\"comprehension approach\",\"music psychology\",\"music psychology\",\"music psychology\",\"music psychology\",\"music psychology\",\"music psychology\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"gratitude\",\"ego integrity\",\"hereditarianism\",\"cognitive intervention\",\"subconscious\",\"subconscious\",\"subconscious\",\"subconscious\",\"subconscious\",\"subconscious\",\"trait ascription bias\",\"trait ascription bias\",\"trait ascription bias\",\"cognitivism (psychology)\",\"cognitivism (psychology)\",\"cognitivism (psychology)\",\"cognitivism (psychology)\",\"cognitivism (psychology)\",\"cognitivism (psychology)\",\"timeline of psychotherapy\",\"timeline of psychotherapy\",\"timeline of psychotherapy\",\"poker\",\"neutral stimulus\",\"persistent vegetative state\",\"persistent vegetative state\",\"list of mnemonics\",\"piaget's theory of cognitive development\",\"ferdinand de saussure\",\"ferdinand de saussure\",\"burlesque\",\"burlesque\",\"feeling good: the new mood therapy\",\"list of neurological conditions and disorders\",\"list of neurological conditions and disorders\",\"list of neurological conditions and disorders\",\"list of psychology awards\",\"list of psychology awards\",\"cosmos and psyche\",\"cosmos and psyche\",\"cosmos and psyche\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"eating disorder\",\"computational theory of mind\",\"computational theory of mind\",\"computational theory of mind\",\"proportionality bias\",\"proportionality bias\",\"appraisal theory\",\"appraisal theory\",\"appraisal theory\",\"appraisal theory\",\"appraisal theory\",\"appraisal theory\",\"appraisal theory\",\"appraisal theory\",\"appraisal theory\",\"appraisal theory\",\"behavioural despair test\",\"behavioural despair test\",\"behavioural despair test\",\"civilization in transition\",\"civilization in transition\",\"civilization in transition\",\"civilization in transition\",\"civilization in transition\",\"psychological resistance\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"mania\",\"list of psychiatric medications by condition treated\",\"list of psychiatric medications by condition treated\",\"list of psychiatric medications by condition treated\",\"dysthymia\",\"dysthymia\",\"dysthymia\",\"dysthymia\",\"dysthymia\",\"dysthymia\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"neglect\",\"bicameral mentality\",\"bicameral mentality\",\"bicameral mentality\",\"bicameral mentality\",\"bicameral mentality\",\"ernst mally\",\"ernst mally\",\"ernst mally\",\"gnosis (chaos magic)\",\"gnosis (chaos magic)\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"rationalism\",\"theories of humor\",\"normalcy bias\",\"normalcy bias\",\"defence mechanism\",\"defence mechanism\",\"defence mechanism\",\"richard wiseman\",\"richard wiseman\",\"richard wiseman\",\"lady wonder\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"harry harlow\",\"history of psychotherapy\",\"history of psychotherapy\",\"eustress\",\"eustress\",\"henri poincar\\u00e9\",\"henri poincar\\u00e9\",\"henri poincar\\u00e9\",\"henri poincar\\u00e9\",\"sunk cost\",\"sunk cost\",\"law of the instrument\",\"law of the instrument\",\"law of the instrument\",\"abilene paradox\",\"implicit-association test\",\"implicit-association test\",\"implicit-association test\",\"dark triad\",\"frieda fromm-reichmann\",\"international general medical society for psychotherapy\",\"stimulation\",\"stimulation\",\"stimulation\",\"stimulation\",\"stimulation\",\"stimulation\",\"stimulation\",\"stimulation\",\"stimulation\",\"ambidexterity\",\"adaptive unconscious\",\"harvey jackins\",\"obliviousness\",\"chaining\",\"chaining\",\"chaining\",\"list of cycles\",\"gustave le bon\",\"cabin fever\",\"emotions in virtual communication\",\"emotions in virtual communication\",\"emotions in virtual communication\",\"emotions in virtual communication\",\"emotions in virtual communication\",\"emotions in virtual communication\",\"emotions in virtual communication\",\"emotions in virtual communication\",\"emotions in virtual communication\",\"task force\",\"task force\",\"task force\",\"fight-or-flight response\",\"emotional selection\",\"emotional selection\",\"emotional selection\",\"emotional selection\",\"emotional selection\",\"emotional selection\",\"emotional selection\",\"emotional selection\",\"emotional selection\",\"repertory grid\",\"automatic writing\",\"automatic writing\",\"social cognition and interaction training\",\"social cognition and interaction training\",\"international society of political psychology\",\"meta learning\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"psychoanalytic theory\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"kindness\",\"mad pride\",\"mad pride\",\"mad pride\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"astrology\",\"contemplation\",\"contemplation\",\"contemplation\",\"contemplation\",\"psychological statistics\",\"philosophical analysis\",\"philosophical analysis\",\"philosophical analysis\",\"philosophical analysis\",\"philosophical analysis\",\"field theory (psychology)\",\"destabilisation\",\"destabilisation\",\"destabilisation\",\"vocabulary development\",\"waking the tiger\",\"alchemical studies\",\"alchemical studies\",\"alchemical studies\",\"alchemical studies\",\"cover-up\",\"statistical inference\",\"statistical inference\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"pathos\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"psychometrics\",\"reliability (statistics)\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"confusion\",\"bipolar i disorder\",\"bipolar i disorder\",\"bipolar i disorder\",\"facial expression\",\"facial expression\",\"tortured artist\",\"emotivism\",\"quantitative psychological research\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"david chalmers\",\"rage (emotion)\",\"rage (emotion)\",\"rage (emotion)\",\"rage (emotion)\",\"rage (emotion)\",\"rage (emotion)\",\"rage (emotion)\",\"rage (emotion)\",\"pattern recognition (psychology)\",\"pattern recognition (psychology)\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"acceptance and commitment therapy\",\"d\\u00e9j\\u00e0 vu\",\"richard dawkins\",\"post-cognitivist psychology\",\"anhedonia\",\"anhedonia\",\"anhedonia\",\"anhedonia\",\"anhedonia\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"hostility\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"learning\",\"crying\",\"crying\",\"marie-louise von franz\",\"marie-louise von franz\",\"marie-louise von franz\",\"marie-louise von franz\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"acceptance\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"gestalt psychology\",\"cogito, ergo sum\",\"cogito, ergo sum\",\"cogito, ergo sum\",\"altered state of consciousness\",\"altered state of consciousness\",\"altered state of consciousness\",\"altered state of consciousness\",\"altered state of consciousness\",\"altered state of consciousness\",\"awareness\",\"awareness\",\"awareness\",\"awareness\",\"awareness\",\"noosphere\",\"list of psychological research methods\",\"outline of thought\",\"outline of thought\",\"outline of thought\",\"psychological trauma\",\"psychological trauma\",\"psychological trauma\",\"list of mental disorders\",\"list of mental disorders\",\"attachment parenting\",\"id\\u00e9e fixe (psychology)\",\"mortido\",\"affect (psychology)\",\"affect (psychology)\",\"affect (psychology)\",\"affect (psychology)\",\"occupational health psychology\",\"emotional abuse\",\"list of cognitive biases\",\"list of cognitive biases\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"soul\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"amusement\",\"creativity and mental health\",\"anti-psychiatry\",\"anti-psychiatry\",\"anti-psychiatry\",\"hermann lotze\",\"hermann lotze\",\"hermann lotze\",\"joint attention\",\"shadow (psychology)\",\"list of psychology organizations\",\"social dominance orientation\",\"social dominance orientation\",\"spirituality\",\"asch conformity experiments\",\"asch conformity experiments\",\"aion: researches into the phenomenology of the self\",\"list of psychological schools\",\"list of psychological schools\",\"major depressive disorder\",\"major depressive disorder\",\"moral emotions\",\"moral emotions\",\"moral emotions\",\"open field (animal test)\",\"open field (animal test)\",\"pathognomy\",\"pathognomy\",\"pathognomy\",\"interpersonal neurobiology\",\"cognitive bias\",\"neurophilosophy\",\"self-awareness\",\"wilhelm windelband\",\"wilhelm windelband\",\"wilhelm windelband\",\"identity crisis\",\"jacqueline rose\",\"dynamicism\",\"johann friedrich herbart\",\"emotionality\",\"schadenfreude\",\"swanson, nolan and pelham teacher and parent rating scale\"]},\"selected\":{\"id\":\"2709\"},\"selection_policy\":{\"id\":\"2708\"}},\"id\":\"1619\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"1603\",\"type\":\"SaveTool\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1585\",\"type\":\"Range1d\"},{\"attributes\":{\"callback\":null,\"tooltips\":[[\"Page\",\"@index\"]]},\"id\":\"1605\",\"type\":\"HoverTool\"},{\"attributes\":{},\"id\":\"1591\",\"type\":\"LinearScale\"},{\"attributes\":{\"formatter\":{\"id\":\"2688\"},\"major_label_policy\":{\"id\":\"2686\"},\"ticker\":{\"id\":\"1598\"},\"visible\":false},\"id\":\"1597\",\"type\":\"LinearAxis\"},{\"attributes\":{\"graph_layout\":{\"abilene paradox\":[177.020718909177,-161.0029893194465],\"abnormal psychology\":[90.02838265664775,-24.017394362798274],\"acceptance\":[-174.3446754435217,-116.6954476999582],\"acceptance and commitment therapy\":[64.64385272776076,89.51031790662515],\"accuracy and precision\":[104.99363788180487,-169.1990554152659],\"adaptive unconscious\":[-126.86580592858147,82.9724542743659],\"adlerian\":[126.5939078302812,87.9728996796654],\"affect (psychology)\":[-198.6388398066552,-116.9587448792852],\"aion: researches into the phenomenology of the self\":[95.82031721723479,157.8025365334912],\"alchemical studies\":[83.02930103003978,149.6354294754019],\"alter ego\":[110.81087307747059,161.26993221896487],\"altered state of consciousness\":[5.018284789826429,89.34095296985181],\"altered states\":[-7.269504303845479,220.80393471282372],\"ambidexterity\":[-0.043973143882012455,57.435565654211395],\"american association for the abolition of involuntary mental hospitalization\":[299.06395741520237,-12.355737029808122],\"amusement\":[-161.9591483334185,-147.4005854125028],\"anguish\":[-193.27195665876357,-130.2480983214558],\"anhedonia\":[167.79521520168527,-48.495199600365325],\"answer to job\":[73.83855530442345,152.55127743128716],\"anti-psychiatry\":[200.96346930056004,-8.955227348542866],\"applied psychological measurement\":[137.72253315287517,-286.6697617717961],\"appraisal theory\":[-202.81788659650397,-104.31075447362518],\"apprehension (understanding)\":[-140.9531590901365,130.82694274868783],\"asch conformity experiments\":[-129.6077464474541,66.4111611647154],\"astrology\":[-55.32570600068925,110.38364958782297],\"attachment parenting\":[49.93655649136458,-0.3295962820289884],\"auditory hallucination\":[78.7102592744427,-74.89507088100505],\"autogenic training\":[83.0153422473024,131.13537337888485],\"automatic writing\":[-48.22881233509892,162.67155465954346],\"aversives\":[-1.0500362594879282,-145.09852875008636],\"awareness\":[-17.233001718903694,96.66373809757286],\"barbara rogoff\":[-26.617429380440527,-145.04798658606708],\"behavior\":[-7.211392025381466,-45.82668009448964],\"behavioral neuroscience\":[31.677869663501337,-80.42910470464471],\"behavioral pharmacology\":[767.6918710296675,577.0047117214352],\"behaviour therapy\":[80.75050846071517,117.34395337675019],\"behavioural despair test\":[-33.649989305340306,-176.562451010139],\"bicameral mentality\":[-45.13416702618273,76.6962097195788],\"biophilia hypothesis\":[-88.27742790583295,58.285645594170134],\"biorhythm (pseudoscience)\":[-43.245862885221,119.63778707144904],\"biosocial criminology\":[-58.90419118167464,22.375054792056044],\"bipolar i disorder\":[190.27680775834156,-43.83294030941723],\"blank expression\":[-233.49361006445153,-8.228729695607255],\"blink: the power of thinking without thinking\":[-201.5047030703695,55.14407177632634],\"boris maciejovsky\":[-302.0760634651154,-1149.7381545409896],\"bps barbara wilson lifetime achievement award\":[10.035545123895472,-281.9084608655811],\"brainwashing\":[-96.74669120488178,133.70384295955657],\"british psychotherapy foundation\":[113.34703070202355,110.99920463553336],\"burlesque\":[220.04547147373583,1186.1006445303506],\"cabin fever\":[274.71308645153226,-111.41122483991352],\"cat intelligence\":[-30.876743011419546,-76.36213645446523],\"categorical perception\":[-6.307299194942396,-133.14035818660105],\"catharsis\":[49.72678451750247,100.58059863637693],\"causa sui\":[-112.87805711355396,0.3714977659073756],\"causes of transsexuality\":[968.8095468201084,-231.67889814888972],\"chaining\":[74.0540462458139,108.90498594811528],\"character computing\":[-17.856741767021063,-52.771919723209],\"child behavior checklist\":[-27.702256570771443,-138.18260456329998],\"civilization in transition\":[78.9507570670167,171.5920012814385],\"classical test theory\":[129.96226878930761,-244.9449028679583],\"cogito, ergo sum\":[-89.28004250272227,6.7559251315456645],\"cognitive bias\":[58.94257542749385,-82.05612771834939],\"cognitive intervention\":[83.06778888447907,109.36791095351562],\"cognitivism (psychology)\":[4.912123279545231,-119.5074558134571],\"coma\":[28.794264537660375,174.95787540135785],\"comprehension approach\":[-296.9777036676081,85.00206551955269],\"computational theory of mind\":[-50.98863017052477,-28.847737625821132],\"conditioned emotional response\":[17.629750808750945,-126.52444349177648],\"confusion\":[-157.0849420204667,-108.23253075910057],\"conjoint analysis\":[-612.7613241630206,683.8268232329932],\"conspicuous conservation\":[-801.5579745094449,-582.7366766763771],\"contemplation\":[-110.33791568383005,98.93310583770977],\"conversational model\":[96.18691058175123,128.44781561908337],\"core self-evaluations\":[748.9870205885868,-544.873892965648],\"cosmos and psyche\":[-58.50488060326093,79.74480278134463],\"cover-up\":[-691.3800482858087,931.4546458483987],\"crazy therapies\":[268.0258263167058,-12.489412067022261],\"creativity\":[64.40352485161073,-9.350841760637069],\"creativity and mental health\":[19.084901158977218,32.347530934834914],\"crying\":[5.670755612123336,-54.5505959729444],\"cyranoid\":[429.5773299828929,-815.9330210546881],\"dark triad\":[-4.583865182653555,33.827772772306965],\"david chalmers\":[-56.71513602017515,53.82564368844882],\"david marks (psychologist)\":[-65.65070837621637,-119.36474128422789],\"defence mechanism\":[168.6969846507661,64.1736134967045],\"destabilisation\":[-154.44802368459537,39.84112453469282],\"detection theory\":[36.32594460395255,-108.15150090343607],\"developmental psychology\":[-12.293809122849092,-115.71215576307168],\"direct and indirect realism\":[-88.69079136355934,33.03882638971819],\"disordered eating\":[195.9383711130595,-33.39442245660961],\"dsm-iv codes\":[167.75642663997,-8.728536058784702],\"dynamicism\":[17.88942576018987,-229.16832226621062],\"dysthymia\":[179.63408562396455,-50.28669528407412],\"d\\u00e9j\\u00e0 vu\":[14.052879824491407,209.52267142342544],\"eating disorder\":[149.77216753987165,-19.82388926307751],\"ecological psychology\":[18.834146720976584,-33.798255517749034],\"ego integrity\":[72.99853318434909,-68.83661579135179],\"egosyntonic and egodystonic\":[141.01270318608508,57.71351342941545],\"emotional abuse\":[-155.4715638830718,33.04225479123744],\"emotional reasoning\":[-125.83446631717943,-128.63026482830136],\"emotional selection\":[-176.92234438537284,-133.55823387757403],\"emotionality\":[-173.66622819707848,-171.10223065293792],\"emotions in virtual communication\":[-188.24722448787483,-116.48978308650294],\"emotivism\":[-111.19104197789268,71.76467991497633],\"ernest jones\":[158.77385433347249,80.20258640273191],\"ernst mally\":[-85.64091559522352,-11.425342365938459],\"european federation of psychologists' associations\":[32.271301345028874,-228.87644499421575],\"eustress\":[52.632164341880454,34.85074499770028],\"evolutionary psychology\":[-17.013728956892752,-9.32088843717013],\"facial expression\":[-277.80723117871025,-20.00718597264588],\"feeling good: the new mood therapy\":[82.27870821296017,31.919233960246995],\"ferdinand de saussure\":[0.48561355653417887,46.60111170902224],\"field theory (psychology)\":[48.52067514065123,-172.11599597831093],\"fight-or-flight response\":[-100.87742810129883,76.75539353121793],\"five stages of grief\":[-239.87260296947957,-157.93824686975518],\"flashback (psychology)\":[18.361780147826565,-101.20444110690858],\"flow (psychology)\":[-70.21081605868723,110.72903305435364],\"freud's seduction theory\":[178.88212146449652,145.42383054760467],\"frieda fromm-reichmann\":[24.078835117978873,52.15686895282346],\"frustration\\u2013aggression hypothesis\":[-150.61171969352182,64.2419886019763],\"general knowledge\":[-178.73348710667665,-1.3809029094469392],\"general semantics\":[-221.21008635428512,-1164.2777087793716],\"gestalt psychology\":[35.21070342226018,-130.5370833187816],\"gestalt theoretical psychotherapy\":[35.25699797651433,-177.01431262841857],\"gestaltzerfall\":[41.796319093669815,-172.2047573616658],\"global workspace theory\":[-30.854393260038695,101.60324438746287],\"gnosis (chaos magic)\":[29.39135050820236,162.67076701453425],\"gratitude\":[-197.13093838315132,-76.1781562139319],\"grotesque body\":[214.64912001186363,1181.179639719385],\"gustave le bon\":[119.19688302119914,24.20123500090583],\"guttman scale\":[151.19005170512312,-285.2294514811101],\"harry harlow\":[47.506450426602896,-68.15419175743655],\"harvey jackins\":[150.9043379927685,51.805939032585535],\"hedonism\":[105.2842963435321,-90.72428357330467],\"helene deutsch\":[182.7003487886356,90.9532508659061],\"henri poincar\\u00e9\":[-50.11974739667023,-3.002583189657111],\"hereditarianism\":[-62.49981790235325,-144.9828218455334],\"hermann lotze\":[-85.85169240608876,-24.58852327265451],\"history of dyslexia research\":[556.538259383832,733.6017999523682],\"history of psychotherapy\":[82.29092954738687,80.25657449213274],\"histrionic personality disorder\":[80.00789881367099,-35.38115701503163],\"hong kong college of psychiatrists\":[198.55709674841316,18.89234033083937],\"hostility\":[-150.45718453204313,-128.0720978701989],\"how are we to live?\":[140.07975425582237,-1213.9599895348133],\"hypnodermatology\":[10.57786120817692,184.77360896724187],\"hypnosis\":[14.067550718405728,145.70562592844584],\"id, ego and super-ego\":[166.78147523589567,111.88068078380839],\"identity (philosophy)\":[-91.91640732271092,-3.309204674189419],\"identity crisis\":[28.994810143192097,-45.93705137999713],\"id\\u00e9e fixe (psychology)\":[84.951405192223,-126.56304416481322],\"imaginary audience\":[-41.48914528246701,-60.03122143485448],\"implicit-association test\":[-137.94547838582096,16.577098246575474],\"index of psychometrics articles\":[66.50356582421695,-160.85843856579802],\"influence: science and practice\":[349.23441529044254,-861.4915533970212],\"information metabolism\":[149.1896070022251,80.1209851592871],\"inner peace\":[-113.18349360396782,50.82751395126239],\"intelligence\":[-61.12259134030376,-84.58709863336276],\"intelligence quotient\":[43.11563194665276,-138.85709713461105],\"internal family systems model\":[-162.72080982184667,25.52784496211961],\"international association of art critics\":[977.2266709440003,-155.55017770169073],\"international general medical society for psychotherapy\":[99.0042212676955,201.0515138605489],\"international society of political psychology\":[55.98627062962176,-196.20128098275643],\"interpersonal neurobiology\":[5.772338952176781,-103.26851943343384],\"is the glass half empty or half full?\":[177.5285496341646,-112.5286945619724],\"jacqueline rose\":[197.87570674809277,102.15632463277151],\"james\\u2013lange theory\":[-44.673799779539074,-186.99390829482084],\"jenkins activity survey\":[85.43828953565358,-158.4717301374771],\"johann friedrich herbart\":[-128.69672057637035,-44.619755444263646],\"joint attention\":[-180.5764913106587,59.70216107499823],\"journal of the american psychoanalytic association\":[172.75979575859594,126.31656484902335],\"just-noticeable difference\":[57.912314960360185,-151.12631869016658],\"kindness\":[-168.85079552086776,-89.53620127159489],\"koestler parapsychology unit\":[-50.60672601919381,181.78493705242244],\"kurt koffka medal\":[11.66058292199166,-164.76290399096038],\"la borde clinic\":[-411.16754209969406,757.874575574893],\"lady wonder\":[-70.04563720682775,164.84970656550476],\"laterality\":[-36.89264895934644,87.93472346613602],\"law of effect\":[-3.1912618714694903,-68.56906592644113],\"law of the instrument\":[157.40342089711714,-75.61852968962727],\"learning\":[17.191221849825336,-60.73483368214924],\"levitation (paranormal)\":[-46.541188276486466,136.82434568539682],\"life and how to survive it\":[205.23687214957852,143.1754743068488],\"list of cognitive biases\":[143.2802360453012,-89.34169679922438],\"list of credentials in psychology\":[116.93619503418093,-74.43593908362713],\"list of cycles\":[-39.867752634375464,192.2623762799401],\"list of mental disorders\":[177.43087481174547,-20.60108635372304],\"list of mnemonics\":[65.97889980171902,-34.69765123389338],\"list of neurological conditions and disorders\":[181.51752784089035,39.166960246066786],\"list of psychiatric medications\":[187.73325097217457,7.924265438316758],\"list of psychiatric medications by condition treated\":[185.377980590267,-4.658413996818391],\"list of psychological research methods\":[45.26947657723353,-105.97365344076867],\"list of psychological schools\":[49.56879154920514,-47.84865276306141],\"list of psychology awards\":[9.231982447509862,-247.8444067639322],\"list of psychology organizations\":[42.88649795263107,-155.09178276091257],\"list of schools of psychoanalysis\":[167.65562552038077,90.35076233098988],\"little albert experiment\":[19.135514520720612,-147.24051775366422],\"mad pride\":[233.13125416094744,-21.924505286337922],\"major depressive disorder\":[133.61265275566134,-20.025645481843416],\"mania\":[141.99920717531964,-43.926373856122645],\"marie-louise von franz\":[82.32873585101963,161.1624079654481],\"medical psychology\":[35.223228727412156,-94.39659340616932],\"mediumship\":[-61.06032418189041,160.09243649700744],\"menninger foundation\":[143.12313972074048,150.24122006481957],\"mental environment\":[-29.105578616595935,6.253524264228482],\"mentalization\":[1080.472864584691,-4.202523803370702],\"meta learning\":[1084.4530508059909,-4.48648189192585],\"microexpression\":[-270.51320508195363,29.337655808756132],\"mindfreedom international\":[283.90586003711775,-5.76653675536568],\"minsky's burlesque\":[223.4986400199584,1179.6636108738887],\"models of abnormality\":[84.72693269853642,-90.15449123667689],\"modular cognition framework\":[-778.3571156911918,516.1077132878918],\"moral emotions\":[-167.4676886261089,-132.30784222632914],\"mortido\":[148.85882746358556,109.45377742405337],\"motivational salience\":[231.02486792672397,19.279744396133808],\"mourning and melancholia\":[163.43389824402567,135.4655710220711],\"multidimensional aptitude battery ii\":[59.580469847532946,-181.18719455325737],\"music psychology\":[49.48262826014196,-96.46277222854967],\"national association of school psychologists\":[50.22369002021308,-198.64446507660114],\"naturalistic observation\":[-20.495656435560164,-145.14940686819077],\"neglect\":[-180.68087352631142,-75.6536192343364],\"neural adaptation\":[1209.8743071513597,-117.95348374374355],\"neurophilosophy\":[-29.88650778456898,-34.25535977780848],\"neutral stimulus\":[8.497940269409007,-179.47656556503782],\"nobody nowhere\":[192.49362559964678,-147.30757270013794],\"nominative determinism\":[-351.6813414496332,883.4663247075238],\"noosphere\":[1054.3894319922533,-539.9772691296337],\"normalcy bias\":[129.81870177310464,-108.6937327591647],\"object relations theory\":[129.48313799950594,41.827470498969994],\"obliviousness\":[-26.844836910084673,133.65275461825635],\"obtundation\":[7.9584397918432765,238.6704670899541],\"occupational health psychology\":[67.67888231122468,-93.32852723788618],\"on narcissism\":[133.34858335328337,117.13974975463508],\"open field (animal test)\":[-83.35010440406165,-206.56019091877474],\"open-mindedness\":[642.620846932162,-1000.7948666762327],\"oskar pfister award\":[7.426754699035215,-276.9324388876656],\"out-of-body experience\":[-11.842990014223208,151.21624848831715],\"outline of autism\":[162.5105317726398,-122.83893041826748],\"outline of psychology\":[88.54816207931502,-56.19044232677856],\"outline of thought\":[24.25662079053282,-16.687275192477834],\"paradoxical intention\":[80.03646920176197,-160.2999579833308],\"participatory theory\":[-19.702264629747326,49.307544669466324],\"pathognomy\":[-214.0054594742905,-116.29161383864313],\"pathos\":[-182.69968341585584,-102.78206702740506],\"pattern recognition (psychology)\":[-14.167423491870371,-142.4428906481302],\"paul ferdinand schilder\":[43.05043657924838,-177.97521855888928],\"performance\":[78.24304453705713,-137.58136507549239],\"persistent vegetative state\":[-8.119898039999667,204.0948329997649],\"philosophical analysis\":[-71.587191123116,9.27595450224386],\"philosophy of sex\":[-104.83941301085355,10.565014112220922],\"piaget's theory of cognitive development\":[-21.70835959538903,-61.28455889667619],\"pit of despair\":[-25.129505626530527,-186.07686968010347],\"poker\":[-185.52781594999308,74.92956578906816],\"post-cognitivist psychology\":[24.14319377210031,-266.9760353153503],\"preconscious\":[140.40084033391165,94.84243918005265],\"pride\":[-135.0584256225802,-107.56002188471655],\"probability matching\":[175.85871890433273,-118.28801942481641],\"proportionality bias\":[124.16522959454433,-104.86565308141084],\"pseudodysphagia\":[108.64317647991564,-32.29446660603547],\"psycho-oncology\":[213.29670313326613,8.264079714302104],\"psychoanalysis\":[124.11829974537214,66.47950025191236],\"psychoanalytic theory\":[157.47468107735943,23.190960269781893],\"psychohistory\":[8.15460200613544,6.067038257397523],\"psychoinformatics\":[88.22945587431542,-153.49453617371043],\"psychological evaluation\":[142.1370442066843,19.177130472671376],\"psychological nativism\":[-58.02146358626288,1.9162846598917398],\"psychological resistance\":[222.32205662655394,68.15802181263425],\"psychological statistics\":[117.578561190754,-238.3135151693643],\"psychological trauma\":[-122.85521958454666,11.02805134668795],\"psychometrics\":[61.56189474431517,-119.00904683381309],\"psychomotor retardation\":[190.16976533333636,-61.21619112631087],\"psychonautics\":[-0.9555331692590862,178.2050926524359],\"quantitative psychological research\":[26.315610604214793,-109.7704092858962],\"radical psychology network\":[264.2476453995452,-2.793824802972196],\"rage (emotion)\":[-195.4513383748336,-141.49011734201682],\"rationalism\":[-75.61415343055418,-1.5137644791311153],\"reasoned action approach\":[-23.490537504371765,-47.30112374811904],\"relational developmental systems\":[-22.357098508543483,-139.5576191460019],\"reliability (statistics)\":[119.49877075646783,-209.74284978248022],\"repeatability\":[130.3280476006994,-212.58841056100874],\"repertory grid\":[14.454819574408166,-106.38487627858528],\"resentment\":[-186.93689462992688,-150.00963352514435],\"richard dawkins\":[-39.20582847215135,34.018753912009615],\"richard wiseman\":[-51.38263205986789,153.3371454211402],\"sarnoff a. mednick\":[79.15631264200192,1.6235236192669698],\"sascha altman dubrul\":[272.0617355862146,-1.0877111333384597],\"schadenfreude\":[-213.65321114130865,-140.3300832996491],\"schizotypy\":[86.87774788790166,37.41464224489],\"seasonal affective disorder\":[178.43255739410333,-65.8896964561661],\"self-assessment\":[-53.266674101363236,-205.78046791584237],\"self-awareness\":[-70.72350557604217,33.36885043546695],\"self-criticism\":[209.38693927571018,-48.876152417137554],\"self-deception\":[72.1903048282612,23.518666573242733],\"self-defeating prophecy\":[208.0379158476199,-189.70146231795553],\"self-hypnosis\":[46.97598129263096,174.81723271078508],\"sensory threshold\":[52.570110218083755,-152.28890770905747],\"sequential probability ratio test\":[143.8861832307895,-272.0293625641689],\"shadow (psychology)\":[105.40869449590208,95.63849237705716],\"shock value\":[-163.24399986033535,92.09881152534687],\"sid parnes\":[83.54644208202352,-3.0363890585840316],\"slain in the spirit\":[17.052837849169517,187.99301331302962],\"sleep and learning\":[46.98695811353168,80.06676295464105],\"sleep-learning\":[22.9083617964725,96.8576412597575],\"snackwell effect\":[-721.9037607458752,-607.1123307176265],\"social cognition and interaction training\":[58.90073056500251,25.279336505041996],\"social degeneration\":[-853.0511803039121,-537.384802233716],\"social dominance orientation\":[-117.03518328195521,24.54011046397986],\"society for philosophy and psychology\":[-80.43547715985892,83.14601307581042],\"sociometric status\":[-41.256686724502764,-182.75752545736043],\"sock puppet account\":[1143.3280797681098,185.0185910011147],\"solitary confinement\":[-104.87871261985036,109.48651843179438],\"sopor (sleep)\":[8.736144351637758,229.9795184310605],\"soul\":[-26.906522508327992,69.5101559517438],\"spearman medal\":[5.9144204785937955,-289.9864063141428],\"specialist in psychology\":[-23.12068089505128,-151.34776348396673],\"spirituality\":[-74.47362899621906,55.32623431515561],\"statistical inference\":[92.42698540425874,-181.37773709397365],\"stimulation\":[-203.0685846020281,-157.54424229776967],\"subconscious\":[-2.576765588960339,70.47306059331984],\"sublimation (psychology)\":[53.80486602009948,134.48158993760666],\"sunk cost\":[-51.41921766380147,-124.5396564784427],\"superiority complex\":[70.10027147183611,37.17039305435293],\"swanson, nolan and pelham teacher and parent rating scale\":[18.066631374611376,-114.77408759850852],\"sybil (schreiber book)\":[10.757275249183195,190.6503855515445],\"task analysis\":[49.088777223078694,52.21444368101899],\"task force\":[-77.86788954671637,15.25358851643479],\"technobiophilia\":[-117.92039057941992,87.96158994845206],\"the concept of anxiety\":[-104.06712851585851,-71.80850748258345],\"the emperor's new mind\":[-39.84330901443308,102.09037699600036],\"the freudian coverup\":[228.92182015448614,196.1517757866949],\"theories of humor\":[-270.54835247891464,-172.4163101505387],\"theory x and theory y\":[768.9713751195658,521.4212910134069],\"thumos\":[661.946239511871,-635.5380390272945],\"timeline of psychology\":[40.50261493543142,-36.8698951120038],\"timeline of psychotherapy\":[105.62508258511419,0.846655094920415],\"titicut follies\":[-655.6340723327238,-731.6809215730038],\"tortured artist\":[18.68415275420323,51.01790996111663],\"trait ascription bias\":[111.21519772342401,-118.07905239744433],\"transfer (propaganda)\":[-771.0612720933888,-746.333149067886],\"transliminality\":[88.93892811134342,18.70314176646486],\"transpersonal psychology\":[27.72883611276114,6.010585186054598],\"two-factor theory of emotion\":[-38.50320134748313,-142.4457816455592],\"unipolar mania\":[174.2424852993211,-78.26457480645891],\"unitarian universalism\":[-43.030573407793625,48.91027328759678],\"verbal behavior\":[76.24426008756332,-100.6425163766297],\"vocabulary development\":[-240.6457760553779,58.20552099637131],\"wakefulness\":[22.55046058274062,132.12198986059516],\"waking the tiger\":[-157.48429117881122,22.153321390199626],\"who moved my cheese?\":[788.1098504401642,-451.5430932991038],\"why zebras don't get ulcers\":[-131.9828287950495,107.18198980919993],\"wilhelm windelband\":[-143.18355777428837,-69.97881028175138],\"william frankena\":[-144.01832845089433,99.97186133687546],\"women-are-wonderful effect\":[11.900323161194434,-95.02352255424955]}},\"id\":\"1626\",\"type\":\"StaticLayoutProvider\"},{\"attributes\":{\"data_source\":{\"id\":\"1615\"},\"glyph\":{\"id\":\"1639\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1617\"}},\"id\":\"1616\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"1598\",\"type\":\"BasicTicker\"},{\"attributes\":{\"line_alpha\":{\"value\":0.8},\"line_width\":{\"value\":0.1}},\"id\":\"1644\",\"type\":\"MultiLine\"},{\"attributes\":{\"edge_renderer\":{\"id\":\"1620\"},\"inspection_policy\":{\"id\":\"2701\"},\"layout_provider\":{\"id\":\"1626\"},\"node_renderer\":{\"id\":\"1616\"},\"selection_policy\":{\"id\":\"2692\"}},\"id\":\"1613\",\"type\":\"GraphRenderer\"},{\"attributes\":{\"formatter\":{\"id\":\"2672\"},\"major_label_policy\":{\"id\":\"2670\"},\"ticker\":{\"id\":\"1468\"},\"visible\":false},\"id\":\"1467\",\"type\":\"LinearAxis\"},{\"attributes\":{\"source\":{\"id\":\"1485\"}},\"id\":\"1487\",\"type\":\"CDSView\"},{\"attributes\":{\"data_source\":{\"id\":\"1485\"},\"glyph\":{\"id\":\"1509\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1487\"}},\"id\":\"1486\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"1464\",\"type\":\"BasicTicker\"},{\"attributes\":{\"line_alpha\":{\"value\":0.8},\"line_width\":{\"value\":0.1}},\"id\":\"1514\",\"type\":\"MultiLine\"},{\"attributes\":{},\"id\":\"1459\",\"type\":\"LinearScale\"},{\"attributes\":{},\"id\":\"2672\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"2666\",\"type\":\"Title\"},{\"attributes\":{\"active_multi\":null,\"active_scroll\":{\"id\":\"1472\"},\"tools\":[{\"id\":\"1471\"},{\"id\":\"1472\"},{\"id\":\"1473\"},{\"id\":\"1474\"},{\"id\":\"1475\"}]},\"id\":\"1476\",\"type\":\"Toolbar\"},{\"attributes\":{},\"id\":\"1471\",\"type\":\"PanTool\"},{\"attributes\":{\"axis\":{\"id\":\"1467\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"1470\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"2673\",\"type\":\"AllLabels\"},{\"attributes\":{\"data\":{\"alpha\":[0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75],\"depth\":[1,2,2,2,1,2,2,2,2,1,2,2,2,2,2,2,2,2,2,0,2,2,2,2,1,0,2,0,1,2,1,2,2,2,2,2,1,1,2,2,2,2,2,2,1,2,2,2,0,2,2,2,2,2,2,2,2,2,2,2,1,2,1,1,2,1,2,2,2,2,2,2,2,1,2,2,1,2,0,2,2,1,2,1,1,2,2,2,0,2,2,0,2,2,2,0,2,1,2,2,2,2,2,2,2,2,2,2,2,2,1,1,2,2,2,1,2,2,2,2,1,1,2,2,2,2,2,2,2,2,2,2,1,1,2,2,1,2,2,2,1,2,2,1,1,2,2,2,1,2,1,2,2,2,2,2,2,2,0,2,1,2,2,2,1,1,2,2,1,2,2,2,2,2,1,1,1,2,2,1,2,2,2,2,2,2,2,1,2,1,2,2,2,0,2,2,2,0,2,1,1,2,0,1,2,2,2,1,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,2,1,1,2,2,2,2,2,2,2,0,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,1,2,2,1,2,1,2,2,2,1,2,1,2,1,2,2,2,2,2,2,2,2,2,1,2,2,2,1,2,2,2,1,2,1,2,2,2,2,1,2,2,2,1,2,2,2,2,2,0,2,1,2,0,2,2,2,2,1,1,2,2,2,2,2,2,2,2,2,2,1,2,2,1,1,2,0,1,1,2,2,2,2,2,2,1,1,2,2,2,2,1,2,0,2,2,2,2,2,2,2,2,2,0,2,2,2,2,2,2,1,1,1,2,2,2,2,1,2,1,2,2,2,2,2,1,2,2,2,0,1,2,2,1,2,2,2,1,2,2,2,2,1,0,2,2,2,2,2,2,2,2,2,2,2,1,2,0,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,1,2,2,2,2,2,1,2,2,2,2,2,2,1,2,1,2,2,2,2,2,2,1,1,2,2,2,2,2,2,2,2,1,2,2,1,1,2,2,1,2,2,2,2,0,2,2,1,2,1,2,2,1,1,2,2,2,2,2,2,2,2,2,2,2,1,2,2,1,2,2,2,2,2,2,1,1,2,2,2,2,2,2,1,1,2,2,2,2,1,1,2,0,2,2,2,2,2,1,2,2,2,2,2,2,1,2,2,2,1,2,1,1,2,2,2,2,2,2,2,1,1,2,2,2,1,0,2,2,1,2,1,2,2,1,1,1,2,2,2,2,2,2,2,0,0,2,1,2,2,1,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,2,2,2,2,2,2,2,2,2,1,2,2,2,1,2,2,2,2,2,1,2,2,2,2,2,2,1,2,0,2,2,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,2,0,1,1,2,2,2,2,2,0,2,2,1,2,2,2,2,1,2,2,2,1,0,2,1,2,2,1,2,1,2,1,2,2,2,2,2,2,1,2,2,2,2,2,2,1,0,2,2,2,2,1,2,2,1,1,2,2,2,1,1,1,2,2,2,2,2,2,2,1,2,1,1,2,2,2,2,2,2,2,2,1,2,2,0,2,2,2,2,2,1,1,2,2,1,2,1,2,2,2,2,2,2,2,0,2,2,2,1,2,1,1,1,2,2,1,2,2,2,2,2,2,2,2,2,1,0,2,2,2,2,2,1,1,2,2,1,2,2,2,2,2,2,2,1,2,1,2,2,1,2,2,2,2,1,1,2,2,2,0,2,2,2,2,2,1,0,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,2,2,1,2,0,1,2,2,2,2,2,2,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,2,2,2,2,2,2,0,2,2,2,2,2,1,2,2,2,2,1,2,2,2,2,2,1,1,2,2,1,2,2,2,1,2,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,0,2,2,2,2,2,1,2,1,2,0,2,2,2,2,2,1,2,2,2,1,0,1,1,1,2,1,2,2,2,2,2,1,1,0,2,1,2,1,0,1,2,2,2,2,0,2,2,2,2,2,2,2,1,2,2,2,1,2,2,2,2,2,2,2,1,2,2,2,2,2,2,2,2,2,2,2,0,1,2,1,2,1,2,2,2,0,2,2,2,1,1,2,2,2,2,2,2,0,1,1,1,2,2,2,1,2,1,1,1,2,2,2,1,2,2,2,2,0,2,2,2,2,1,2,2,2],\"index\":[\"archibald crossley\",\"tobacco-free pharmacy\",\"sanford school of public policy\",\"peace dividend\",\"civic political culture\",\"comparing media systems\",\"fourteen words\",\"regional autonomy\",\"blavatnik school of government\",\"two-level game theory\",\"cyberocracy\",\"worldwide influence of the constitution of the united states\",\"how voters feel\",\"resource conservation and recovery act\",\"we don't coast\",\"jurisprudence of concepts\",\"american journal of political science\",\"australian quarterly\",\"joseph rowntree foundation\",\"latin american public opinion project\",\"institutionalist political economy\",\"communications management\",\"consensus democracy\",\"dependent territory\",\"mass media and american politics\",\"political science\",\"science & diplomacy\",\"selectorate theory\",\"pal lahara state\",\"islam and children\",\"political jurisprudence\",\"international review of the red cross\",\"land consolidation\",\"blood and soil\",\"anglo-saxon model\",\"rivers state civil service\",\"nation state\",\"university of chicago institute of politics\",\"prague conference\",\"rent-setting\",\"human resource management in public administration\",\"william a. niskanen\",\"politique africaine\",\"primakov readings\",\"denationalized citizenship\",\"occupatio\",\"liberal corporatism\",\"liesbet hooghe\",\"twitter diplomacy\",\"responsibility to protect\",\"robert christison\",\"her majesty's government (term)\",\"list of liberal theorists\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"journal of european integration\",\"universal basic income\",\"carles boix\",\"gevald campaign\",\"national crime victimization survey\",\"political party\",\"political studies association\",\"liberalism and conservatism in latin america\",\"bad governance\",\"fred w. riggs\",\"electronic media\",\"big man (political science)\",\"public image of cristina fern\\u00e1ndez de kirchner\",\"galician student league\",\"list of left-wing internationals\",\"dominium maris baltici\",\"magna carta for philippine internet freedom\",\"bay'ah\",\"live free or die\",\"horace campbell\",\"decolonization\",\"karl schwedler\",\"foreign policy\",\"decentralized autonomous organization\",\"political methodology\",\"slapsoftware\",\"international journal of intelligence and counterintelligence\",\"bloc party (politics)\",\"grab em by the pussy\",\"religious socialism\",\"antinaturalism (politics)\",\"secession\",\"robert kent gooch\",\"the great transformation (book)\",\"systems theory in political science\",\"syed hayatullah\",\"day of empire\",\"strict father model\",\"alexandra goujon\",\"c. d. broad\",\"predictive policing\",\"perestroika movement (political science)\",\"constitutionality\",\"sacralism\",\"katharine hayhoe\",\"better red than dead\",\"london school of economics\",\"proactive policing\",\"zombie liberalism\",\"robert m. la follette school of public affairs\",\"neil maccormick\",\"neoclassical liberalism\",\"religious communism\",\"industrial democracy\",\"law of equal liberty\",\"timocracy\",\"master of public policy\",\"canadian political science association\",\"antimilitarism\",\"international workers' day\",\"usul fiqh in ja'fari school\",\"international ethics\",\"a green new deal\",\"emilia justyna powell\",\"multiliteracy\",\"passing on the right\",\"constitutional autochthony\",\"the final days (2000 film)\",\"feoffment\",\"eric helleiner\",\"international area studies review\",\"coal phase-out\",\"2000-watt society\",\"national liberalism\",\"technoliberalism\",\"election law journal\",\"journal of ethnic and migration studies\",\"gar alperovitz\",\"security of tenure\",\"the civic culture\",\"journal of current southeast asian affairs\",\"ethnarch\",\"commodity form theory\",\"antemurale myth\",\"international conference on theory and practice of electronic governance\",\"andr\\u00e9 du pisani\",\"local service delivery\",\"in place of strife\",\"rent extraction\",\"social patriotism\",\"data editing\",\"plurinationalism\",\"risk, hazards & crisis in public policy\",\"history of social democracy\",\"civilization state\",\"list of national legal systems\",\"barracks communism\",\"health policy\",\"regulation of science\",\"business oligarch\",\"prohibition of dying\",\"frankfurt declaration\",\"carl albert center\",\"ursula apitzsch\",\"computational politics\",\"violent non-state actors at sea\",\"code of hammurabi\",\"ideocracy\",\"josepha laroche\",\"review of international political economy\",\"social media use in politics\",\"cube root rule\",\"proposed national unification promotion law\",\"perestroika\",\"culture 21\",\"role ethics\",\"no war, no peace\",\"nigel simmonds\",\"no war but the class war\",\"leslie green (philosopher)\",\"broken windows theory\",\"kremlinology\",\"eco-nationalism\",\"harvard institute of politics\",\"nonkilling global political science\",\"principle of inalienability of the public domain\",\"regulatory economics\",\"vocational panel\",\"f\\u00fchrer\",\"thucydides trap\",\"school of public policy at central european university\",\"institut d'\\u00e9tudes politiques de toulouse\",\"the democratic paradox\",\"transitology\",\"social corporatism\",\"holocaust trivialization\",\"diplomatic protection\",\"advocacy journalism\",\"arab barometer\",\"multistakeholder governance\",\"socialist realism\",\"swiss neutrality\",\"christian fascism\",\"coercion, capital, and european states, ad 990\\u20131992\",\"particracy\",\"public opinion on climate change\",\"overview of 21st-century propaganda\",\"marcellina (gnostic)\",\"public engagement\",\"distributive tendency\",\"policy sciences\",\"british journal of politics and international relations\",\"garveyism\",\"successor ideology\",\"ralph borsodi\",\"ecocide\",\"in defense of the national interest\",\"christian corporatism\",\"history of science policy\",\"people's democracy (marxism\\u2013leninism)\",\"argumentation and advocacy\",\"olivier ihl\",\"school of diplomacy\",\"parochial political culture\",\"franciscan school of theology\",\"civil libertarianism\",\"clientelism\",\"global terrorism index\",\"the journal of political philosophy\",\"clarita carlos\",\"philip converse\",\"non-governmental organization\",\"development bureau\",\"communication university of china\",\"history of communism\",\"international law\",\"nancy program\",\"peruvian nitrate monopoly\",\"making democracy work\",\"public comment\",\"rodney tiffen\",\"electronic authentication\",\"night-watchman state\",\"corporative federalism\",\"all animals are equal, but some animals are more equal than others\",\"atlanticism\",\"health policy in bangladesh\",\"biological organisation\",\"social policy\",\"media circus\",\"green institute foundation\",\"sovereignty of puerto rico during the cold war\",\"constitutionalism\",\"edinburgh university socialist society\",\"against equality of opportunity\",\"regionalisation\",\"karl deutsch award\",\"school of international and public affairs, columbia university\",\"give peace a chance\",\"national conservatism\",\"res publica christiana\",\"uk heo\",\"global politics\",\"ministry of infrastructure (ukraine)\",\"marie-christine kessler\",\"second-order election\",\"corporate anniversary\",\"international journal of public opinion research\",\"virtue jurisprudence\",\"political culture of germany\",\"nonna mayer\",\"salvador minguij\\u00f3n adri\\u00e1n\",\"private property\",\"william james booth\",\"public policy school\",\"an economic theory of democracy\",\"german model\",\"journal of democracy\",\"niamh reilly\",\"behavioralism\",\"situationist international\",\"balkanization\",\"insight turkey\",\"urban legend\",\"sam potolicchio\",\"mccourt school of public policy\",\"isaiah berlin\",\"al-ahram center for political and strategic studies\",\"national forum (georgia)\",\"walter f. dodd\",\"corporate communication\",\"american political thought\",\"overlapping consensus\",\"the twenty years' crisis\",\"kissinger lecture\",\"deliberation\",\"colin rallings\",\"domestic trade\",\"whiggism\",\"the end of liberalism\",\"muhammad taqi usmani\",\"eternity clause\",\"spin room\",\"public opinion and activism in the terri schiavo case\",\"comparative politics\",\"gish gallop\",\"peelian principles\",\"pensions crisis\",\"bureaucratic drift\",\"inclusion and democracy\",\"small government\",\"robin hood effect\",\"stephen barber\",\"constitutional patriotism\",\"filter bubble\",\"executive order\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"petition of right\",\"constitutional dictatorship\",\"graduate school of public policy, university of tokyo\",\"state order\",\"say's political economy\",\"canadian public policy\",\"might makes right\",\"fiqh\",\"party identification\",\"exclusive federal powers\",\"democracies: patterns of majoritarian & consensus government in twenty-one countries\",\"influence of mass media\",\"ap comparative government and politics\",\"digest of middle east studies\",\"legitimation crisis\",\"johnson cult\",\"perpetual war\",\"united nations parliamentary assembly\",\"crypto-communism\",\"kalergi plan\",\"community policing\",\"proletarian revolution\",\"peace journalism\",\"parallel state\",\"coverage error\",\"celeb jihad\",\"technocracy\",\"caudillo\",\"margaret clark (political scientist)\",\"bonai state\",\"scotland's future\",\"bureau-shaping model\",\"political studies review\",\"stakeholder (corporate)\",\"catherine eschle\",\"quadrilateral security dialogue\",\"national power\",\"list of enlightened despots\",\"regional hegemony\",\"equal opportunity\",\"drang nach osten\",\"democracy-dictatorship index\",\"mediations (journal)\",\"islamic sexual jurisprudence\",\"colin hughes\",\"steven b. smith (professor)\",\"journal of political ideologies\",\"proactive law\",\"otto kirchheimer\",\"european union studies association\",\"full spectrum diplomacy\",\"research excellence framework\",\"democratic globalization\",\"western cape department of transport and public works\",\"democratic party for a new society\",\"social media in the 2016 united states presidential election\",\"maxims of islamic law\",\"total survey error\",\"publicity stunt\",\"high policing\",\"american university school of international service\",\"freedom of contract\",\"neosocialism\",\"international political science association\",\"ash-shab yurid isqat an-nizam\",\"energy superpower\",\"limitarianism (ethical)\",\"nurturant parent model\",\"victim study\",\"energy community\",\"islamic toilet etiquette\",\"deviationism\",\"status quo state\",\"parliamentary procedure\",\"pickens plan\",\"postfunctionalism\",\"decoloniality\",\"decentralized computing\",\"communist front\",\"molon labe\",\"social media in the 2020 united states presidential election\",\"open philanthropy (doctrine)\",\"marc lynch\",\"scientocracy\",\"scientific man versus power politics\",\"supreme court of justice of colombia\",\"small office/home office\",\"crimes against humanity under communist regimes\",\"christian privilege\",\"they shall not pass\",\"jean bethke elshtain\",\"postinternationalism\",\"american recovery and reinvestment act of 2009\",\"cand.scient.pol.\",\"wyn grant\",\"valence issue\",\"labour voucher\",\"reactionary\",\"helen margetts\",\"new political economy (journal)\",\"classification of advocacy groups\",\"authoritarian democracy\",\"afrobarometer\",\"marian van landingham\",\"environmental politics (journal)\",\"the soldier and the state\",\"home rule\",\"left\\u2013right political spectrum\",\"corporate republic\",\"content marketing\",\"cacique\",\"wilson\\u2013patterson conservatism scale\",\"peace through strength\",\"ngo-ization\",\"liberal international order\",\"afke schaart\",\"debate\",\"ethical socialism\",\"free newfoundland\",\"security studies\",\"harvest hills cooperative community\",\"modern liberalism in the united states\",\"renewable energy transition\",\"rasma k\\u0101rkli\\u0146a\",\"implementation\",\"knowledge gap hypothesis\",\"regional power\",\"list of social democratic parties\",\"we shall overcome\",\"united federal workers of america\",\"the good society\",\"bananas, beaches and bases\",\"jane duckett\",\"divided government in the united states\",\"principle-policy puzzle\",\"transformation processes (media systems)\",\"the crisis of democracy\",\"international sanctions\",\"the indian struggle\",\"international energy agency\",\"animal testing regulations\",\"mahr\",\"law and order\",\"chiara bottici\",\"logology (science)\",\"eurosphere\",\"institution\",\"fenno's paradox\",\"jihad satire\",\"anthony downs\",\"strategy of tension\",\"energy charter treaty\",\"feeding the chooks\",\"outline of anarchism\",\"worshipful company of butchers\",\"linked fate\",\"dang guo\",\"sexual jihad\",\"instituts d'\\u00e9tudes politiques\",\"social impact entertainment\",\"statism\",\"futarchy\",\"personhood\",\"data collection system\",\"pi sigma alpha\",\"cipp evaluation model\",\"kinder, k\\u00fcche, kirche\",\"julius stone\",\"authoritarian left\",\"debate chamber\",\"inter-municipal cooperation\",\"yelyzaveta yasko\",\"institut d'\\u00e9tudes politiques d'aix-en-provence\",\"asu college of public service & community solutions\",\"ordoliberalism\",\"raisons politiques\",\"malikism in algeria\",\"corporatization\",\"journal of current chinese affairs\",\"charg\\u00e9 de mission\",\"lloyd\\u2013la follette act\",\"marco tarchi\",\"tiocfaidh \\u00e1r l\\u00e1\",\"liberal social movement (portugal)\",\"appeasement\",\"dictatorship of the proletariat\",\"cosmopolitan democracy\",\"military policy\",\"eurasianism\",\"the castle (novel)\",\"obreption and subreption (catholic canon law)\",\"commentary on palestine: peace not apartheid\",\"greek withdrawal from the eurozone\",\"policy studies journal\",\"dark figure of crime\",\"social liberalism\",\"public affairs quarterly\",\"praxis: the fletcher journal of human security\",\"comunismo a la tica\",\"spatial justice\",\"journal of policy history\",\"jurisprudence\",\"green industrial policy\",\"gladstone professor of government\",\"earned media\",\"composite index of national capability\",\"ipm (software)\",\"national question (quebec)\",\"national student survey\",\"politico-media complex\",\"proletarian nation\",\"east turkestan\",\"oryx and crake\",\"dyab abou jahjah\",\"emmette redford\",\"majoritarianism\",\"roper center for public opinion research\",\"fukoku ky\\u014dhei\",\"list of public works ministries\",\"demonizing the enemy\",\"deployment management\",\"administrative divisions of peru\",\"nolan chart\",\"peace and conflict studies\",\"federal law\",\"democratic liberalism\",\"maddaddam\",\"principles of political economy\",\"continuismo\",\"attorney-general v de keyser's royal hotel ltd\",\"powering past coal alliance\",\"public opinion on nuclear issues\",\"white power music\",\"lectures on jurisprudence\",\"voting rights in the united states\",\"communist era\",\"nonpartisanism\",\"east european politics\",\"terry karl\",\"cleavage (politics)\",\"taftian theory\",\"foreign service officer\",\"prediction market\",\"journal of european social policy\",\"awza'i\",\"opinion leadership\",\"equality before the law\",\"post-truth politics\",\"one man, one vote\",\"violent non-state actor\",\"conservative research department\",\"bevanism\",\"svoboda ili smart\",\"list of futurama characters\",\"islamic funeral\",\"benevolence and the mandate of heaven\",\"moderation theory\",\"stephanos bibas\",\"preselection\",\"right-wing politics\",\"brocard (law)\",\"trusteeship (gandhism)\",\"gadsden flag\",\"conservative corporatism\",\"global justice movement\",\"political repression\",\"danish defence agreement 2013\\u20132017\",\"public administration\",\"political man\",\"revolutionary students federation\",\"grey-zone (international relations)\",\"idealism in international relations\",\"note verbale\",\"public image of narendra modi\",\"list of rugrats characters\",\"principles of political economy (malthus book)\",\"rosa brooks\",\"fritz w. scharpf\",\"administrative divisions of portugal\",\"keep indy indie\",\"fiscal transparency\",\"master of public administration\",\"indonesian village law\",\"boosterism\",\"interviewer effect\",\"journal of theoretical politics\",\"multi-level governance\",\"frank batten school of leadership and public policy\",\"indian political philosophy\",\"institute for economics and peace\",\"an anarchist faq\",\"behavioral public administration\",\"international security\",\"non-interventionism\",\"values modes\",\"early social changes under islam\",\"wisconsin school (diplomatic history)\",\"world revolution\",\"opinion poll\",\"archon fung\",\"left group of finnish workers\",\"electronic process of law\",\"elif shafak\",\"history of democratic socialism\",\"philip oxhorn\",\"enemy of the people\",\"fascism: a warning\",\"history of the american legal profession\",\"grazing rights\",\"kaarlo juho st\\u00e5hlberg\",\"edward j. bloustein school of planning and public policy\",\"great power\",\"independent labour publications\",\"comparative study of electoral systems\",\"the independent review\",\"burmese way to socialism\",\"coppieters foundation\",\"united nations office on drugs and crime\",\"public opinion quarterly\",\"consumer sovereignty\",\"world politics\",\"liberal democratic basic order\",\"ethnosymbolism\",\"enbau\",\"university of san diego\",\"campaign finance\",\"andrew westmoreland\",\"roman question\",\"unearned income\",\"cato institute\",\"critique: journal of socialist theory\",\"dualism (law)\",\"synarchism\",\"dictablanda\",\"seek truth from facts\",\"expansionary fiscal contraction\",\"radical egalitarianism\",\"music and political warfare\",\"polarized pluralism\",\"small media, big revolution\",\"institutional analysis\",\"political criticism\",\"parochialism\",\"urban village\",\"contemporary voices\",\"carbon fee and dividend\",\"common informer\",\"after saturday comes sunday\",\"peace\\u2013industrial complex\",\"menstruation in islam\",\"reichsministerium des innern\",\"security sector governance and reform\",\"nur f\\u00fcr deutsche\",\"crown servant\",\"border control\",\"revealed preference\",\"public policy doctrine\",\"third-person effect\",\"socialist campaign group\",\"ministry of magic\",\"caucus for a new political science\",\"digital era governance\",\"basket of deplorables\",\"right to exist\",\"politics, philosophy & economics\",\"worker cooperative\",\"propaganda\",\"carl joachim friedrich\",\"critical security studies\",\"history of the legal profession\",\"transnational progressivism\",\"pippa norris\",\"popular socialism\",\"nicole bacharan\",\"left-wing populism\",\"proclamation by the crown act 1539\",\"\\u00fcmit cizre\",\"kyklos\",\"erguer-estudantes da galiza\",\"border outpost\",\"politics (academic journal)\",\"notary (catholic canon law)\",\"consequentialist justifications of the state\",\"stein rokkan\",\"vaticanology\",\"serfdom in tibet controversy\",\"food sovereignty\",\"rena dourou\",\"maladministration\",\"one-party state\",\"high and low politics\",\"i like ike\",\"left-wing politics\",\"elective dictatorship\",\"public consultation\",\"enemy of the people (albania)\",\"lorena parini\",\"revolutions of 1989\",\"civil service\",\"polyarchy\",\"regulatory competition\",\"\\u00bfpor qu\\u00e9 no te callas?\",\"white paper\",\"international isolation\",\"the triple revolution\",\"bolivarian revolution\",\"triangular diplomacy\",\"bankocracy\",\"social conservatism\",\"murfee\",\"hierarchical organization\",\"domestic analogy\",\"the machiavellian moment\",\"designing social inquiry\",\"intergovernmentalism\",\"ernest barker\",\"comparative criminal justice\",\"westphalian sovereignty\",\"ronen palan\",\"ucla luskin school of public affairs\",\"democratic peace theory\",\"val\\u00e9rie igounet\",\"pilar calveiro\",\"voter turnout\",\"national communism\",\"plenary power\",\"superpower collapse\",\"the permanent revolution and results and prospects\",\"v-dem institute\",\"survey data collection\",\"faculty of political science, chulalongkorn university\",\"labor theory of property\",\"malinda s. smith\",\"china watcher\",\"global apartheid\",\"associationalism\",\"power-to-x\",\"environmental policy of the european union\",\"princeton school of public and international affairs\",\"jus commune\",\"appropriate technology\",\"patient participation\",\"present age\",\"security, territory, population\",\"commanding heights of the economy\",\"the hidden hand: middle east fears of conspiracy\",\"soft despotism\",\"ljiljana radoni\\u0107\",\"bryan caplan\",\"interventionism (politics)\",\"intergenerational policy\",\"enterprise theory\",\"party system\",\"the good soldier \\u0161vejk\",\"political research associates\",\"constitutional economics\",\"post-politics\",\"this machine kills fascists\",\"catch-22\",\"fiscal policy of the philippines\",\"gary l. francione\",\"feminist legal theory\",\"political studies (journal)\",\"frente despertar\",\"berkeley school of political theory\",\"the establishment (pakistan)\",\"ariane chebel d'appollonia\",\"global citizenship\",\"w. meredith bacon\",\"the journal of politics\",\"classical realism (international relations)\",\"party platform\",\"autonomous communities administration\",\"christian communism\",\"slogan\",\"the engineering of consent\",\"list of environmental ministries\",\"hardline\",\"german university of administrative sciences speyer\",\"free migration\",\"inquisitorial system\",\"special relationship (international relations)\",\"oliver lepsius\",\"militarized interstate dispute\",\"rumor\",\"nanosocialism\",\"private military company\",\"mariya gabriel\",\"curvilinear disparity\",\"catonism\",\"qazi syed inayatullah\",\"custom (catholic canon law)\",\"tactical voting\",\"blanquism\",\"regionalism (international relations)\",\"legal naturalism\",\"ministry of infrastructure and water management\",\"left communism\",\"rowman & littlefield award in innovative teaching\",\"alternatives: turkish journal of international relations\",\"equality of outcome\",\"free market fairness\",\"global environmental politics\",\"choosing scotland's future\",\"corporate statism\",\"minimal effects hypothesis\",\"science diplomacy\",\"thawri\",\"promulgation (catholic canon law)\",\"galician workers union\",\"implied powers\",\"gun control\",\"problem-oriented policing\",\"international convention concerning the use of broadcasting in the cause of peace\",\"on the principles of political economy and taxation\",\"state decoration\",\"madhhab\",\"david e. campbell (political scientist)\",\"glory to hong kong\",\"singleton (global governance)\",\"brigitte young\",\"effective number of parties\",\"job cohen\",\"maternalism\",\"grey room\",\"lesser of two evils principle\",\"parliamentary debate\",\"(don't) touch me on my studio\",\"\\u00e5land islands peace institute\",\"squirrel (debate)\",\"new left review\",\"pork barrel\",\"social media use by donald trump\",\"istihlal\",\"world values survey\",\"social media use in african politics\",\"gruppi di acquisto solidale\",\"beatrice heuser\",\"bibliography of works about communism\",\"security studies (journal)\",\"economic stimulus appropriations act of 1977\",\"rosa luxemburg foundation\",\"china university of political science and law\",\"oligarchy\",\"median voter theorem\",\"ilminism\",\"list of food labeling regulations\",\"jamiat-e islami\",\"janet ajzenstat\",\"european school of political and social sciences\",\"science & society\",\"open energy system databases\",\"e. f. schumacher\",\"energy certificate\",\"centre for health and international relations\",\"collaboration\",\"english votes for english laws\",\"european master of public administration consortium\",\"bush school of government and public service\",\"ratification\",\"ecoauthoritarianism\",\"communism and lgbt rights\",\"horseshoe theory\",\"criticism of capitalism\",\"right to the city\",\"far-right politics\",\"fiscal imbalance\",\"hannah arendt institute for totalitarianism studies\",\"louise dandurand\",\"political alienation\",\"henry e. brady\",\"democratic marxism\",\"glory to ukraine\",\"joe biden (the onion)\",\"a call to action: women, religion, violence, and power\",\"statecraft (political science)\",\"maritza montero\",\"i did not have sexual relations with that woman\",\"official bilingualism in the public service of canada\",\"timeline of voting rights in the united states\",\"rentier state\",\"counterpropaganda\",\"build\\u2013operate\\u2013transfer\",\"un-energy\",\"warren miller (political scientist)\",\"challengeaccepted\",\"party political broadcast\",\"paid survey\",\"critical review (journal)\",\"jewish-palestinian living room dialogue group\",\"essence of decision\",\"donatella della porta\",\"chester barnard\",\"relative gain (international relations)\",\"law without the state\",\"imperium\",\"print capitalism\",\"international peacekeeping\",\"capitalist peace\",\"james tully (philosopher)\",\"legalism (chinese philosophy)\",\"brandalism\",\"liberal legalism\",\"australian journal of political science\",\"third way\",\"priya kurian\",\"liberal conservatism\",\"institute for political studies \\u2013 catholic university of portugal\",\"eastern bloc\",\"enlightened absolutism\",\"british polling council\",\"nazism\",\"nominate (scaling method)\",\"petitions of right (ireland) act 1873\",\"you have two cows\",\"environmental peacebuilding\",\"pakistan public works department\",\"participism\",\"echo chamber (media)\",\"politeia (journal)\",\"sciences po\",\"kim campbell\",\"tryph\\u00e9\",\"voluntary society\",\"tractatus politicus\",\"schar school of policy and government\",\"winner-take-all politics\",\"subsidy\",\"history of propaganda\",\"failed state\",\"populism\",\"concurrent powers\",\"experimental political science\",\"india quarterly\",\"donald e. stokes\",\"political socialization\",\"fundacion manantiales\",\"michael l. gross (ethicist)\",\"cultural liberalism\",\"xuanchuan\",\"liechtenstein institute on self-determination\",\"authoritarian capitalism\",\"robert f. wagner graduate school of public service\",\"christian egalitarianism\",\"totalitarianism\",\"school of politics and international relations, university of nottingham\",\"political communication\",\"making peace\",\"scale analysis (statistics)\",\"aromanian question\",\"alan wolfe\",\"political groups of the european parliament\",\"glossary of international relations terms\",\"grenoble institute of political studies\",\"index of social and political philosophy articles\",\"michael thrasher\",\"health system\",\"the birth of biopolitics\",\"violence peace and peace research\",\"dizzy with success\",\"national agrarian party\",\"ed miliband bacon sandwich photograph\",\"ministry of land, infrastructure, transport and tourism\",\"extemporaneous speaking\",\"microgeneration\",\"sophomore surge\",\"exequatur\",\"siobhan o'sullivan\",\"free-market healthcare\",\"democratic recession\",\"sovereignty of the philippines\",\"graduate program in public management\",\"gwendolen m. carter\",\"catherine wihtol de wenden\",\"the province of jurisprudence determined\",\"vacatio legis\",\"ahl al-hadith\",\"kansas city preventive patrol experiment\",\"public budgeting\",\"real socialism\",\"martens centre\",\"non-state actor\",\"autonomous administrative division\",\"fiscal policy of the united states\",\"international council for science\",\"valerie bryson\",\"grace skogstad\",\"neoauthoritarianism (china)\",\"social welfare in luxembourg\",\"international centre for black sea studies\",\"spatial politics\",\"tyranny of the majority\",\"conservative liberalism\",\"international relations and security network\",\"school of political and social sciences, unam\",\"organicism\",\"autonomous communities of spain\",\"svetlana tatunts\",\"biology and political orientation\",\"political geography (journal)\",\"new aspects of politics\",\"political cartoon\",\"tripartite consultation (international labour standards) convention, 1976\",\"institute for international law of peace and armed conflict\",\"managerialism\",\"paul van riper (political scientist)\",\"e-government\",\"comit\\u00e9s abertos de estudantes\",\"fiscal capacity\",\"red wall (us politics)\",\"history of political science\",\"nation-building\",\"non-sampling error\",\"proprietary community\",\"norman chester\",\"workplace democracy\",\"phillip blond\",\"post-behavioralism\",\"friedrich naumann foundation\",\"social imperialism\",\"legal norm\",\"political culture of the united states\",\"marlon bundo\",\"yehuda zvi blum\",\"john coakley\",\"ishraga mustafa hamid\",\"henry habib\",\"list of national independence days\",\"territorialisation of carbon governance\",\"democracy and security\",\"politics of memory\",\"ministry of housing and works (pakistan)\",\"class traitor\",\"blue labour\",\"alex brillantes jr.\",\"societal attitudes towards abortion\",\"writ\",\"contingent sovereignty\",\"he who does not work, neither shall he eat\"],\"node_colour\":[\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\",\"#440154\"],\"node_sizes\":[0.5,0.0,2.0,0.25,1.25,0.75,1.25,0.25,1.0,0.25,2.25,1.0,0.5,0.75,0.5,0.25,1.0,0.25,0.0,0.25,0.5,0.5,3.5,6.25,0.25,60.0,0.5,0.25,0.25,1.0,0.5,0.25,0.25,3.25,1.5,0.25,9.0,0.0,0.25,1.0,0.5,1.0,0.25,0.25,0.25,0.5,1.25,1.0,0.25,1.25,0.5,0.25,5.5,4.0,0.25,2.0,0.5,0.5,0.75,10.25,2.0,2.5,0.25,0.5,0.25,0.25,0.25,1.0,4.25,0.25,0.25,1.5,0.5,0.5,4.0,0.25,14.25,1.25,0.25,0.25,0.25,0.5,0.25,5.25,0.25,3.5,0.25,0.25,0.75,0.75,0.0,0.25,0.5,0.75,2.5,0.5,0.25,0.25,0.5,0.0,8.75,0.75,2.0,1.25,0.5,5.25,3.25,9.0,7.25,1.0,2.0,0.5,3.75,0.75,0.5,3.0,0.75,0.25,0.0,0.5,0.25,0.25,1.0,0.5,0.0,0.75,0.75,3.5,1.25,0.25,0.25,1.75,0.25,0.25,0.25,0.5,0.5,1.25,0.75,0.5,0.5,0.25,0.75,1.0,0.0,2.5,0.25,3.25,2.5,3.0,3.0,3.25,1.25,0.25,0.0,1.75,0.75,0.0,0.25,0.75,1.0,0.75,0.25,0.75,1.75,0.25,0.75,3.75,0.0,0.5,0.25,0.5,0.75,0.5,1.25,0.75,1.25,0.25,0.75,0.0,0.25,0.25,2.25,0.5,0.5,0.75,0.0,0.25,2.0,0.5,0.25,0.5,0.5,0.5,2.75,0.25,3.75,0.25,4.75,0.75,0.5,0.0,0.25,0.25,0.0,0.75,0.25,0.25,0.5,1.0,0.25,1.5,1.25,3.25,0.25,0.75,0.5,0.75,0.25,5.0,3.5,1.25,0.25,0.5,1.75,2.75,0.5,0.75,7.5,12.0,0.25,0.25,0.25,0.0,0.25,0.25,5.5,1.5,0.75,1.25,0.25,0.0,3.5,1.0,0.0,1.25,7.5,4.25,0.5,0.0,0.75,2.0,1.25,3.5,0.25,0.25,2.5,0.25,0.5,0.25,0.25,0.25,3.0,0.5,0.5,0.25,13.5,0.25,5.75,0.5,0.5,0.75,0.25,1.25,4.75,2.5,0.25,2.0,0.25,0.75,2.75,0.25,0.0,1.5,0.5,0.25,0.0,0.75,0.25,1.0,0.25,0.25,7.25,0.25,1.25,0.25,0.5,0.0,7.5,1.25,0.75,0.0,0.5,0.25,3.25,0.0,0.25,5.5,1.75,3.0,1.0,1.75,4.5,1.0,0.5,0.0,0.25,0.75,7.0,0.75,0.25,0.5,2.0,0.25,0.25,1.0,0.25,2.0,1.75,1.5,1.75,2.0,8.75,2.0,0.25,1.75,0.25,15.75,1.0,0.25,0.25,0.5,0.25,1.5,0.0,0.25,0.25,1.25,0.25,0.5,7.75,0.25,1.0,0.25,1.5,0.25,0.25,0.25,0.0,1.0,0.75,1.5,0.25,2.25,0.25,0.25,1.0,0.25,1.75,0.25,0.25,1.5,3.0,2.25,2.0,0.25,0.5,0.25,0.25,0.5,0.75,0.75,0.5,0.5,1.0,1.0,0.5,0.25,0.25,1.25,0.5,0.25,0.0,0.25,2.75,2.0,0.0,0.5,1.75,0.75,0.5,0.25,1.25,1.5,0.25,0.5,0.25,4.25,10.25,1.75,0.5,0.25,6.0,2.25,0.25,0.25,0.75,1.5,5.5,5.25,0.5,0.75,0.25,0.25,0.5,1.0,0.25,3.75,6.25,0.25,2.75,0.25,3.5,1.0,0.25,1.0,0.5,5.75,5.0,0.25,0.5,0.25,1.25,0.5,0.25,0.25,1.0,0.5,1.5,0.25,1.75,0.5,2.25,1.0,0.25,2.0,1.75,1.25,0.25,0.25,1.75,1.0,0.5,0.25,2.5,0.0,0.25,0.5,0.25,1.75,0.0,8.25,2.0,1.25,0.5,0.25,0.25,0.25,0.75,5.75,0.5,0.25,0.5,0.5,0.75,3.0,0.5,1.25,1.0,0.25,1.5,0.25,0.75,0.25,0.25,4.75,9.5,0.75,1.25,2.25,0.0,1.0,0.25,0.0,0.25,0.5,5.5,0.0,0.25,1.5,0.0,0.5,15.0,0.25,0.25,0.25,2.25,0.25,0.25,0.25,1.0,3.75,0.5,0.5,0.25,1.25,3.25,0.25,0.5,1.0,1.25,0.75,0.0,4.25,3.0,0.5,1.5,0.25,1.0,0.25,0.25,0.25,0.25,1.5,0.0,1.75,1.25,0.5,0.25,0.75,1.25,0.25,0.0,0.75,0.25,1.25,0.5,3.0,1.5,1.0,2.0,0.0,0.5,0.25,0.25,0.5,0.0,0.25,0.75,1.75,7.5,0.25,0.25,1.25,1.5,4.0,2.25,0.25,12.25,0.5,0.5,1.0,2.0,1.5,0.25,0.0,0.5,0.5,0.5,0.0,0.5,0.0,2.0,0.0,0.25,0.25,1.0,1.5,0.5,0.25,0.25,1.5,0.5,3.0,6.25,0.25,0.5,0.25,7.75,3.0,0.0,0.25,0.5,0.75,5.5,0.25,4.5,0.25,2.75,0.5,0.75,0.75,6.25,0.5,1.75,0.75,1.0,0.5,0.25,1.5,0.0,0.5,0.25,1.5,0.25,0.75,2.0,0.25,0.25,0.0,4.75,0.5,0.75,1.5,3.25,0.25,0.0,0.5,0.5,0.25,0.25,0.0,0.25,0.25,0.0,0.25,0.25,0.25,0.0,0.5,0.75,0.25,0.5,1.75,0.75,1.5,0.5,2.75,0.5,0.5,0.75,0.25,1.25,1.0,1.0,0.25,6.25,14.0,2.5,3.75,2.75,1.5,1.5,2.25,0.25,3.75,0.25,0.25,0.75,1.0,0.0,0.5,1.0,0.25,2.0,0.75,0.0,0.25,0.5,1.0,8.25,1.75,0.25,13.5,0.5,0.25,3.75,0.25,4.5,3.5,5.75,0.5,0.5,1.5,0.75,0.25,1.75,2.0,1.75,4.25,0.0,0.25,0.5,0.5,0.25,5.25,0.75,0.25,2.0,1.25,0.0,6.25,0.25,0.25,2.25,4.75,0.75,2.5,0.5,0.75,2.0,0.5,1.25,0.5,0.25,1.25,1.0,0.5,0.5,2.75,2.0,1.25,0.25,0.0,1.25,4.0,0.25,3.25,0.5,5.5,0.25,0.25,0.0,5.25,0.25,0.5,1.5,0.5,0.0,1.0,0.0,1.5,2.0,0.5,1.25,0.5,0.25,0.5,2.0,0.25,0.75,1.25,1.25,0.25,8.75,3.75,0.25,0.75,5.25,1.75,3.25,2.0,0.25,0.25,0.25,1.0,6.25,0.75,0.75,0.25,0.25,0.75,1.0,1.25,5.75,1.5,2.0,0.25,6.75,0.5,0.25,4.25,0.75,0.25,0.25,0.75,0.25,2.25,1.25,1.0,0.5,1.0,2.0,0.75,0.5,0.25,0.5,2.25,0.25,1.25,0.25,0.25,0.75,0.75,2.5,0.25,1.25,1.5,0.5,0.25,0.25,1.0,0.75,1.0,0.75,3.0,0.25,0.0,0.25,4.75,0.75,1.0,0.25,0.5,10.25,1.25,1.5,0.0,0.0,0.25,0.25,0.25,0.25,1.5,0.25,0.5,1.75,0.25,0.75,2.5,1.0,5.5,2.5,5.0,11.5,0.25,6.75,0.0,1.25,0.25,0.25,1.75,0.25,0.25,0.25,0.75,0.25,0.25,0.5,0.25,0.75,0.25,1.0,0.25,0.0,1.25,0.0,0.5,0.25,0.25,0.25,0.25,0.5,0.75,1.25,1.0,1.5,0.25,0.25,3.25,0.75,3.5,0.25,0.5,1.0,14.5,0.25,5.75,0.25,7.75,3.75,0.0,15.5,0.5,0.25,0.25,0.0,0.5,9.25,1.75,0.5,5.75,0.75,0.75,3.5,0.5,2.5,0.0,0.0,3.5,1.25,12.0,1.0,0.75,0.25,0.5,0.25,0.25,0.25,3.0,0.75,0.75,5.75,1.0,0.75,18.25,0.25,3.25,0.25,0.25,0.5,0.75,1.75,1.25,0.75,10.75,0.5,0.25,1.25,0.25,0.25,0.25,0.0,0.25,0.25,2.5,0.25,2.75,1.0,0.75,0.25,0.25,0.25,0.25,0.25,0.25,2.0,1.5,0.25,0.5,8.0,0.75,0.5,1.25,0.5,0.5,0.0,0.25,1.75,0.0,0.75,3.0,8.0,3.75,0.5,0.5,2.5,1.25,0.5,6.0,0.25,0.5,1.0,0.25,0.25,0.75,0.5,4.75,0.5,0.25,0.25,0.75,1.5,1.75,0.25,0.5,8.25,0.75,0.25,0.5,6.5,0.5,0.75,0.75,0.5,0.5,0.25,0.5,0.5,0.25,0.25,0.0,0.25,0.25,1.5,0.25,0.5,0.25,0.75,0.75],\"parent\":[\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\",\"political_science\"]},\"selected\":{\"id\":\"2703\"},\"selection_policy\":{\"id\":\"2702\"}},\"id\":\"1485\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"2709\",\"type\":\"Selection\"},{\"attributes\":{\"above\":[{\"id\":\"1482\"}],\"below\":[{\"id\":\"1463\"}],\"center\":[{\"id\":\"1466\"},{\"id\":\"1470\"}],\"height\":500,\"left\":[{\"id\":\"1467\"}],\"renderers\":[{\"id\":\"1483\"}],\"title\":{\"id\":\"2666\"},\"toolbar\":{\"id\":\"1476\"},\"width\":500,\"x_range\":{\"id\":\"1454\"},\"x_scale\":{\"id\":\"1459\"},\"y_range\":{\"id\":\"1455\"},\"y_scale\":{\"id\":\"1461\"}},\"id\":\"1456\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{},\"id\":\"2685\",\"type\":\"NodesOnly\"},{\"attributes\":{},\"id\":\"2675\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"2688\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"1461\",\"type\":\"LinearScale\"},{\"attributes\":{},\"id\":\"2708\",\"type\":\"UnionRenderers\"},{\"attributes\":{\"axis\":{\"id\":\"1463\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"1466\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"2691\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"1468\",\"type\":\"BasicTicker\"},{\"attributes\":{},\"id\":\"2692\",\"type\":\"NodesOnly\"},{\"attributes\":{\"formatter\":{\"id\":\"2675\"},\"major_label_policy\":{\"id\":\"2673\"},\"ticker\":{\"id\":\"1464\"},\"visible\":false},\"id\":\"1463\",\"type\":\"LinearAxis\"},{\"attributes\":{},\"id\":\"1472\",\"type\":\"WheelZoomTool\"},{\"attributes\":{},\"id\":\"2702\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"2706\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"2676\",\"type\":\"NodesOnly\"},{\"attributes\":{},\"id\":\"1473\",\"type\":\"SaveTool\"},{\"attributes\":{},\"id\":\"2689\",\"type\":\"AllLabels\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1454\",\"type\":\"Range1d\"},{\"attributes\":{\"text\":\"Network for discipline: political science\",\"text_font_size\":\"12pt\"},\"id\":\"1482\",\"type\":\"Title\"},{\"attributes\":{\"fill_alpha\":{\"field\":\"alpha\"},\"fill_color\":{\"field\":\"node_colour\"},\"size\":{\"field\":\"node_sizes\"}},\"id\":\"1509\",\"type\":\"Circle\"},{\"attributes\":{\"source\":{\"id\":\"1489\"}},\"id\":\"1491\",\"type\":\"CDSView\"},{\"attributes\":{},\"id\":\"2703\",\"type\":\"Selection\"},{\"attributes\":{\"data_source\":{\"id\":\"1489\"},\"glyph\":{\"id\":\"1514\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1491\"}},\"id\":\"1490\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"2705\",\"type\":\"Selection\"},{\"attributes\":{\"fill_alpha\":{\"field\":\"alpha\"},\"fill_color\":{\"field\":\"node_colour\"},\"size\":{\"field\":\"node_sizes\"}},\"id\":\"1639\",\"type\":\"Circle\"},{\"attributes\":{\"data\":{\"end\":[\"opinion poll\",\"public opinion quarterly\",\"london school of economics\",\"public policy school\",\"sciences po\",\"princeton school of public and international affairs\",\"schar school of policy and government\",\"school of international and public affairs, columbia university\",\"american university school of international service\",\"bush school of government and public service\",\"military policy\",\"political science\",\"parochial political culture\",\"political culture of germany\",\"the civic culture\",\"political culture of the united states\",\"comparative politics\",\"clientelism\",\"transformation processes (media systems)\",\"reactionary\",\"far-right politics\",\"blood and soil\",\"kalergi plan\",\"basket of deplorables\",\"nation state\",\"public administration\",\"public policy school\",\"master of public policy\",\"yelyzaveta yasko\",\"political science\",\"technocracy\",\"digital era governance\",\"e-government\",\"regional power\",\"particracy\",\"great power\",\"totalitarianism\",\"oligarchy\",\"dependent territory\",\"constitutionalism\",\"concurrent powers\",\"implied powers\",\"plenary power\",\"political science\",\"political communication\",\"federal law\",\"resource conservation and recovery act\",\"slogan\",\"keep indy indie\",\"legal naturalism\",\"political science\",\"party platform\",\"knowledge gap hypothesis\",\"henry e. brady\",\"political science\",\"afrobarometer\",\"constitutional economics\",\"institution\",\"collaboration\",\"managerialism\",\"political party\",\"populism\",\"situationist international\",\"tyranny of the majority\",\"majoritarianism\",\"polyarchy\",\"proletarian revolution\",\"industrial democracy\",\"criticism of capitalism\",\"participism\",\"law of equal liberty\",\"an anarchist faq\",\"index of social and political philosophy articles\",\"outline of anarchism\",\"technocracy\",\"nation state\",\"e-government\",\"totalitarianism\",\"oligarchy\",\"particracy\",\"autonomous communities of spain\",\"polyarchy\",\"scientocracy\",\"bankocracy\",\"futarchy\",\"corporative federalism\",\"civilization state\",\"corporate republic\",\"secession\",\"dependent territory\",\"regional power\",\"night-watchman state\",\"autonomous administrative division\",\"home rule\",\"great power\",\"constitutional dictatorship\",\"legalism (chinese philosophy)\",\"social media use in politics\",\"deployment management\",\"journal of political ideologies\",\"horseshoe theory\",\"stephen barber\",\"risk, hazards & crisis in public policy\",\"grenoble institute of political studies\",\"security of tenure\",\"the journal of politics\",\"uk heo\",\"margaret clark (political scientist)\",\"journal of current southeast asian affairs\",\"history of propaganda\",\"rowman & littlefield award in innovative teaching\",\"institut d'\\u00e9tudes politiques de toulouse\",\"democracy and security\",\"katharine hayhoe\",\"british journal of politics and international relations\",\"international ethics\",\"andr\\u00e9 du pisani\",\"politics, philosophy & economics\",\"marie-christine kessler\",\"experimental political science\",\"polarized pluralism\",\"rasma k\\u0101rkli\\u0146a\",\"preselection\",\"political geography (journal)\",\"second-order election\",\"public opinion quarterly\",\"public policy doctrine\",\"australian journal of political science\",\"boosterism\",\"inclusion and democracy\",\"the end of liberalism\",\"critical security studies\",\"east european politics\",\"journal of democracy\",\"lorena parini\",\"security, territory, population\",\"computational politics\",\"faculty of political science, chulalongkorn university\",\"the hidden hand: middle east fears of conspiracy\",\"ishraga mustafa hamid\",\"andrew westmoreland\",\"social patriotism\",\"triangular diplomacy\",\"sacralism\",\"raisons politiques\",\"brigitte young\",\"steven b. smith (professor)\",\"journal of european integration\",\"jean bethke elshtain\",\"alexandra goujon\",\"election law journal\",\"catherine wihtol de wenden\",\"ljiljana radoni\\u0107\",\"campaign finance\",\"bonai state\",\"political alienation\",\"security studies (journal)\",\"democracies: patterns of majoritarian & consensus government in twenty-one countries\",\"the machiavellian moment\",\"canadian public policy\",\"philip oxhorn\",\"w. meredith bacon\",\"politics (academic journal)\",\"biology and political orientation\",\"comparative politics\",\"terry karl\",\"paul van riper (political scientist)\",\"pi sigma alpha\",\"fascism: a warning\",\"rentier state\",\"security studies\",\"new political economy (journal)\",\"malinda s. smith\",\"nonkilling global political science\",\"german university of administrative sciences speyer\",\"china university of political science and law\",\"trusteeship (gandhism)\",\"journal of theoretical politics\",\"journal of european social policy\",\"critique: journal of socialist theory\",\"transitology\",\"a call to action: women, religion, violence, and power\",\"international journal of intelligence and counterintelligence\",\"polyarchy\",\"european union studies association\",\"peace\\u2013industrial complex\",\"gwendolen m. carter\",\"principle-policy puzzle\",\"philip converse\",\"peace and conflict studies\",\"public policy school\",\"the good society\",\"list of national legal systems\",\"clientelism\",\"niamh reilly\",\"priya kurian\",\"bureaucratic drift\",\"kissinger lecture\",\"robert m. la follette school of public affairs\",\"linked fate\",\"pal lahara state\",\"alternatives: turkish journal of international relations\",\"political methodology\",\"school of political and social sciences, unam\",\"school of international and public affairs, columbia university\",\"michael l. gross (ethicist)\",\"horace campbell\",\"small media, big revolution\",\"logology (science)\",\"marian van landingham\",\"yelyzaveta yasko\",\"systems theory in political science\",\"multi-level governance\",\"constitutional autochthony\",\"political man\",\"median voter theorem\",\"making democracy work\",\"sophomore surge\",\"transformation processes (media systems)\",\"wilson\\u2013patterson conservatism scale\",\"digest of middle east studies\",\"behavioralism\",\"nanosocialism\",\"political studies review\",\"nation state\",\"journal of policy history\",\"political science\",\"new aspects of politics\",\"al-ahram center for political and strategic studies\",\"grey room\",\"cleavage (politics)\",\"journal of ethnic and migration studies\",\"josepha laroche\",\"anthony downs\",\"world politics\",\"regional power\",\"donatella della porta\",\"pippa norris\",\"institute for political studies \\u2013 catholic university of portugal\",\"val\\u00e9rie igounet\",\"david e. campbell (political scientist)\",\"\\u00fcmit cizre\",\"elif shafak\",\"louise dandurand\",\"minimal effects hypothesis\",\"bush school of government and public service\",\"technocracy\",\"essence of decision\",\"edward j. bloustein school of planning and public policy\",\"james tully (philosopher)\",\"charg\\u00e9 de mission\",\"environmental politics (journal)\",\"insight turkey\",\"alex brillantes jr.\",\"public administration\",\"afke schaart\",\"the birth of biopolitics\",\"cultural liberalism\",\"domestic analogy\",\"criticism of capitalism\",\"high and low politics\",\"the independent review\",\"robert kent gooch\",\"journal of current chinese affairs\",\"critical review (journal)\",\"science & society\",\"print capitalism\",\"voter turnout\",\"olivier ihl\",\"international review of the red cross\",\"siobhan o'sullivan\",\"history of political science\",\"clarita carlos\",\"cand.scient.pol.\",\"henry habib\",\"reactionary\",\"behavioral public administration\",\"social policy\",\"contemporary voices\",\"janet ajzenstat\",\"participism\",\"tryph\\u00e9\",\"politique africaine\",\"populism\",\"maritza montero\",\"praxis: the fletcher journal of human security\",\"marco tarchi\",\"rodney tiffen\",\"elective dictatorship\",\"review of international political economy\",\"foreign policy\",\"political communication\",\"fiscal capacity\",\"implementation\",\"american political thought\",\"jane duckett\",\"sciences po\",\"cube root rule\",\"party system\",\"antinaturalism (politics)\",\"donald e. stokes\",\"institution\",\"helen margetts\",\"her majesty's government (term)\",\"karl deutsch award\",\"effective number of parties\",\"statecraft (political science)\",\"statism\",\"international political science association\",\"perestroika movement (political science)\",\"fred w. riggs\",\"india quarterly\",\"william james booth\",\"big man (political science)\",\"managerialism\",\"e-government\",\"passing on the right\",\"politeia (journal)\",\"rena dourou\",\"walter f. dodd\",\"political studies (journal)\",\"nonna mayer\",\"dyab abou jahjah\",\"the permanent revolution and results and prospects\",\"democratic recession\",\"mediations (journal)\",\"parallel state\",\"pilar calveiro\",\"berkeley school of political theory\",\"jurisprudence\",\"svetlana tatunts\",\"policy studies journal\",\"foreign policy\",\"science diplomacy\",\"democratic peace theory\",\"jurisprudence\",\"fiqh\",\"mahr\",\"early social changes under islam\",\"jurisprudence\",\"index of social and political philosophy articles\",\"eastern bloc\",\"propaganda\",\"totalitarianism\",\"nazism\",\"far-right politics\",\"kalergi plan\",\"blood and soil\",\"basket of deplorables\",\"nur f\\u00fcr deutsche\",\"authoritarian democracy\",\"organicism\",\"f\\u00fchrer\",\"third way\",\"ordoliberalism\",\"private property\",\"criticism of capitalism\",\"corporatization\",\"german model\",\"civil service\",\"public administration\",\"technocracy\",\"national liberalism\",\"particracy\",\"antemurale myth\",\"balkanization\",\"oligarchy\",\"nazism\",\"authoritarian left\",\"roman question\",\"enemy of the people (albania)\",\"law without the state\",\"security, territory, population\",\"history of propaganda\",\"equal opportunity\",\"plurinationalism\",\"civilization state\",\"the birth of biopolitics\",\"secession\",\"coercion, capital, and european states, ad 990\\u20131992\",\"regional power\",\"nation-building\",\"enemy of the people\",\"totalitarianism\",\"ethnosymbolism\",\"westphalian sovereignty\",\"right to exist\",\"constitutional patriotism\",\"national conservatism\",\"eco-nationalism\",\"national communism\",\"great power\",\"superpower collapse\",\"propaganda\",\"clientelism\",\"failed state\",\"maladministration\",\"rent extraction\",\"public administration\",\"chester barnard\",\"public administration\",\"anthony downs\",\"cato institute\",\"bryan caplan\",\"international security\",\"diplomatic protection\",\"international law\",\"imperium\",\"third way\",\"private property\",\"list of liberal theorists\",\"whiggism\",\"organicism\",\"sciences po\",\"postfunctionalism\",\"multi-level governance\",\"european union studies association\",\"social media use by donald trump\",\"international law\",\"peace and conflict studies\",\"non-governmental organization\",\"non-interventionism\",\"contingent sovereignty\",\"robert christison\",\"third way\",\"ordoliberalism\",\"oligarchy\",\"cultural liberalism\",\"national liberalism\",\"tyranny of the majority\",\"private property\",\"social liberalism\",\"isaiah berlin\",\"civil libertarianism\",\"technoliberalism\",\"conservative liberalism\",\"equal opportunity\",\"neoclassical liberalism\",\"whiggism\",\"liberalism and conservatism in latin america\",\"liberal conservatism\",\"modern liberalism in the united states\",\"equality before the law\",\"democratic liberalism\",\"law of equal liberty\",\"jurisprudence\",\"political party\",\"international law\",\"nazism\",\"fiqh\",\"virtue jurisprudence\",\"history of the legal profession\",\"history of the american legal profession\",\"executive order\",\"exequatur\",\"jus commune\",\"vacatio legis\",\"notary (catholic canon law)\",\"promulgation (catholic canon law)\",\"custom (catholic canon law)\",\"obreption and subreption (catholic canon law)\",\"london school of economics\",\"cato institute\",\"equality of outcome\",\"limitarianism (ethical)\",\"the triple revolution\",\"technoliberalism\",\"universal basic income\",\"comparative politics\",\"liechtenstein institute on self-determination\",\"post-truth politics\",\"campaign finance\",\"community policing\",\"victim study\",\"dark figure of crime\",\"foreign policy\",\"jurisprudence\",\"afrobarometer\",\"voter turnout\",\"tactical voting\",\"party political broadcast\",\"effective number of parties\",\"predictive policing\",\"one-party state\",\"party identification\",\"blanquism\",\"list of national legal systems\",\"inquisitorial system\",\"left group of finnish workers\",\"decolonization\",\"cleavage (politics)\",\"clientelism\",\"nonpartisanism\",\"international law\",\"populism\",\"security sector governance and reform\",\"london school of economics\",\"bloc party (politics)\",\"feminist legal theory\",\"left\\u2013right political spectrum\",\"multistakeholder governance\",\"preselection\",\"bad governance\",\"otto kirchheimer\",\"executive order\",\"history of the legal profession\",\"cato institute\",\"party platform\",\"non-governmental organization\",\"history of the american legal profession\",\"party system\",\"fiqh\",\"synarchism\",\"democratic party for a new society\",\"international political science association\",\"isaiah berlin\",\"political studies (journal)\",\"michael thrasher\",\"politics (academic journal)\",\"wyn grant\",\"british journal of politics and international relations\",\"political studies review\",\"third way\",\"reactionary\",\"decolonization\",\"right-wing politics\",\"private property\",\"eurasianism\",\"maternalism\",\"whiggism\",\"international peacekeeping\",\"public administration\",\"party system\",\"left-wing populism\",\"comit\\u00e9s abertos de estudantes\",\"erguer-estudantes da galiza\",\"revolutionary students federation\",\"galician workers union\",\"technocracy\",\"left-wing politics\",\"situationist international\",\"christian communism\",\"equal opportunity\",\"dictatorship of the proletariat\",\"proletarian revolution\",\"nanosocialism\",\"industrial democracy\",\"labour voucher\",\"workplace democracy\",\"blanquism\",\"criticism of capitalism\",\"participism\",\"left communism\",\"equality of outcome\",\"history of communism\",\"international law\",\"nation-building\",\"fiqh\",\"islamic sexual jurisprudence\",\"islamic toilet etiquette\",\"menstruation in islam\",\"islamic funeral\",\"mahr\",\"live free or die\",\"comparative politics\",\"left-wing politics\",\"nation-building\",\"liberal international order\",\"regional power\",\"list of national independence days\",\"balkanization\",\"democratic peace theory\",\"food sovereignty\",\"decolonization\",\"eastern bloc\",\"decoloniality\",\"secession\",\"superpower collapse\",\"propaganda\",\"comparative politics\",\"public administration\",\"technocracy\",\"autonomous communities of spain\",\"bolivarian revolution\",\"clarita carlos\",\"centre for health and international relations\",\"the crisis of democracy\",\"authoritarian left\",\"english votes for english laws\",\"full spectrum diplomacy\",\"biology and political orientation\",\"rosa brooks\",\"i did not have sexual relations with that woman\",\"the soldier and the state\",\"katharine hayhoe\",\"social media use by donald trump\",\"list of futurama characters\",\"third way\",\"national power\",\"foreign policy\",\"political communication\",\"preselection\",\"security studies\",\"cato institute\",\"party system\",\"american university school of international service\",\"public policy doctrine\",\"the final days (2000 film)\",\"australian journal of political science\",\"polyarchy\",\"health policy\",\"public policy school\",\"authoritarian capitalism\",\"non-interventionism\",\"marc lynch\",\"taftian theory\",\"thucydides trap\",\"grab em by the pussy\",\"clientelism\",\"johnson cult\",\"e-government\",\"rena dourou\",\"appeasement\",\"school of international and public affairs, columbia university\",\"american recovery and reinvestment act of 2009\",\"high and low politics\",\"political groups of the european parliament\",\"princeton school of public and international affairs\",\"\\u00bfpor qu\\u00e9 no te callas?\",\"arab barometer\",\"svetlana tatunts\",\"i like ike\",\"prediction market\",\"decentralized computing\",\"predictive policing\",\"decentralized autonomous organization\",\"electronic process of law\",\"eastern bloc\",\"technocracy\",\"left-wing politics\",\"private property\",\"christian corporatism\",\"christian communism\",\"equal opportunity\",\"dictatorship of the proletariat\",\"proletarian revolution\",\"nanosocialism\",\"industrial democracy\",\"labour voucher\",\"workplace democracy\",\"blanquism\",\"criticism of capitalism\",\"participism\",\"left communism\",\"equality of outcome\",\"history of communism\",\"religious communism\",\"christian fascism\",\"christian egalitarianism\",\"list of national independence days\",\"balkanization\",\"cato institute\",\"autonomous administrative division\",\"private property\",\"home rule\",\"corporative federalism\",\"proposed national unification promotion law\",\"burmese way to socialism\",\"secession\",\"labor theory of property\",\"behavioralism\",\"list of national legal systems\",\"fiqh\",\"muhammad taqi usmani\",\"qazi syed inayatullah\",\"nurturant parent model\",\"sciences po\",\"c. d. broad\",\"logology (science)\",\"jurisprudence\",\"international law\",\"fiqh\",\"history of the legal profession\",\"history of the american legal profession\",\"executive order\",\"community policing\",\"inquisitorial system\",\"perestroika\",\"united federal workers of america\",\"public administration\",\"social policy\",\"political groups of the european parliament\",\"schar school of policy and government\",\"instituts d'\\u00e9tudes politiques\",\"ernest barker\",\"national student survey\",\"kim campbell\",\"ronen palan\",\"stein rokkan\",\"andr\\u00e9 du pisani\",\"master of public administration\",\"populism\",\"london school of economics\",\"third way\",\"pippa norris\",\"cato institute\",\"sciences po\",\"journal of theoretical politics\",\"bureau-shaping model\",\"beatrice heuser\",\"perpetual war\",\"bush school of government and public service\",\"colin hughes\",\"eric helleiner\",\"helen margetts\",\"research excellence framework\",\"graduate school of public policy, university of tokyo\",\"left-wing populism\",\"ethnosymbolism\",\"princeton school of public and international affairs\",\"broken windows theory\",\"community policing\",\"peelian principles\",\"left-wing politics\",\"intergovernmentalism\",\"third way\",\"constitutional patriotism\",\"authoritarian capitalism\",\"private property\",\"liberal conservatism\",\"criticism of capitalism\",\"social policy\",\"health policy\",\"public policy school\",\"wisconsin school (diplomatic history)\",\"jurisprudence\",\"virtue jurisprudence\",\"constitutionalism\",\"third way\",\"constitutional patriotism\",\"small government\",\"night-watchman state\",\"private property\",\"whiggism\",\"liberal conservatism\",\"cato institute\",\"participism\",\"antimilitarism\",\"non-interventionism\",\"freedom of contract\",\"civil libertarianism\",\"voluntary society\",\"bryan caplan\",\"free migration\",\"global justice movement\",\"gadsden flag\",\"free market fairness\",\"left-wing politics\",\"private property\",\"christian communism\",\"world revolution\",\"worker cooperative\",\"criticism of capitalism\",\"history of communism\",\"index of social and political philosophy articles\",\"bibliography of works about communism\",\"national communism\",\"crimes against humanity under communist regimes\",\"harvest hills cooperative community\",\"technocracy\",\"left-wing politics\",\"populism\",\"third way\",\"situationist international\",\"tyranny of the majority\",\"christian communism\",\"ethical socialism\",\"majoritarianism\",\"polyarchy\",\"equal opportunity\",\"dictatorship of the proletariat\",\"proletarian revolution\",\"worker cooperative\",\"real socialism\",\"nanosocialism\",\"equality of outcome\",\"history of communism\",\"labour voucher\",\"list of social democratic parties\",\"industrial democracy\",\"blanquism\",\"frankfurt declaration\",\"participism\",\"left communism\",\"workplace democracy\",\"edinburgh university socialist society\",\"criticism of capitalism\",\"popular socialism\",\"law of equal liberty\",\"history of democratic socialism\",\"social corporatism\",\"left-wing politics\",\"constitutionalism\",\"third way\",\"constitutional patriotism\",\"small government\",\"night-watchman state\",\"private property\",\"whiggism\",\"equal opportunity\",\"liberal conservatism\",\"worker cooperative\",\"nanosocialism\",\"labour voucher\",\"workplace democracy\",\"blanquism\",\"criticism of capitalism\",\"participism\",\"left communism\",\"antimilitarism\",\"freedom of contract\",\"equality before the law\",\"civil libertarianism\",\"global justice movement\",\"voluntary society\",\"bryan caplan\",\"free migration\",\"oligarchy\",\"kyklos\",\"corporate republic\",\"one-party state\",\"public administration\",\"public policy school\",\"master of public administration\",\"princeton school of public and international affairs\",\"graduate school of public policy, university of tokyo\",\"mccourt school of public policy\",\"school of public policy at central european university\",\"grace skogstad\",\"james tully (philosopher)\",\"left-wing populism\",\"peace and conflict studies\",\"night-watchman state\",\"criticism of capitalism\",\"participism\",\"index of social and political philosophy articles\",\"appeasement\",\"civil libertarianism\",\"global justice movement\",\"peace journalism\",\"give peace a chance\",\"non-interventionism\",\"free migration\",\"eastern bloc\",\"international workers' day\",\"jurisprudence\",\"fiqh\",\"intergovernmentalism\",\"democratic peace theory\",\"capitalist peace\",\"critical security studies\",\"classical realism (international relations)\",\"postinternationalism\",\"scientific man versus power politics\",\"relative gain (international relations)\",\"regionalism (international relations)\",\"bananas, beaches and bases\",\"idealism in international relations\",\"pickens plan\",\"american recovery and reinvestment act of 2009\",\"microgeneration\",\"political studies review\",\"the independent review\",\"state decoration\",\"feoffment\",\"state order\",\"review of international political economy\",\"international energy agency\",\"microgeneration\",\"powering past coal alliance\",\"microgeneration\",\"carbon fee and dividend\",\"enbau\",\"jurisprudence\",\"third way\",\"nazism\",\"constitutional patriotism\",\"plurinationalism\",\"index of social and political philosophy articles\",\"whiggism\",\"isaiah berlin\",\"liberal conservatism\",\"social liberalism\",\"private property\",\"conservative liberalism\",\"third way\",\"private property\",\"whiggism\",\"perestroika\",\"eastern bloc\",\"workplace democracy\",\"revolutions of 1989\",\"sovereignty of puerto rico during the cold war\",\"harvard institute of politics\",\"triangular diplomacy\",\"oligarchy\",\"enlightened absolutism\",\"jurisprudence\",\"index of social and political philosophy articles\",\"propaganda\",\"nazism\",\"constitutional patriotism\",\"plurinationalism\",\"e-government\",\"international conference on theory and practice of electronic governance\",\"inter-municipal cooperation\",\"corporatization\",\"white paper\",\"clientelism\",\"failed state\",\"social imperialism\",\"world revolution\",\"no war but the class war\",\"nazism\",\"constitutional patriotism\",\"national conservatism\",\"enemy of the people\",\"eco-nationalism\",\"enemy of the people (albania)\",\"national communism\",\"third way\",\"reactionary\",\"oligarchy\",\"eastern bloc\",\"private property\",\"ethical socialism\",\"modern liberalism in the united states\",\"dictatorship of the proletariat\",\"workplace democracy\",\"criticism of capitalism\",\"frankfurt declaration\",\"social corporatism\",\"revolutions of 1989\",\"technocracy\",\"totalitarianism\",\"ethnosymbolism\",\"nation-building\",\"oligarchy\",\"particracy\",\"regional power\",\"great power\",\"jurisprudence\",\"international law\",\"fiqh\",\"code of hammurabi\",\"virtue jurisprudence\",\"history of the legal profession\",\"history of the american legal profession\",\"executive order\",\"dualism (law)\",\"perestroika\",\"social imperialism\",\"enemy of the people\",\"index of social and political philosophy articles\",\"people's democracy (marxism\\u2013leninism)\",\"proletarian revolution\",\"real socialism\",\"commanding heights of the economy\",\"dictatorship of the proletariat\",\"enemy of the people (albania)\",\"world revolution\",\"worker cooperative\",\"public administration\",\"social policy\",\"public policy school\",\"edward j. bloustein school of planning and public policy\",\"cato institute\",\"health system\",\"patient participation\",\"health policy in bangladesh\",\"frank batten school of leadership and public policy\",\"multi-level governance\",\"public policy doctrine\",\"technocracy\",\"science diplomacy\",\"scientocracy\",\"history of science policy\",\"logology (science)\",\"oligarchy\",\"third way\",\"ethical socialism\",\"criticism of capitalism\",\"list of social democratic parties\",\"social corporatism\",\"political man\",\"carl albert center\",\"private military company\",\"failed state\",\"violent non-state actor\",\"jurisprudence\",\"code of hammurabi\",\"hardline\",\"superpower collapse\",\"all animals are equal, but some animals are more equal than others\",\"new political economy (journal)\",\"political communication\",\"social media use in african politics\",\"social media in the 2016 united states presidential election\",\"politico-media complex\",\"global politics\",\"social media use by donald trump\",\"propaganda\",\"dang guo\",\"history of communism\",\"propaganda\",\"triangular diplomacy\",\"totalitarianism\",\"perestroika\",\"revolutions of 1989\",\"sovereignty of puerto rico during the cold war\",\"socialist realism\",\"eastern bloc\",\"political repression\",\"superpower collapse\",\"school of diplomacy\",\"legalism (chinese philosophy)\",\"grey-zone (international relations)\",\"jurisprudence\",\"virtue jurisprudence\",\"enemy of the people\",\"enemy of the people (albania)\",\"jurisprudence\",\"virtue jurisprudence\",\"community policing\",\"broken windows theory\",\"problem-oriented policing\",\"carl joachim friedrich\",\"vaticanology\",\"china watcher\",\"nazism\",\"constitutional patriotism\",\"ecoauthoritarianism\",\"nonkilling global political science\",\"constitutional economics\",\"civil service\",\"propaganda\",\"totalitarianism\",\"nazism\",\"far-right politics\",\"authoritarian democracy\",\"f\\u00fchrer\",\"caudillo\",\"great power\",\"master of public administration\",\"public policy school\",\"instituts d'\\u00e9tudes politiques\",\"third way\",\"ethical socialism\",\"criticism of capitalism\",\"organicism\",\"list of social democratic parties\",\"nazism\",\"ljiljana radoni\\u0107\",\"peace journalism\",\"transformation processes (media systems)\",\"journal of democracy\",\"build\\u2013operate\\u2013transfer\",\"propaganda\",\"totalitarianism\",\"situationist international\",\"real socialism\",\"index of social and political philosophy articles\",\"socialist realism\",\"music and political warfare\",\"history of propaganda\",\"eastern bloc\",\"non-interventionism\",\"propaganda\",\"totalitarianism\",\"populism\",\"nazism\",\"far-right politics\",\"synarchism\",\"one-party state\",\"authoritarian democracy\",\"proletarian nation\",\"ilminism\",\"perpetual war\",\"christian communism\",\"christian fascism\",\"technocracy\",\"e-government\",\"totalitarianism\",\"oligarchy\",\"regional power\",\"polyarchy\",\"scientocracy\",\"night-watchman state\",\"bankocracy\",\"one-party state\",\"futarchy\",\"great power\",\"constitutional dictatorship\",\"legalism (chinese philosophy)\",\"corporate republic\",\"party identification\",\"public opinion on nuclear issues\",\"global environmental politics\",\"propaganda\",\"xuanchuan\",\"filter bubble\",\"pork barrel\",\"helen margetts\",\"populism\",\"reactionary\",\"ralph borsodi\",\"international law\",\"list of environmental ministries\",\"ecocide\",\"scientific man versus power politics\",\"totalitarianism\",\"social conservatism\",\"christian communism\",\"organicism\",\"ethical socialism\",\"technocracy\",\"civil service\",\"scientocracy\",\"logology (science)\",\"totalitarianism\",\"social imperialism\",\"one-party state\",\"enemy of the people\",\"eastern bloc\",\"dictatorship of the proletariat\",\"proletarian revolution\",\"world revolution\",\"commanding heights of the economy\",\"worker cooperative\",\"real socialism\",\"revolutions of 1989\",\"debate\",\"populism\",\"grenoble institute of political studies\",\"legalism (chinese philosophy)\",\"political culture of germany\",\"political culture of the united states\",\"university of san diego\",\"constitutionalism\",\"third way\",\"cultural liberalism\",\"small government\",\"night-watchman state\",\"private property\",\"whiggism\",\"participism\",\"non-interventionism\",\"freedom of contract\",\"global justice movement\",\"free-market healthcare\",\"voluntary society\",\"bryan caplan\",\"outline of anarchism\",\"free migration\",\"comparative politics\",\"public administration\",\"technocracy\",\"biology and political orientation\",\"ngo-ization\",\"capitalist peace\",\"pork barrel\",\"maladministration\",\"comparative politics\",\"composite index of national capability\",\"democracy-dictatorship index\",\"institute for economics and peace\",\"v-dem institute\",\"equality of outcome\",\"donald e. stokes\",\"warren miller (political scientist)\",\"walter f. dodd\",\"emmette redford\",\"carl joachim friedrich\",\"henry e. brady\",\"international law\",\"master of public administration\",\"fundacion manantiales\",\"ngo-ization\",\"politico-media complex\",\"non-governmental organization\",\"united nations parliamentary assembly\",\"friedrich naumann foundation\",\"civil service\",\"list of public works ministries\",\"china university of political science and law\",\"communication university of china\",\"left-wing politics\",\"christian communism\",\"ethical socialism\",\"dictatorship of the proletariat\",\"proletarian revolution\",\"world revolution\",\"worker cooperative\",\"real socialism\",\"nanosocialism\",\"workplace democracy\",\"criticism of capitalism\",\"left communism\",\"index of social and political philosophy articles\",\"list of social democratic parties\",\"communism and lgbt rights\",\"crypto-communism\",\"revolutions of 1989\",\"communist era\",\"crimes against humanity under communist regimes\",\"legal naturalism\",\"edinburgh university socialist society\",\"comunismo a la tica\",\"bibliography of works about communism\",\"national communism\",\"history of democratic socialism\",\"jurisprudence\",\"eurosphere\",\"constitutionalism\",\"rowman & littlefield award in innovative teaching\",\"index of social and political philosophy articles\",\"yehuda zvi blum\",\"comparative criminal justice\",\"international sanctions\",\"grey-zone (international relations)\",\"henry habib\",\"inquisitorial system\",\"rosa brooks\",\"contingent sovereignty\",\"border control\",\"feminist legal theory\",\"regulatory competition\",\"glossary of international relations terms\",\"executive order\",\"history of the legal profession\",\"history of the american legal profession\",\"fiqh\",\"idealism in international relations\",\"list of environmental ministries\",\"united nations parliamentary assembly\",\"non-state actor\",\"institute for international law of peace and armed conflict\",\"non-interventionism\",\"kaarlo juho st\\u00e5hlberg\",\"dualism (law)\",\"international law\",\"implied powers\",\"appeasement\",\"violent non-state actor\",\"atlanticism\",\"\\u00e5land islands peace institute\",\"equality before the law\",\"westphalian sovereignty\",\"julius stone\",\"party platform\",\"caudillo\",\"e-government\",\"technocracy\",\"constitutionalism\",\"totalitarianism\",\"oligarchy\",\"statism\",\"regional power\",\"great power\",\"small government\",\"bryan caplan\",\"global justice movement\",\"cato institute\",\"non-interventionism\",\"free migration\",\"participism\",\"voluntary society\",\"freedom of contract\",\"balkanization\",\"autonomous administrative division\",\"right to exist\",\"home rule\",\"propaganda\",\"totalitarianism\",\"constitutionalism\",\"eurasianism\",\"equality before the law\",\"special relationship (international relations)\",\"public administration\",\"siobhan o'sullivan\",\"public policy school\",\"ministry of infrastructure (ukraine)\",\"statism\",\"jane duckett\",\"authoritarian left\",\"the birth of biopolitics\",\"public policy doctrine\",\"intergenerational policy\",\"propaganda\",\"urban legend\",\"influence of mass media\",\"publicity stunt\",\"totalitarianism\",\"eastern bloc\",\"revolutions of 1989\",\"jurisprudence\",\"left-wing politics\",\"eurosphere\",\"legitimation crisis\",\"echo chamber (media)\",\"hardline\",\"one man, one vote\",\"revolutions of 1989\",\"non-interventionism\",\"statism\",\"reactionary\",\"authoritarian left\",\"constitutional economics\",\"liberal legalism\",\"participism\",\"ecoauthoritarianism\",\"populism\",\"whiggism\",\"bryan caplan\",\"cato institute\",\"equality before the law\",\"right-wing politics\",\"virtue jurisprudence\",\"technocracy\",\"left-wing politics\",\"debate\",\"christian communism\",\"equal opportunity\",\"dictatorship of the proletariat\",\"proletarian revolution\",\"nanosocialism\",\"labour voucher\",\"workplace democracy\",\"blanquism\",\"criticism of capitalism\",\"participism\",\"left communism\",\"equality of outcome\",\"equal opportunity\",\"political studies review\",\"international political science association\",\"pippa norris\",\"master of public administration\",\"sciences po\",\"princeton school of public and international affairs\",\"bush school of government and public service\",\"schar school of policy and government\",\"peace and conflict studies\",\"appeasement\",\"non-interventionism\",\"peace journalism\",\"nazism\",\"reactionary\",\"constitutional patriotism\",\"law and order\",\"eurasianism\",\"ilminism\",\"one-party state\",\"maternalism\",\"private property\",\"right-wing politics\",\"national agrarian party\",\"social conservatism\",\"imperium\",\"comparative politics\",\"global citizenship\",\"world politics\",\"centre for health and international relations\",\"democratic globalization\",\"global apartheid\",\"ronen palan\",\"global politics\",\"instituts d'\\u00e9tudes politiques\",\"propaganda\",\"public opinion quarterly\",\"jurisprudence\",\"index of social and political philosophy articles\",\"maternalism\",\"law without the state\",\"legalism (chinese philosophy)\",\"legal norm\",\"sciences po\",\"jurisprudence\",\"left\\u2013right political spectrum\",\"third way\",\"nazism\",\"constitutional patriotism\",\"ordoliberalism\",\"cultural liberalism\",\"authoritarian capitalism\",\"small government\",\"social conservatism\",\"bolivarian revolution\",\"labor theory of property\",\"social liberalism\",\"participism\",\"equal opportunity\",\"legal naturalism\",\"whiggism\",\"bryan caplan\",\"party platform\",\"christian communism\",\"neoauthoritarianism (china)\",\"democratic liberalism\",\"frente despertar\",\"isaiah berlin\",\"dictatorship of the proletariat\",\"private property\",\"conservative liberalism\",\"voluntary society\",\"world revolution\",\"left communism\",\"conservative corporatism\",\"corporatization\",\"liberal conservatism\",\"criticism of capitalism\",\"bibliography of works about communism\",\"ethical socialism\",\"modern liberalism in the united states\",\"equality before the law\",\"outline of anarchism\",\"public administration\",\"public policy doctrine\",\"master of public administration\",\"schar school of policy and government\",\"military policy\",\"institut d'\\u00e9tudes politiques d'aix-en-provence\",\"edward j. bloustein school of planning and public policy\",\"sciences po\",\"princeton school of public and international affairs\",\"graduate program in public management\",\"robert f. wagner graduate school of public service\",\"graduate school of public policy, university of tokyo\",\"mccourt school of public policy\",\"frank batten school of leadership and public policy\",\"anthony downs\",\"median voter theorem\",\"ordoliberalism\",\"terry karl\",\"history of political science\",\"berkeley school of political theory\",\"post-behavioralism\",\"index of social and political philosophy articles\",\"brandalism\",\"new left review\",\"collaboration\",\"situationist international\",\"an anarchist faq\",\"blanquism\",\"outline of anarchism\",\"proletarian revolution\",\"participism\",\"eastern bloc\",\"world revolution\",\"left communism\",\"worker cooperative\",\"filter bubble\",\"reactionary\",\"westphalian sovereignty\",\"majoritarianism\",\"balkanization\",\"propaganda\",\"kalergi plan\",\"rumor\",\"slogan\",\"history of propaganda\",\"urban legend\",\"mccourt school of public policy\",\"jurisprudence\",\"third way\",\"social liberalism\",\"whiggism\",\"index of social and political philosophy articles\",\"isaiah berlin\",\"carl joachim friedrich\",\"warren miller (political scientist)\",\"emmette redford\",\"henry e. brady\",\"propaganda\",\"statism\",\"international security\",\"scientific man versus power politics\",\"idealism in international relations\",\"parliamentary procedure\",\"jewish-palestinian living room dialogue group\",\"deliberation\",\"michael thrasher\",\"commanding heights of the economy\",\"technocracy\",\"left-wing politics\",\"populism\",\"third way\",\"reactionary\",\"hardline\",\"ordoliberalism\",\"cultural liberalism\",\"right-wing politics\",\"statism\",\"social liberalism\",\"conservative liberalism\",\"equal opportunity\",\"liberal conservatism\",\"cato institute\",\"modern liberalism in the united states\",\"equality before the law\",\"democratic liberalism\",\"fiqh\",\"muhammad taqi usmani\",\"qazi syed inayatullah\",\"majoritarianism\",\"debate\",\"propaganda\",\"australian journal of political science\",\"polyarchy\",\"democracies: patterns of majoritarian & consensus government in twenty-one countries\",\"composite index of national capability\",\"technocracy\",\"public administration\",\"hannah arendt institute for totalitarianism studies\",\"stein rokkan\",\"biology and political orientation\",\"john coakley\",\"ap comparative government and politics\",\"e-government\",\"terry karl\",\"political communication\",\"preselection\",\"high and low politics\",\"otto kirchheimer\",\"carl joachim friedrich\",\"pippa norris\",\"democracy-dictatorship index\",\"party system\",\"public policy doctrine\",\"propaganda\",\"history of propaganda\",\"demonizing the enemy\",\"lesser of two evils principle\",\"slogan\",\"community policing\",\"problem-oriented policing\",\"journal of theoretical politics\",\"reactionary\",\"right-wing politics\",\"statism\",\"non-interventionism\",\"maternalism\",\"bryan caplan\",\"participism\",\"eurasianism\",\"left-wing populism\",\"third way\",\"nazism\",\"ethnosymbolism\",\"social liberalism\",\"enemy of the people (albania)\",\"conservative liberalism\",\"liberal conservatism\",\"enemy of the people\",\"criticism of capitalism\",\"national communism\",\"democratic liberalism\",\"echo chamber (media)\",\"propaganda\",\"post-truth politics\",\"counterpropaganda\",\"strategy of tension\",\"jurisprudence\",\"feminist legal theory\",\"history of the legal profession\",\"history of the american legal profession\",\"border control\",\"inquisitorial system\",\"federal law\",\"ash-shab yurid isqat an-nizam\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"glory to hong kong\",\"civil service\",\"attorney-general v de keyser's royal hotel ltd\",\"proclamation by the crown act 1539\",\"common informer\",\"petitions of right (ireland) act 1873\",\"petition of right\",\"technocracy\",\"totalitarianism\",\"nazism\",\"oligarchy\",\"statism\",\"regional power\",\"great power\",\"tyranny of the majority\",\"authoritarian capitalism\",\"one-party state\",\"soft despotism\",\"authoritarian democracy\",\"enlightened absolutism\",\"dictablanda\",\"corporate republic\",\"ecoauthoritarianism\",\"sciences po\",\"state decoration\",\"political repression\",\"might makes right\",\"jurisprudence\",\"malikism in algeria\",\"inquisitorial system\",\"thawri\",\"awza'i\",\"feminist legal theory\",\"ahl al-hadith\",\"madhhab\",\"history of the legal profession\",\"islamic sexual jurisprudence\",\"qazi syed inayatullah\",\"history of the american legal profession\",\"writ\",\"fiqh\",\"maxims of islamic law\",\"mahr\",\"istihlal\",\"party system\",\"concurrent powers\",\"propaganda\",\"perpetual war\",\"third-person effect\",\"social media in the 2016 united states presidential election\",\"echo chamber (media)\",\"microgeneration\",\"opinion leadership\",\"otto kirchheimer\",\"legitimation crisis\",\"nazism\",\"authoritarian democracy\",\"proletarian nation\",\"democratic peace theory\",\"neosocialism\",\"cato institute\",\"global citizenship\",\"cosmopolitan democracy\",\"democratic globalization\",\"global apartheid\",\"left-wing politics\",\"world revolution\",\"worker cooperative\",\"national communism\",\"crimes against humanity under communist regimes\",\"nazism\",\"reactionary\",\"far-right politics\",\"basket of deplorables\",\"kansas city preventive patrol experiment\",\"asu college of public service & community solutions\",\"problem-oriented policing\",\"left-wing politics\",\"totalitarianism\",\"social imperialism\",\"enemy of the people\",\"political repression\",\"christian communism\",\"ethical socialism\",\"dictatorship of the proletariat\",\"list of social democratic parties\",\"nanosocialism\",\"blanquism\",\"enemy of the people (albania)\",\"world revolution\",\"left communism\",\"workplace democracy\",\"legal naturalism\",\"bevanism\",\"criticism of capitalism\",\"bibliography of works about communism\",\"real socialism\",\"worker cooperative\",\"commanding heights of the economy\",\"national communism\",\"proletarian revolution\",\"history of democratic socialism\",\"peace and conflict studies\",\"appeasement\",\"non-interventionism\",\"peace journalism\",\"world values survey\",\"non-sampling error\",\"survey data collection\",\"afrobarometer\",\"comparative study of electoral systems\",\"opinion poll\",\"total survey error\",\"jihad satire\",\"public administration\",\"hardline\",\"list of social democratic parties\",\"scientocracy\",\"social liberalism\",\"nanosocialism\",\"reactionary\",\"biology and political orientation\",\"populism\",\"regional power\",\"political communication\",\"preselection\",\"totalitarianism\",\"christian communism\",\"neoauthoritarianism (china)\",\"great power\",\"left-wing politics\",\"party system\",\"history of democratic socialism\",\"science diplomacy\",\"public policy doctrine\",\"polyarchy\",\"bankocracy\",\"technocracy\",\"oligarchy\",\"statism\",\"futarchy\",\"workplace democracy\",\"corporate republic\",\"cultural liberalism\",\"ecoauthoritarianism\",\"e-government\",\"civil service\",\"criticism of capitalism\",\"high and low politics\",\"neosocialism\",\"ethical socialism\",\"modern liberalism in the united states\",\"post-politics\",\"real socialism\",\"logology (science)\",\"right-wing politics\",\"legalism (chinese philosophy)\",\"crown servant\",\"continuismo\",\"cacique\",\"white paper\",\"choosing scotland's future\",\"third way\",\"school of politics and international relations, university of nottingham\",\"global justice movement\",\"note verbale\",\"composite index of national capability\",\"superpower collapse\",\"national power\",\"enlightened absolutism\",\"regional power\",\"great power\",\"left\\u2013right political spectrum\",\"third way\",\"social liberalism\",\"christian communism\",\"ethical socialism\",\"equality of outcome\",\"labour voucher\",\"list of social democratic parties\",\"nanosocialism\",\"blanquism\",\"conservative liberalism\",\"participism\",\"equal opportunity\",\"workplace democracy\",\"popular socialism\",\"criticism of capitalism\",\"modern liberalism in the united states\",\"equality before the law\",\"real socialism\",\"history of democratic socialism\",\"nazism\",\"composite index of national capability\",\"v-dem institute\",\"jurisprudence\",\"mahr\",\"menstruation in islam\",\"sexual jihad\",\"critical security studies\",\"fritz w. scharpf\",\"appeasement\",\"charg\\u00e9 de mission\",\"exequatur\",\"note verbale\",\"science diplomacy\",\"democratic peace theory\",\"transnational progressivism\",\"global citizenship\",\"cosmopolitan democracy\",\"global justice movement\",\"global apartheid\",\"ronen palan\",\"list of public works ministries\",\"social media in the 2020 united states presidential election\",\"social media use by donald trump\",\"world values survey\",\"non-sampling error\",\"opinion poll\",\"afrobarometer\",\"comparative study of electoral systems\",\"public opinion quarterly\",\"international security\",\"sciences po\",\"princeton school of public and international affairs\",\"bush school of government and public service\",\"schar school of policy and government\",\"public policy doctrine\",\"participism\",\"non-interventionism\",\"index of social and political philosophy articles\",\"bryan caplan\",\"free migration\",\"global justice movement\",\"voluntary society\",\"propaganda\",\"totalitarianism\",\"populism\",\"nazism\",\"authoritarian democracy\",\"proletarian nation\",\"blanquism\",\"history of political science\",\"carl joachim friedrich\",\"stein rokkan\",\"norman chester\",\"john coakley\",\"composite index of national capability\",\"superpower collapse\",\"dark figure of crime\",\"eurosphere\",\"energy charter treaty\",\"energy certificate\",\"jurisprudence\",\"mahr\",\"populism\",\"dictatorship of the proletariat\",\"great power\",\"glossary of international relations terms\",\"debate\",\"ratification\",\"parliamentary debate\",\"cato institute\",\"power-to-x\",\"microgeneration\",\"intergovernmentalism\",\"totalitarianism\",\"one-party state\",\"eastern bloc\",\"commanding heights of the economy\",\"revolutions of 1989\",\"gun control\",\"they shall not pass\",\"totalitarianism\",\"oligarchy\",\"regional power\",\"great power\",\"science diplomacy\",\"logology (science)\",\"intergovernmentalism\",\"democratic peace theory\",\"capitalist peace\",\"critical security studies\",\"new aspects of politics\",\"small office/home office\",\"christian communism\",\"world revolution\",\"comunismo a la tica\",\"bibliography of works about communism\",\"tyranny of the majority\",\"enemy of the people\",\"white power music\",\"slogan\",\"intergovernmentalism\",\"democratic peace theory\",\"capitalist peace\",\"critical security studies\",\"cato institute\",\"economic stimulus appropriations act of 1977\",\"american recovery and reinvestment act of 2009\",\"classification of advocacy groups\",\"gun control\",\"christian communism\",\"ethical socialism\",\"real socialism\",\"nanosocialism\",\"list of social democratic parties\",\"criticism of capitalism\",\"popular socialism\",\"blanquism\",\"participism\",\"workplace democracy\",\"history of democratic socialism\",\"biology and political orientation\",\"left-wing politics\",\"propaganda\",\"horseshoe theory\",\"totalitarianism\",\"populism\",\"left\\u2013right political spectrum\",\"nolan chart\",\"third way\",\"nazism\",\"social imperialism\",\"transnational progressivism\",\"index of social and political philosophy articles\",\"hardline\",\"statism\",\"reactionary\",\"authoritarian left\",\"dictatorship of the proletariat\",\"far-right politics\",\"conservative liberalism\",\"conservative corporatism\",\"social conservatism\",\"ecoauthoritarianism\",\"spatial politics\",\"basket of deplorables\",\"liberal conservatism\",\"right-wing politics\",\"neoauthoritarianism (china)\",\"public administration\",\"digital era governance\",\"australian journal of political science\",\"journal of theoretical politics\",\"propaganda\",\"totalitarianism\",\"populism\",\"nazism\",\"oligarchy\",\"statism\",\"corporate republic\",\"dictablanda\",\"one-party state\",\"authoritarian capitalism\",\"proletarian nation\",\"polyarchy\",\"majoritarianism\",\"soft despotism\",\"enlightened absolutism\",\"ecoauthoritarianism\",\"tyranny of the majority\",\"nur f\\u00fcr deutsche\",\"world values survey\",\"non-sampling error\",\"opinion poll\",\"survey data collection\",\"comparative study of electoral systems\",\"nazism\",\"the crisis of democracy\",\"autonomous communities of spain\",\"autonomous administrative division\",\"voting rights in the united states\",\"biology and political orientation\",\"left-wing politics\",\"stein rokkan\",\"party system\",\"horseshoe theory\",\"totalitarianism\",\"populism\",\"left-wing populism\",\"hardline\",\"spatial politics\",\"third way\",\"social imperialism\",\"nolan chart\",\"cato institute\",\"nazism\",\"authoritarian left\",\"right-wing politics\",\"far-right politics\",\"totalitarianism\",\"nazism\",\"oligarchy\",\"statism\",\"regional power\",\"great power\",\"corporatization\",\"corporate statism\",\"tyranny of the majority\",\"authoritarian capitalism\",\"one-party state\",\"soft despotism\",\"enlightened absolutism\",\"dictablanda\",\"ecoauthoritarianism\",\"white paper\",\"earned media\",\"cacique\",\"appeasement\",\"populism\",\"cosmopolitan democracy\",\"liberal democratic basic order\",\"digital era governance\",\"joe biden (the onion)\",\"extemporaneous speaking\",\"renewable energy transition\",\"appeasement\",\"debate chamber\",\"debate\",\"parliamentary debate\",\"stephanos bibas\",\"marlon bundo\",\"left-wing politics\",\"third way\",\"social conservatism\",\"social liberalism\",\"christian communism\",\"equality of outcome\",\"list of social democratic parties\",\"nanosocialism\",\"criticism of capitalism\",\"blanquism\",\"dictatorship of the proletariat\",\"participism\",\"left communism\",\"workplace democracy\",\"slogan\",\"international relations and security network\",\"peace and conflict studies\",\"international security\",\"ariane chebel d'appollonia\",\"critical security studies\",\"security studies (journal)\",\"security studies\",\"malinda s. smith\",\"left-wing politics\",\"left-wing populism\",\"third way\",\"gun control\",\"cultural liberalism\",\"social liberalism\",\"index of social and political philosophy articles\",\"conservative liberalism\",\"appropriate technology\",\"international energy agency\",\"microgeneration\",\"implementation\",\"cipp evaluation model\",\"political communication\",\"composite index of national capability\",\"e-government\",\"totalitarianism\",\"oligarchy\",\"polyarchy\",\"bankocracy\",\"futarchy\",\"great power\",\"legalism (chinese philosophy)\",\"superpower collapse\",\"left-wing politics\",\"third way\",\"christian communism\",\"dictatorship of the proletariat\",\"nanosocialism\",\"workplace democracy\",\"blanquism\",\"criticism of capitalism\",\"participism\",\"left communism\",\"equality of outcome\",\"glory to hong kong\",\"public administration\",\"intergovernmentalism\",\"democratic peace theory\",\"capitalist peace\",\"critical security studies\",\"cato institute\",\"political communication\",\"democratic peace theory\",\"glossary of international relations terms\",\"international sanctions\",\"international isolation\",\"totalitarianism\",\"green industrial policy\",\"energy charter treaty\",\"international energy agency\",\"open energy system databases\",\"gary l. francione\",\"siobhan o'sullivan\",\"islamic funeral\",\"menstruation in islam\",\"mahr\",\"propaganda\",\"far-right politics\",\"liberal conservatism\",\"domestic analogy\",\"jurisprudence\",\"white paper\",\"political groups of the european parliament\",\"equality before the law\",\"intergovernmentalism\",\"environmental policy of the european union\",\"jurisprudence\",\"institution\",\"catch-22\",\"public administration\",\"voter turnout\",\"median voter theorem\",\"bryan caplan\",\"propaganda\",\"post-truth politics\",\"counterpropaganda\",\"liberal conservatism\",\"statism\",\"hierarchical organization\",\"cato institute\",\"participism\",\"left communism\",\"an anarchist faq\",\"propaganda\",\"stein rokkan\",\"sciences po\",\"institut d'\\u00e9tudes politiques d'aix-en-provence\",\"grenoble institute of political studies\",\"left-wing politics\",\"party system\",\"totalitarianism\",\"populism\",\"nolan chart\",\"third way\",\"nazism\",\"hardline\",\"oligarchy\",\"right-wing politics\",\"authoritarian capitalism\",\"one-party state\",\"soft despotism\",\"eastern bloc\",\"enlightened absolutism\",\"ecoauthoritarianism\",\"fukoku ky\\u014dhei\",\"tyranny of the majority\",\"capitalist peace\",\"dictablanda\",\"totalitarianism\",\"oligarchy\",\"great power\",\"prediction market\",\"equality before the law\",\"societal attitudes towards abortion\",\"personhood\",\"gary l. francione\",\"opinion poll\",\"survey data collection\",\"nazism\",\"jurisprudence\",\"yehuda zvi blum\",\"biology and political orientation\",\"world values survey\",\"left-wing politics\",\"party system\",\"horseshoe theory\",\"totalitarianism\",\"populism\",\"nolan chart\",\"third way\",\"nazism\",\"social imperialism\",\"hardline\",\"right-wing politics\",\"social liberalism\",\"non-interventionism\",\"conservative liberalism\",\"cleavage (politics)\",\"collaboration\",\"public administration\",\"journal of policy history\",\"third way\",\"nazism\",\"the birth of biopolitics\",\"social liberalism\",\"authoritarian capitalism\",\"liberal conservatism\",\"criticism of capitalism\",\"sciences po\",\"awza'i\",\"ahl al-hadith\",\"madhhab\",\"thawri\",\"appeasement\",\"exequatur\",\"note verbale\",\"science diplomacy\",\"civil service\",\"political communication\",\"populism\",\"slogan\",\"social liberalism\",\"peace and conflict studies\",\"history of propaganda\",\"exequatur\",\"appeasement\",\"note verbale\",\"grey-zone (international relations)\",\"science diplomacy\",\"non-interventionism\",\"idealism in international relations\",\"left-wing politics\",\"social imperialism\",\"one-party state\",\"tyranny of the majority\",\"enemy of the people\",\"eastern bloc\",\"christian communism\",\"nanosocialism\",\"enemy of the people (albania)\",\"legal naturalism\",\"commanding heights of the economy\",\"worker cooperative\",\"history of democratic socialism\",\"democratic marxism\",\"dictatorship of the proletariat\",\"world revolution\",\"left communism\",\"workplace democracy\",\"collaboration\",\"criticism of capitalism\",\"bibliography of works about communism\",\"class traitor\",\"real socialism\",\"public administration\",\"public policy doctrine\",\"private military company\",\"social conservatism\",\"neoauthoritarianism (china)\",\"conservative liberalism\",\"liberal conservatism\",\"conservative corporatism\",\"jurisprudence\",\"jus commune\",\"vacatio legis\",\"a call to action: women, religion, violence, and power\",\"left-wing populism\",\"third way\",\"cultural liberalism\",\"social conservatism\",\"index of social and political philosophy articles\",\"liberal conservatism\",\"social liberalism\",\"conservative liberalism\",\"left-wing politics\",\"world revolution\",\"worker cooperative\",\"national communism\",\"public administration\",\"index of social and political philosophy articles\",\"echo chamber (media)\",\"job cohen\",\"inquisitorial system\",\"law without the state\",\"brocard (law)\",\"feminist legal theory\",\"liechtenstein institute on self-determination\",\"jus commune\",\"ahl al-hadith\",\"oliver lepsius\",\"madhhab\",\"legal norm\",\"early social changes under islam\",\"history of the legal profession\",\"maternalism\",\"history of the american legal profession\",\"vacatio legis\",\"istihlal\",\"exequatur\",\"constitutional economics\",\"grazing rights\",\"promulgation (catholic canon law)\",\"custom (catholic canon law)\",\"the province of jurisprudence determined\",\"stephanos bibas\",\"notary (catholic canon law)\",\"gary l. francione\",\"jurisprudence\",\"legalism (chinese philosophy)\",\"imperium\",\"public administration\",\"great power\",\"v-dem institute\",\"superpower collapse\",\"opinion poll\",\"official bilingualism in the public service of canada\",\"e-government\",\"propaganda\",\"propaganda\",\"totalitarianism\",\"populism\",\"nazism\",\"social imperialism\",\"synarchism\",\"one-party state\",\"proletarian nation\",\"ilminism\",\"bibliography of works about communism\",\"east turkestan\",\"propaganda\",\"maddaddam\",\"carl joachim friedrich\",\"warren miller (political scientist)\",\"henry e. brady\",\"populism\",\"oligarchy\",\"tyranny of the majority\",\"democratic peace theory\",\"echo chamber (media)\",\"polyarchy\",\"associationalism\",\"workplace democracy\",\"opinion poll\",\"slogan\",\"pakistan public works department\",\"ministry of land, infrastructure, transport and tourism\",\"propaganda\",\"history of propaganda\",\"lesser of two evils principle\",\"slogan\",\"deployment management\",\"biology and political orientation\",\"left-wing politics\",\"horseshoe theory\",\"totalitarianism\",\"populism\",\"hardline\",\"spatial politics\",\"third way\",\"social imperialism\",\"gun control\",\"nazism\",\"right-wing politics\",\"far-right politics\",\"peace\\u2013industrial complex\",\"international security\",\"critical security studies\",\"non-interventionism\",\"sciences po\",\"third way\",\"liberal conservatism\",\"principles of political economy\",\"principles of political economy (malthus book)\",\"history of democratic socialism\",\"populism\",\"nazism\",\"far-right politics\",\"one-party state\",\"enemy of the people\",\"voter turnout\",\"tactical voting\",\"campaign finance\",\"timeline of voting rights in the united states\",\"united nations office on drugs and crime\",\"one man, one vote\",\"left-wing politics\",\"world revolution\",\"worker cooperative\",\"national communism\",\"party system\",\"stein rokkan\",\"party system\",\"public opinion quarterly\",\"ahl al-hadith\",\"madhhab\",\"thawri\",\"echo chamber (media)\",\"third way\",\"equality of outcome\",\"propaganda\",\"counterpropaganda\",\"campaign finance\",\"slogan\",\"timeline of voting rights in the united states\",\"international security\",\"westphalian sovereignty\",\"law without the state\",\"non-state actor\",\"failed state\",\"grey-zone (international relations)\",\"commanding heights of the economy\",\"nation-building\",\"median voter theorem\",\"parliamentary debate\",\"public administration\",\"biology and political orientation\",\"left-wing politics\",\"party system\",\"horseshoe theory\",\"totalitarianism\",\"populism\",\"third way\",\"nazism\",\"social imperialism\",\"hardline\",\"far-right politics\",\"conservative liberalism\",\"organicism\",\"conservative corporatism\",\"social conservatism\",\"ecoauthoritarianism\",\"public image of narendra modi\",\"spatial politics\",\"liberal conservatism\",\"neoauthoritarianism (china)\",\"bryan caplan\",\"political cartoon\",\"gadsden flag\",\"maternalism\",\"organicism\",\"left-wing politics\",\"participism\",\"non-interventionism\",\"voluntary society\",\"donatella della porta\",\"free migration\",\"index of social and political philosophy articles\",\"free-market healthcare\",\"totalitarianism\",\"authoritarian capitalism\",\"bolivarian revolution\",\"(don't) touch me on my studio\",\"revolutions of 1989\",\"history of democratic socialism\",\"white paper\",\"european master of public administration consortium\",\"behavioral public administration\",\"biology and political orientation\",\"master of public administration\",\"paul van riper (political scientist)\",\"political communication\",\"german university of administrative sciences speyer\",\"sciences po\",\"maladministration\",\"party system\",\"norman chester\",\"public policy doctrine\",\"polyarchy\",\"public budgeting\",\"public administration\",\"security, territory, population\",\"faculty of political science, chulalongkorn university\",\"e-government\",\"politeia (journal)\",\"digital era governance\",\"civil service\",\"school of political and social sciences, unam\",\"high and low politics\",\"electronic process of law\",\"crown servant\",\"erguer-estudantes da galiza\",\"intergovernmentalism\",\"democratic peace theory\",\"capitalist peace\",\"critical security studies\",\"science diplomacy\",\"exequatur\",\"on the principles of political economy and taxation\",\"pippa norris\",\"slogan\",\"robert f. wagner graduate school of public service\",\"public opinion quarterly\",\"intergovernmentalism\",\"stein rokkan\",\"territorialisation of carbon governance\",\"index of social and political philosophy articles\",\"participism\",\"left communism\",\"bryan caplan\",\"security sector governance and reform\",\"security studies (journal)\",\"international security\",\"high and low politics\",\"democratic peace theory\",\"participism\",\"bryan caplan\",\"triangular diplomacy\",\"non-interventionism\",\"free migration\",\"interventionism (politics)\",\"voluntary society\",\"world values survey\",\"left-wing politics\",\"social imperialism\",\"enemy of the people\",\"christian communism\",\"communism and lgbt rights\",\"blanquism\",\"revolutions of 1989\",\"enemy of the people (albania)\",\"world revolution\",\"left communism\",\"legal naturalism\",\"the permanent revolution and results and prospects\",\"bibliography of works about communism\",\"real socialism\",\"commanding heights of the economy\",\"national communism\",\"worker cooperative\",\"world values survey\",\"non-sampling error\",\"survey data collection\",\"comparative study of electoral systems\",\"tactical voting\",\"elif shafak\",\"left-wing politics\",\"populism\",\"third way\",\"eastern bloc\",\"christian communism\",\"nanosocialism\",\"workplace democracy\",\"blanquism\",\"criticism of capitalism\",\"participism\",\"left communism\",\"equality of outcome\",\"popular socialism\",\"propaganda\",\"nazism\",\"social imperialism\",\"tyranny of the majority\",\"real socialism\",\"commanding heights of the economy\",\"worker cooperative\",\"feminist legal theory\",\"history of the legal profession\",\"inquisitorial system\",\"labor theory of property\",\"kaarlo juho st\\u00e5hlberg\",\"e-government\",\"totalitarianism\",\"oligarchy\",\"polyarchy\",\"bankocracy\",\"sciences po\",\"eastern bloc\",\"legalism (chinese philosophy)\",\"superpower collapse\",\"blue labour\",\"socialist campaign group\",\"world values survey\",\"non-sampling error\",\"survey data collection\",\"bryan caplan\",\"totalitarianism\",\"one-party state\",\"international isolation\",\"political groups of the european parliament\",\"martens centre\",\"nazism\",\"nation-building\",\"university of san diego\",\"party political broadcast\",\"timeline of voting rights in the united states\",\"campaign finance\",\"bryan caplan\",\"free market fairness\",\"index of social and political philosophy articles\",\"ratification\",\"totalitarianism\",\"nazism\",\"oligarchy\",\"totalitarianism\",\"nazism\",\"oligarchy\",\"tyranny of the majority\",\"authoritarian capitalism\",\"one-party state\",\"soft despotism\",\"enlightened absolutism\",\"ecoauthoritarianism\",\"social imperialism\",\"equality of outcome\",\"christian egalitarianism\",\"propaganda\",\"political communication\",\"pork barrel\",\"civil service\",\"propaganda\",\"totalitarianism\",\"nazism\",\"nur f\\u00fcr deutsche\",\"civil service\",\"eastern bloc\",\"free migration\",\"border control\",\"revealed preference\",\"biology and political orientation\",\"propaganda\",\"blue labour\",\"nazism\",\"ministry of magic\",\"alan wolfe\",\"e-government\",\"right to exist\",\"social imperialism\",\"e. f. schumacher\",\"christian communism\",\"commanding heights of the economy\",\"communism and lgbt rights\",\"enemy of the people (albania)\",\"participism\",\"workplace democracy\",\"bibliography of works about communism\",\"real socialism\",\"national communism\",\"political communication\",\"echo chamber (media)\",\"rumor\",\"nazism\",\"enemy of the people (albania)\",\"history of propaganda\",\"eastern bloc\",\"the engineering of consent\",\"propaganda\",\"xuanchuan\",\"tyranny of the majority\",\"totalitarianism\",\"aromanian question\",\"international convention concerning the use of broadcasting in the cause of peace\",\"revolutions of 1989\",\"security, territory, population\",\"corporate statism\",\"political socialization\",\"criticism of capitalism\",\"counterpropaganda\",\"slogan\",\"index of social and political philosophy articles\",\"warren miller (political scientist)\",\"totalitarianism\",\"henry e. brady\",\"intergovernmentalism\",\"democratic peace theory\",\"capitalist peace\",\"classical realism (international relations)\",\"relative gain (international relations)\",\"regionalism (international relations)\",\"feminist legal theory\",\"inquisitorial system\",\"cultural liberalism\",\"far-right politics\",\"democratic peace theory\",\"global citizenship\",\"populism\",\"left-wing populism\",\"nanosocialism\",\"workplace democracy\",\"blanquism\",\"criticism of capitalism\",\"sciences po\",\"left-wing politics\",\"horseshoe theory\",\"populism\",\"bolivarian revolution\",\"criticism of capitalism\",\"nazism\",\"cultural liberalism\",\"oligarchy\",\"index of social and political philosophy articles\",\"comit\\u00e9s abertos de estudantes\",\"galician workers union\",\"jus commune\",\"vacatio legis\",\"index of social and political philosophy articles\",\"party system\",\"vaticanology\",\"failed state\",\"party system\",\"totalitarianism\",\"populism\",\"third way\",\"nazism\",\"oligarchy\",\"communism and lgbt rights\",\"authoritarian capitalism\",\"soft despotism\",\"eastern bloc\",\"enlightened absolutism\",\"social conservatism\",\"ecoauthoritarianism\",\"tyranny of the majority\",\"bibliography of works about communism\",\"real socialism\",\"national communism\",\"biology and political orientation\",\"world values survey\",\"hardline\",\"communism and lgbt rights\",\"horseshoe theory\",\"nanosocialism\",\"nazism\",\"far-right politics\",\"eastern bloc\",\"legal naturalism\",\"populism\",\"third way\",\"social imperialism\",\"totalitarianism\",\"christian communism\",\"national communism\",\"party system\",\"microgeneration\",\"left communism\",\"workplace democracy\",\"ecoauthoritarianism\",\"spatial politics\",\"criticism of capitalism\",\"bibliography of works about communism\",\"real socialism\",\"tyranny of the majority\",\"tyranny of the majority\",\"nazism\",\"social imperialism\",\"tyranny of the majority\",\"commanding heights of the economy\",\"real socialism\",\"totalitarianism\",\"eastern bloc\",\"real socialism\",\"criticism of capitalism\",\"communism and lgbt rights\",\"triangular diplomacy\",\"bibliography of works about communism\",\"political groups of the european parliament\",\"civil service\",\"german university of administrative sciences speyer\",\"biology and political orientation\",\"totalitarianism\",\"populism\",\"oligarchy\",\"tyranny of the majority\",\"democratic peace theory\",\"polyarchy\",\"associationalism\",\"workplace democracy\",\"bryan caplan\",\"bolivarian revolution\",\"e. f. schumacher\",\"(don't) touch me on my studio\",\"totalitarianism\",\"workplace democracy\",\"totalitarianism\",\"eastern bloc\",\"political cartoon\",\"totalitarianism\",\"oligarchy\",\"cultural liberalism\",\"far-right politics\",\"index of social and political philosophy articles\",\"blue labour\",\"maternalism\",\"christian communism\",\"social conservatism\",\"index of social and political philosophy articles\",\"henry e. brady\",\"political groups of the european parliament\",\"frente despertar\",\"third way\",\"classical realism (international relations)\",\"capitalist peace\",\"authoritarian capitalism\",\"relative gain (international relations)\",\"global citizenship\",\"environmental policy of the european union\",\"regionalism (international relations)\",\"democratic peace theory\",\"ernest barker\",\"westphalian sovereignty\",\"sovereignty of the philippines\",\"contingent sovereignty\",\"global citizenship\",\"global apartheid\",\"populism\",\"tyranny of the majority\",\"classical realism (international relations)\",\"relative gain (international relations)\",\"violence peace and peace research\",\"capitalist peace\",\"glossary of international relations terms\",\"militarized interstate dispute\",\"regionalism (international relations)\",\"experimental political science\",\"populism\",\"tactical voting\",\"voter turnout\",\"nazism\",\"far-right politics\",\"christian communism\",\"communism and lgbt rights\",\"bibliography of works about communism\",\"aromanian question\",\"concurrent powers\",\"implied powers\",\"eastern bloc\",\"world values survey\",\"non-sampling error\",\"paid survey\",\"voluntary society\",\"index of social and political philosophy articles\",\"global citizenship\",\"populism\",\"tyranny of the majority\",\"microgeneration\",\"sciences po\",\"schar school of policy and government\",\"liechtenstein institute on self-determination\",\"bush school of government and public service\",\"exequatur\",\"promulgation (catholic canon law)\",\"custom (catholic canon law)\",\"vacatio legis\",\"e. f. schumacher\",\"appropriate technology\",\"microgeneration\",\"the birth of biopolitics\",\"social imperialism\",\"eastern bloc\",\"communism and lgbt rights\",\"bibliography of works about communism\",\"real socialism\",\"totalitarianism\",\"nazism\",\"oligarchy\",\"authoritarian capitalism\",\"ecoauthoritarianism\",\"enlightened absolutism\",\"tyranny of the majority\",\"participism\",\"voluntary society\",\"singleton (global governance)\",\"bryan caplan\",\"free migration\",\"biology and political orientation\",\"effective number of parties\",\"party platform\",\"far-right politics\",\"catch-22\",\"horseshoe theory\",\"far-right politics\",\"public budgeting\",\"liberal legalism\",\"populism\",\"catch-22\",\"siobhan o'sullivan\",\"gary l. francione\",\"index of social and political philosophy articles\",\"third way\",\"authoritarian capitalism\",\"criticism of capitalism\",\"oligarchy\",\"sciences po\",\"world values survey\",\"free market fairness\",\"making peace\",\"capitalist peace\",\"autonomous communities of spain\",\"index of social and political philosophy articles\",\"equality of outcome\",\"nanosocialism\",\"he who does not work, neither shall he eat\",\"blanquism\",\"participism\",\"left communism\",\"workplace democracy\",\"criticism of capitalism\",\"bibliography of works about communism\",\"real socialism\",\"christian egalitarianism\",\"history of propaganda\",\"lesser of two evils principle\",\"slogan\",\"ministry of infrastructure and water management\",\"biology and political orientation\",\"horseshoe theory\",\"totalitarianism\",\"populism\",\"third way\",\"nazism\",\"social imperialism\",\"spatial politics\",\"far-right politics\",\"ecoauthoritarianism\",\"sciences po\",\"european master of public administration consortium\",\"schar school of policy and government\",\"robert f. wagner graduate school of public service\",\"participism\",\"voluntary society\",\"free-market healthcare\",\"rumor\",\"real socialism\",\"equality of outcome\",\"criticism of capitalism\",\"blanquism\",\"participism\",\"left communism\",\"workplace democracy\",\"voluntary society\",\"martens centre\",\"mariya gabriel\",\"median voter theorem\",\"index of social and political philosophy articles\",\"vacatio legis\",\"experimental political science\",\"real socialism\",\"workplace democracy\",\"index of social and political philosophy articles\",\"participism\",\"criticism of capitalism\",\"capitalist peace\",\"glossary of international relations terms\",\"left communism\",\"nazism\",\"real socialism\",\"workplace democracy\",\"criticism of capitalism\",\"participism\",\"index of social and political philosophy articles\",\"bibliography of works about communism\",\"real socialism\",\"workplace democracy\",\"criticism of capitalism\",\"organicism\",\"exequatur\",\"ahl al-hadith\",\"madhhab\",\"vacatio legis\",\"concurrent powers\",\"economic stimulus appropriations act of 1977\",\"fiscal policy of the united states\",\"i did not have sexual relations with that woman\",\"nominate (scaling method)\",\"history of propaganda\",\"ahl al-hadith\",\"madhhab\",\"istihlal\",\"glory to ukraine\",\"glory to hong kong\",\"job cohen\",\"neoauthoritarianism (china)\",\"conservative liberalism\",\"liberal conservatism\",\"lesser of two evils principle\",\"squirrel (debate)\",\"parliamentary debate\",\"totalitarianism\",\"real socialism\",\"right to the city\",\"populism\",\"non-sampling error\",\"totalitarianism\",\"social imperialism\",\"eastern bloc\",\"fiscal policy of the united states\",\"a call to action: women, religion, violence, and power\",\"friedrich naumann foundation\",\"e-government\",\"totalitarianism\",\"nazism\",\"index of social and political philosophy articles\",\"tyranny of the majority\",\"oligarchy\",\"authoritarian capitalism\",\"enlightened absolutism\",\"ecoauthoritarianism\",\"criticism of capitalism\",\"legalism (chinese philosophy)\",\"totalitarianism\",\"nazism\",\"liberal conservatism\",\"sciences po\",\"e. f. schumacher\",\"microgeneration\",\"collaboration\",\"managerialism\",\"sciences po\",\"sciences po\",\"schar school of policy and government\",\"bush school of government and public service\",\"history of propaganda\",\"tripartite consultation (international labour standards) convention, 1976\",\"totalitarianism\",\"populism\",\"third way\",\"nazism\",\"authoritarian capitalism\",\"enlightened absolutism\",\"tyranny of the majority\",\"totalitarianism\",\"eastern bloc\",\"biology and political orientation\",\"populism\",\"spatial politics\",\"third way\",\"social imperialism\",\"horseshoe theory\",\"totalitarianism\",\"nazism\",\"far-right politics\",\"third way\",\"authoritarian capitalism\",\"liberal conservatism\",\"real socialism\",\"workplace democracy\",\"participism\",\"criticism of capitalism\",\"totalitarianism\",\"populism\",\"third way\",\"nazism\",\"social imperialism\",\"far-right politics\",\"organicism\",\"totalitarianism\",\"nazism\",\"hannah arendt institute for totalitarianism studies\",\"warren miller (political scientist)\",\"chester barnard\",\"capitalist peace\",\"index of social and political philosophy articles\",\"imperium\",\"index of social and political philosophy articles\",\"totalitarianism\",\"index of social and political philosophy articles\",\"legalism (chinese philosophy)\",\"biology and political orientation\",\"totalitarianism\",\"populism\",\"nazism\",\"third way\",\"social imperialism\",\"authoritarian capitalism\",\"conservative liberalism\",\"cultural liberalism\",\"spatial politics\",\"liberal conservatism\",\"real socialism\",\"eastern bloc\",\"index of social and political philosophy articles\",\"conservative liberalism\",\"totalitarianism\",\"populism\",\"real socialism\",\"dizzy with success\",\"totalitarianism\",\"nazism\",\"authoritarian capitalism\",\"tyranny of the majority\",\"biology and political orientation\",\"totalitarianism\",\"populism\",\"tyranny of the majority\",\"you have two cows\",\"authoritarian capitalism\",\"organicism\",\"spatial politics\",\"scale analysis (statistics)\",\"ministry of housing and works (pakistan)\",\"authoritarian capitalism\",\"real socialism\",\"workplace democracy\",\"voluntary society\",\"schar school of policy and government\",\"kim campbell\",\"tryph\\u00e9\",\"proprietary community\",\"tractatus politicus\",\"robert f. wagner graduate school of public service\",\"xuanchuan\",\"history of propaganda\",\"biology and political orientation\",\"index of social and political philosophy articles\",\"tyranny of the majority\",\"workplace democracy\",\"spatial politics\",\"totalitarianism\",\"tyranny of the majority\",\"biology and political orientation\",\"e-government\",\"index of social and political philosophy articles\",\"tyranny of the majority\",\"totalitarianism\",\"spatial politics\",\"real socialism\",\"biology and political orientation\",\"alan wolfe\",\"martens centre\",\"tyranny of the majority\",\"real socialism\",\"organicism\",\"societal attitudes towards abortion\",\"exequatur\",\"vacatio legis\",\"social imperialism\",\"workplace democracy\",\"autonomous communities of spain\",\"international council for science\",\"workplace democracy\",\"international centre for black sea studies\",\"international relations and security network\",\"social imperialism\",\"tyranny of the majority\",\"workplace democracy\",\"e-government\",\"social imperialism\",\"political cartoon\",\"e-government\",\"political culture of the united states\",\"blue labour\",\"phillip blond\",\"marlon bundo\",\"blue labour\",\"he who does not work, neither shall he eat\"],\"start\":[\"archibald crossley\",\"archibald crossley\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"sanford school of public policy\",\"peace dividend\",\"civic political culture\",\"civic political culture\",\"civic political culture\",\"civic political culture\",\"civic political culture\",\"comparing media systems\",\"comparing media systems\",\"comparing media systems\",\"fourteen words\",\"fourteen words\",\"fourteen words\",\"fourteen words\",\"fourteen words\",\"regional autonomy\",\"blavatnik school of government\",\"blavatnik school of government\",\"blavatnik school of government\",\"blavatnik school of government\",\"two-level game theory\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"cyberocracy\",\"worldwide influence of the constitution of the united states\",\"worldwide influence of the constitution of the united states\",\"worldwide influence of the constitution of the united states\",\"worldwide influence of the constitution of the united states\",\"how voters feel\",\"how voters feel\",\"resource conservation and recovery act\",\"resource conservation and recovery act\",\"we don't coast\",\"we don't coast\",\"jurisprudence of concepts\",\"american journal of political science\",\"american journal of political science\",\"american journal of political science\",\"american journal of political science\",\"australian quarterly\",\"latin american public opinion project\",\"institutionalist political economy\",\"institutionalist political economy\",\"communications management\",\"communications management\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"consensus democracy\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"dependent territory\",\"mass media and american politics\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"political science\",\"science & diplomacy\",\"science & diplomacy\",\"selectorate theory\",\"islam and children\",\"islam and children\",\"islam and children\",\"islam and children\",\"political jurisprudence\",\"political jurisprudence\",\"land consolidation\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"blood and soil\",\"anglo-saxon model\",\"anglo-saxon model\",\"anglo-saxon model\",\"anglo-saxon model\",\"anglo-saxon model\",\"anglo-saxon model\",\"rivers state civil service\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"nation state\",\"prague conference\",\"rent-setting\",\"rent-setting\",\"rent-setting\",\"rent-setting\",\"human resource management in public administration\",\"human resource management in public administration\",\"william a. niskanen\",\"william a. niskanen\",\"william a. niskanen\",\"william a. niskanen\",\"primakov readings\",\"denationalized citizenship\",\"occupatio\",\"occupatio\",\"liberal corporatism\",\"liberal corporatism\",\"liberal corporatism\",\"liberal corporatism\",\"liberal corporatism\",\"liesbet hooghe\",\"liesbet hooghe\",\"liesbet hooghe\",\"liesbet hooghe\",\"twitter diplomacy\",\"responsibility to protect\",\"responsibility to protect\",\"responsibility to protect\",\"responsibility to protect\",\"responsibility to protect\",\"robert christison\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"list of liberal theorists\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"philosophy, theology, and fundamental theory of catholic canon law\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"universal basic income\",\"carles boix\",\"carles boix\",\"gevald campaign\",\"gevald campaign\",\"national crime victimization survey\",\"national crime victimization survey\",\"national crime victimization survey\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political party\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"political studies association\",\"liberalism and conservatism in latin america\",\"liberalism and conservatism in latin america\",\"liberalism and conservatism in latin america\",\"liberalism and conservatism in latin america\",\"liberalism and conservatism in latin america\",\"liberalism and conservatism in latin america\",\"liberalism and conservatism in latin america\",\"liberalism and conservatism in latin america\",\"liberalism and conservatism in latin america\",\"fred w. riggs\",\"electronic media\",\"public image of cristina fern\\u00e1ndez de kirchner\",\"galician student league\",\"galician student league\",\"galician student league\",\"galician student league\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"list of left-wing internationals\",\"dominium maris baltici\",\"magna carta for philippine internet freedom\",\"bay'ah\",\"bay'ah\",\"bay'ah\",\"bay'ah\",\"bay'ah\",\"bay'ah\",\"live free or die\",\"horace campbell\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"decolonization\",\"karl schwedler\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"foreign policy\",\"decentralized autonomous organization\",\"decentralized autonomous organization\",\"decentralized autonomous organization\",\"decentralized autonomous organization\",\"slapsoftware\",\"bloc party (politics)\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"religious socialism\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"secession\",\"the great transformation (book)\",\"systems theory in political science\",\"systems theory in political science\",\"syed hayatullah\",\"syed hayatullah\",\"syed hayatullah\",\"strict father model\",\"alexandra goujon\",\"c. d. broad\",\"c. d. broad\",\"predictive policing\",\"predictive policing\",\"predictive policing\",\"predictive policing\",\"predictive policing\",\"predictive policing\",\"predictive policing\",\"predictive policing\",\"perestroika movement (political science)\",\"constitutionality\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"london school of economics\",\"proactive policing\",\"proactive policing\",\"proactive policing\",\"zombie liberalism\",\"zombie liberalism\",\"zombie liberalism\",\"zombie liberalism\",\"zombie liberalism\",\"zombie liberalism\",\"zombie liberalism\",\"zombie liberalism\",\"robert m. la follette school of public affairs\",\"robert m. la follette school of public affairs\",\"robert m. la follette school of public affairs\",\"robert m. la follette school of public affairs\",\"neil maccormick\",\"neil maccormick\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"neoclassical liberalism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"religious communism\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"industrial democracy\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"law of equal liberty\",\"timocracy\",\"timocracy\",\"timocracy\",\"timocracy\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"master of public policy\",\"canadian political science association\",\"canadian political science association\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"antimilitarism\",\"international workers' day\",\"international workers' day\",\"usul fiqh in ja'fari school\",\"usul fiqh in ja'fari school\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"international ethics\",\"a green new deal\",\"a green new deal\",\"a green new deal\",\"emilia justyna powell\",\"passing on the right\",\"feoffment\",\"feoffment\",\"feoffment\",\"eric helleiner\",\"coal phase-out\",\"coal phase-out\",\"coal phase-out\",\"2000-watt society\",\"2000-watt society\",\"2000-watt society\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"national liberalism\",\"technoliberalism\",\"technoliberalism\",\"technoliberalism\",\"gar alperovitz\",\"gar alperovitz\",\"gar alperovitz\",\"gar alperovitz\",\"gar alperovitz\",\"gar alperovitz\",\"gar alperovitz\",\"ethnarch\",\"ethnarch\",\"commodity form theory\",\"commodity form theory\",\"antemurale myth\",\"antemurale myth\",\"antemurale myth\",\"antemurale myth\",\"international conference on theory and practice of electronic governance\",\"international conference on theory and practice of electronic governance\",\"local service delivery\",\"local service delivery\",\"in place of strife\",\"rent extraction\",\"rent extraction\",\"social patriotism\",\"social patriotism\",\"social patriotism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"plurinationalism\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"history of social democracy\",\"civilization state\",\"civilization state\",\"civilization state\",\"civilization state\",\"civilization state\",\"civilization state\",\"civilization state\",\"civilization state\",\"list of national legal systems\",\"list of national legal systems\",\"list of national legal systems\",\"list of national legal systems\",\"list of national legal systems\",\"list of national legal systems\",\"list of national legal systems\",\"list of national legal systems\",\"list of national legal systems\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"barracks communism\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"health policy\",\"regulation of science\",\"regulation of science\",\"regulation of science\",\"regulation of science\",\"regulation of science\",\"business oligarch\",\"frankfurt declaration\",\"frankfurt declaration\",\"frankfurt declaration\",\"frankfurt declaration\",\"frankfurt declaration\",\"carl albert center\",\"carl albert center\",\"violent non-state actors at sea\",\"violent non-state actors at sea\",\"violent non-state actors at sea\",\"code of hammurabi\",\"code of hammurabi\",\"ideocracy\",\"ideocracy\",\"ideocracy\",\"review of international political economy\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"social media use in politics\",\"proposed national unification promotion law\",\"proposed national unification promotion law\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"perestroika\",\"role ethics\",\"role ethics\",\"no war, no peace\",\"nigel simmonds\",\"nigel simmonds\",\"no war but the class war\",\"no war but the class war\",\"leslie green (philosopher)\",\"leslie green (philosopher)\",\"broken windows theory\",\"broken windows theory\",\"broken windows theory\",\"kremlinology\",\"kremlinology\",\"kremlinology\",\"eco-nationalism\",\"eco-nationalism\",\"eco-nationalism\",\"nonkilling global political science\",\"regulatory economics\",\"vocational panel\",\"f\\u00fchrer\",\"f\\u00fchrer\",\"f\\u00fchrer\",\"f\\u00fchrer\",\"f\\u00fchrer\",\"f\\u00fchrer\",\"f\\u00fchrer\",\"thucydides trap\",\"school of public policy at central european university\",\"institut d'\\u00e9tudes politiques de toulouse\",\"institut d'\\u00e9tudes politiques de toulouse\",\"social corporatism\",\"social corporatism\",\"social corporatism\",\"social corporatism\",\"social corporatism\",\"holocaust trivialization\",\"holocaust trivialization\",\"advocacy journalism\",\"advocacy journalism\",\"arab barometer\",\"multistakeholder governance\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"socialist realism\",\"swiss neutrality\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"christian fascism\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"particracy\",\"public opinion on climate change\",\"public opinion on climate change\",\"public opinion on climate change\",\"overview of 21st-century propaganda\",\"overview of 21st-century propaganda\",\"public engagement\",\"distributive tendency\",\"british journal of politics and international relations\",\"garveyism\",\"successor ideology\",\"ralph borsodi\",\"ecocide\",\"ecocide\",\"ecocide\",\"in defense of the national interest\",\"christian corporatism\",\"christian corporatism\",\"christian corporatism\",\"christian corporatism\",\"christian corporatism\",\"history of science policy\",\"history of science policy\",\"history of science policy\",\"history of science policy\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"people's democracy (marxism\\u2013leninism)\",\"argumentation and advocacy\",\"olivier ihl\",\"olivier ihl\",\"school of diplomacy\",\"parochial political culture\",\"parochial political culture\",\"franciscan school of theology\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"civil libertarianism\",\"clientelism\",\"clientelism\",\"clientelism\",\"clientelism\",\"clientelism\",\"clientelism\",\"clientelism\",\"clientelism\",\"global terrorism index\",\"global terrorism index\",\"global terrorism index\",\"global terrorism index\",\"global terrorism index\",\"the journal of political philosophy\",\"philip converse\",\"philip converse\",\"philip converse\",\"philip converse\",\"philip converse\",\"philip converse\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"non-governmental organization\",\"development bureau\",\"development bureau\",\"communication university of china\",\"communication university of china\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"history of communism\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"international law\",\"nancy program\",\"peruvian nitrate monopoly\",\"electronic authentication\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"night-watchman state\",\"corporative federalism\",\"corporative federalism\",\"corporative federalism\",\"corporative federalism\",\"all animals are equal, but some animals are more equal than others\",\"all animals are equal, but some animals are more equal than others\",\"atlanticism\",\"atlanticism\",\"atlanticism\",\"atlanticism\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"social policy\",\"media circus\",\"media circus\",\"media circus\",\"media circus\",\"sovereignty of puerto rico during the cold war\",\"sovereignty of puerto rico during the cold war\",\"sovereignty of puerto rico during the cold war\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"constitutionalism\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"edinburgh university socialist society\",\"against equality of opportunity\",\"against equality of opportunity\",\"karl deutsch award\",\"karl deutsch award\",\"school of international and public affairs, columbia university\",\"school of international and public affairs, columbia university\",\"school of international and public affairs, columbia university\",\"school of international and public affairs, columbia university\",\"school of international and public affairs, columbia university\",\"give peace a chance\",\"give peace a chance\",\"give peace a chance\",\"give peace a chance\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"national conservatism\",\"res publica christiana\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"global politics\",\"marie-christine kessler\",\"corporate anniversary\",\"international journal of public opinion research\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"virtue jurisprudence\",\"nonna mayer\",\"salvador minguij\\u00f3n adri\\u00e1n\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"private property\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"public policy school\",\"an economic theory of democracy\",\"an economic theory of democracy\",\"german model\",\"journal of democracy\",\"behavioralism\",\"behavioralism\",\"behavioralism\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"situationist international\",\"balkanization\",\"balkanization\",\"balkanization\",\"balkanization\",\"balkanization\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"urban legend\",\"sam potolicchio\",\"isaiah berlin\",\"isaiah berlin\",\"isaiah berlin\",\"isaiah berlin\",\"isaiah berlin\",\"isaiah berlin\",\"walter f. dodd\",\"walter f. dodd\",\"walter f. dodd\",\"walter f. dodd\",\"corporate communication\",\"corporate communication\",\"the twenty years' crisis\",\"the twenty years' crisis\",\"the twenty years' crisis\",\"deliberation\",\"deliberation\",\"deliberation\",\"colin rallings\",\"domestic trade\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"whiggism\",\"muhammad taqi usmani\",\"muhammad taqi usmani\",\"muhammad taqi usmani\",\"eternity clause\",\"spin room\",\"spin room\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"comparative politics\",\"gish gallop\",\"gish gallop\",\"gish gallop\",\"gish gallop\",\"gish gallop\",\"peelian principles\",\"peelian principles\",\"bureaucratic drift\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"small government\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"constitutional patriotism\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"filter bubble\",\"executive order\",\"executive order\",\"executive order\",\"executive order\",\"executive order\",\"executive order\",\"executive order\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\",\"petition of right\",\"petition of right\",\"petition of right\",\"petition of right\",\"petition of right\",\"petition of right\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"constitutional dictatorship\",\"graduate school of public policy, university of tokyo\",\"state order\",\"might makes right\",\"might makes right\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"fiqh\",\"party identification\",\"exclusive federal powers\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"influence of mass media\",\"legitimation crisis\",\"legitimation crisis\",\"perpetual war\",\"perpetual war\",\"perpetual war\",\"perpetual war\",\"perpetual war\",\"united nations parliamentary assembly\",\"united nations parliamentary assembly\",\"united nations parliamentary assembly\",\"united nations parliamentary assembly\",\"united nations parliamentary assembly\",\"crypto-communism\",\"crypto-communism\",\"crypto-communism\",\"crypto-communism\",\"crypto-communism\",\"kalergi plan\",\"kalergi plan\",\"kalergi plan\",\"kalergi plan\",\"community policing\",\"community policing\",\"community policing\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"proletarian revolution\",\"peace journalism\",\"peace journalism\",\"peace journalism\",\"peace journalism\",\"coverage error\",\"coverage error\",\"coverage error\",\"coverage error\",\"coverage error\",\"coverage error\",\"coverage error\",\"celeb jihad\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"technocracy\",\"caudillo\",\"caudillo\",\"scotland's future\",\"scotland's future\",\"political studies review\",\"political studies review\",\"catherine eschle\",\"quadrilateral security dialogue\",\"national power\",\"national power\",\"national power\",\"list of enlightened despots\",\"regional hegemony\",\"regional hegemony\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"equal opportunity\",\"drang nach osten\",\"democracy-dictatorship index\",\"democracy-dictatorship index\",\"islamic sexual jurisprudence\",\"islamic sexual jurisprudence\",\"islamic sexual jurisprudence\",\"islamic sexual jurisprudence\",\"otto kirchheimer\",\"european union studies association\",\"full spectrum diplomacy\",\"full spectrum diplomacy\",\"full spectrum diplomacy\",\"full spectrum diplomacy\",\"full spectrum diplomacy\",\"democratic globalization\",\"democratic globalization\",\"democratic globalization\",\"democratic globalization\",\"democratic globalization\",\"democratic globalization\",\"democratic globalization\",\"western cape department of transport and public works\",\"social media in the 2016 united states presidential election\",\"social media in the 2016 united states presidential election\",\"total survey error\",\"total survey error\",\"total survey error\",\"total survey error\",\"total survey error\",\"total survey error\",\"high policing\",\"american university school of international service\",\"american university school of international service\",\"american university school of international service\",\"american university school of international service\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"freedom of contract\",\"neosocialism\",\"neosocialism\",\"neosocialism\",\"neosocialism\",\"neosocialism\",\"neosocialism\",\"neosocialism\",\"international political science association\",\"international political science association\",\"international political science association\",\"international political science association\",\"international political science association\",\"energy superpower\",\"energy superpower\",\"victim study\",\"energy community\",\"energy community\",\"energy community\",\"islamic toilet etiquette\",\"islamic toilet etiquette\",\"deviationism\",\"deviationism\",\"status quo state\",\"status quo state\",\"parliamentary procedure\",\"parliamentary procedure\",\"parliamentary procedure\",\"pickens plan\",\"pickens plan\",\"pickens plan\",\"postfunctionalism\",\"communist front\",\"communist front\",\"communist front\",\"communist front\",\"communist front\",\"molon labe\",\"molon labe\",\"scientocracy\",\"scientocracy\",\"scientocracy\",\"scientocracy\",\"scientocracy\",\"scientocracy\",\"scientific man versus power politics\",\"scientific man versus power politics\",\"scientific man versus power politics\",\"scientific man versus power politics\",\"scientific man versus power politics\",\"small office/home office\",\"crimes against humanity under communist regimes\",\"crimes against humanity under communist regimes\",\"crimes against humanity under communist regimes\",\"crimes against humanity under communist regimes\",\"christian privilege\",\"christian privilege\",\"christian privilege\",\"they shall not pass\",\"postinternationalism\",\"postinternationalism\",\"postinternationalism\",\"postinternationalism\",\"american recovery and reinvestment act of 2009\",\"american recovery and reinvestment act of 2009\",\"american recovery and reinvestment act of 2009\",\"wyn grant\",\"valence issue\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"labour voucher\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"reactionary\",\"helen margetts\",\"helen margetts\",\"helen margetts\",\"helen margetts\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"authoritarian democracy\",\"afrobarometer\",\"afrobarometer\",\"afrobarometer\",\"afrobarometer\",\"afrobarometer\",\"the soldier and the state\",\"the soldier and the state\",\"home rule\",\"home rule\",\"home rule\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"left\\u2013right political spectrum\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"corporate republic\",\"content marketing\",\"content marketing\",\"cacique\",\"peace through strength\",\"liberal international order\",\"liberal international order\",\"liberal international order\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"debate\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"ethical socialism\",\"free newfoundland\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"security studies\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"modern liberalism in the united states\",\"renewable energy transition\",\"renewable energy transition\",\"renewable energy transition\",\"implementation\",\"implementation\",\"knowledge gap hypothesis\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"regional power\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"list of social democratic parties\",\"we shall overcome\",\"united federal workers of america\",\"bananas, beaches and bases\",\"bananas, beaches and bases\",\"bananas, beaches and bases\",\"bananas, beaches and bases\",\"divided government in the united states\",\"transformation processes (media systems)\",\"international sanctions\",\"international sanctions\",\"international sanctions\",\"international sanctions\",\"the indian struggle\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"international energy agency\",\"animal testing regulations\",\"animal testing regulations\",\"mahr\",\"mahr\",\"mahr\",\"law and order\",\"law and order\",\"law and order\",\"chiara bottici\",\"logology (science)\",\"logology (science)\",\"eurosphere\",\"eurosphere\",\"eurosphere\",\"eurosphere\",\"institution\",\"institution\",\"fenno's paradox\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"anthony downs\",\"strategy of tension\",\"strategy of tension\",\"strategy of tension\",\"feeding the chooks\",\"outline of anarchism\",\"outline of anarchism\",\"outline of anarchism\",\"outline of anarchism\",\"outline of anarchism\",\"outline of anarchism\",\"dang guo\",\"instituts d'\\u00e9tudes politiques\",\"instituts d'\\u00e9tudes politiques\",\"instituts d'\\u00e9tudes politiques\",\"instituts d'\\u00e9tudes politiques\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"statism\",\"futarchy\",\"futarchy\",\"futarchy\",\"futarchy\",\"personhood\",\"personhood\",\"personhood\",\"personhood\",\"data collection system\",\"data collection system\",\"kinder, k\\u00fcche, kirche\",\"julius stone\",\"julius stone\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"authoritarian left\",\"debate chamber\",\"asu college of public service & community solutions\",\"asu college of public service & community solutions\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"ordoliberalism\",\"raisons politiques\",\"malikism in algeria\",\"malikism in algeria\",\"malikism in algeria\",\"malikism in algeria\",\"charg\\u00e9 de mission\",\"charg\\u00e9 de mission\",\"charg\\u00e9 de mission\",\"charg\\u00e9 de mission\",\"lloyd\\u2013la follette act\",\"marco tarchi\",\"marco tarchi\",\"tiocfaidh \\u00e1r l\\u00e1\",\"liberal social movement (portugal)\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"appeasement\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"dictatorship of the proletariat\",\"military policy\",\"military policy\",\"military policy\",\"eurasianism\",\"eurasianism\",\"eurasianism\",\"eurasianism\",\"eurasianism\",\"obreption and subreption (catholic canon law)\",\"obreption and subreption (catholic canon law)\",\"obreption and subreption (catholic canon law)\",\"commentary on palestine: peace not apartheid\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"social liberalism\",\"comunismo a la tica\",\"comunismo a la tica\",\"comunismo a la tica\",\"comunismo a la tica\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"jurisprudence\",\"gladstone professor of government\",\"composite index of national capability\",\"composite index of national capability\",\"composite index of national capability\",\"ipm (software)\",\"national question (quebec)\",\"politico-media complex\",\"politico-media complex\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"proletarian nation\",\"east turkestan\",\"oryx and crake\",\"oryx and crake\",\"emmette redford\",\"emmette redford\",\"emmette redford\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"majoritarianism\",\"roper center for public opinion research\",\"fukoku ky\\u014dhei\",\"list of public works ministries\",\"list of public works ministries\",\"demonizing the enemy\",\"demonizing the enemy\",\"demonizing the enemy\",\"demonizing the enemy\",\"deployment management\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"nolan chart\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"peace and conflict studies\",\"democratic liberalism\",\"democratic liberalism\",\"principles of political economy\",\"principles of political economy\",\"principles of political economy\",\"white power music\",\"white power music\",\"white power music\",\"white power music\",\"white power music\",\"voting rights in the united states\",\"voting rights in the united states\",\"voting rights in the united states\",\"voting rights in the united states\",\"voting rights in the united states\",\"voting rights in the united states\",\"communist era\",\"communist era\",\"communist era\",\"communist era\",\"nonpartisanism\",\"cleavage (politics)\",\"cleavage (politics)\",\"prediction market\",\"awza'i\",\"awza'i\",\"awza'i\",\"opinion leadership\",\"equality before the law\",\"equality before the law\",\"post-truth politics\",\"post-truth politics\",\"post-truth politics\",\"one man, one vote\",\"one man, one vote\",\"violent non-state actor\",\"violent non-state actor\",\"violent non-state actor\",\"violent non-state actor\",\"violent non-state actor\",\"violent non-state actor\",\"bevanism\",\"svoboda ili smart\",\"moderation theory\",\"stephanos bibas\",\"preselection\",\"preselection\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"right-wing politics\",\"gadsden flag\",\"gadsden flag\",\"gadsden flag\",\"conservative corporatism\",\"conservative corporatism\",\"global justice movement\",\"global justice movement\",\"global justice movement\",\"global justice movement\",\"global justice movement\",\"global justice movement\",\"global justice movement\",\"global justice movement\",\"political repression\",\"political repression\",\"political repression\",\"political repression\",\"political repression\",\"political repression\",\"danish defence agreement 2013\\u20132017\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"public administration\",\"revolutionary students federation\",\"idealism in international relations\",\"idealism in international relations\",\"idealism in international relations\",\"idealism in international relations\",\"note verbale\",\"note verbale\",\"principles of political economy (malthus book)\",\"fritz w. scharpf\",\"keep indy indie\",\"master of public administration\",\"interviewer effect\",\"multi-level governance\",\"multi-level governance\",\"multi-level governance\",\"indian political philosophy\",\"an anarchist faq\",\"an anarchist faq\",\"an anarchist faq\",\"international security\",\"international security\",\"international security\",\"international security\",\"international security\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"non-interventionism\",\"values modes\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"world revolution\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"opinion poll\",\"elif shafak\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"history of democratic socialism\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"enemy of the people\",\"history of the american legal profession\",\"history of the american legal profession\",\"history of the american legal profession\",\"grazing rights\",\"kaarlo juho st\\u00e5hlberg\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"great power\",\"independent labour publications\",\"independent labour publications\",\"comparative study of electoral systems\",\"comparative study of electoral systems\",\"comparative study of electoral systems\",\"the independent review\",\"burmese way to socialism\",\"burmese way to socialism\",\"burmese way to socialism\",\"coppieters foundation\",\"coppieters foundation\",\"ethnosymbolism\",\"ethnosymbolism\",\"university of san diego\",\"campaign finance\",\"campaign finance\",\"campaign finance\",\"cato institute\",\"cato institute\",\"critique: journal of socialist theory\",\"dualism (law)\",\"synarchism\",\"synarchism\",\"synarchism\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"dictablanda\",\"seek truth from facts\",\"radical egalitarianism\",\"radical egalitarianism\",\"music and political warfare\",\"political criticism\",\"parochialism\",\"reichsministerium des innern\",\"nur f\\u00fcr deutsche\",\"nur f\\u00fcr deutsche\",\"nur f\\u00fcr deutsche\",\"nur f\\u00fcr deutsche\",\"crown servant\",\"border control\",\"border control\",\"border control\",\"revealed preference\",\"public policy doctrine\",\"third-person effect\",\"socialist campaign group\",\"ministry of magic\",\"ministry of magic\",\"caucus for a new political science\",\"digital era governance\",\"right to exist\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"worker cooperative\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"propaganda\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"carl joachim friedrich\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"critical security studies\",\"history of the legal profession\",\"history of the legal profession\",\"transnational progressivism\",\"transnational progressivism\",\"transnational progressivism\",\"transnational progressivism\",\"pippa norris\",\"popular socialism\",\"popular socialism\",\"popular socialism\",\"popular socialism\",\"popular socialism\",\"nicole bacharan\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"left-wing populism\",\"kyklos\",\"kyklos\",\"erguer-estudantes da galiza\",\"erguer-estudantes da galiza\",\"notary (catholic canon law)\",\"notary (catholic canon law)\",\"consequentialist justifications of the state\",\"stein rokkan\",\"vaticanology\",\"maladministration\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"one-party state\",\"high and low politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"left-wing politics\",\"elective dictatorship\",\"public consultation\",\"enemy of the people (albania)\",\"enemy of the people (albania)\",\"enemy of the people (albania)\",\"enemy of the people (albania)\",\"enemy of the people (albania)\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"revolutions of 1989\",\"civil service\",\"civil service\",\"civil service\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"polyarchy\",\"regulatory competition\",\"\\u00bfpor qu\\u00e9 no te callas?\",\"white paper\",\"international isolation\",\"bolivarian revolution\",\"bolivarian revolution\",\"triangular diplomacy\",\"triangular diplomacy\",\"triangular diplomacy\",\"bankocracy\",\"bankocracy\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"social conservatism\",\"the machiavellian moment\",\"designing social inquiry\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"intergovernmentalism\",\"ernest barker\",\"westphalian sovereignty\",\"westphalian sovereignty\",\"westphalian sovereignty\",\"ronen palan\",\"ronen palan\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"democratic peace theory\",\"voter turnout\",\"voter turnout\",\"voter turnout\",\"voter turnout\",\"national communism\",\"national communism\",\"national communism\",\"national communism\",\"national communism\",\"national communism\",\"plenary power\",\"plenary power\",\"superpower collapse\",\"survey data collection\",\"survey data collection\",\"survey data collection\",\"labor theory of property\",\"labor theory of property\",\"global apartheid\",\"associationalism\",\"associationalism\",\"power-to-x\",\"princeton school of public and international affairs\",\"princeton school of public and international affairs\",\"princeton school of public and international affairs\",\"princeton school of public and international affairs\",\"jus commune\",\"jus commune\",\"jus commune\",\"jus commune\",\"appropriate technology\",\"appropriate technology\",\"appropriate technology\",\"security, territory, population\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"commanding heights of the economy\",\"soft despotism\",\"soft despotism\",\"soft despotism\",\"soft despotism\",\"soft despotism\",\"soft despotism\",\"soft despotism\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"bryan caplan\",\"party system\",\"party system\",\"party system\",\"party system\",\"the good soldier \\u0161vejk\",\"political research associates\",\"political research associates\",\"constitutional economics\",\"constitutional economics\",\"post-politics\",\"catch-22\",\"gary l. francione\",\"gary l. francione\",\"feminist legal theory\",\"frente despertar\",\"frente despertar\",\"frente despertar\",\"the establishment (pakistan)\",\"ariane chebel d'appollonia\",\"global citizenship\",\"the journal of politics\",\"the journal of politics\",\"classical realism (international relations)\",\"autonomous communities administration\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"christian communism\",\"slogan\",\"slogan\",\"slogan\",\"list of environmental ministries\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"hardline\",\"german university of administrative sciences speyer\",\"german university of administrative sciences speyer\",\"german university of administrative sciences speyer\",\"german university of administrative sciences speyer\",\"free migration\",\"free migration\",\"free migration\",\"rumor\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"nanosocialism\",\"private military company\",\"mariya gabriel\",\"mariya gabriel\",\"curvilinear disparity\",\"catonism\",\"custom (catholic canon law)\",\"tactical voting\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"blanquism\",\"regionalism (international relations)\",\"regionalism (international relations)\",\"legal naturalism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"left communism\",\"equality of outcome\",\"equality of outcome\",\"equality of outcome\",\"corporate statism\",\"science diplomacy\",\"thawri\",\"thawri\",\"promulgation (catholic canon law)\",\"implied powers\",\"gun control\",\"gun control\",\"gun control\",\"gun control\",\"international convention concerning the use of broadcasting in the cause of peace\",\"madhhab\",\"madhhab\",\"madhhab\",\"glory to hong kong\",\"glory to hong kong\",\"job cohen\",\"maternalism\",\"maternalism\",\"maternalism\",\"lesser of two evils principle\",\"parliamentary debate\",\"parliamentary debate\",\"new left review\",\"new left review\",\"new left review\",\"world values survey\",\"world values survey\",\"bibliography of works about communism\",\"bibliography of works about communism\",\"bibliography of works about communism\",\"economic stimulus appropriations act of 1977\",\"economic stimulus appropriations act of 1977\",\"rosa luxemburg foundation\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"oligarchy\",\"ilminism\",\"ilminism\",\"ilminism\",\"european school of political and social sciences\",\"e. f. schumacher\",\"e. f. schumacher\",\"collaboration\",\"collaboration\",\"european master of public administration consortium\",\"bush school of government and public service\",\"bush school of government and public service\",\"bush school of government and public service\",\"ratification\",\"ratification\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"ecoauthoritarianism\",\"communism and lgbt rights\",\"communism and lgbt rights\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"horseshoe theory\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"criticism of capitalism\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"far-right politics\",\"hannah arendt institute for totalitarianism studies\",\"hannah arendt institute for totalitarianism studies\",\"hannah arendt institute for totalitarianism studies\",\"henry e. brady\",\"chester barnard\",\"relative gain (international relations)\",\"imperium\",\"imperium\",\"james tully (philosopher)\",\"legalism (chinese philosophy)\",\"legalism (chinese philosophy)\",\"legalism (chinese philosophy)\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"third way\",\"liberal conservatism\",\"liberal conservatism\",\"liberal conservatism\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"eastern bloc\",\"enlightened absolutism\",\"enlightened absolutism\",\"enlightened absolutism\",\"enlightened absolutism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nazism\",\"nominate (scaling method)\",\"pakistan public works department\",\"participism\",\"participism\",\"participism\",\"participism\",\"sciences po\",\"kim campbell\",\"tryph\\u00e9\",\"voluntary society\",\"tractatus politicus\",\"schar school of policy and government\",\"history of propaganda\",\"history of propaganda\",\"populism\",\"populism\",\"populism\",\"populism\",\"populism\",\"authoritarian capitalism\",\"authoritarian capitalism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"totalitarianism\",\"political communication\",\"alan wolfe\",\"political groups of the european parliament\",\"index of social and political philosophy articles\",\"index of social and political philosophy articles\",\"index of social and political philosophy articles\",\"index of social and political philosophy articles\",\"exequatur\",\"exequatur\",\"real socialism\",\"real socialism\",\"autonomous administrative division\",\"international council for science\",\"neoauthoritarianism (china)\",\"international centre for black sea studies\",\"international centre for black sea studies\",\"spatial politics\",\"tyranny of the majority\",\"tyranny of the majority\",\"biology and political orientation\",\"biology and political orientation\",\"political cartoon\",\"e-government\",\"red wall (us politics)\",\"phillip blond\",\"phillip blond\",\"marlon bundo\",\"blue labour\",\"he who does not work, neither shall he eat\"]},\"selected\":{\"id\":\"2705\"},\"selection_policy\":{\"id\":\"2704\"}},\"id\":\"1489\",\"type\":\"ColumnDataSource\"},{\"attributes\":{},\"id\":\"2668\",\"type\":\"Title\"},{\"attributes\":{\"active_multi\":null,\"active_scroll\":{\"id\":\"1602\"},\"tools\":[{\"id\":\"1601\"},{\"id\":\"1602\"},{\"id\":\"1603\"},{\"id\":\"1604\"},{\"id\":\"1605\"}]},\"id\":\"1606\",\"type\":\"Toolbar\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1584\",\"type\":\"Range1d\"},{\"attributes\":{},\"id\":\"2686\",\"type\":\"AllLabels\"},{\"attributes\":{\"callback\":null,\"tooltips\":[[\"Page\",\"@index\"]]},\"id\":\"1475\",\"type\":\"HoverTool\"},{\"attributes\":{},\"id\":\"2707\",\"type\":\"Selection\"},{\"attributes\":{\"graph_layout\":{\"(don't) touch me on my studio\":[-287.03076357012964,-137.9006197401423],\"2000-watt society\":[256.33421642406216,-161.77446919276005],\"a call to action: women, religion, violence, and power\":[145.85497653007147,262.99369407562807],\"a green new deal\":[50.25021126920977,41.55898179573897],\"administrative divisions of peru\":[288.9331846706219,-2012.265497576973],\"administrative divisions of portugal\":[-457.6874901552651,2035.5514401323458],\"advocacy journalism\":[143.93937634278544,27.22547628995482],\"afke schaart\":[291.25864073062814,122.69893261709612],\"afrobarometer\":[-22.286765437359474,-487.7822013999503],\"after saturday comes sunday\":[118.05039759701027,-2563.073702616322],\"against equality of opportunity\":[-105.93877244622655,270.541652454624],\"ahl al-hadith\":[260.97019326048644,-429.29773488815147],\"al-ahram center for political and strategic studies\":[274.868122444727,122.84866144473509],\"alan wolfe\":[-1209.414547055661,2072.5266291525395],\"alex brillantes jr.\":[311.88191092784365,88.93263113707638],\"alexandra goujon\":[281.67096279133125,158.38509602284128],\"all animals are equal, but some animals are more equal than others\":[-277.0786171202594,-160.95253700320998],\"alternatives: turkish journal of international relations\":[302.00409403547474,129.66471049981126],\"american journal of political science\":[238.79212890918717,16.011459149691984],\"american political thought\":[274.94868512820517,117.5060104135024],\"american recovery and reinvestment act of 2009\":[45.60544060990267,147.242465185913],\"american university school of international service\":[243.390872733552,214.44605027272576],\"an anarchist faq\":[-237.92442257837902,202.32099572735785],\"an economic theory of democracy\":[279.05426929831754,213.16514764500403],\"andrew westmoreland\":[276.99241781535034,114.7550334417972],\"andr\\u00e9 du pisani\":[182.25125145351765,156.4501781864997],\"anglo-saxon model\":[-253.66199141379002,165.9345292873073],\"animal testing regulations\":[242.30604651214205,-37.097478638542974],\"antemurale myth\":[-285.32965183150446,-73.52611905380506],\"anthony downs\":[158.33466808962837,148.88993306333202],\"antimilitarism\":[-60.435099977199016,108.14425782594992],\"antinaturalism (politics)\":[284.02828608727236,64.94041482176934],\"ap comparative government and politics\":[143.8317520761402,-4.634934918410297],\"appeasement\":[103.29797119618526,-117.85594682434909],\"appropriate technology\":[58.66423753663259,-62.20664659232091],\"arab barometer\":[183.08977380845383,37.03153253356394],\"archibald crossley\":[56.43474820837753,-493.3794511592997],\"archon fung\":[494.48960036539864,2598.6040109954224],\"argumentation and advocacy\":[-15.58567088307025,-308.4944123094738],\"ariane chebel d'appollonia\":[329.08035714036424,95.16735630362037],\"aromanian question\":[-394.4020628569079,-87.0412728781192],\"ash-shab yurid isqat an-nizam\":[-1589.771660715086,1839.268772643462],\"associationalism\":[-161.7948246401601,-40.929757377328805],\"asu college of public service & community solutions\":[429.4175531985246,-9.432614723414147],\"atlanticism\":[-37.584957379248564,-35.89186463158161],\"attorney-general v de keyser's royal hotel ltd\":[545.2835725959903,-335.2113359114222],\"australian journal of political science\":[158.6090786248633,61.93324981309337],\"australian quarterly\":[299.69123136866824,107.74296414757241],\"authoritarian capitalism\":[-209.46151304452658,-8.822180840990034],\"authoritarian democracy\":[-267.34723848088873,-100.25408620609403],\"authoritarian left\":[-124.38459279496571,7.652610777698102],\"autonomous administrative division\":[-123.14972117495677,-218.0157565466478],\"autonomous communities administration\":[-61.8446451815318,-236.50564744574825],\"autonomous communities of spain\":[-63.388517544690494,-183.9423185547822],\"awza'i\":[285.4838456723402,-457.21508251202846],\"bad governance\":[71.72176135519297,-205.88536996403815],\"balkanization\":[-155.4695836352616,-183.96911137409387],\"bananas, beaches and bases\":[166.36269714805928,-106.74435561726628],\"bankocracy\":[-137.37565070222556,-96.87255292163165],\"barracks communism\":[-401.6550121696531,62.093574994410275],\"basket of deplorables\":[-351.52115089778755,-95.13963705731103],\"bay'ah\":[275.981458243448,-500.206802902088],\"beatrice heuser\":[126.12625153228934,224.75838345866367],\"behavioral public administration\":[199.7053417045781,118.70455927051563],\"behavioralism\":[362.2102424564913,51.017742836882604],\"benevolence and the mandate of heaven\":[17.561804054499508,2500.773218169756],\"berkeley school of political theory\":[344.3392016938063,68.16070118514102],\"better red than dead\":[1562.3873630025796,1363.5600252095376],\"bevanism\":[-511.69480238064966,110.49942275446844],\"bibliography of works about communism\":[-389.4882180129421,83.22367082969657],\"big man (political science)\":[307.19713435524284,88.12264580502047],\"biological organisation\":[129.49067925506554,2289.601215380352],\"biology and political orientation\":[-43.43875025219819,23.148078927570804],\"blanquism\":[-292.1599228983399,164.73264816235286],\"blavatnik school of government\":[268.057136466218,214.8895078539422],\"bloc party (politics)\":[-139.53379344816324,-124.44671338180208],\"blood and soil\":[-341.82661961091065,-109.3321488549317],\"blue labour\":[-624.0758804858148,203.25735726948017],\"bolivarian revolution\":[-168.0636844166574,80.24333274920143],\"bonai state\":[304.85313998770056,97.68568336995168],\"boosterism\":[276.208932460179,90.9837834312517],\"border control\":[-14.167108160371574,-107.48734734553534],\"border outpost\":[2232.53575561457,293.84030270694376],\"brandalism\":[-397.98883239978545,198.19885724378685],\"brigitte young\":[275.8506411562108,79.68222083540347],\"british journal of politics and international relations\":[201.16199965166774,186.4437911292175],\"british polling council\":[-593.7983475980977,-2000.589708331236],\"brocard (law)\":[145.14776286939855,-299.9898374078897],\"broken windows theory\":[740.3058970573168,-154.29393587799893],\"bryan caplan\":[-52.359481638978195,165.71187782125855],\"build\\u2013operate\\u2013transfer\":[77.43091158257658,-342.7629836029133],\"bureau-shaping model\":[118.49895899977227,223.09152717385052],\"bureaucratic drift\":[248.02085165270347,148.00454495459616],\"burmese way to socialism\":[-233.15094158961034,-156.9225884790888],\"bush school of government and public service\":[253.2015227767082,217.44918448013394],\"business oligarch\":[-197.3622895271594,-136.92463424635213],\"c. d. broad\":[92.65076677710479,-28.618962948481606],\"cacique\":[-720.0036868206014,-356.00818051271165],\"campaign finance\":[-49.96933972804385,-274.78037754427714],\"canadian political science association\":[116.66475374702291,305.1006293946532],\"canadian public policy\":[303.7866062285791,72.54595002581601],\"cand.scient.pol.\":[303.93151166147845,102.23771234497723],\"capitalist peace\":[153.68113191943294,-104.05770465103828],\"carbon fee and dividend\":[313.67038752323026,-178.71483490172702],\"carl albert center\":[487.458116197414,194.94878245326953],\"carl joachim friedrich\":[280.1696439374846,29.61567227843712],\"carles boix\":[194.70146239665522,-25.054671422315785],\"catch-22\":[960.306484411715,-2278.435887335896],\"catherine eschle\":[-61.453514699942346,200.4827581909571],\"catherine wihtol de wenden\":[299.8519370367573,78.63293456962607],\"cato institute\":[-8.850242141577707,105.05303829772964],\"catonism\":[-111.24809695952328,58.375887384512716],\"caucus for a new political science\":[-1206.4714581519847,2067.012074491654],\"caudillo\":[-629.3652537535448,-300.83838077695725],\"celeb jihad\":[1654.8332648532307,-1616.821728380014],\"centre for health and international relations\":[130.04745168105958,-26.919931623123766],\"challengeaccepted\":[715.9093467726983,-1906.2882665495588],\"charg\\u00e9 de mission\":[174.43386517234296,-143.0688085291917],\"chester barnard\":[317.3327169381954,322.601721476103],\"chiara bottici\":[431.30054552808775,156.38896829329903],\"china university of political science and law\":[388.1196444906674,149.03917602219073],\"china watcher\":[541.0598892772141,57.06872364305907],\"choosing scotland's future\":[128.43028804236025,461.91757532071665],\"christian communism\":[-372.3044886206226,177.84602068563296],\"christian corporatism\":[-333.51103188865414,111.7037892309476],\"christian egalitarianism\":[-402.7499772845494,255.4624521494142],\"christian fascism\":[-306.645993082166,-51.89370877375054],\"christian privilege\":[-356.1354386324485,-31.465005751904968],\"cipp evaluation model\":[452.521535979779,152.530329089184],\"civic political culture\":[575.0568646028421,355.2553402297355],\"civil libertarianism\":[-120.12863486399827,167.92395343920558],\"civil service\":[280.18105813362814,-88.76083972897214],\"civilization state\":[-146.40188046846978,-104.13954302940124],\"clarita carlos\":[171.17775568178396,73.66593495817419],\"class traitor\":[-441.44996908597943,155.3938387708134],\"classical realism (international relations)\":[169.09420932121114,-114.39681496233425],\"classification of advocacy groups\":[250.20607165893344,440.1995936947768],\"cleavage (politics)\":[53.37596822772479,2.5235610858482658],\"clientelism\":[183.73525554491104,-33.22901107236981],\"coal phase-out\":[261.93185899277444,-202.15857353362472],\"code of hammurabi\":[198.72200787823752,-289.4736577813441],\"coercion, capital, and european states, ad 990\\u20131992\":[-159.99623190644485,-116.48326371917794],\"colin hughes\":[118.48596071620214,215.60994187109134],\"colin rallings\":[294.4243274860806,485.9949381847646],\"collaboration\":[-159.32724223245404,171.48630140198307],\"comit\\u00e9s abertos de estudantes\":[1909.6541032008342,1613.7636620349424],\"commanding heights of the economy\":[-440.4970924929548,58.89073132732737],\"commentary on palestine: peace not apartheid\":[165.62384023358473,316.65043178529237],\"commodity form theory\":[0.8892427142067173,-138.61151195272555],\"common informer\":[565.2828405395861,-359.6294349126454],\"communication university of china\":[461.9063480163855,177.39743816506981],\"communications management\":[-63.02319113278681,226.0264536537369],\"communism and lgbt rights\":[-389.15792894768674,37.73326108357575],\"communist era\":[-431.165105041736,107.50917494478364],\"communist front\":[-373.7625881790527,-25.16778583918716],\"community policing\":[657.2592311963698,-151.21971902145862],\"comparative criminal justice\":[194.39361785173298,-230.5621238891801],\"comparative politics\":[111.47379410385082,3.924696525035635],\"comparative study of electoral systems\":[-38.43693024339002,-522.1998854991316],\"comparing media systems\":[181.76938885482997,-8.14979378950014],\"composite index of national capability\":[-22.712201499194524,-126.69655189494146],\"computational politics\":[297.82486663413357,91.040436011479],\"comunismo a la tica\":[-444.7014464355003,122.92982937697617],\"concurrent powers\":[320.44716232752745,-333.08631417200235],\"consensus democracy\":[-219.05898132487005,85.1467264682958],\"consequentialist justifications of the state\":[-104.93187900474317,56.83399425540376],\"conservative corporatism\":[-241.87798744937282,50.36080783306016],\"conservative liberalism\":[-209.22826023105907,110.97211007982759],\"conservative research department\":[1911.5140889016113,-609.7048377975804],\"constitutional autochthony\":[290.45955966893973,66.82652277903276],\"constitutional dictatorship\":[-203.25943435517416,-96.20600565610954],\"constitutional economics\":[114.39460669197753,-145.3633749986201],\"constitutional patriotism\":[-251.61965508039248,68.28215106410835],\"constitutionalism\":[-67.32865381941815,-22.980148712013346],\"constitutionality\":[335.8044114015211,233.9705417570593],\"consumer sovereignty\":[2133.8945295845274,-561.2798657690502],\"contemporary voices\":[285.3521097061176,78.60143328152027],\"content marketing\":[126.22098696650856,416.3886540933764],\"contingent sovereignty\":[127.5649028281647,-197.51148512847647],\"continuismo\":[-659.0569527670798,-323.67432266090015],\"coppieters foundation\":[350.04218060389303,-55.99993248294217],\"corporate anniversary\":[-342.6353289659428,-236.26623297296098],\"corporate communication\":[-262.60954695235114,-146.61815467683476],\"corporate republic\":[-222.7674713268944,-94.45819159098166],\"corporate statism\":[-305.35149426077453,-120.16382774733879],\"corporative federalism\":[-141.8119440291616,-222.54963218347933],\"corporatization\":[-335.6864126994494,68.23040552376652],\"cosmopolitan democracy\":[37.04786485587211,-133.04918675422655],\"counterpropaganda\":[-285.29815894890675,-313.975584983875],\"coverage error\":[-30.241643811390112,-526.2860139422597],\"crimes against humanity under communist regimes\":[-487.59261594376625,159.73707245952986],\"critical review (journal)\":[307.2549003008522,119.06911773430878],\"critical security studies\":[193.63852963100652,-83.27863725728085],\"criticism of capitalism\":[-277.15751408854993,142.7036787653673],\"critique: journal of socialist theory\":[57.58177558857812,79.92374568772945],\"crown servant\":[136.38524408445215,7.489045200007578],\"crypto-communism\":[-474.51674310427353,133.28936731909758],\"cube root rule\":[299.19779889702716,122.56860594173142],\"cultural liberalism\":[-119.62858879459974,124.61692478216148],\"culture 21\":[-2231.9341018979558,-287.7487878224003],\"curvilinear disparity\":[365.394571447596,247.05999900735114],\"custom (catholic canon law)\":[150.51918264260095,-338.3720356645922],\"cyberocracy\":[-86.4310383304229,-78.52663221299507],\"dang guo\":[-319.82282996222,-243.0182780903779],\"danish defence agreement 2013\\u20132017\":[96.58930661676158,351.8026329534958],\"dark figure of crime\":[867.8305196887753,-105.9405767795599],\"data collection system\":[-23.123063176610074,-603.8671288450644],\"data editing\":[-1807.652338338532,942.301933914463],\"david e. campbell (political scientist)\":[280.821820779709,81.22104352172997],\"day of empire\":[-1409.8084685407366,-1453.6634796988292],\"debate\":[-21.87349242459858,-256.5929572910574],\"debate chamber\":[-76.36958387009473,-61.16536178274368],\"decentralized autonomous organization\":[193.36534840078627,-452.91359216080514],\"decentralized computing\":[206.88447992969793,-493.0734972753882],\"decoloniality\":[-143.96331654059486,-204.11875327250402],\"decolonization\":[-140.08046362111887,-149.41663697987332],\"deliberation\":[23.51232097757691,-586.1989688170438],\"democracies: patterns of majoritarian & consensus government in twenty-one countries\":[195.23275400343283,34.65874739800129],\"democracy and security\":[305.13328415156,82.85084489397636],\"democracy-dictatorship index\":[47.390978789135424,-115.25748758587767],\"democratic globalization\":[67.4543488005467,-77.79051186830209],\"democratic liberalism\":[-214.40956762853568,148.73553467636307],\"democratic marxism\":[-442.9094942407124,148.6887966935308],\"democratic party for a new society\":[67.94974460739432,-197.2366562404363],\"democratic peace theory\":[69.74124154710434,-116.03509108566557],\"democratic recession\":[283.77700964827227,133.80472827220203],\"demonizing the enemy\":[-317.84088053535805,-311.95594089191707],\"denationalized citizenship\":[-555.4262798330321,2203.779519137786],\"dependent territory\":[-120.62545679015439,-128.41905961043943],\"deployment management\":[339.07172072047115,106.75795276524937],\"designing social inquiry\":[458.2888902550603,35.268733266049225],\"development bureau\":[426.0832311866263,-355.39106877389156],\"deviationism\":[-288.0658660167833,51.088310383033054],\"dictablanda\":[-241.30204862381163,-87.02337796708296],\"dictatorship of the proletariat\":[-364.9257813760139,120.58329536683246],\"digest of middle east studies\":[285.2480583476759,69.50285431842707],\"digital era governance\":[45.71330384905192,-39.32228174913245],\"diplomatic protection\":[-552.3678239260348,2206.3634747810506],\"distributive tendency\":[441.4994727814459,-91.33112090153082],\"divided government in the united states\":[9.832140235087103,148.42827576582425],\"dizzy with success\":[-401.56348728241176,-39.62973279197695],\"domestic analogy\":[374.6786528819929,136.28196302810116],\"domestic trade\":[-511.71650502957965,55.9841699052178],\"dominium maris baltici\":[201.12394665626965,-232.28888357504965],\"donald e. stokes\":[360.02278367749875,75.20287629184033],\"donatella della porta\":[81.13147201781108,138.99104550686582],\"drang nach osten\":[-314.5006448611329,-83.92178277604191],\"dualism (law)\":[100.45650166039917,-315.6916962896676],\"dyab abou jahjah\":[283.5131612266677,100.00064996417608],\"e-government\":[-18.141650057016957,-50.74060488803975],\"e. f. schumacher\":[-39.64864050718531,90.32799177098478],\"early social changes under islam\":[187.0899978027184,-369.40943080889093],\"earned media\":[142.46637848359487,462.8207570692628],\"east european politics\":[290.01590199558945,113.96244669851616],\"east turkestan\":[-1145.972643351172,2415.7669066031244],\"eastern bloc\":[-326.9002302273994,-12.847016230228885],\"echo chamber (media)\":[-157.99505053524675,-228.26600001166872],\"eco-nationalism\":[-262.323624028268,-13.38483867680419],\"ecoauthoritarianism\":[-214.06869402486348,-37.59014943414433],\"ecocide\":[253.74075151237193,-275.18054133863734],\"economic stimulus appropriations act of 1977\":[15.994635115009826,277.2700240585652],\"ed miliband bacon sandwich photograph\":[1413.0782728573104,-1474.6844864312031],\"edinburgh university socialist society\":[-298.4487922313915,139.68049365635756],\"edward j. bloustein school of planning and public policy\":[229.95124230662233,205.84341001585432],\"effective number of parties\":[104.65316570216001,-31.223496216178443],\"el pueblo unido jam\\u00e1s ser\\u00e1 vencido\":[-1591.546992748904,1848.3336624268436],\"election law journal\":[304.6323642159175,78.12266921287141],\"elective dictatorship\":[13.175963159500009,41.772171852725954],\"electronic authentication\":[-2.560370566923437,-72.70914549582677],\"electronic media\":[1.1300457197411788,6.142880948592719],\"electronic process of law\":[207.94328794019276,236.10428839627951],\"elif shafak\":[336.5454788090661,127.75738071739657],\"emilia justyna powell\":[56.33674390617203,304.6486461391773],\"emmette redford\":[414.04556963515296,39.95257070158911],\"enbau\":[308.64034744140434,-181.59830778914954],\"enemy of the people\":[-373.3514749369681,17.427903241323616],\"enemy of the people (albania)\":[-361.6519498720762,33.074938677008525],\"energy certificate\":[379.7316136168631,-208.7281091828159],\"energy charter treaty\":[367.2851093905582,-238.49237869010867],\"energy community\":[329.9122970159896,-190.19125869782093],\"energy superpower\":[-85.57129455714941,-169.27714367750576],\"english votes for english laws\":[116.62376779967462,52.198089530206566],\"enlightened absolutism\":[-249.26540017284842,-104.85264238329812],\"enterprise theory\":[-724.771209585912,-1922.6303023332202],\"environmental peacebuilding\":[224.72053434778027,-2371.649626626455],\"environmental policy of the european union\":[155.69961824294143,-75.67761973650504],\"environmental politics (journal)\":[290.9329410361399,95.52854259095733],\"equal opportunity\":[-259.51120386839347,189.58968767303978],\"equality before the law\":[-90.09181970351652,78.27103526635833],\"equality of outcome\":[-310.2399933549551,228.09936855275853],\"erguer-estudantes da galiza\":[1908.9913231916346,1624.2797217616019],\"eric helleiner\":[215.0444264829341,208.29656950129632],\"ernest barker\":[132.93650328801488,244.69939775021058],\"essence of decision\":[271.5286975698125,130.27924825733677],\"eternity clause\":[-196.6472648592588,-126.675931004119],\"ethical socialism\":[-309.9492373407771,174.492246943329],\"ethnarch\":[-237.4514926651543,-136.56902527175842],\"ethnosymbolism\":[-140.11222141146212,-37.56434492046702],\"eurasianism\":[-213.75722201105137,71.10774485279177],\"european master of public administration consortium\":[250.35270419771507,160.18925962919724],\"european school of political and social sciences\":[305.78519245721645,218.06016195373178],\"european union studies association\":[301.1579174527313,53.73731669769292],\"eurosphere\":[139.6463086073855,-77.21255031844582],\"exclusive federal powers\":[359.70216488509806,-362.52366094288624],\"executive order\":[164.4168975829549,-278.60043377317464],\"exequatur\":[162.22828132397387,-242.32288440856053],\"expansionary fiscal contraction\":[-1885.2039022349634,868.9877088980074],\"experimental political science\":[132.8726173216975,-112.3465006951605],\"extemporaneous speaking\":[-18.563573631096922,-313.8180307506963],\"faculty of political science, chulalongkorn university\":[211.57590032709896,116.86978770152982],\"failed state\":[296.25260480429085,-97.60349906546962],\"far-right politics\":[-278.86650510622474,-6.252657994007635],\"fascism: a warning\":[297.70734211695077,104.19220932549491],\"federal law\":[271.50018719947604,-377.4165435647568],\"feeding the chooks\":[-258.00315559209724,126.86778188743025],\"feminist legal theory\":[143.30336724537477,-250.7837355747029],\"fenno's paradox\":[953.8876183292788,-2274.0649851584167],\"feoffment\":[-361.4527775388746,2535.0074127264334],\"filter bubble\":[-251.48892008187812,-303.7085468274515],\"fiqh\":[239.09339407917298,-395.4221361021516],\"fiscal capacity\":[276.3072549006843,72.57219373282082],\"fiscal imbalance\":[-232.22006813987693,2342.395777992776],\"fiscal policy of the philippines\":[1603.7541446065404,-1227.969795055524],\"fiscal policy of the united states\":[-41.458544052657395,308.6974638688041],\"fiscal transparency\":[1821.0500444868223,-904.2043835590209],\"food sovereignty\":[-149.61994131480287,-206.68860147956616],\"foreign policy\":[86.86633637493844,43.49049486537731],\"foreign service officer\":[1955.4307949271836,-572.0611509252724],\"fourteen words\":[-343.8766776256141,-82.82522763360333],\"franciscan school of theology\":[-1359.370285364441,2013.8036765914835],\"frank batten school of leadership and public policy\":[218.9843773673235,268.02829069174555],\"frankfurt declaration\":[-294.5749854676085,183.5147923428336],\"fred w. riggs\":[205.38992372367028,122.5689390426539],\"free market fairness\":[20.6185323700226,187.69620211234155],\"free migration\":[-83.12464262924304,154.4557167637531],\"free newfoundland\":[-359.66820911955807,-368.89476232768743],\"free-market healthcare\":[-85.94933016599897,198.44609209490704],\"freedom of contract\":[-81.16866310557462,165.69554701293842],\"frente despertar\":[-144.91064548972406,81.58563298923335],\"friedrich naumann foundation\":[307.06140980160114,-191.21936844547722],\"fritz w. scharpf\":[260.9525604547517,53.76258426971382],\"fukoku ky\\u014dhei\":[-265.8064297348136,-219.00886984633456],\"full spectrum diplomacy\":[150.28033764231506,-150.1024548085946],\"fundacion manantiales\":[239.5237887593365,-156.66525968607098],\"futarchy\":[-106.0259357474751,-143.30244558167425],\"f\\u00fchrer\":[-369.1829388875656,-139.54583314315948],\"gadsden flag\":[-94.80545938542502,226.28725502017411],\"galician student league\":[1904.73590129928,1620.771730945668],\"galician workers union\":[1899.5269346264174,1616.3631170435474],\"gar alperovitz\":[-382.52592615751985,-4.421327737092167],\"garveyism\":[-136.75485743304222,-24.273951754695254],\"gary l. francione\":[183.03753382416085,-69.73660961613477],\"german model\":[-235.7554575841607,211.10963532835166],\"german university of administrative sciences speyer\":[271.6882160178275,151.366040986496],\"gevald campaign\":[-150.39669925923923,-344.2784819949553],\"gish gallop\":[-324.6327064730335,-308.6561567732094],\"give peace a chance\":[58.253437378300035,24.265184849580297],\"gladstone professor of government\":[170.2666709229768,133.2941200370341],\"global apartheid\":[116.93442758987537,-101.80238003440924],\"global citizenship\":[78.65651516547612,-132.05238533755843],\"global environmental politics\":[300.8638967448444,-364.95543890115215],\"global justice movement\":[-80.11223673845375,141.28748837712413],\"global politics\":[127.07648876289196,-84.20428064374727],\"global terrorism index\":[50.112577513257264,-127.18614739201075],\"glory to hong kong\":[-1583.780755022667,1852.6378512651281],\"glory to ukraine\":[-1576.0404189109208,1844.1000826338475],\"glossary of international relations terms\":[93.5902583488359,-190.27445250315293],\"grab em by the pussy\":[112.22781841673861,66.26700319458908],\"grace skogstad\":[134.4968025409488,354.8042722453857],\"graduate program in public management\":[266.92213776278237,293.26859387363083],\"graduate school of public policy, university of tokyo\":[230.95934222118402,250.00545053084724],\"grazing rights\":[32.246960319229814,-97.02767910394878],\"great power\":[-99.01698155939036,-83.64193155118346],\"greek withdrawal from the eurozone\":[1565.7873195788434,-1332.2571812331273],\"green industrial policy\":[380.8372276240993,-271.71190629581963],\"green institute foundation\":[-20.984860352413833,2518.745052095964],\"grenoble institute of political studies\":[191.48771734975273,157.23861772754276],\"grey room\":[269.9267464229699,122.61670012192096],\"grey-zone (international relations)\":[209.77251611129694,-202.84214611875962],\"gruppi di acquisto solidale\":[-1594.3034035892144,1236.3440982566458],\"gun control\":[-109.88540828122602,255.9507520226806],\"gwendolen m. carter\":[298.0754614634162,100.14462293576847],\"hannah arendt institute for totalitarianism studies\":[-115.4613383183165,-47.93272852643486],\"hardline\":[-189.3107102746991,3.1167995021412827],\"harvard institute of politics\":[-451.98980470312404,-23.580641148040904],\"harvest hills cooperative community\":[-483.69498911457237,178.9749056873078],\"he who does not work, neither shall he eat\":[-453.9973506818673,238.98762984082302],\"health policy\":[172.79948000893444,204.25235417347352],\"health policy in bangladesh\":[194.0641541349074,262.18450884292133],\"health system\":[189.96866177792958,255.98432830875947],\"helen margetts\":[166.05932598235708,120.45443338681811],\"henry e. brady\":[401.4780705977146,34.06672353621692],\"henry habib\":[224.65868015678822,-69.02919872333204],\"her majesty's government (term)\":[275.44367629092494,111.27450746636538],\"hierarchical organization\":[-247.49373919554333,321.6793257927199],\"high and low politics\":[119.72912602185025,30.53563798860872],\"high policing\":[307.6739599861757,-108.18716539676176],\"history of communism\":[-394.3320044674298,152.2031963447113],\"history of democratic socialism\":[-332.39659926771355,165.2486579966106],\"history of political science\":[324.97120921176645,104.00464106800324],\"history of propaganda\":[-212.291216138927,-239.08441601719593],\"history of science policy\":[51.24365466710018,-53.23187713383198],\"history of social democracy\":[-292.36552297181555,102.96893287296979],\"history of the american legal profession\":[173.93662527112005,-298.39892597579126],\"history of the legal profession\":[182.2160374165087,-290.64518394823045],\"holocaust trivialization\":[-55.055968141306565,39.35695971913928],\"home rule\":[-111.90157781583076,-234.13483537696874],\"horace campbell\":[191.81323094365118,40.998135149668855],\"horseshoe theory\":[-181.42185626980296,33.80534024694722],\"how voters feel\":[172.47668624405142,34.23555263145541],\"human resource management in public administration\":[265.2378142870633,256.94141205455475],\"i did not have sexual relations with that woman\":[-2.3573136559255894,184.96333857394364],\"i like ike\":[110.60314209627818,53.01601800569104],\"idealism in international relations\":[173.987581548794,-130.5426937604763],\"ideocracy\":[-225.9235525548801,-136.38396831115315],\"ilminism\":[-299.02959504962024,-29.31891811134733],\"imperium\":[29.93848490901073,-229.24842302868205],\"implementation\":[399.81544503927086,135.91814536298426],\"implied powers\":[279.39110837633086,-300.972804017143],\"in defense of the national interest\":[268.4044094910989,-132.50566679836302],\"in place of strife\":[101.7944479095794,349.2518107729467],\"inclusion and democracy\":[284.45447690011036,112.28866366713085],\"independent labour publications\":[-690.3317631692072,228.5111178793427],\"index of social and political philosophy articles\":[-127.96541764086385,38.360318525902024],\"india quarterly\":[293.16651210423123,126.8155887035163],\"indian political philosophy\":[-100.27646424419464,53.27890597036513],\"indonesian village law\":[1266.6355291485493,-1610.906498367981],\"industrial democracy\":[-305.6398770842607,154.1222761644338],\"influence of mass media\":[-179.22301058256437,-243.4453219052648],\"inquisitorial system\":[188.68964286861427,-301.58349189012034],\"insight turkey\":[309.6524362141482,69.56851674503707],\"institut d'\\u00e9tudes politiques d'aix-en-provence\":[244.93486164255597,264.14284996021263],\"institut d'\\u00e9tudes politiques de toulouse\":[255.3074558132486,202.9694110622787],\"institute for economics and peace\":[72.92006836042451,-168.53052512101598],\"institute for international law of peace and armed conflict\":[194.41248393040578,-238.02757573868297],\"institute for political studies \\u2013 catholic university of portugal\":[301.64780360051384,119.87984369025178],\"institution\":[226.97101301159492,-134.02216155615397],\"institutional analysis\":[-460.9123451208043,-2067.8713999415077],\"institutionalist political economy\":[204.88692729318947,-162.44036048704638],\"instituts d'\\u00e9tudes politiques\":[211.8338161092532,200.18985990557684],\"inter-municipal cooperation\":[-554.1279568962187,81.76889905590319],\"intergenerational policy\":[137.24345392610033,193.85793378213938],\"intergovernmentalism\":[114.6920386763497,-62.65895701100558],\"international area studies review\":[-804.133870230271,-1843.470508750619],\"international centre for black sea studies\":[532.3408990634075,-21.721993879730057],\"international conference on theory and practice of electronic governance\":[2.0379596960143402,-86.23615101458326],\"international convention concerning the use of broadcasting in the cause of peace\":[-279.3813954795525,-252.34695633390209],\"international council for science\":[-2795.2433201870435,209.27177596827508],\"international energy agency\":[333.10620280952355,-252.87983609889162],\"international ethics\":[193.2002001910144,-101.61185650956934],\"international isolation\":[-172.52989574412499,-208.79362879710092],\"international journal of intelligence and counterintelligence\":[311.9156568065736,95.46849686860217],\"international journal of public opinion research\":[120.08220491535268,-443.91541957578016],\"international law\":[153.7687670715013,-200.82954104982016],\"international peacekeeping\":[-197.10428696435176,83.29376587750568],\"international political science association\":[235.29235457641946,139.81025796952167],\"international relations and security network\":[446.06188892333876,-15.840390183270808],\"international review of the red cross\":[298.03000226400843,115.08069106417943],\"international sanctions\":[39.7889190299651,-217.0543062639605],\"international security\":[250.65220467139883,-88.37430136523659],\"international workers' day\":[-428.66694891455364,-49.74249997576129],\"interventionism (politics)\":[5.314446165049721,113.98899404882779],\"interviewer effect\":[114.23758937816062,-444.4486609740638],\"ipm (software)\":[-9.137121939708345,-570.7380888289083],\"isaiah berlin\":[-93.14773811167495,103.1355734933223],\"ishraga mustafa hamid\":[293.3712225270563,131.45861852848915],\"islam and children\":[212.85615316522237,-407.12435226800517],\"islamic funeral\":[290.13027666676334,-530.1820168764269],\"islamic sexual jurisprudence\":[252.18649020037623,-471.50010366636184],\"islamic toilet etiquette\":[232.4742033741149,-445.256153533745],\"istihlal\":[219.8063995031842,-387.1770858929415],\"james tully (philosopher)\":[76.74206730604963,174.1252926498888],\"jamiat-e islami\":[-527.8476625437909,2195.5837972718273],\"jane duckett\":[190.7825887672129,142.71138499272837],\"janet ajzenstat\":[295.3155257794863,64.7031014103807],\"jean bethke elshtain\":[294.9342473807158,122.15706769201202],\"jewish-palestinian living room dialogue group\":[34.67937876655214,-638.1221265630179],\"jihad satire\":[1657.5770817826067,-1613.9050839776457],\"job cohen\":[132.50866361639936,-343.3963337537756],\"joe biden (the onion)\":[-22.503278762385694,-308.35704111396774],\"john coakley\":[186.02585008130453,83.53756531159856],\"johnson cult\":[104.51539961305133,60.52442204452072],\"joseph rowntree foundation\":[1885.03737368657,-676.8855949487904],\"josepha laroche\":[289.6904452557545,88.92708208629023],\"journal of current chinese affairs\":[292.44012468839503,73.18631028761207],\"journal of current southeast asian affairs\":[276.85558788374897,102.94795188480313],\"journal of democracy\":[240.71965329782947,38.77494107244888],\"journal of ethnic and migration studies\":[291.82859773724965,102.91135891089762],\"journal of european integration\":[306.1422415930225,92.89432476137259],\"journal of european social policy\":[307.0382775355269,102.3446194348134],\"journal of policy history\":[370.5241697599585,32.44469385644496],\"journal of political ideologies\":[276.4215883479481,106.97016706878367],\"journal of theoretical politics\":[205.43645644688775,153.7347490112679],\"julius stone\":[187.63585982937823,-262.34021968876687],\"jurisprudence\":[123.23703004873366,-256.4586634277723],\"jurisprudence of concepts\":[-487.62481252194584,212.08067084515687],\"jus commune\":[171.5342863688826,-338.9833560167251],\"kaarlo juho st\\u00e5hlberg\":[222.932132205509,-251.0425023129946],\"kalergi plan\":[-330.8769937676953,-109.68544164081405],\"kansas city preventive patrol experiment\":[692.3750577483664,-145.34402593783634],\"karl deutsch award\":[222.29895222879776,127.29341777730878],\"karl schwedler\":[-349.3042537292006,-236.8428265815809],\"katharine hayhoe\":[176.41426491592483,68.54548798513865],\"keep indy indie\":[-372.7833359145187,-388.4572017801774],\"kim campbell\":[127.17316315625357,251.47084310432868],\"kinder, k\\u00fcche, kirche\":[-320.3263322187173,-79.85529619356761],\"kissinger lecture\":[297.4122849706084,110.97519626401609],\"knowledge gap hypothesis\":[188.1372344285934,1.6191054500894573],\"kremlinology\":[495.8464021331433,51.913254897626786],\"kyklos\":[-194.43093700640685,-88.45999818328225],\"labor theory of property\":[-76.25433561541175,93.08968049518423],\"labour voucher\":[-326.1446068215792,212.12618363651387],\"land consolidation\":[-395.2450505318267,-40.75151574965293],\"latin american public opinion project\":[-15.197158277943425,-540.806929876358],\"law and order\":[-309.9241545681621,-37.21711644975818],\"law of equal liberty\":[-197.86886099527717,165.3065293927096],\"law without the state\":[62.945394223344344,-206.5754066607146],\"lectures on jurisprudence\":[309.6119216124919,2767.5589326181134],\"left communism\":[-347.90305958642347,182.4362468248103],\"left group of finnish workers\":[71.50697860471895,-200.20352335195918],\"left-wing politics\":[-283.4653379488801,76.60305378881735],\"left-wing populism\":[-165.9756950439055,129.35206932849547],\"left\\u2013right political spectrum\":[-160.5098622376738,41.23154767930012],\"legal naturalism\":[-419.11405310388557,172.54600814377883],\"legal norm\":[85.81115949854514,-264.2934263360604],\"legalism (chinese philosophy)\":[-86.1615871524314,-142.91667470430085],\"legitimation crisis\":[29.224724366139977,-75.29987095328086],\"leslie green (philosopher)\":[79.40753655680966,-264.05993822964297],\"lesser of two evils principle\":[-349.8364137941222,-354.25151379307863],\"liberal conservatism\":[-227.97542884908862,98.7493366754614],\"liberal corporatism\":[-215.2404231321054,127.305720105295],\"liberal democratic basic order\":[-69.12022649203898,-205.55925334754193],\"liberal international order\":[-71.13717381809087,-153.4106108553617],\"liberal legalism\":[30.372805058342557,-105.12423840747127],\"liberal social movement (portugal)\":[-183.6360054188881,211.8983579841361],\"liberalism and conservatism in latin america\":[-188.82071048138056,62.90208151912729],\"liechtenstein institute on self-determination\":[213.78275272935318,-39.045588851991916],\"liesbet hooghe\":[276.16564418350714,64.03311019726719],\"limitarianism (ethical)\":[-79.16143903119632,322.1085295150304],\"linked fate\":[285.44942413075114,84.16913235769574],\"list of enlightened despots\":[-289.8718796707501,-153.8639275153576],\"list of environmental ministries\":[267.8897531725468,-284.9492869667686],\"list of food labeling regulations\":[1749.225636875891,-1046.9528708522712],\"list of futurama characters\":[107.83014778734865,67.05267358404255],\"list of left-wing internationals\":[-332.76545913255626,185.76826198063202],\"list of liberal theorists\":[-171.35201760012228,148.72811980734943],\"list of national independence days\":[-164.84902960722832,-196.7686038582939],\"list of national legal systems\":[183.98559836685683,-241.70905898098994],\"list of public works ministries\":[524.6399939818605,-576.871166048403],\"list of rugrats characters\":[1426.0041488759953,-1435.6994612365504],\"list of social democratic parties\":[-316.2864587927017,193.22717559167532],\"live free or die\":[-196.93026550854057,-3561.469594936509],\"ljiljana radoni\\u0107\":[98.26199630835168,81.48058666344703],\"lloyd\\u2013la follette act\":[335.97741367747966,-109.36462944938971],\"local service delivery\":[-495.4767394388299,77.96317463811867],\"logology (science)\":[63.328138735648004,-14.852846322385183],\"london school of economics\":[108.78978193168132,169.94947417156928],\"lorena parini\":[270.56450645779137,113.76990724447923],\"louise dandurand\":[286.93022186927647,61.15207260559997],\"maddaddam\":[-443.2156216324738,-318.70142415975243],\"madhhab\":[251.6790390685062,-429.9302691055826],\"magna carta for philippine internet freedom\":[-194.02867890427711,-224.13947852266992],\"mahr\":[266.227249123675,-493.72444222991675],\"majoritarianism\":[-186.112385766012,-56.074210762712376],\"making democracy work\":[274.4691654126078,95.71811471485611],\"making peace\":[160.08121749691063,268.4588256452667],\"maladministration\":[265.0075566986223,-35.769697256028095],\"malikism in algeria\":[276.6807696616649,-460.67572669801086],\"malinda s. smith\":[307.5403432382861,28.71342648836714],\"managerialism\":[11.067847502928704,193.0049631164806],\"marc lynch\":[102.06523776661878,66.0144538762448],\"marcellina (gnostic)\":[1865.3907453633103,-730.3332468058356],\"marco tarchi\":[59.24117819015645,36.3985657170493],\"margaret clark (political scientist)\":[317.1551864797832,88.69653724280214],\"marian van landingham\":[276.5063664002453,127.99286579644235],\"marie-christine kessler\":[256.4107680028974,163.60979459541716],\"maritza montero\":[312.09979159020935,101.86095539169311],\"mariya gabriel\":[459.24450989272026,-79.10678292843869],\"marlon bundo\":[-17.624796170820545,-338.3837450419203],\"martens centre\":[383.7774665179487,-62.28532929599314],\"mass media and american politics\":[65.76643314602377,-243.01721213204272],\"master of public administration\":[232.33777458088596,179.15576191947682],\"master of public policy\":[268.1279046250094,248.20060996086562],\"maternalism\":[-171.966976600161,12.916709957077279],\"maxims of islamic law\":[271.17695963991,-433.73306154345045],\"mccourt school of public policy\":[304.265507587945,304.6779052801853],\"media circus\":[-306.4817284044487,-287.9339353371159],\"median voter theorem\":[316.4061277140896,215.09734484427918],\"mediations (journal)\":[303.5466137065383,114.45328547833482],\"menstruation in islam\":[281.6771194028594,-517.4385884937706],\"michael l. gross (ethicist)\":[279.7110701034684,122.39701640235248],\"michael thrasher\":[251.1418292184526,411.3126803792504],\"microgeneration\":[41.775279251498965,-75.16468677187123],\"might makes right\":[-439.6275288778912,-19.21673022282555],\"militarized interstate dispute\":[93.0778134063952,-151.78607804058154],\"military policy\":[166.79215484749895,189.27099739496748],\"minimal effects hypothesis\":[287.69549795464246,119.03166116229096],\"ministry of housing and works (pakistan)\":[556.3880960380936,-681.2286428754095],\"ministry of infrastructure (ukraine)\":[142.33447529671926,189.20105111594296],\"ministry of infrastructure and water management\":[310.6163201180657,-313.10778532547266],\"ministry of land, infrastructure, transport and tourism\":[532.4273294101009,-609.8182780827347],\"ministry of magic\":[-361.10955094932814,-86.0989031806433],\"moderation theory\":[363.6188843396013,252.639053479291],\"modern liberalism in the united states\":[-179.84189871840303,160.61505610270422],\"molon labe\":[-250.08493493996383,41.7132303456788],\"muhammad taqi usmani\":[315.5880557114849,-481.3584598309368],\"multi-level governance\":[198.201096239429,73.45499927719003],\"multiliteracy\":[1717.6825862696055,-1014.7957934360821],\"multistakeholder governance\":[68.11410776908991,-291.4848263063571],\"murfee\":[-1674.5526729763935,-1210.8581783832794],\"music and political warfare\":[-356.39344457948624,-162.50843800322184],\"nancy program\":[36.700673981663904,-9.337548718989837],\"nanosocialism\":[-287.2099065563097,196.8067244206108],\"nation state\":[-150.8288497988844,-68.01945434680778],\"nation-building\":[-173.87798575462605,-172.3028698993922],\"national agrarian party\":[-346.837528952584,-11.301179592517805],\"national communism\":[-385.24892797215296,61.63396301590047],\"national conservatism\":[-278.0833998148962,15.388641944202424],\"national crime victimization survey\":[817.2018258808247,-118.9289077249027],\"national forum (georgia)\":[2058.0390024669796,413.2492506912503],\"national liberalism\":[-169.51052210804235,58.25205457002278],\"national power\":[-20.856504563639884,-91.27478564343252],\"national question (quebec)\":[-1052.3904957721943,2025.9688087005295],\"national student survey\":[124.31182697050005,219.24064783524142],\"nazism\":[-258.7046757472611,-35.33185730873405],\"neil maccormick\":[79.8465103576943,-272.6412273608719],\"neoauthoritarianism (china)\":[-227.6942613222149,66.50139028875289],\"neoclassical liberalism\":[-110.9681980184928,151.05410569145164],\"neosocialism\":[-256.5798488526201,-63.88501735177151],\"new aspects of politics\":[261.0735356459728,-20.8076019139158],\"new left review\":[-380.1747459674031,50.36792585045471],\"new political economy (journal)\":[307.0944437407584,160.76472285034302],\"ngo-ization\":[225.235349750633,-94.62161255171117],\"niamh reilly\":[284.93229240342674,88.89438358909096],\"nicole bacharan\":[306.601458317059,224.34755309124114],\"nigel simmonds\":[85.96218245322206,-271.3821599612676],\"night-watchman state\":[-103.60124525273694,72.76083043637293],\"no war but the class war\":[-364.1181932896351,47.522119128513616],\"no war, no peace\":[258.5645257601608,-233.52251104182886],\"nolan chart\":[-205.84391652824405,32.90354187876061],\"nominate (scaling method)\":[-118.62743081672782,432.5661654003033],\"non-governmental organization\":[189.08082271081568,-127.57404353014408],\"non-interventionism\":[-19.67671361915563,79.35995550273415],\"non-sampling error\":[-31.029314129515484,-516.7658663776753],\"non-state actor\":[215.74193622768342,-214.1064618626125],\"nonkilling global political science\":[329.82046135030674,123.68376131587374],\"nonna mayer\":[280.02476792589977,164.1839570233294],\"nonpartisanism\":[22.785564376892214,-99.02395498409695],\"norman chester\":[216.28386413285543,149.20978016091664],\"notary (catholic canon law)\":[157.660080530194,-346.11830097458636],\"note verbale\":[178.9684201539828,-179.60795658654362],\"nur f\\u00fcr deutsche\":[-315.3238643566278,-132.57142374995135],\"nurturant parent model\":[-2381.2466575684175,127.05324917997847],\"obreption and subreption (catholic canon law)\":[158.79369243327076,-332.4122186185357],\"occupatio\":[92.95843335606355,-250.7982635314252],\"official bilingualism in the public service of canada\":[-1050.0495655747623,2029.2157282207768],\"oligarchy\":[-181.66579902973902,-78.73045045371353],\"oliver lepsius\":[143.2292100658347,-310.44146208949144],\"olivier ihl\":[95.90471873446982,104.30589171632487],\"on the principles of political economy and taxation\":[-618.0180446925549,514.3637300686478],\"one man, one vote\":[-137.0358300017658,-275.2900746738627],\"one-party state\":[-285.2619635792914,-47.4991612502083],\"open energy system databases\":[380.2933890512845,-277.44268941084295],\"open philanthropy (doctrine)\":[-839.3609432051296,-1877.8533030122876],\"opinion leadership\":[-179.77425045776067,-279.49311051587426],\"opinion poll\":[-9.78295304085056,-523.3461486842859],\"ordoliberalism\":[-202.99102863035912,131.23116255509547],\"organicism\":[-292.4193826560985,25.413927022784257],\"oryx and crake\":[-406.4291877233362,-282.73152254566486],\"otto kirchheimer\":[106.30417577878883,-86.93009177581858],\"outline of anarchism\":[-216.05191248812147,199.41682347498175],\"overlapping consensus\":[-2183.5102562461666,-260.2044226728391],\"overview of 21st-century propaganda\":[-333.00428618819797,-256.76878685705844],\"paid survey\":[-36.672626404573556,-628.7945781186953],\"pakistan public works department\":[549.1978715974141,-650.1836625497713],\"pal lahara state\":[285.14763566819596,74.30669305155129],\"parallel state\":[288.22107437556576,105.87347509042507],\"parliamentary debate\":[12.823880944534466,-410.7511940957889],\"parliamentary procedure\":[-4.064440827923671,-439.20855347534626],\"parochial political culture\":[623.9813229878954,397.43657479533954],\"parochialism\":[439.69709585827337,-96.93988198252784],\"participism\":[-216.16284871551585,182.06493720688795],\"particracy\":[-126.47724246789213,-91.24869501979163],\"party identification\":[113.5488839778574,-188.91328495879762],\"party platform\":[25.124003827107863,-5.445196189932977],\"party political broadcast\":[5.964564730190207,-253.8008136048625],\"party system\":[-16.871740863080618,-1.3005381152061273],\"passing on the right\":[200.05728622458307,155.40244009921653],\"patient participation\":[197.04342137395702,256.76486224764545],\"paul van riper (political scientist)\":[198.18838196652783,111.77544984477566],\"peace and conflict studies\":[160.63849170457948,9.137617433208476],\"peace dividend\":[184.95103893812185,241.80665615577112],\"peace journalism\":[71.05142428295629,26.125560446258714],\"peace through strength\":[133.28509350208466,-151.24057026892248],\"peace\\u2013industrial complex\":[227.53095765444573,35.3731749637464],\"peelian principles\":[724.8839960450774,-152.49248887700873],\"pensions crisis\":[106.27800921496389,2084.5571782482816],\"people's democracy (marxism\\u2013leninism)\":[-401.8393714982825,44.26375688682743],\"perestroika\":[-338.2711444311917,-33.46806998293927],\"perestroika movement (political science)\":[-36.94623243449511,38.641532490048355],\"perpetual war\":[-178.2658745274345,-96.68115061874445],\"personhood\":[30.454428610834427,26.010209517230553],\"peruvian nitrate monopoly\":[-662.3469159912739,-318.7529145989165],\"petition of right\":[518.6513069832172,-308.4414117130795],\"petitions of right (ireland) act 1873\":[547.4565218989865,-341.54538619692664],\"philip converse\":[393.1211422815557,56.01449667268114],\"philip oxhorn\":[272.9144163665563,103.70183249080117],\"phillip blond\":[-689.4401235389316,217.5367680673131],\"philosophy, theology, and fundamental theory of catholic canon law\":[129.03251306792944,-303.06144836610775],\"pi sigma alpha\":[292.60561101454834,108.61569575795863],\"pickens plan\":[39.32792368658681,12.125524348793807],\"pilar calveiro\":[283.7606764661435,122.27270007334003],\"pippa norris\":[137.87420024626422,78.06027782684104],\"plenary power\":[304.08436779207517,-321.5780850248783],\"plurinationalism\":[-307.771824512305,1.5259033648440572],\"polarized pluralism\":[295.45661606281624,96.60609605287559],\"policy sciences\":[-32.54519402522201,-2840.2664506483543],\"policy studies journal\":[310.59799122949175,107.96031125775355],\"politeia (journal)\":[209.81484329514552,125.30415099059859],\"political alienation\":[283.66825003773107,108.05179829765355],\"political cartoon\":[-139.53822504198547,202.8252100782256],\"political communication\":[79.07694830967517,-4.417961633611353],\"political criticism\":[101.31722287017888,-12.159275715744005],\"political culture of germany\":[614.858075641443,389.8709777771647],\"political culture of the united states\":[633.6746717671726,408.15992579796466],\"political geography (journal)\":[272.01911846647965,88.920676533176],\"political groups of the european parliament\":[235.47968847535543,-26.4572174559956],\"political jurisprudence\":[3.1177453836028626,-132.03163604413254],\"political man\":[405.2728328774808,159.76325944024867],\"political methodology\":[310.6277808359525,114.37139291171955],\"political party\":[50.83882568309036,-159.181282451698],\"political repression\":[-336.76940751732985,7.898411865561366],\"political research associates\":[-257.1865615773324,12.591436958297368],\"political science\":[228.82194002892598,83.39856451809224],\"political socialization\":[-343.1481353261903,-229.3823425424534],\"political studies (journal)\":[213.72271995040734,216.4447148991873],\"political studies association\":[173.05402576745482,272.40700385160716],\"political studies review\":[42.96535444468467,253.7228973210398],\"politico-media complex\":[-18.72332831206878,-168.93884627896352],\"politics (academic journal)\":[220.10509559787727,215.50370673910007],\"politics of memory\":[1511.6358636243467,-1348.190368943074],\"politics, philosophy & economics\":[288.6521164157459,100.40399305951003],\"politique africaine\":[278.7088517823445,98.21945801985868],\"polyarchy\":[-96.23971973023055,-22.045598457136546],\"popular socialism\":[-294.90936076259425,211.17868847837826],\"populism\":[-147.1273400170259,0.7708497846269231],\"pork barrel\":[390.1356767613286,-83.56917365009838],\"post-behavioralism\":[424.68889402052247,61.226513361648394],\"post-politics\":[-105.56584508986212,-3.0845343799262044],\"post-truth politics\":[-233.5165212715762,-331.077059596491],\"postfunctionalism\":[229.50330927005265,-7.194391429677545],\"postinternationalism\":[174.62492807232755,-105.01469930694816],\"power-to-x\":[55.205868213840006,-36.27857349130451],\"powering past coal alliance\":[312.35665697803694,-226.07041730246388],\"prague conference\":[-353.349951885253,-228.94101454478132],\"praxis: the fletcher journal of human security\":[298.5011538299661,74.17699866986149],\"prediction market\":[68.47164049024343,-364.22631068084746],\"predictive policing\":[233.44489466750798,-300.35908047105204],\"preselection\":[81.03837177668072,15.053382286371967],\"present age\":[-1699.7868814779672,1061.0465449220112],\"primakov readings\":[303.5154872047264,-113.27266322251499],\"princeton school of public and international affairs\":[233.57962423911158,197.4338091060795],\"principle of inalienability of the public domain\":[1882.4501773594602,-907.8113936101096],\"principle-policy puzzle\":[298.78780387958346,87.7599201159943],\"principles of political economy\":[-491.1877818245299,354.98946821563123],\"principles of political economy (malthus book)\":[-585.6482173591372,471.7280390360251],\"print capitalism\":[280.4322351404214,77.06457697797035],\"private military company\":[117.6158361959105,122.95639120065638],\"private property\":[-228.70483203276956,131.99563848247442],\"priya kurian\":[299.3708464985352,95.32458391438549],\"proactive law\":[1770.620400391001,-956.5522176156255],\"proactive policing\":[729.6280955795746,-158.40670442464045],\"problem-oriented policing\":[731.9079132241586,-149.1464827214741],\"proclamation by the crown act 1539\":[540.7503668276654,-341.2308460512722],\"prohibition of dying\":[831.6811795481093,-1916.4043782014196],\"proletarian nation\":[-297.9364246432906,-78.81304307259832],\"proletarian revolution\":[-385.32385267759497,128.4701150471284],\"promulgation (catholic canon law)\":[151.40157414869412,-347.71432455347326],\"propaganda\":[-304.6736710077652,-187.8190726382308],\"proposed national unification promotion law\":[-283.0187843841988,-231.3598001364176],\"proprietary community\":[-75.51634655665602,241.81014163302098],\"public administration\":[152.96731581366427,95.48970360320256],\"public affairs quarterly\":[2279.389972361703,258.12946785628753],\"public budgeting\":[155.87516974069854,-32.96103555258528],\"public comment\":[496.34303072986216,-2142.4832217510566],\"public consultation\":[-282.2194597000679,-64.54651781129263],\"public engagement\":[-270.2288251749899,-356.6578688534182],\"public image of cristina fern\\u00e1ndez de kirchner\":[-164.00969876503754,202.0985169893868],\"public image of narendra modi\":[-261.3528028917275,43.82829345294405],\"public opinion and activism in the terri schiavo case\":[-2060.6707445748616,606.1680173633207],\"public opinion on climate change\":[266.8834529967254,-330.6405244398429],\"public opinion on nuclear issues\":[305.7211058732345,-362.23241625409366],\"public opinion quarterly\":[103.81127810794014,-394.01403399361214],\"public policy doctrine\":[99.32400352528478,127.56363264840209],\"public policy school\":[230.18649380405486,233.0435032901871],\"publicity stunt\":[-337.8619868998567,-338.16474863431097],\"qazi syed inayatullah\":[310.2165673773714,-471.67059429183496],\"quadrilateral security dialogue\":[228.05013163334388,-211.92837910076324],\"radical egalitarianism\":[-388.3166176038338,283.37272200989514],\"raisons politiques\":[288.12982423079944,159.56043557524632],\"ralph borsodi\":[-771.0933920375296,-2485.18116247018],\"rasma k\\u0101rkli\\u0146a\":[300.3991201347216,64.86185546762017],\"ratification\":[-39.321827116113404,-390.329181882051],\"reactionary\":[-218.8412090330797,11.067974585807308],\"real socialism\":[-344.91778222176544,95.50703222404341],\"red wall (us politics)\":[652.4110647639973,429.5645323906913],\"regional autonomy\":[-168.86064403244202,-125.8930581163742],\"regional hegemony\":[-80.72780315696147,-125.93300196196105],\"regional power\":[-96.7408464611303,-100.6978911039984],\"regionalisation\":[1775.781755034792,1060.008308123935],\"regionalism (international relations)\":[151.03286273028996,-129.24036493122466],\"regulation of science\":[19.353100278569915,-61.435068017663674],\"regulatory competition\":[62.007022155418376,-25.473141277440213],\"regulatory economics\":[145.15029539254297,-174.04617743437112],\"reichsministerium des innern\":[335.3459847487834,-115.27853686723564],\"relative gain (international relations)\":[169.48561296318692,-97.35283566896437],\"religious communism\":[-403.4129236307611,141.54724981855034],\"religious socialism\":[-352.3023615288511,203.46980599307608],\"rena dourou\":[169.7134628168285,67.94232140377946],\"renewable energy transition\":[119.21495245240324,-180.8017824905291],\"rent extraction\":[295.6764229990395,-78.57796969743295],\"rent-setting\":[294.41752273165093,-68.53486625199244],\"rentier state\":[266.6348767220107,118.72069760377205],\"res publica christiana\":[32.492688844811035,-283.70767145101814],\"research excellence framework\":[125.94659621823983,213.67388221850112],\"resource conservation and recovery act\":[326.68728668159594,-423.1572309586821],\"responsibility to protect\":[140.37922198807414,-99.86516860249127],\"revealed preference\":[-130.36853950465783,3422.784747830068],\"review of international political economy\":[286.37349454133187,177.5033747845608],\"revolutionary students federation\":[1898.7438385652206,1626.843396869308],\"revolutions of 1989\":[-356.64737080203065,14.9195650409475],\"right to exist\":[-157.32195245656862,-202.44492638940625],\"right to the city\":[-467.6736934512493,36.62867622251039],\"right-wing politics\":[-220.00569494592597,43.35422475484586],\"risk, hazards & crisis in public policy\":[281.2090685185537,113.74573613953174],\"rivers state civil service\":[328.92213232917527,-116.56631045648511],\"robert christison\":[-2123.41550154376,1670.63708615304],\"robert f. wagner graduate school of public service\":[284.1393254810798,227.22319829211605],\"robert kent gooch\":[277.9019114897606,86.26605807102112],\"robert m. la follette school of public affairs\":[202.43508153768283,220.770201930742],\"robin hood effect\":[-1910.4294835764356,-842.472351730522],\"rodney tiffen\":[289.48946815672366,78.14418216990502],\"role ethics\":[-87.54162909396777,-224.34820038188744],\"roman question\":[-164.61876229475712,-120.47843833545105],\"ronen palan\":[118.78430479590185,-47.23804643312215],\"roper center for public opinion research\":[-3.7376776897141157,-568.1245869421608],\"rosa brooks\":[146.7893444409892,-90.50997742363074],\"rosa luxemburg foundation\":[354.54760324825116,-213.90696904001638],\"rowman & littlefield award in innovative teaching\":[229.68798943155986,-72.62843429869153],\"rumor\":[-360.87974166978495,-272.91302820912415],\"sacralism\":[283.4628109876092,94.73309895974056],\"salvador minguij\\u00f3n adri\\u00e1n\":[146.59688171905447,-308.3502677986536],\"sam potolicchio\":[340.589025694221,343.756076878945],\"sanford school of public policy\":[249.45842625658028,238.21593319964495],\"say's political economy\":[1327.719653667332,1614.9821358647257],\"scale analysis (statistics)\":[-124.8278418669827,518.4465931577955],\"schar school of policy and government\":[262.71758068068414,231.71416866457574],\"school of diplomacy\":[-85.46803945641149,-219.8159922280285],\"school of international and public affairs, columbia university\":[246.47678620848103,195.26887488709943],\"school of political and social sciences, unam\":[205.36435619212045,113.72514863802189],\"school of politics and international relations, university of nottingham\":[51.59802715935752,307.82511956786504],\"school of public policy at central european university\":[288.5002318595099,252.17713210550164],\"science & diplomacy\":[103.1554075762444,-48.830637765406294],\"science & society\":[264.5530867100918,114.47490547432203],\"science diplomacy\":[94.8192506454305,-132.72504535101834],\"sciences po\":[254.32624930912377,179.01131106198764],\"scientific man versus power politics\":[217.25681433895684,-106.86136958014981],\"scientocracy\":[-53.38097925758681,-87.31094190656522],\"scotland's future\":[115.32024760609484,415.94294407281615],\"secession\":[-164.22073004977108,-160.80302601874178],\"second-order election\":[312.0371794408603,77.93969440480654],\"security of tenure\":[285.12639907619445,126.39141626963055],\"security sector governance and reform\":[185.44797264667525,-149.75717642314777],\"security studies\":[288.95346549172973,-1.0322153094067916],\"security studies (journal)\":[295.61146013773805,-13.866452676833337],\"security, territory, population\":[1.524203749586341,-1.6858653735544176],\"seek truth from facts\":[-402.4420569767167,22.98554913943531],\"selectorate theory\":[94.5034909373451,-159.62831528988897],\"serfdom in tibet controversy\":[1914.0143919465386,-755.8157598782493],\"sexual jihad\":[270.8881116622787,-517.6475476131582],\"singleton (global governance)\":[-38.2786250835242,221.6269747940824],\"siobhan o'sullivan\":[219.88954573839004,20.191679627873153],\"situationist international\":[-330.23420702133245,139.81632567674976],\"slapsoftware\":[235.8481297162914,295.5645296465065],\"slogan\":[-328.5864121269842,-326.1460093286333],\"small government\":[-139.24771510895343,112.12277067983861],\"small media, big revolution\":[297.6331220947655,70.33060328079186],\"small office/home office\":[2017.2109325888073,-1716.4486058307718],\"social conservatism\":[-293.0292171022789,92.51754196349053],\"social corporatism\":[-320.23967171325444,154.15115831977266],\"social impact entertainment\":[1090.1520439630115,-1742.3181214853926],\"social imperialism\":[-319.28255649102323,49.707650396148786],\"social liberalism\":[-186.1948605925365,134.86302443225296],\"social media in the 2016 united states presidential election\":[-28.077790408518442,-273.59182128168345],\"social media in the 2020 united states presidential election\":[-31.697853002695584,-325.6567662851196],\"social media use by donald trump\":[42.124136434441816,-192.79470654782523],\"social media use in african politics\":[60.30868525454512,-245.51084360311864],\"social media use in politics\":[54.01778683202105,-196.2802669137046],\"social patriotism\":[-234.81445362741405,83.18420060557516],\"social policy\":[123.90274902363433,144.308989085599],\"social welfare in luxembourg\":[-1270.119863766375,-1600.01434016856],\"socialist campaign group\":[-685.327085730653,227.73188330193383],\"socialist realism\":[-327.3708227500061,-68.50736633218614],\"societal attitudes towards abortion\":[-28.825896160367655,45.45206103495453],\"soft despotism\":[-251.9210249520753,-83.34469135969836],\"sophomore surge\":[280.92575494185985,88.98008413974514],\"sovereignty of puerto rico during the cold war\":[-372.6053124995107,-39.59078688872772],\"sovereignty of the philippines\":[56.65300202411853,-268.81997207283234],\"spatial justice\":[-1676.6526670866272,1175.8455028459011],\"spatial politics\":[-235.7910041342384,25.016219960075272],\"special relationship (international relations)\":[-25.153923815773734,-64.6086270346306],\"spin room\":[-171.88647243281625,-265.5304802766023],\"squirrel (debate)\":[22.713481175499112,-460.0686571538053],\"stakeholder (corporate)\":[327.5537195138074,-2025.5297203401096],\"state decoration\":[-357.8112713254669,2528.1567902350666],\"state order\":[-363.49901603142115,2527.5139512654955],\"statecraft (political science)\":[304.4445437952516,108.98098517922168],\"statism\":[-170.02417217390487,-20.92914922573419],\"status quo state\":[1.1219749738305673,-168.56514260576924],\"stein rokkan\":[99.88650588248393,94.54676454446813],\"stephanos bibas\":[40.355904578647475,-343.1948816918215],\"stephen barber\":[283.50677847550554,103.89503149192767],\"steven b. smith (professor)\":[298.37192723002073,82.838035194799],\"strategy of tension\":[-280.5875573555894,-318.34887527262],\"strict father model\":[-2384.7825729917854,128.9897960202858],\"subsidy\":[62.90841320475653,-2532.8555312642698],\"successor ideology\":[-250.76662876712714,3.903956577409158],\"superpower collapse\":[-154.9721353884555,-127.12828507897963],\"supreme court of justice of colombia\":[2056.006111653661,566.8807945756714],\"survey data collection\":[-35.08049214535376,-551.5052353711297],\"svetlana tatunts\":[174.7006699789587,61.041836007136496],\"svoboda ili smart\":[-192.5172364017605,-229.68620950294465],\"swiss neutrality\":[1.1718613594055094,119.48779597267064],\"syed hayatullah\":[306.03805479223644,-476.1046329301014],\"synarchism\":[-216.62315495947138,-119.95446337600251],\"systems theory in political science\":[296.86809783775834,-46.122543022529946],\"tactical voting\":[41.34201089452687,-267.0878664110072],\"taftian theory\":[109.77968009160793,58.95102487150484],\"technocracy\":[-98.83706079308048,21.52809451833938],\"technoliberalism\":[-163.19379229982064,193.26037933634825],\"territorialisation of carbon governance\":[247.84136006305735,53.199327931553825],\"terry karl\":[216.49029742007815,33.42049896467365],\"thawri\":[278.9579681646825,-453.4529302886123],\"the birth of biopolitics\":[13.836562250997972,72.28305799313293],\"the castle (novel)\":[-1314.8374539204474,1711.7809860164627],\"the civic culture\":[594.2139176559746,375.20470683390204],\"the crisis of democracy\":[39.80112085161234,44.55258102154404],\"the democratic paradox\":[1742.1286881742592,-1113.3181957604477],\"the end of liberalism\":[294.69410420773403,78.2286564279771],\"the engineering of consent\":[-348.02710190123105,-230.6595681611656],\"the establishment (pakistan)\":[-202.65335847891546,-140.02882189403547],\"the final days (2000 film)\":[114.79972128879213,60.5555170820774],\"the good society\":[283.5595142178571,116.82453318697729],\"the good soldier \\u0161vejk\":[961.4785250643389,-2270.7687333020767],\"the great transformation (book)\":[-45.1918363564415,132.15611787819745],\"the hidden hand: middle east fears of conspiracy\":[282.7543984831784,129.59541572217015],\"the independent review\":[138.08244069527456,163.23193691013495],\"the indian struggle\":[-285.97332169577595,-110.73799656298324],\"the journal of political philosophy\":[-345.0651439557861,298.4175862469018],\"the journal of politics\":[145.63204969649766,214.02718795356893],\"the machiavellian moment\":[58.89830230594128,86.2001322920841],\"the permanent revolution and results and prospects\":[-72.82614973705724,124.04456986234233],\"the province of jurisprudence determined\":[149.37658190124978,-303.0711299600791],\"the soldier and the state\":[-23.052650263768808,21.10722558557375],\"the triple revolution\":[-73.60844351696389,320.31884921937103],\"the twenty years' crisis\":[250.32394119057275,-125.2958845141362],\"they shall not pass\":[-329.4586007295244,-176.78287427511574],\"third way\":[-188.86040911257413,100.98283374807131],\"third-person effect\":[-259.158550655085,-254.337602241147],\"this machine kills fascists\":[-1584.058494240464,-1265.0199981560413],\"thucydides trap\":[11.35080901977289,-28.808813496200663],\"timeline of voting rights in the united states\":[-85.07571456615028,-317.3562858000121],\"timocracy\":[-237.29727418312544,-120.61226442976516],\"tiocfaidh \\u00e1r l\\u00e1\":[-354.0772059357109,-372.1421740063757],\"tobacco-free pharmacy\":[-1924.076651292576,772.9239801092231],\"total survey error\":[-10.25588067995612,-499.2119721650084],\"totalitarianism\":[-232.65605113528417,-53.8840974483273],\"tractatus politicus\":[-2879.988772478426,-471.7289729676076],\"transformation processes (media systems)\":[179.9142612271724,20.82886737200279],\"transitology\":[313.07624861674816,82.14225496597668],\"transnational progressivism\":[-55.05524655010363,-46.96516447339162],\"triangular diplomacy\":[-198.77038841832888,43.59423084034761],\"tripartite consultation (international labour standards) convention, 1976\":[-40.42173896119141,-439.7477074157953],\"trusteeship (gandhism)\":[293.9082175027686,115.1224195161586],\"tryph\\u00e9\":[335.0040869427396,117.54335880562667],\"twitter diplomacy\":[47.64769585308801,-247.60818585328505],\"two-level game theory\":[289.7968323225144,82.3023074384834],\"tyranny of the majority\":[-233.98015135632116,-18.928509739922745],\"ucla luskin school of public affairs\":[-2206.3496661529603,220.5803970361845],\"uk heo\":[294.01145588717344,87.80969852312828],\"un-energy\":[1211.1276597041694,-1661.8626615020714],\"unearned income\":[1829.3844411726075,-1027.4444591481138],\"united federal workers of america\":[285.093500887329,195.59918342121685],\"united nations office on drugs and crime\":[-50.27302024712424,-344.87135235729517],\"united nations parliamentary assembly\":[102.92509775851919,-105.60794588911477],\"universal basic income\":[-81.11967295288459,264.0361474408184],\"university of chicago institute of politics\":[-260.6136920749804,2134.88497537222],\"university of san diego\":[-1362.27209722169,2019.2593693656115],\"urban legend\":[-331.5086701952624,-269.3410078103404],\"urban village\":[1357.9712466875035,-1527.9451053394148],\"ursula apitzsch\":[-415.81776963829793,-2375.0950702499117],\"usul fiqh in ja'fari school\":[202.6202952692664,-358.0926679666489],\"v-dem institute\":[26.66543702331709,-147.27281042488153],\"vacatio legis\":[164.25513982106975,-341.6307269223159],\"valence issue\":[-107.32776671875004,327.1856552208482],\"valerie bryson\":[1845.1512075118815,-797.3945660725458],\"values modes\":[-70.73459636939734,-418.9763581768411],\"val\\u00e9rie igounet\":[261.20947387359246,124.22419388405314],\"vaticanology\":[563.1802456410036,59.70055635198092],\"victim study\":[862.7701288294992,-108.12176027279894],\"violence peace and peace research\":[90.29691011243074,-156.28631208864255],\"violent non-state actor\":[211.2357764962155,-177.77730592210065],\"violent non-state actors at sea\":[242.39834951964284,-59.474888013325916],\"virtue jurisprudence\":[30.66376672621947,-205.2091212293797],\"vocational panel\":[329.54558369243927,-110.30968764523384],\"voluntary society\":[-86.73177839716222,181.48748110644274],\"voter turnout\":[71.9004133710286,-96.31140506185413],\"voting rights in the united states\":[-47.60628555036544,-290.6575664394059],\"w. meredith bacon\":[269.004300879913,100.97897274013783],\"walter f. dodd\":[385.9693127989014,48.02625748190131],\"warren miller (political scientist)\":[412.7568930774308,47.45789656675392],\"we don't coast\":[-368.42547402934235,-391.0648187781889],\"we shall overcome\":[-1574.9581852054982,1851.136349687963],\"western cape department of transport and public works\":[537.0033909409718,-606.046631397273],\"westphalian sovereignty\":[49.9639393084799,-217.05506279256917],\"whiggism\":[-159.68189752294748,111.75360666636855],\"white paper\":[84.88771836235985,298.5451674308557],\"white power music\":[-320.75474139511743,-33.473735777934216],\"william a. niskanen\":[68.80122662568915,153.71628782008221],\"william james booth\":[288.05711577199656,93.15626843898477],\"wilson\\u2013patterson conservatism scale\":[267.59481026451084,106.65395561134663],\"winner-take-all politics\":[-2280.153172320328,453.9613691315264],\"wisconsin school (diplomatic history)\":[230.07610531866143,284.1070547669856],\"worker cooperative\":[-390.67694587809007,105.62805562735232],\"workplace democracy\":[-313.3661233399731,128.3028857032243],\"world politics\":[209.20489323442024,-8.493818854491021],\"world revolution\":[-410.03175949698544,109.09710329481865],\"world values survey\":[-64.19202087101952,-368.55482925912236],\"worldwide influence of the constitution of the united states\":[235.03643385049025,-265.16422878938545],\"worshipful company of butchers\":[1306.2250088032358,-1559.4720630896238],\"writ\":[274.1559839910723,-428.1768073465622],\"wyn grant\":[228.6053736466245,399.0510262675884],\"xuanchuan\":[-304.1875618240993,-260.82746033798037],\"yehuda zvi blum\":[203.4827797196379,-259.5188910151223],\"yelyzaveta yasko\":[293.5194905353123,180.5134858336712],\"you have two cows\":[-315.1975277781357,-76.00490574335522],\"zombie liberalism\":[-196.89353312855,77.32446845360441],\"\\u00bfpor qu\\u00e9 no te callas?\":[-32.92693623598393,72.96905388121587],\"\\u00e5land islands peace institute\":[200.398688096042,-239.86219793725274],\"\\u00fcmit cizre\":[302.0797854490967,88.90603185555891]}},\"id\":\"1496\",\"type\":\"StaticLayoutProvider\"},{\"attributes\":{},\"id\":\"2670\",\"type\":\"AllLabels\"},{\"attributes\":{\"edge_renderer\":{\"id\":\"1490\"},\"inspection_policy\":{\"id\":\"2685\"},\"layout_provider\":{\"id\":\"1496\"},\"node_renderer\":{\"id\":\"1486\"},\"selection_policy\":{\"id\":\"2676\"}},\"id\":\"1483\",\"type\":\"GraphRenderer\"},{\"attributes\":{},\"id\":\"1474\",\"type\":\"ResetTool\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1455\",\"type\":\"Range1d\"},{\"attributes\":{},\"id\":\"2701\",\"type\":\"NodesOnly\"},{\"attributes\":{},\"id\":\"2704\",\"type\":\"UnionRenderers\"}],\"root_ids\":[\"2599\"]},\"title\":\"Bokeh Application\",\"version\":\"2.3.2\"}};\n",
       "  var render_items = [{\"docid\":\"c6a9d662-5601-4411-994d-bbd296e617fa\",\"root_ids\":[\"2599\"],\"roots\":{\"2599\":\"1a2ecd43-a87d-4925-af88-bb27ed642fc4\"}}];\n",
       "  root.Bokeh.embed.embed_items_notebook(docs_json, render_items);\n",
       "\n",
       "  }\n",
       "  if (root.Bokeh !== undefined) {\n",
       "    embed_document(root);\n",
       "  } else {\n",
       "    var attempts = 0;\n",
       "    var timer = setInterval(function(root) {\n",
       "      if (root.Bokeh !== undefined) {\n",
       "        clearInterval(timer);\n",
       "        embed_document(root);\n",
       "      } else {\n",
       "        attempts++;\n",
       "        if (attempts > 100) {\n",
       "          clearInterval(timer);\n",
       "          console.log(\"Bokeh: ERROR: Unable to run BokehJS code because BokehJS library is missing\");\n",
       "        }\n",
       "      }\n",
       "    }, 10, root)\n",
       "  }\n",
       "})(window);"
      ],
      "application/vnd.bokehjs_exec.v0+json": ""
     },
     "metadata": {
      "application/vnd.bokehjs_exec.v0+json": {
       "id": "2599"
      }
     },
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "\n",
       "  <div class=\"bk-root\" id=\"6fdd0e64-ca17-4969-b122-42121c1f08d7\" data-root-id=\"1521\"></div>\n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "(function(root) {\n",
       "  function embed_document(root) {\n",
       "    \n",
       "  var docs_json = {\"4176f86f-d8de-4ae3-a326-5e3b28a22eec\":{\"defs\":[],\"roots\":{\"references\":[{\"attributes\":{\"above\":[{\"id\":\"1547\"}],\"below\":[{\"id\":\"1528\"}],\"center\":[{\"id\":\"1531\"},{\"id\":\"1535\"}],\"height\":500,\"left\":[{\"id\":\"1532\"}],\"renderers\":[{\"id\":\"1548\"}],\"title\":{\"id\":\"3573\"},\"toolbar\":{\"id\":\"1541\"},\"width\":500,\"x_range\":{\"id\":\"1519\"},\"x_scale\":{\"id\":\"1524\"},\"y_range\":{\"id\":\"1520\"},\"y_scale\":{\"id\":\"1526\"}},\"id\":\"1521\",\"subtype\":\"Figure\",\"type\":\"Plot\"},{\"attributes\":{},\"id\":\"1537\",\"type\":\"WheelZoomTool\"},{\"attributes\":{},\"id\":\"3592\",\"type\":\"Selection\"},{\"attributes\":{\"callback\":null,\"tooltips\":[[\"Page\",\"@index\"]]},\"id\":\"1540\",\"type\":\"HoverTool\"},{\"attributes\":{},\"id\":\"1538\",\"type\":\"SaveTool\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1519\",\"type\":\"Range1d\"},{\"attributes\":{\"fill_alpha\":{\"field\":\"alpha\"},\"fill_color\":{\"field\":\"node_colour\"},\"size\":{\"field\":\"node_sizes\"}},\"id\":\"1574\",\"type\":\"Circle\"},{\"attributes\":{},\"id\":\"3580\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{\"source\":{\"id\":\"1554\"}},\"id\":\"1556\",\"type\":\"CDSView\"},{\"attributes\":{\"data\":{\"alpha\":[0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75],\"depth\":[1,1,2,2,2,1,2,1,1,1,1,2,2,2,1,2,1,1,2,1,2,2,2,1,1,1,1,1,2,1,2,1,2,1,2,2,2,1,2,1,2,1,1,1,2,2,2,1,1,2,1,2,1,1,2,2,1,1,1,1,1,1,1,1,1,2,1,2,2,1,2,1,2,1,2,2,1,1,2,2,1,1,1,2,2,2,1,1,1,1,2,2,2,1,1,2,2,1,1,2,1,1,2,2,1,2,2,1,1,2,2,2,1,2,1,1,1,1,1,2,1,1,1,2,2,1,1,2,2,2,1,1,1,2,2,1,1,1,1,2,1,2,2,1,2,1,1,2,1,2,2,1,2,2,1,2,1,1,1,2,1,2,1,1,1,2,1,1,1,2,2,1,2,2,2,1,1,2,1,1,1,1,2,1,2,1,1,1,1,1,1,2,2,2,1,1,2,2,1,2,2,2,1,2,1,2,2,2,1,1,2,1,2,1,1,1,1,2,2,1,1,2,2,2,1,2,2,2,2,2,1,2,1,2,1,1,1,1,1,2,2,1,1,2,2,2,1,2,1,2,1,1,2,2,1,1,2,2,1,2,2,1,1,1,2,2,1,2,1,1,1,2,2,1,1,1,1,1,2,1,1,2,1,1,2,1,1,1,1,1,2,1,2,1,1,2,2,2,1,1,1,1,2,1,1,2,1,1,1,1,2,1,2,1,1,1,1,1,1,2,1,2,2,1,1,2,2,1,2,1,1,1,2,1,1,2,2,1,1,2,1,2,2,2,2,2,2,1,2,2,1,1,1,1,1,1,2,1,1,2,1,2,1,2,2,1,1,1,1,1,2,1,1,2],\"index\":[\"christian fuchs (sociologist)\",\"ren\\u00e9-k\\u00f6nig-gesellschaft\",\"kurt heinrich wolff\",\"summerhill (book)\",\"cooper do-nuts riot\",\"ideology\",\"culturgen\",\"field theory (sociology)\",\"status attainment\",\"sociologists without borders\",\"german sociological association\",\"queer ecology\",\"the american journal of economics and sociology\",\"ecolabel\",\"social situation in the french suburbs\",\"journal of sociology\",\"sociology of manchester\",\"social conflict\",\"xeira\",\"reality distortion field\",\"women's week provincetown\",\"franz oppenheimer\",\"daphne dorman\",\"substitutes for leadership theory\",\"preference theory\",\"mudsill theory\",\"religious literacy\",\"generosity\",\"science as a vocation\",\"sociological positivism\",\"sex and gender distinction\",\"computational sociology\",\"digital ecosystem\",\"social organism\",\"family disruption\",\"time & society\",\"richard rottenburg\",\"iron cage\",\"viola klein\",\"person of color\",\"doncaster pride\",\"modernity\",\"hypodermic needle model\",\"responsibility\",\"ecomodernism\",\"delmos jones\",\"historical sociology\",\"oppression\",\"status\\u2013income disequilibrium\",\"sociology of scientific ignorance\",\"social phenomenon\",\"ernst borinski\",\"antipositivism\",\"value judgment\",\"development-supported agriculture\",\"silence=death project\",\"social invisibility\",\"social vulnerability\",\"occupational closure\",\"state of affairs (sociology)\",\"social order\",\"social geometry\",\"civic virtue\",\"reductionism\",\"injustice\",\"garden of allah (cabaret)\",\"online research methods\",\"list of countries by labour force\",\"marxist sociology\",\"tschandala\",\"attention economy\",\"sociologists for women in society\",\"greenwashing\",\"recuperation (politics)\",\"concession (contract)\",\"list of bordering countries with greatest relative differences in gdp (ppp) per capita\",\"social actions\",\"matrix of domination\",\"performative activism\",\"porter hypothesis\",\"chicago school (sociology)\",\"necropolitics\",\"social model of disability\",\"nw 39th street enclave\",\"bioregionalism\",\"martine-anstett award\",\"middle-range theory (sociology)\",\"pay it forward\",\"symbolic power\",\"friendly fascism (book)\",\"list of scientific occupations\",\"communist correspondence committee\",\"theory of change\",\"norwegian sociology canon\",\"social experiment\",\"organizational adaptation\",\"werturteilsstreit\",\"sociological naturalism\",\"analytical sociology\",\"rajputisation\",\"davis\\u2013moore hypothesis\",\"mesosociology\",\"alva myrdal\",\"sociology of the world religions\",\"bioculture\",\"globalization and women in china\",\"control (management)\",\"international sociological association\",\"microsociology\",\"social service review\",\"ecological imperialism\",\"julia's on broadway\",\"backlash (sociology)\",\"material flow analysis\",\"performative interval\",\"social system\",\"feminist theory\",\"life-process model of addiction\",\"racial threat\",\"urban metabolism\",\"agency (sociology)\",\"mapping controversies\",\"index of sociology articles\",\"sustainability standards and certification\",\"food bank\",\"adaptive capacity\",\"dynamic density\",\"moor's head (heraldry)\",\"capital (marxism)\",\"right to development\",\"post-work society\",\"market-dominant minority\",\"law of the jungle\",\"sustainable development goal 12\",\"carmen a. mir\\u00f3\",\"analytic frame\",\"informal social control\",\"protest cycle\",\"openness\",\"renata salecl\",\"passing (sociology)\",\"sustainable development goal 14\",\"eviatar zerubavel\",\"label (sociology)\",\"the protestant ethic and the spirit of capitalism\",\"social complexity\",\"social construction of the body\",\"medical sociologist\",\"social balance theory\",\"medicalization\",\"anti-gender movement\",\"clustering (demographics)\",\"global social policy\",\"black eagle (montreal)\",\"blacklisting\",\"sustainable business\",\"ferdinand t\\u00f6nnies society\",\"analytic induction\",\"contest mobility\",\"blue justice\",\"humanistic coefficient\",\"scare\",\"figurational sociology\",\"international political sociology (ips)\",\"mass action (sociology)\",\"agonism\",\"collective mental state\",\"humanistic sociology\",\"bibliography of sociology\",\"verbal self-defense\",\"gochisosama\",\"list of sociology journals\",\"discrimination against autistic people\",\"demonstration effect\",\"communal reinforcement\",\"social rights (social contract theory)\",\"taste (sociology)\",\"requisite organization\",\"weighted network\",\"sociology in poland\",\"science in action (book)\",\"racial literacy\",\"alphons silbermann\",\"radicalization\",\"payment for ecosystem services\",\"correspondence principle (sociology)\",\"list of sociologists\",\"greatness\",\"structuration theory\",\"social revolution\",\"comparative historical research\",\"lowell l. bennion\",\"gender essentialism\",\"quiet revolution\",\"double hermeneutic\",\"generative actor\",\"games for change\",\"sustainable development goal 11\",\"ideal type\",\"natural capital\",\"encyclopedia of women and islamic cultures\",\"the lexus and the olive tree\",\"normalization process theory\",\"sustainable energy\",\"social threefolding\",\"resource justice\",\"noel ignatiev\",\"list of countries by inequality-adjusted income\",\"sociology of punishment\",\"new social movements\",\"nonprofit and voluntary sector quarterly\",\"structural inequality\",\"ecofeminism\",\"instrumental and value rationality\",\"indian sociological society\",\"social death\",\"group threat theory\",\"elihu katz\",\"the state (book)\",\"structural violence\",\"black tax\",\"critique of modernity\",\"sissyphobia: gay men and effeminate behavior\",\"energy research & social science\",\"performativity\",\"organigraph\",\"population and development review\",\"randy david\",\"eugen relgis\",\"instrumentalism\",\"groupism\",\"philosophy of max stirner\",\"norwegian sociological association\",\"flourish of approval\",\"index of sociopolitical thinkers\",\"authority (sociology)\",\"base and superstructure\",\"people power\",\"action theory (sociology)\",\"organizational space\",\"numbers (vancouver)\",\"agency (philosophy)\",\"reflexivity (social theory)\",\"suzanne kessler\",\"collective memory\",\"civil discourse\",\"emotive (sociology)\",\"air rights\",\"public morality\",\"p\\u0131nar selek\",\"european sociological association\",\"instrumental and intrinsic value\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"saskia wieringa\",\"consumption (sociology)\",\"manifest and latent functions and dysfunctions\",\"conflict resolution research\",\"entitlement\",\"group action (sociology)\",\"degrowth\",\"ipse dixit\",\"social reproduction\",\"sociological imagination\",\"total institution\",\"contemporary jewry\",\"civility\",\"collective effervescence\",\"programme for economic advancement and community empowerment\",\"social reality\",\"relational sociology\",\"identity (social science)\",\"das argument\",\"revisionist school of islamic studies\",\"instrumental and value-rational action\",\"moral entrepreneur\",\"grave candle\",\"value-added theory\",\"indian economic and social history review\",\"matrix management\",\"visible minority\",\"doing gender\",\"delegated authority\",\"organizational theory\",\"social multiplier effect\",\"list of countries by share of income of the richest one percent\",\"vulnerable adult\",\"sociotechnology\",\"private sphere\",\"structure and agency\",\"structural discrimination\",\"research in social stratification and mobility\",\"interactionism\",\"sustainable development goal 17\",\"policy sociology\",\"new york state sociological association\",\"archery\",\"the culture of narcissism\",\"john murray cuddihy\",\"outline of globalization\",\"average joe\",\"reflexive modernization\",\"safety-valve institution\",\"norwegian journal of sociology\",\"norm entrepreneur\",\"control theory (sociology)\",\"west pride\",\"quantitative research\",\"heterosociality\",\"island mentality\",\"immigrant-host model\",\"the revolution of everyday life\",\"freedom\",\"roman agrarian history and its significance for public and private law\",\"vertical mobility\",\"dyad (sociology)\",\"duality of structure\",\"procreative beneficence\",\"intergroup anxiety\",\"sociology of morality\",\"gender and development\",\"blau space\",\"angst und vorurteil\",\"organization & environment\",\"social integration\",\"social organization\",\"impeachment\",\"the morals of chess\",\"hobbesian trap\",\"word gap\",\"assortative mixing\",\"leipzig school (sociology)\",\"ressentiment\",\"symbol\",\"sociological insight\",\"institutional trust (social sciences)\",\"astrosociology\",\"peer pressure\",\"secondary deviance\",\"memory space (social science)\",\"work, employment & society\",\"life chances\",\"argument from authority\",\"complex adaptive system\",\"journal of lesbian studies\",\"environmental racism in the united states\",\"rogers brubaker\",\"morphological freedom\",\"social rule system theory\",\"civilian-based defense\",\"political journalism\",\"science capital\",\"akademie f\\u00fcr soziologie\",\"anti-modernization\",\"asabiyyah\",\"sociology in japan\",\"obshchestvovedeniye\",\"center on conscience & war\",\"social transformation\",\"imagery of nude celebrities\",\"argument from marginal cases\",\"concentrated disadvantage\",\"chua beng huat\",\"index of urban sociology articles\",\"obscurantism\",\"anti-gender campaigns in europe\",\"social risk positions\",\"fragmentation (sociology)\",\"strategic choice theory\",\"symbolic religiosity\",\"resocialization\",\"sustainability and environmental management\",\"tripartite classification of authority\",\"l'ann\\u00e9e sociologique\",\"knowledge of the holocaust in nazi germany and german-occupied europe\"],\"node_colour\":[\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\",\"#5BC862\"],\"node_sizes\":[0.25,0.25,0.25,0.25,1.0,4.75,0.25,0.75,0.75,0.0,0.25,1.0,0.5,1.0,0.0,0.25,0.0,1.25,0.0,0.0,0.25,0.75,0.0,0.0,0.0,1.0,0.25,0.5,1.75,4.75,1.5,1.5,0.25,0.0,0.25,0.0,0.0,2.25,0.25,0.5,0.0,2.25,0.25,1.25,1.0,0.25,2.75,3.5,0.0,2.75,1.25,0.25,4.0,0.75,0.0,0.0,0.5,0.0,0.25,0.0,1.5,0.25,1.0,2.5,1.25,0.5,0.0,0.0,2.0,0.25,0.0,0.0,1.5,0.25,0.0,0.0,2.5,0.25,0.25,0.0,0.25,0.5,1.5,0.0,0.0,0.0,0.25,0.75,0.5,0.25,0.0,0.0,0.0,0.0,11.5,0.5,2.25,0.75,0.25,0.0,0.25,0.25,0.75,1.75,0.25,0.25,0.5,2.75,1.25,0.25,0.25,0.75,0.0,1.0,0.25,4.25,2.0,0.0,0.25,1.25,1.5,1.75,9.0,0.25,0.25,0.25,0.0,0.25,0.25,0.0,0.0,0.0,0.0,0.0,0.0,0.5,0.25,0.25,0.5,0.0,0.0,0.0,0.25,0.0,2.75,11.75,0.0,1.25,0.25,1.0,1.75,0.0,0.0,0.25,1.25,0.25,0.25,0.25,0.5,0.0,0.25,0.0,1.0,0.0,0.5,0.0,1.0,1.0,2.0,0.25,0.0,2.25,0.75,0.0,1.0,0.0,0.5,0.0,0.5,1.5,0.25,0.0,0.0,0.25,0.25,0.0,3.0,0.5,2.5,0.75,1.0,0.25,1.25,0.5,1.75,0.25,0.0,0.0,3.25,1.25,0.0,0.0,1.5,0.5,0.5,0.0,0.5,0.25,1.25,0.5,0.0,0.5,2.25,0.75,0.25,0.0,1.0,0.75,0.25,1.75,0.25,0.25,0.5,0.25,0.75,0.25,0.25,0.25,0.0,2.75,0.25,0.0,0.75,0.25,0.0,0.25,2.0,1.0,1.75,0.0,0.25,0.5,1.25,0.5,0.25,0.75,0.5,0.0,0.0,0.75,1.5,0.75,1.5,0.25,0.25,1.25,0.25,0.75,0.75,1.0,1.0,1.75,0.5,1.25,0.25,0.5,2.0,0.25,2.5,1.0,1.75,0.0,0.0,1.5,1.0,0.0,1.25,0.0,0.0,1.0,0.5,0.0,2.0,0.0,0.25,0.0,1.5,0.25,3.0,0.75,0.25,1.25,0.0,0.25,0.0,0.5,0.25,0.25,0.5,0.0,0.75,0.25,0.25,0.25,0.75,0.5,1.5,0.5,0.5,0.5,0.25,1.25,2.25,0.75,1.75,0.25,0.25,0.25,0.75,0.25,0.25,0.25,0.0,2.0,1.0,0.5,0.75,0.0,0.0,0.5,0.0,0.25,1.25,0.25,0.25,11.0,1.5,0.5,0.25,0.0,1.75,1.0,1.5,0.25,0.0,0.5,0.25,0.5,0.0,0.0,0.25,0.25,0.25,0.75,0.75,0.0,0.0,0.5,0.0,0.0,0.75,0.25,0.25,0.5,0.25,0.25,0.25,0.25,0.75,0.5,0.25,2.0,1.25,0.25],\"parent\":[\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\",\"sociology\"]},\"selected\":{\"id\":\"3592\"},\"selection_policy\":{\"id\":\"3591\"}},\"id\":\"1550\",\"type\":\"ColumnDataSource\"},{\"attributes\":{\"active_multi\":null,\"active_scroll\":{\"id\":\"1537\"},\"tools\":[{\"id\":\"1536\"},{\"id\":\"1537\"},{\"id\":\"1538\"},{\"id\":\"1539\"},{\"id\":\"1540\"}]},\"id\":\"1541\",\"type\":\"Toolbar\"},{\"attributes\":{\"axis\":{\"id\":\"1532\"},\"dimension\":1,\"grid_line_color\":null,\"ticker\":null},\"id\":\"1535\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"3573\",\"type\":\"Title\"},{\"attributes\":{\"data_source\":{\"id\":\"1554\"},\"glyph\":{\"id\":\"1579\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1556\"}},\"id\":\"1555\",\"type\":\"GlyphRenderer\"},{\"attributes\":{\"source\":{\"id\":\"1550\"}},\"id\":\"1552\",\"type\":\"CDSView\"},{\"attributes\":{},\"id\":\"3591\",\"type\":\"UnionRenderers\"},{\"attributes\":{},\"id\":\"3593\",\"type\":\"UnionRenderers\"},{\"attributes\":{\"data_source\":{\"id\":\"1550\"},\"glyph\":{\"id\":\"1574\"},\"hover_glyph\":null,\"muted_glyph\":null,\"view\":{\"id\":\"1552\"}},\"id\":\"1551\",\"type\":\"GlyphRenderer\"},{\"attributes\":{},\"id\":\"3581\",\"type\":\"NodesOnly\"},{\"attributes\":{},\"id\":\"1526\",\"type\":\"LinearScale\"},{\"attributes\":{},\"id\":\"3575\",\"type\":\"AllLabels\"},{\"attributes\":{},\"id\":\"3578\",\"type\":\"AllLabels\"},{\"attributes\":{},\"id\":\"1533\",\"type\":\"BasicTicker\"},{\"attributes\":{},\"id\":\"1539\",\"type\":\"ResetTool\"},{\"attributes\":{},\"id\":\"3577\",\"type\":\"BasicTickFormatter\"},{\"attributes\":{},\"id\":\"1536\",\"type\":\"PanTool\"},{\"attributes\":{\"graph_layout\":{\"action theory (sociology)\":[25.872489856436143,21.029902929311113],\"adaptive capacity\":[22.247273675495393,-135.42597213707026],\"agency (philosophy)\":[-10.123670557308673,8.898863464502082],\"agency (sociology)\":[34.09054178679811,8.115417230703562],\"agonism\":[-602.0529829730904,-158.58061508573172],\"air rights\":[-423.84127519186677,363.19421384807595],\"akademie f\\u00fcr soziologie\":[83.64014975255392,98.34858857422438],\"alphons silbermann\":[-490.46568628528354,-307.83886653633874],\"alva myrdal\":[-787.4933419034172,243.831221711727],\"analytic frame\":[-16.692467223544718,-66.6269490879971],\"analytic induction\":[65.38877510321423,120.80081300643351],\"analytical sociology\":[-739.4833470673686,-258.7840232425808],\"angst und vorurteil\":[-27.865386845395577,0.1406107506586444],\"anti-gender campaigns in europe\":[-316.265649711629,-55.509724788258204],\"anti-gender movement\":[-300.4091197600372,-52.957730000742195],\"anti-modernization\":[96.91303079232566,-104.20633208557295],\"antipositivism\":[-5.535058947836014,53.64692209700851],\"archery\":[-71.0129488947054,-820.2148726158493],\"argument from authority\":[954.0004079959679,207.25480904790095],\"argument from marginal cases\":[-349.74538910522233,499.8950735084913],\"asabiyyah\":[89.17098709452726,-27.056504784964932],\"assortative mixing\":[51.87691800279495,-922.3133184582897],\"astrosociology\":[63.62657472434987,-35.63464097363827],\"attention economy\":[187.7837866665545,541.1218722849187],\"authority (sociology)\":[-74.62645049382286,166.84642411788755],\"average joe\":[559.0708949520725,-212.33510000859383],\"backlash (sociology)\":[-463.121419926407,-368.4550630452939],\"base and superstructure\":[21.079726683020066,-36.14463757153335],\"bibliography of sociology\":[11.617776027142945,18.26589305883699],\"bioculture\":[430.03745612018974,-651.6309836793812],\"bioregionalism\":[-510.01894171371157,-270.4085390092963],\"black eagle (montreal)\":[-644.3102702149071,459.25785428210713],\"black tax\":[137.41934340380988,-321.98375191180673],\"blacklisting\":[-53.41752559847841,-154.96985630829494],\"blau space\":[-136.47611400131407,-113.23545968492265],\"blue justice\":[-52.50617605688089,-548.6870407222821],\"b\\u00e9la h. b\\u00e1n\\u00e1thy\":[-35.66052465035651,-129.90038334470378],\"capital (marxism)\":[60.21362868945326,30.091033781370136],\"carmen a. mir\\u00f3\":[-567.6867761794228,137.2725212455982],\"center on conscience & war\":[-384.87673160492824,429.59905530117084],\"chicago school (sociology)\":[-62.50329421286832,-0.78953664963787],\"christian fuchs (sociologist)\":[124.40600072782965,57.79003208681383],\"chua beng huat\":[196.70520042908072,-39.664607697713414],\"civic virtue\":[-316.08904946337145,147.57623176825413],\"civil discourse\":[-328.7709692200041,166.72886240413288],\"civilian-based defense\":[-424.1123069757378,-429.4919732834195],\"civility\":[-287.0006143121612,111.25199454754231],\"clustering (demographics)\":[75.8766187727872,669.395943099474],\"collective effervescence\":[-85.49109259119815,-51.07456713153906],\"collective memory\":[-162.9563091268388,-736.9600873476479],\"collective mental state\":[93.62310789613672,-49.77975640352394],\"communal reinforcement\":[-46.93700159348,-141.883434120528],\"communist correspondence committee\":[5.159564926823383,617.33850554319],\"comparative historical research\":[99.59391387666057,-3.5591381064987786],\"complex adaptive system\":[17.963962366658016,-110.86516699579873],\"computational sociology\":[35.160063291441396,-63.79264968747274],\"concentrated disadvantage\":[80.50686808132757,-27.343702194011808],\"concession (contract)\":[-8.742543071390454,736.3921450784187],\"conflict resolution research\":[-692.4351023461679,-380.3087194732186],\"consumption (sociology)\":[-326.81915011675125,20.056229965069008],\"contemporary jewry\":[120.47344345953216,-101.63354768161125],\"contest mobility\":[-24.896589440741778,-12.806649058774038],\"control (management)\":[48.959685213090815,-111.02936821087515],\"control theory (sociology)\":[81.09659670947525,-33.444654110492706],\"cooper do-nuts riot\":[-325.8761783599782,-49.15289339099988],\"correspondence principle (sociology)\":[-544.9390827239386,-224.5097893239482],\"critique of modernity\":[-183.02654867178023,37.93514312591543],\"culturgen\":[432.5709388161766,-648.5284055777419],\"daphne dorman\":[405.70373911972376,-389.1141384340543],\"das argument\":[510.38515221105274,244.19348246464133],\"davis\\u2013moore hypothesis\":[-215.05315484693458,-139.85184994249278],\"degrowth\":[-305.9012803170434,11.957837083282698],\"delegated authority\":[588.8801421624186,-67.15363386552163],\"delmos jones\":[-179.23039806151226,-24.282929093081723],\"demonstration effect\":[-325.8055451977057,-484.2620524628279],\"development-supported agriculture\":[-427.5958315705465,399.6520833795184],\"digital ecosystem\":[0.6939621656925098,-88.1960622997082],\"discrimination against autistic people\":[-147.7927985634181,-43.1862058835666],\"doing gender\":[-320.2234706149777,-27.09137369714638],\"doncaster pride\":[607.6958998857045,-115.25741154307205],\"double hermeneutic\":[-2.7996328388576526,80.0544443117385],\"duality of structure\":[-42.62770230319481,99.33485573047157],\"dyad (sociology)\":[28.261668598121673,43.7183775698686],\"dynamic density\":[-382.1549203523911,478.07573718415483],\"ecofeminism\":[-251.21037438083962,-32.126344555349334],\"ecolabel\":[-142.31413585766433,-142.18851238220543],\"ecological imperialism\":[235.28049527062248,748.0667421675136],\"ecomodernism\":[-237.00166509483583,11.626498335868177],\"elihu katz\":[158.0045425879672,-63.38081156593939],\"emotive (sociology)\":[-54.05522953150856,5.452122607538407],\"encyclopedia of women and islamic cultures\":[197.2887046043115,-554.5231928684311],\"energy research & social science\":[658.0953067195459,-457.8018206820675],\"entitlement\":[-872.8573499409023,34.2602577152471],\"environmental racism in the united states\":[-573.2343649964714,-130.3995593530029],\"ernst borinski\":[202.8102202242493,-45.8453786974313],\"eugen relgis\":[-427.8412425371227,-393.7654510112449],\"european sociological association\":[99.87720831281946,41.69133303745774],\"eviatar zerubavel\":[197.66109532003725,-52.45735408146542],\"family disruption\":[112.70123600558382,26.78178184938305],\"feminist theory\":[-223.4995674987597,-45.60567479035091],\"ferdinand t\\u00f6nnies society\":[-35.191062911534175,-33.79784919469232],\"field theory (sociology)\":[79.26510097312453,-38.619192542843926],\"figurational sociology\":[59.7505000156042,15.355714902447618],\"flourish of approval\":[-8.888432257451718,-144.31705881640934],\"food bank\":[375.1921710112376,-634.8248805637276],\"fragmentation (sociology)\":[-179.1779185792627,-13.220337253257295],\"franz oppenheimer\":[201.76787602211982,-78.80466538975939],\"freedom\":[-109.8025751646044,-67.69675268449203],\"friendly fascism (book)\":[-80.282703336279,33.8588460270946],\"games for change\":[361.94897544092555,-406.389675007351],\"garden of allah (cabaret)\":[-364.95689028623696,-51.206598809900974],\"gender and development\":[-265.68257133459684,-30.113893532248234],\"gender essentialism\":[-293.86933624743443,-58.45607745143359],\"generative actor\":[-29.263319869802597,106.93020336311199],\"generosity\":[168.29004568186673,-836.1634348708391],\"german sociological association\":[138.6864221417152,-24.153992074565657],\"global social policy\":[-376.7604344031757,-409.091739168036],\"globalization and women in china\":[225.33467699995714,751.0988391199477],\"gochisosama\":[55.439545983619574,596.8575087207884],\"grave candle\":[-570.7976707626904,-170.87816823614222],\"greatness\":[-738.4361185180893,388.6085758558338],\"greenwashing\":[-239.09513197235654,-90.23253088631073],\"group action (sociology)\":[-79.7953770585128,5.838223906283156],\"group threat theory\":[113.7434481509391,-35.40606776184975],\"groupism\":[265.28214080744795,-40.356273054826865],\"heterosociality\":[-242.2294928199323,2.701501495797822],\"historical sociology\":[82.21653831113731,15.009150955651103],\"hobbesian trap\":[559.4692898072906,105.56648546588535],\"humanistic coefficient\":[59.59345455584046,122.17940360980943],\"humanistic sociology\":[53.3781708601865,97.67508513411417],\"hypodermic needle model\":[179.3932721015211,-72.94729192494009],\"ideal type\":[-31.379124395375246,92.13128021794483],\"identity (social science)\":[91.33361592138961,-63.320126243941445],\"ideology\":[-66.09414310062378,-28.23520340117086],\"imagery of nude celebrities\":[264.32328395325186,531.2887148235277],\"immigrant-host model\":[-175.59161075430237,-99.05694428024994],\"impeachment\":[777.5356057433942,-271.7457783338885],\"index of sociology articles\":[-10.016951863070531,-23.46439158678436],\"index of sociopolitical thinkers\":[546.4806880886795,194.58522069649823],\"index of urban sociology articles\":[117.3432397242925,1.5476076519974316],\"indian economic and social history review\":[640.9304141050022,-10.194793388021724],\"indian sociological society\":[108.62928481230449,31.402426362070667],\"informal social control\":[-370.7413428021244,-682.4550331964012],\"injustice\":[-244.18064572184812,61.38812114166397],\"institutional trust (social sciences)\":[601.2640626938634,597.3702222542687],\"instrumental and intrinsic value\":[-77.7240560228264,59.43290062942601],\"instrumental and value rationality\":[-80.84628165985137,54.52344789580216],\"instrumental and value-rational action\":[-65.42910245308661,44.88194154945438],\"instrumentalism\":[-48.92942235981547,46.194464700236935],\"interactionism\":[40.21891375129222,-2.5089059668285127],\"intergroup anxiety\":[-29.801812980074033,-119.14114669610332],\"international political sociology (ips)\":[-550.5088540215256,247.64257206114522],\"international sociological association\":[70.15215122914618,80.26204093516226],\"ipse dixit\":[956.2195011242005,199.75146788207718],\"iron cage\":[-56.902955556206315,120.3695408310107],\"island mentality\":[949.2047017654844,201.77755118443866],\"john murray cuddihy\":[-180.59098298869185,43.46548221979557],\"journal of lesbian studies\":[-391.66053498917506,672.655967504576],\"journal of sociology\":[127.41936363596878,-98.47074423789493],\"julia's on broadway\":[-385.474990667144,-52.11079890816984],\"knowledge of the holocaust in nazi germany and german-occupied europe\":[104.52963510612729,-148.10255106804078],\"kurt heinrich wolff\":[90.32676985017993,98.84385839044158],\"l'ann\\u00e9e sociologique\":[-45.948587814990404,-81.06697821630966],\"label (sociology)\":[501.6939735493186,-319.01445260239035],\"law of the jungle\":[32.61643049761552,-526.7780525406386],\"leipzig school (sociology)\":[129.02441242330977,-550.1945747872581],\"life chances\":[-35.793101353070554,132.68729172675197],\"life-process model of addiction\":[81.90745576688651,-556.4569349940297],\"list of bordering countries with greatest relative differences in gdp (ppp) per capita\":[-634.7692913889257,-124.14024432639668],\"list of countries by inequality-adjusted income\":[797.8963658698791,-26.10306869754319],\"list of countries by labour force\":[-543.848663345998,202.0820035469085],\"list of countries by share of income of the richest one percent\":[797.5804176181192,-30.09534845625931],\"list of scientific occupations\":[305.04813547312233,466.94567484836887],\"list of sociologists\":[177.355639694202,-43.78340616067131],\"list of sociology journals\":[103.37216452550108,-86.9677453067937],\"lowell l. bennion\":[378.24255928170527,-632.227967350536],\"manifest and latent functions and dysfunctions\":[79.30155774072824,-54.4719569252259],\"mapping controversies\":[-23.313483259843174,63.98344379925458],\"market-dominant minority\":[415.4146300931626,439.07289909339306],\"martine-anstett award\":[-531.6266095787489,287.0323316363422],\"marxist sociology\":[48.70348180287877,6.866425827616797],\"mass action (sociology)\":[-88.11067226694789,31.52403234254614],\"material flow analysis\":[-89.47064034448135,-155.1228202397398],\"matrix management\":[139.23641497369232,601.0206332885069],\"matrix of domination\":[-177.6582293642152,-18.794340378062614],\"medical sociologist\":[42.47153677374077,-28.21259094990306],\"medicalization\":[-49.040943898286855,-38.48116017445782],\"memory space (social science)\":[-158.98985117425354,-737.5057502715822],\"mesosociology\":[102.04885292435263,18.126146991986086],\"microsociology\":[65.68174984171355,-0.6022597420553362],\"middle-range theory (sociology)\":[-741.3026963156548,-255.21576886591708],\"modernity\":[-166.12312045810185,32.05689783223899],\"moor's head (heraldry)\":[-8.548734728527908,-149.6302948447137],\"moral entrepreneur\":[112.43890577646214,-15.729467110669935],\"morphological freedom\":[514.3124994346167,-589.6291439377037],\"mudsill theory\":[68.83820488160038,11.127535847604399],\"natural capital\":[-359.3034057074534,31.412009207341203],\"necropolitics\":[-827.3793096251891,103.11613135623216],\"new social movements\":[-141.7140376294573,-0.7801586980209082],\"new york state sociological association\":[342.8614129655378,470.4280036492442],\"noel ignatiev\":[58.10493562823789,797.1257045708724],\"nonprofit and voluntary sector quarterly\":[671.145156367237,72.7732976201998],\"norm entrepreneur\":[146.5057874666225,-10.179364331927964],\"normalization process theory\":[-11.455902954308375,64.27181938360889],\"norwegian journal of sociology\":[130.7015031427566,104.9569848613867],\"norwegian sociological association\":[112.85897846558512,87.04573922072751],\"norwegian sociology canon\":[-509.13535247948045,317.3079527510946],\"numbers (vancouver)\":[-646.9144804670902,456.2150329742575],\"nw 39th street enclave\":[513.3874417910653,-270.1121906939504],\"obscurantism\":[-832.2167654139031,255.48280435713224],\"obshchestvovedeniye\":[-566.7828180257404,-258.9732425163187],\"occupational closure\":[-256.5668105312187,72.8689848586537],\"online research methods\":[-462.4988203729385,-294.0484840575887],\"openness\":[-851.2496121526752,-110.22567310234733],\"oppression\":[-159.60124960596974,-18.80130874368417],\"organigraph\":[-98.32023855926428,-174.01299026288564],\"organization & environment\":[212.95546171837694,-512.7302290191938],\"organizational adaptation\":[56.0011214462566,-114.99359037071753],\"organizational space\":[-452.6952746954534,410.78059681211744],\"organizational theory\":[80.58620275917163,-81.56679638865484],\"outline of globalization\":[231.10092463299605,752.1567680554891],\"passing (sociology)\":[-152.99269978249728,-554.8743512202439],\"pay it forward\":[899.7506191844911,-238.69351541273852],\"payment for ecosystem services\":[-371.1160198038976,33.782282726486066],\"peer pressure\":[-59.402978277162696,-105.222336471887],\"people power\":[-34.22125580017319,-156.26370455548118],\"performative activism\":[-65.41069382955492,195.68287136547872],\"performative interval\":[-69.10706495302774,199.69151535469172],\"performativity\":[-52.888521019879825,190.4731296076474],\"person of color\":[126.72304115909338,-311.48318880466485],\"philosophy of max stirner\":[-348.99885334431474,-437.70569335195125],\"policy sociology\":[28.925705608057264,50.794662781593665],\"political journalism\":[347.4331017504237,432.3079362027002],\"population and development review\":[120.2025518909691,-108.06342816053836],\"porter hypothesis\":[491.8923455741184,320.45458744479936],\"post-work society\":[509.82561111349384,292.13266990127767],\"preference theory\":[-53.05541616250367,-576.2962938950634],\"private sphere\":[-374.3166222586028,-680.6519703434177],\"procreative beneficence\":[514.7323504462711,-593.6076180318648],\"programme for economic advancement and community empowerment\":[663.9179835195579,-449.21065800734146],\"protest cycle\":[-5.700838623981935,-88.0110861723492],\"public morality\":[470.602059368783,-372.3162246594668],\"p\\u0131nar selek\":[214.98751693682874,-45.20572325900059],\"quantitative research\":[8.76245506239495,-4.122392368013893],\"queer ecology\":[-276.82542387438707,-62.17661967638035],\"quiet revolution\":[68.66414825503578,-234.33270190579933],\"racial literacy\":[-598.3782027684348,-86.80833006844851],\"racial threat\":[143.2553660545524,-41.50537912802956],\"radicalization\":[-87.03797680842783,-31.990128831016577],\"rajputisation\":[228.4853901203563,549.8219768410788],\"randy david\":[203.03050671883736,-40.317277182070534],\"reality distortion field\":[593.8586763607582,-34.96981196819484],\"recuperation (politics)\":[-158.72482968640247,760.6040714798222],\"reductionism\":[-38.74923190102559,4.383763172141337],\"reflexive modernization\":[-192.0997478719484,17.78927947903915],\"reflexivity (social theory)\":[-3.9399929009102985,107.26874072121689],\"relational sociology\":[106.36659048901365,-24.362620791575164],\"religious literacy\":[-124.93703795766326,-81.35596913029232],\"renata salecl\":[583.0951459286392,142.49060498377256],\"ren\\u00e9-k\\u00f6nig-gesellschaft\":[80.30661453146435,104.8360655557439],\"requisite organization\":[237.93323311361755,504.60703275462583],\"research in social stratification and mobility\":[87.43511838513113,105.65836249406955],\"resocialization\":[-40.1433025614647,-57.17018267903858],\"resource justice\":[455.1031906254472,383.2417306355119],\"responsibility\":[91.05333608301719,-126.37848111690035],\"ressentiment\":[320.84375107916986,-724.613424095091],\"revisionist school of islamic studies\":[287.91776841141154,499.1538859900781],\"richard rottenburg\":[335.5421455863111,-443.82520491145743],\"right to development\":[-456.85076267630456,-333.3364242047702],\"rogers brubaker\":[237.34307919902574,-41.62131561861478],\"roman agrarian history and its significance for public and private law\":[-52.59551812911045,146.9989814964604],\"safety-valve institution\":[-65.54410902664583,-85.51362135116416],\"saskia wieringa\":[196.32355916095165,-45.01645288519716],\"scare\":[-393.2126634441437,-447.74621916059004],\"science as a vocation\":[-48.55574094473229,136.69034988526857],\"science capital\":[50.01898303721418,37.24228199945514],\"science in action (book)\":[-50.90827187964878,73.53833110133534],\"secondary deviance\":[10.434005660530097,-18.75767814848634],\"sex and gender distinction\":[-295.5570387112105,-30.098079143103398],\"silence=death project\":[-579.6930712429227,210.7272350689359],\"sissyphobia: gay men and effeminate behavior\":[-309.2687332348225,-62.24818718439489],\"social actions\":[-41.9647600685194,20.566923189343587],\"social balance theory\":[-17.049848352227382,-46.556811040889166],\"social complexity\":[78.85785407955748,-12.517408494566212],\"social conflict\":[29.90426128157808,-18.94151395000434],\"social construction of the body\":[-488.8653468287376,-345.5170260994797],\"social death\":[-409.4923552909334,-378.62435375984177],\"social experiment\":[51.71851294211398,-15.984026034080273],\"social geometry\":[-17.73198760952153,-41.84270443596387],\"social integration\":[-128.93265083304266,-55.26537117135146],\"social invisibility\":[48.31652044580688,-917.5385145502057],\"social model of disability\":[-116.31625391612582,-36.40271539436122],\"social multiplier effect\":[-366.29171847723484,457.28418264892906],\"social order\":[-61.34299898209562,23.096659595227344],\"social organism\":[-75.27806171780891,-605.8247976405722],\"social organization\":[-124.15903418759403,-97.57052583612328],\"social phenomenon\":[-28.584491164099102,-99.03182784093644],\"social reality\":[-25.68447790281769,-31.664587535155928],\"social reproduction\":[40.85732236217902,13.390848414564262],\"social revolution\":[21.61817627154688,-157.8886841654934],\"social rights (social contract theory)\":[778.5001196803624,21.687702227395036],\"social risk positions\":[-25.448619341538453,-45.21320118014453],\"social rule system theory\":[-40.27151069166899,-16.264864895636048],\"social service review\":[-293.07884247597116,-684.1124569080092],\"social situation in the french suburbs\":[87.32366910830974,-579.9829676564492],\"social system\":[-2.1537446402660834,-63.377351197675985],\"social threefolding\":[-100.81087035129968,-55.94024910411493],\"social transformation\":[43.9825916396387,78.55965668515404],\"social vulnerability\":[441.90374317485595,-387.7026107665749],\"sociological imagination\":[-25.331767694658364,-77.36513545723709],\"sociological insight\":[126.99472735595326,-104.8144530123248],\"sociological naturalism\":[-18.835626279092725,19.056265065688553],\"sociological positivism\":[-11.926718546515017,33.15830249140827],\"sociologists for women in society\":[161.8185510180802,-546.6605511715952],\"sociologists without borders\":[-479.7644772420175,-430.6599535455134],\"sociology in japan\":[92.44837340493328,-20.74181767285073],\"sociology in poland\":[71.96505194755564,35.370915189496465],\"sociology of manchester\":[-367.10843432116,-477.3390910343702],\"sociology of morality\":[88.58784432095656,-32.31190212062316],\"sociology of punishment\":[64.2721324984524,-9.26211106169096],\"sociology of scientific ignorance\":[4.52803771067759,37.8647386780521],\"sociology of the world religions\":[-56.99256511482602,137.24747923306322],\"sociotechnology\":[-6.27863163675715,71.05840288946106],\"state of affairs (sociology)\":[-474.53752995341495,332.709870314448],\"status attainment\":[23.57320049581942,104.34165868011381],\"status\\u2013income disequilibrium\":[542.7963783350502,252.76575194790996],\"strategic choice theory\":[91.07460828356692,-103.97300607606901],\"structural discrimination\":[-144.39512633278838,-37.16130198024369],\"structural inequality\":[-203.34431280097004,-127.26997484065184],\"structural violence\":[-19.963505234376296,-5.05029733997804],\"structuration theory\":[-19.717566615620502,82.2994403202342],\"structure and agency\":[14.080001750425673,52.29141599137529],\"substitutes for leadership theory\":[396.694851859672,397.1596548311262],\"summerhill (book)\":[-296.8639693583004,-682.8099382054836],\"sustainability and environmental management\":[-371.28617459878376,39.77004516751292],\"sustainability standards and certification\":[-154.33487636863575,-157.5452083048308],\"sustainable business\":[-252.6128817635527,-100.42201961004366],\"sustainable development goal 11\":[-624.4115570092735,23.67958982113489],\"sustainable development goal 12\":[334.32836878880033,-475.6027685709211],\"sustainable development goal 14\":[117.1459304865723,-597.5939749783677],\"sustainable development goal 17\":[474.9338288827846,344.775831782593],\"sustainable energy\":[663.2582525824191,-455.00083219386175],\"suzanne kessler\":[-315.66296196365835,-25.191276961399264],\"symbol\":[-9.25229991143898,-123.68116774311675],\"symbolic power\":[-54.13604169238867,13.216150032446068],\"symbolic religiosity\":[92.60752012706887,-38.448273256102105],\"taste (sociology)\":[644.2565921988452,-536.8301120640858],\"the american journal of economics and sociology\":[166.71072127466266,-93.52891856841262],\"the culture of narcissism\":[-867.3537926951439,34.01770394795804],\"the lexus and the olive tree\":[380.1076255252426,437.3574015032847],\"the morals of chess\":[901.0694364540955,-232.83161597281008],\"the protestant ethic and the spirit of capitalism\":[-55.78225177421892,106.68690431216203],\"the revolution of everyday life\":[-161.02508348630582,763.8700404429156],\"the state (book)\":[222.68999649168228,-83.99728408569243],\"theory of change\":[437.10946546118856,359.919702739774],\"time & society\":[-521.1771334708751,246.78582746697734],\"total institution\":[-50.39007914081152,-67.60534837481394],\"tripartite classification of authority\":[-66.84220323229576,138.55310282323182],\"tschandala\":[324.76774990772844,-723.8202795765158],\"urban metabolism\":[-57.70025341209906,-130.88744687450978],\"value judgment\":[605.0807184803762,601.2902294658055],\"value-added theory\":[36.26019661744647,-45.508406088196566],\"verbal self-defense\":[-695.5221002410569,-377.75894971259004],\"vertical mobility\":[39.02518091551394,44.17981313949162],\"viola klein\":[-782.3340070976809,241.88868034820848],\"visible minority\":[105.40556821233791,-286.7820894776789],\"vulnerable adult\":[60.66122717816931,-540.0193621740164],\"weighted network\":[46.038912051943726,-922.6803248677102],\"werturteilsstreit\":[-45.017616343363294,86.66990975890751],\"west pride\":[-99.84896371453884,1025.1161923671248],\"women's week provincetown\":[-387.65871696122707,672.7593617810603],\"word gap\":[413.4517715240121,-422.5025032132211],\"work, employment & society\":[376.337608209978,-434.9680200326989],\"xeira\":[-618.9014587895014,112.38735132850404]}},\"id\":\"1561\",\"type\":\"StaticLayoutProvider\"},{\"attributes\":{\"line_alpha\":{\"value\":0.8},\"line_width\":{\"value\":0.1}},\"id\":\"1579\",\"type\":\"MultiLine\"},{\"attributes\":{\"text\":\"Network for discipline: sociology\",\"text_font_size\":\"12pt\"},\"id\":\"1547\",\"type\":\"Title\"},{\"attributes\":{},\"id\":\"3590\",\"type\":\"NodesOnly\"},{\"attributes\":{},\"id\":\"3594\",\"type\":\"Selection\"},{\"attributes\":{},\"id\":\"1524\",\"type\":\"LinearScale\"},{\"attributes\":{\"end\":400,\"start\":-400},\"id\":\"1520\",\"type\":\"Range1d\"},{\"attributes\":{\"formatter\":{\"id\":\"3577\"},\"major_label_policy\":{\"id\":\"3575\"},\"ticker\":{\"id\":\"1533\"},\"visible\":false},\"id\":\"1532\",\"type\":\"LinearAxis\"},{\"attributes\":{\"axis\":{\"id\":\"1528\"},\"grid_line_color\":null,\"ticker\":null},\"id\":\"1531\",\"type\":\"Grid\"},{\"attributes\":{},\"id\":\"1529\",\"type\":\"BasicTicker\"},{\"attributes\":{\"data\":{\"end\":[\"european sociological association\",\"international sociological association\",\"international sociological association\",\"social service review\",\"gender essentialism\",\"anti-gender movement\",\"sex and gender distinction\",\"garden of allah (cabaret)\",\"base and superstructure\",\"ideology\",\"marxist sociology\",\"social threefolding\",\"social reality\",\"freedom\",\"social order\",\"contest mobility\",\"social actions\",\"index of sociology articles\",\"medicalization\",\"sociological positivism\",\"reductionism\",\"collective effervescence\",\"new social movements\",\"social integration\",\"peer pressure\",\"radicalization\",\"bioculture\",\"social complexity\",\"astrosociology\",\"social experiment\",\"life chances\",\"vertical mobility\",\"social transformation\",\"relational sociology\",\"ecofeminism\",\"anti-gender movement\",\"gender essentialism\",\"greenwashing\",\"franz oppenheimer\",\"list of sociology journals\",\"greenwashing\",\"material flow analysis\",\"sustainability standards and certification\",\"urban metabolism\",\"list of sociology journals\",\"social complexity\",\"astrosociology\",\"social experiment\",\"index of sociology articles\",\"bibliography of sociology\",\"journal of lesbian studies\",\"list of sociologists\",\"the state (book)\",\"social experiment\",\"vertical mobility\",\"astrosociology\",\"social complexity\",\"freedom\",\"generosity\",\"the protestant ethic and the spirit of capitalism\",\"roman agrarian history and its significance for public and private law\",\"sociology of the world religions\",\"ideal type\",\"iron cage\",\"life chances\",\"tripartite classification of authority\",\"social complexity\",\"astrosociology\",\"social experiment\",\"antipositivism\",\"werturteilsstreit\",\"sociological positivism\",\"instrumentalism\",\"quantitative research\",\"structuration theory\",\"reductionism\",\"double hermeneutic\",\"mapping controversies\",\"index of sociology articles\",\"sociotechnology\",\"sociological naturalism\",\"sociology of scientific ignorance\",\"normalization process theory\",\"feminist theory\",\"anti-gender movement\",\"heterosociality\",\"doing gender\",\"suzanne kessler\",\"social system\",\"social complexity\",\"astrosociology\",\"social experiment\",\"complex adaptive system\",\"index of sociology articles\",\"social system\",\"historical sociology\",\"the protestant ethic and the spirit of capitalism\",\"social order\",\"werturteilsstreit\",\"roman agrarian history and its significance for public and private law\",\"sociology of the world religions\",\"ideal type\",\"life chances\",\"tripartite classification of authority\",\"alva myrdal\",\"black tax\",\"visible minority\",\"critique of modernity\",\"modernity\",\"john murray cuddihy\",\"the protestant ethic and the spirit of capitalism\",\"index of sociology articles\",\"heterosociality\",\"ecomodernism\",\"reflexive modernization\",\"elihu katz\",\"identity (social science)\",\"control (management)\",\"knowledge of the holocaust in nazi germany and german-occupied europe\",\"responsibility\",\"ecofeminism\",\"degrowth\",\"reflexive modernization\",\"oppression\",\"international sociological association\",\"marxist sociology\",\"social complexity\",\"sociology of punishment\",\"comparative historical research\",\"social experiment\",\"index of sociology articles\",\"indian sociological society\",\"astrosociology\",\"medical sociologist\",\"social integration\",\"feminist theory\",\"ecofeminism\",\"structural violence\",\"matrix of domination\",\"social model of disability\",\"discrimination against autistic people\",\"fragmentation (sociology)\",\"bibliography of sociology\",\"injustice\",\"structural discrimination\",\"oppression\",\"social complexity\",\"astrosociology\",\"social experiment\",\"antipositivism\",\"instrumentalism\",\"reductionism\",\"double hermeneutic\",\"mapping controversies\",\"sociotechnology\",\"normalization process theory\",\"communal reinforcement\",\"index of sociology articles\",\"intergroup anxiety\",\"analytic frame\",\"sociological imagination\",\"list of sociologists\",\"social experiment\",\"humanistic sociology\",\"werturteilsstreit\",\"instrumentalism\",\"quantitative research\",\"structuration theory\",\"dyad (sociology)\",\"double hermeneutic\",\"mapping controversies\",\"index of sociology articles\",\"sociotechnology\",\"sociological naturalism\",\"ideal type\",\"normalization process theory\",\"value judgment\",\"institutional trust (social sciences)\",\"assortative mixing\",\"weighted network\",\"injustice\",\"friendly fascism (book)\",\"index of sociology articles\",\"structural violence\",\"symbolic power\",\"index of sociology articles\",\"civil discourse\",\"civic virtue\",\"civility\",\"instrumentalism\",\"social reality\",\"chicago school (sociology)\",\"agency (philosophy)\",\"reductionism\",\"index of sociology articles\",\"injustice\",\"civility\",\"julia's on broadway\",\"social complexity\",\"astrosociology\",\"social experiment\",\"base and superstructure\",\"capital (marxism)\",\"sociology in poland\",\"ressentiment\",\"ecofeminism\",\"sustainable business\",\"greenwashing\",\"the revolution of everyday life\",\"structure and agency\",\"werturteilsstreit\",\"social reality\",\"instrumental and value-rational action\",\"action theory (sociology)\",\"index of sociology articles\",\"group action (sociology)\",\"social actions\",\"performativity\",\"necropolitics\",\"social integration\",\"medicalization\",\"index of sociology articles\",\"structural discrimination\",\"discrimination against autistic people\",\"analytical sociology\",\"the morals of chess\",\"pay it forward\",\"structural violence\",\"comparative historical research\",\"social system\",\"identity (social science)\",\"social complexity\",\"astrosociology\",\"interactionism\",\"base and superstructure\",\"agency (sociology)\",\"group threat theory\",\"list of sociologists\",\"asabiyyah\",\"organizational theory\",\"manifest and latent functions and dysfunctions\",\"value-added theory\",\"quantitative research\",\"figurational sociology\",\"sociology of punishment\",\"sociology in poland\",\"bibliography of sociology\",\"list of sociology journals\",\"dyad (sociology)\",\"control theory (sociology)\",\"index of sociology articles\",\"action theory (sociology)\",\"sociology in japan\",\"social reality\",\"european sociological association\",\"concentrated disadvantage\",\"structural violence\",\"microsociology\",\"sociology of morality\",\"moral entrepreneur\",\"collective mental state\",\"symbolic religiosity\",\"social reproduction\",\"relational sociology\",\"medical sociologist\",\"organizational theory\",\"complex adaptive system\",\"instrumentalism\",\"structuration theory\",\"life chances\",\"tripartite classification of authority\",\"ideal type\",\"index of sociology articles\",\"structural inequality\",\"microsociology\",\"alva myrdal\",\"the protestant ethic and the spirit of capitalism\",\"roman agrarian history and its significance for public and private law\",\"life chances\",\"ideal type\",\"tripartite classification of authority\",\"outline of globalization\",\"social system\",\"structure and agency\",\"the protestant ethic and the spirit of capitalism\",\"bibliography of sociology\",\"akademie f\\u00fcr soziologie\",\"norwegian sociological association\",\"research in social stratification and mobility\",\"european sociological association\",\"sociology in poland\",\"social complexity\",\"astrosociology\",\"index of sociology articles\",\"outline of globalization\",\"julia's on broadway\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"organigraph\",\"urban metabolism\",\"performativity\",\"social system\",\"manifest and latent functions and dysfunctions\",\"value-added theory\",\"protest cycle\",\"social complexity\",\"index of sociology articles\",\"feminist theory\",\"social rule system theory\",\"astrosociology\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"ideal type\",\"urban metabolism\",\"gender essentialism\",\"anti-gender movement\",\"ecofeminism\",\"feminist theory\",\"group threat theory\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"complex adaptive system\",\"structure and agency\",\"social complexity\",\"astrosociology\",\"action theory (sociology)\",\"agency (philosophy)\",\"sociotechnology\",\"double hermeneutic\",\"science in action (book)\",\"normalization process theory\",\"symbol\",\"social complexity\",\"astrosociology\",\"sociology of punishment\",\"base and superstructure\",\"social reality\",\"ideal type\",\"quantitative research\",\"total institution\",\"medicalization\",\"secondary deviance\",\"social risk positions\",\"social balance theory\",\"social reproduction\",\"vertical mobility\",\"sociological imagination\",\"ferdinand t\\u00f6nnies society\",\"value-added theory\",\"resocialization\",\"lowell l. bennion\",\"complex adaptive system\",\"symbol\",\"quantitative research\",\"private sphere\",\"openness\",\"list of sociologists\",\"bibliography of sociology\",\"mass action (sociology)\",\"life chances\",\"tripartite classification of authority\",\"ideal type\",\"roman agrarian history and its significance for public and private law\",\"comparative historical research\",\"identity (social science)\",\"interactionism\",\"base and superstructure\",\"group threat theory\",\"list of sociologists\",\"asabiyyah\",\"organizational theory\",\"manifest and latent functions and dysfunctions\",\"value-added theory\",\"index of urban sociology articles\",\"quantitative research\",\"figurational sociology\",\"sociology of punishment\",\"sociology in poland\",\"bibliography of sociology\",\"list of sociology journals\",\"dyad (sociology)\",\"control theory (sociology)\",\"action theory (sociology)\",\"sociology in japan\",\"social reality\",\"european sociological association\",\"concentrated disadvantage\",\"structural violence\",\"sociology of morality\",\"moral entrepreneur\",\"collective mental state\",\"astrosociology\",\"symbolic religiosity\",\"complex adaptive system\",\"social reproduction\",\"relational sociology\",\"medical sociologist\",\"astrosociology\",\"medicalization\",\"gender essentialism\",\"anti-gender campaigns in europe\",\"sissyphobia: gay men and effeminate behavior\",\"numbers (vancouver)\",\"communal reinforcement\",\"blacklisting\",\"peer pressure\",\"people power\",\"humanistic sociology\",\"social reproduction\",\"humanistic sociology\",\"structure and agency\",\"astrosociology\",\"collective effervescence\",\"identity (social science)\",\"astrosociology\",\"sociology in poland\",\"astrosociology\",\"policy sociology\",\"conflict resolution research\",\"astrosociology\",\"population and development review\",\"l'ann\\u00e9e sociologique\",\"contemporary jewry\",\"sociological insight\",\"social integration\",\"peer pressure\",\"people power\",\"taste (sociology)\",\"assortative mixing\",\"astrosociology\",\"natural capital\",\"astrosociology\",\"elihu katz\",\"rogers brubaker\",\"chua beng huat\",\"randy david\",\"saskia wieringa\",\"p\\u0131nar selek\",\"greatness\",\"structure and agency\",\"instrumentalism\",\"action theory (sociology)\",\"reflexivity (social theory)\",\"duality of structure\",\"generative actor\",\"ideal type\",\"base and superstructure\",\"quiet revolution\",\"people power\",\"astrosociology\",\"sissyphobia: gay men and effeminate behavior\",\"visible minority\",\"sociotechnology\",\"reflexivity (social theory)\",\"normalization process theory\",\"structure and agency\",\"roman agrarian history and its significance for public and private law\",\"dyad (sociology)\",\"tripartite classification of authority\",\"natural capital\",\"sustainability and environmental management\",\"degrowth\",\"sociotechnology\",\"programme for economic advancement and community empowerment\",\"energy research & social science\",\"freedom\",\"noel ignatiev\",\"list of countries by share of income of the richest one percent\",\"astrosociology\",\"reflexive modernization\",\"immigrant-host model\",\"gender and development\",\"ecofeminism\",\"degrowth\",\"instrumentalism\",\"instrumental and value-rational action\",\"instrumental and intrinsic value\",\"astrosociology\",\"manifest and latent functions and dysfunctions\",\"astrosociology\",\"angst und vorurteil\",\"reflexivity (social theory)\",\"instrumental and value-rational action\",\"social rule system theory\",\"emotive (sociology)\",\"instrumental and intrinsic value\",\"rogers brubaker\",\"european sociological association\",\"norwegian journal of sociology\",\"symbol\",\"tripartite classification of authority\",\"structure and agency\",\"astrosociology\",\"peer pressure\",\"structure and agency\",\"astrosociology\",\"structure and agency\",\"dyad (sociology)\",\"doing gender\",\"memory space (social science)\",\"civil discourse\",\"social reality\",\"p\\u0131nar selek\",\"astrosociology\",\"instrumental and value-rational action\",\"complex adaptive system\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"degrowth\",\"astrosociology\",\"the culture of narcissism\",\"entitlement\",\"collective effervescence\",\"instrumental and value-rational action\",\"island mentality\",\"argument from authority\",\"ipse dixit\",\"astrosociology\",\"science capital\",\"social transformation\",\"total institution\",\"safety-valve institution\",\"resocialization\",\"social integration\",\"social organization\",\"peer pressure\",\"social reality\",\"l'ann\\u00e9e sociologique\",\"peer pressure\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"identity (social science)\",\"structure and agency\",\"astrosociology\",\"norm entrepreneur\",\"astrosociology\",\"visible minority\",\"astrosociology\",\"strategic choice theory\",\"anti-modernization\",\"organizational theory\",\"interactionism\",\"dyad (sociology)\",\"social integration\",\"astrosociology\",\"secondary deviance\",\"archery\",\"astrosociology\",\"west pride\",\"argument from authority\",\"social integration\",\"freedom\",\"life chances\",\"tripartite classification of authority\",\"roman agrarian history and its significance for public and private law\",\"astrosociology\",\"morphological freedom\",\"astrosociology\",\"social organization\",\"l'ann\\u00e9e sociologique\",\"social organization\",\"impeachment\",\"the morals of chess\",\"symbol\",\"asabiyyah\",\"sociology in japan\",\"concentrated disadvantage\",\"symbolic religiosity\",\"argument from authority\",\"obscurantism\",\"l'ann\\u00e9e sociologique\"],\"start\":[\"christian fuchs (sociologist)\",\"ren\\u00e9-k\\u00f6nig-gesellschaft\",\"kurt heinrich wolff\",\"summerhill (book)\",\"cooper do-nuts riot\",\"cooper do-nuts riot\",\"cooper do-nuts riot\",\"cooper do-nuts riot\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"ideology\",\"culturgen\",\"field theory (sociology)\",\"field theory (sociology)\",\"field theory (sociology)\",\"status attainment\",\"status attainment\",\"status attainment\",\"german sociological association\",\"queer ecology\",\"queer ecology\",\"queer ecology\",\"queer ecology\",\"the american journal of economics and sociology\",\"the american journal of economics and sociology\",\"ecolabel\",\"ecolabel\",\"ecolabel\",\"ecolabel\",\"journal of sociology\",\"social conflict\",\"social conflict\",\"social conflict\",\"social conflict\",\"social conflict\",\"women's week provincetown\",\"franz oppenheimer\",\"franz oppenheimer\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"mudsill theory\",\"religious literacy\",\"generosity\",\"science as a vocation\",\"science as a vocation\",\"science as a vocation\",\"science as a vocation\",\"science as a vocation\",\"science as a vocation\",\"science as a vocation\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sociological positivism\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"sex and gender distinction\",\"computational sociology\",\"computational sociology\",\"computational sociology\",\"computational sociology\",\"computational sociology\",\"computational sociology\",\"digital ecosystem\",\"family disruption\",\"iron cage\",\"iron cage\",\"iron cage\",\"iron cage\",\"iron cage\",\"iron cage\",\"iron cage\",\"iron cage\",\"viola klein\",\"person of color\",\"person of color\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"modernity\",\"hypodermic needle model\",\"responsibility\",\"responsibility\",\"responsibility\",\"responsibility\",\"ecomodernism\",\"ecomodernism\",\"ecomodernism\",\"delmos jones\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"historical sociology\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"oppression\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"sociology of scientific ignorance\",\"social phenomenon\",\"social phenomenon\",\"social phenomenon\",\"social phenomenon\",\"social phenomenon\",\"ernst borinski\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"antipositivism\",\"value judgment\",\"value judgment\",\"social invisibility\",\"social invisibility\",\"occupational closure\",\"social order\",\"social order\",\"social order\",\"social order\",\"social geometry\",\"civic virtue\",\"civic virtue\",\"civic virtue\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"reductionism\",\"injustice\",\"injustice\",\"garden of allah (cabaret)\",\"marxist sociology\",\"marxist sociology\",\"marxist sociology\",\"marxist sociology\",\"marxist sociology\",\"marxist sociology\",\"tschandala\",\"greenwashing\",\"greenwashing\",\"greenwashing\",\"recuperation (politics)\",\"social actions\",\"social actions\",\"social actions\",\"social actions\",\"social actions\",\"social actions\",\"social actions\",\"social actions\",\"performative activism\",\"necropolitics\",\"social model of disability\",\"social model of disability\",\"social model of disability\",\"social model of disability\",\"social model of disability\",\"middle-range theory (sociology)\",\"pay it forward\",\"pay it forward\",\"symbolic power\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"social experiment\",\"organizational adaptation\",\"organizational adaptation\",\"werturteilsstreit\",\"werturteilsstreit\",\"werturteilsstreit\",\"werturteilsstreit\",\"werturteilsstreit\",\"sociological naturalism\",\"davis\\u2013moore hypothesis\",\"mesosociology\",\"alva myrdal\",\"sociology of the world religions\",\"sociology of the world religions\",\"sociology of the world religions\",\"sociology of the world religions\",\"sociology of the world religions\",\"globalization and women in china\",\"control (management)\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"international sociological association\",\"microsociology\",\"microsociology\",\"microsociology\",\"ecological imperialism\",\"julia's on broadway\",\"material flow analysis\",\"material flow analysis\",\"material flow analysis\",\"performative interval\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"social system\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"feminist theory\",\"racial threat\",\"urban metabolism\",\"urban metabolism\",\"agency (sociology)\",\"agency (sociology)\",\"agency (sociology)\",\"agency (sociology)\",\"agency (sociology)\",\"mapping controversies\",\"mapping controversies\",\"mapping controversies\",\"mapping controversies\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"index of sociology articles\",\"food bank\",\"adaptive capacity\",\"moor's head (heraldry)\",\"analytic frame\",\"informal social control\",\"openness\",\"eviatar zerubavel\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"the protestant ethic and the spirit of capitalism\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"social complexity\",\"medical sociologist\",\"medical sociologist\",\"anti-gender movement\",\"anti-gender movement\",\"anti-gender movement\",\"black eagle (montreal)\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"blacklisting\",\"analytic induction\",\"contest mobility\",\"humanistic coefficient\",\"figurational sociology\",\"figurational sociology\",\"mass action (sociology)\",\"collective mental state\",\"collective mental state\",\"humanistic sociology\",\"bibliography of sociology\",\"bibliography of sociology\",\"verbal self-defense\",\"list of sociology journals\",\"list of sociology journals\",\"list of sociology journals\",\"list of sociology journals\",\"list of sociology journals\",\"discrimination against autistic people\",\"communal reinforcement\",\"communal reinforcement\",\"taste (sociology)\",\"weighted network\",\"sociology in poland\",\"payment for ecosystem services\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"list of sociologists\",\"greatness\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"structuration theory\",\"social revolution\",\"social revolution\",\"social revolution\",\"comparative historical research\",\"gender essentialism\",\"quiet revolution\",\"double hermeneutic\",\"double hermeneutic\",\"double hermeneutic\",\"ideal type\",\"ideal type\",\"ideal type\",\"ideal type\",\"natural capital\",\"natural capital\",\"natural capital\",\"normalization process theory\",\"sustainable energy\",\"sustainable energy\",\"social threefolding\",\"noel ignatiev\",\"list of countries by inequality-adjusted income\",\"sociology of punishment\",\"new social movements\",\"structural inequality\",\"ecofeminism\",\"ecofeminism\",\"ecofeminism\",\"instrumental and value rationality\",\"instrumental and value rationality\",\"instrumental and value rationality\",\"group threat theory\",\"elihu katz\",\"structural violence\",\"structural violence\",\"performativity\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"instrumentalism\",\"groupism\",\"norwegian sociological association\",\"norwegian sociological association\",\"flourish of approval\",\"authority (sociology)\",\"base and superstructure\",\"base and superstructure\",\"people power\",\"action theory (sociology)\",\"action theory (sociology)\",\"reflexivity (social theory)\",\"reflexivity (social theory)\",\"suzanne kessler\",\"collective memory\",\"civil discourse\",\"emotive (sociology)\",\"p\\u0131nar selek\",\"european sociological association\",\"instrumental and intrinsic value\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"b\\u00e9la h. b\\u00e1n\\u00e1thy\",\"consumption (sociology)\",\"manifest and latent functions and dysfunctions\",\"entitlement\",\"entitlement\",\"group action (sociology)\",\"group action (sociology)\",\"ipse dixit\",\"ipse dixit\",\"ipse dixit\",\"social reproduction\",\"social reproduction\",\"social reproduction\",\"total institution\",\"total institution\",\"total institution\",\"collective effervescence\",\"collective effervescence\",\"collective effervescence\",\"collective effervescence\",\"collective effervescence\",\"social reality\",\"social reality\",\"relational sociology\",\"identity (social science)\",\"identity (social science)\",\"instrumental and value-rational action\",\"moral entrepreneur\",\"moral entrepreneur\",\"value-added theory\",\"visible minority\",\"organizational theory\",\"organizational theory\",\"organizational theory\",\"organizational theory\",\"structure and agency\",\"structure and agency\",\"structural discrimination\",\"interactionism\",\"interactionism\",\"archery\",\"control theory (sociology)\",\"west pride\",\"island mentality\",\"immigrant-host model\",\"freedom\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"roman agrarian history and its significance for public and private law\",\"dyad (sociology)\",\"procreative beneficence\",\"sociology of morality\",\"blau space\",\"social integration\",\"social organization\",\"impeachment\",\"the morals of chess\",\"symbol\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"astrosociology\",\"argument from authority\",\"obscurantism\",\"l'ann\\u00e9e sociologique\"]},\"selected\":{\"id\":\"3594\"},\"selection_policy\":{\"id\":\"3593\"}},\"id\":\"1554\",\"type\":\"ColumnDataSource\"},{\"attributes\":{\"edge_renderer\":{\"id\":\"1555\"},\"inspection_policy\":{\"id\":\"3590\"},\"layout_provider\":{\"id\":\"1561\"},\"node_renderer\":{\"id\":\"1551\"},\"selection_policy\":{\"id\":\"3581\"}},\"id\":\"1548\",\"type\":\"GraphRenderer\"},{\"attributes\":{\"formatter\":{\"id\":\"3580\"},\"major_label_policy\":{\"id\":\"3578\"},\"ticker\":{\"id\":\"1529\"},\"visible\":false},\"id\":\"1528\",\"type\":\"LinearAxis\"}],\"root_ids\":[\"1521\"]},\"title\":\"Bokeh Application\",\"version\":\"2.3.2\"}};\n",
       "  var render_items = [{\"docid\":\"4176f86f-d8de-4ae3-a326-5e3b28a22eec\",\"root_ids\":[\"1521\"],\"roots\":{\"1521\":\"6fdd0e64-ca17-4969-b122-42121c1f08d7\"}}];\n",
       "  root.Bokeh.embed.embed_items_notebook(docs_json, render_items);\n",
       "\n",
       "  }\n",
       "  if (root.Bokeh !== undefined) {\n",
       "    embed_document(root);\n",
       "  } else {\n",
       "    var attempts = 0;\n",
       "    var timer = setInterval(function(root) {\n",
       "      if (root.Bokeh !== undefined) {\n",
       "        clearInterval(timer);\n",
       "        embed_document(root);\n",
       "      } else {\n",
       "        attempts++;\n",
       "        if (attempts > 100) {\n",
       "          clearInterval(timer);\n",
       "          console.log(\"Bokeh: ERROR: Unable to run BokehJS code because BokehJS library is missing\");\n",
       "        }\n",
       "      }\n",
       "    }, 10, root)\n",
       "  }\n",
       "})(window);"
      ],
      "application/vnd.bokehjs_exec.v0+json": ""
     },
     "metadata": {
      "application/vnd.bokehjs_exec.v0+json": {
       "id": "1521"
      }
     },
     "output_type": "display_data"
    }
   ],
   "source": [
    "# Plot the graphs\n",
    "show(row(graphs[\"economics\"], graphs[\"anthropology\"]))\n",
    "show(row(graphs[\"political_science\"], graphs[\"psychology\"]))\n",
    "show(graphs[\"sociology\"])"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "472b142e",
   "metadata": {},
   "source": [
    "Once again we see that the metapages are biggest for all of the disciplines. Some of the new information that these plots provide us with is the level of intra-disciplinary clustering. Whereas sociology and anthropology, probably due to their size and our [sampling strategy](explainer_data_collection), seem to relatively be clustered, political science, economics and psychology seem to a higher degree to be split up into minor clusters. To estimate this in a more formal and systematic way we conduct [community detection](explainer_community_detection) and [topic-modelling](explainer_topic_model) in the forthcoming analysis."
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.8"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
